import { Component, AfterViewInit,OnInit, createPlatformFactory,ElementRef,ViewChild } from '@angular/core';
import { CommonService } from '../common-service.service';
import {ActivatedRoute} from "@angular/router";

interface viewData{
  other_inspector_comments_array : Array<string>,
  operator_comments_array : Array<string>,
  port : string
}
@Component({
  selector: 'ObservationOfViqRef',
  templateUrl: './ObservationOfViqRef.component.html',
  styleUrls: ['./ObservationOfViqRef.component.scss']
})
export class ObservationOfViqRefComponent implements AfterViewInit,OnInit {

  //for pagination
  itemsPerPage: number = this.commonService.DefaultItemsPerPage;
  totalItems: number;
  currentPage: number = 1;
  isDisabled = true;
  openRightSidebar : boolean = false;
  public filterObj = {};
  public formData = {};
  public formDataOperatorDate = {};
  public vesselGroup_dropdown = [];
  public vesselFleet_dropdown = [];
  public vesselOwner_dropdown = [];
  public viewData:viewData ={other_inspector_comments_array : [],operator_comments_array :[],port : ''}; 
  public port_dropdown = [];
  public perCompanyObservation;
  public perCompanyRisk;
  public oilMajor_dropdown = [];
  public inspector_dropdown = [];
  public ObservationOfViqRefData = [];
  public configData = [];
  public sortFilter:any = {};
  public template_type;
  public template_type_id;
  public question_no;
  public questions_curr = [];
  public questions_prev = [];
  public linkData = {};  
  public headerInformation;
  public actionButtons;
  public pdfLogo;
  public withoutPaginationData = [];
  public showLoader = false;
  showSideBarLoader : boolean = false;
  

  constructor(
    private commonService: CommonService,private route: ActivatedRoute){   
      this.declareGridVariable();
  }

  ngOnInit(){
    //console.log(location);
    this.pdfLogo = location.origin+location.pathname+'assets/images';    
  
      this.route.params.subscribe(params => {
        this.template_type = params['template_type'];
        this.template_type_id = params['template_type_id'];
        this.question_no = params['question_no']; 
    });
    this.getData();
    //console.log(this.formData);    
  
  }

  ngAfterViewInit(){	
  }

  changePage(page){
    this.currentPage = page;
    this.sendFilterObjectForUpdateData();
    window.scroll(0,0);
    this.getData();
    // this.updateData.emit(page)
  }

  sendFilterObjectForUpdateData(){
    let makeFilterObj = {}
     Object.keys(this.filterObj).forEach((key) => {
       makeFilterObj[key] = this.filterObj[key].replace(/'/g, "\\\'").replace(/"/g, '\\\"')
     });

     this.getData();
   }

 


  getData(){ 
    this.showLoader = true;

    let filterParams:any = {}
   //search filter 
   filterParams = JSON.parse(JSON.stringify(this.filterObj));
   //search filter -end

   // pagination
   filterParams.currentPage = this.currentPage - 1;
   filterParams.itemsPerPage = this.itemsPerPage;

   if(this.template_type && this.template_type != 'undefined'){
    filterParams.template_type = this.template_type;
    filterParams.template_type_id = this.template_type_id;
   }
   if(this.question_no){
    filterParams.question_no = this.question_no;
   }
   
   if(Object.keys(this.sortFilter).length > 0){ 
    filterParams.sortBy = Object.keys(this.sortFilter)[0]; 
    filterParams.sortStatus = this.sortFilter[Object.keys(this.sortFilter)[0]]
  }
   

    this.commonService.sendRequestToNode({method :'get',path:'observation-by-viqref',queryParam:filterParams}).subscribe(result => {
      if(result.status){
        this.showLoader = false;
        // alert(this.forData);
        //this is for global observation
        if(result.data[0].length > 0){
          this.ObservationOfViqRefData = result.data[0];
          this.totalItems = result.data[0].length;
        }
        else{
          this.ObservationOfViqRefData = [];  
          this.totalItems = 0;
        }

      }
      else{
        this.ObservationOfViqRefData = [];
        alert(result.message);
      }
    })
  } 
  

  

  filter($event){
    let obj = $event;
    this.currentPage = obj.page;
    this.filterObj = obj.filter;
    this.sortFilter = obj.sort
    this.getData();
  }

  declareGridVariable(){
    this.headerInformation = [
      {
        title : 'Date',// show title table header
        isDate:'yes',
        name:'INSPECTION_DATE',// name of column in data source
        width : '10%',// width of column in table
        // isSortable : true,// sort by column false or true
        // isFilter:{ // filter 
        //   type : 'text',
        //   placeholder : 'Filter By Date'
        // }
      },
      {
        title : 'Vessel',// show title table header
        //nameIcon : true,// show icon of First letter
        highlight:true,
        name:'VESSEL_NAME',// name of column in data source
        width : '15%',// width of column in table
        // isSortable : true,// sort by column false or true
        // isFilter:{ // filter 
        //   type : 'text',
        //   placeholder : 'Filter By Vessel'
        // }
      },
      {
        title : 'VIQ Ref No.',// show title table header
        //nameIcon : true,// show icon of First letter
        name:'QUESTION_NUMBER',// name of column in data source
        width : '5%',// 
      },
      {
        title : 'VIQ Questions',// show title table header
        //nameIcon : true,// show icon of First letter
        name:'QUESTION_DESCRIPTION',
      },
      {title : 'Inspector Observation',name:'INSPECTION_OBSERVATION',width : '20%'},
      {title : 'Inspector Name',name:'INSPECTOR_NAME',width : '10%',
      // isFilter:{ // filter 
      //   type : 'text',
      //   placeholder : 'Filter By Port Of Inspection'
      // }
    },
      {title : 'Oil Major',name:'OIL_MAJOR',width : '10%',
      // isFilter:{ // filter 
      //   type : 'text',
      //   placeholder : 'Filter By Oil Major'
      // }
    },
    {title : 'Action',name:'action',width : '5%'}
    ];
    this.actionButtons = [
      {title:'View',class : "fas fa-eye"},
    ]
  }

  clickOnAction(actionObj){
    if(actionObj.actionName == 'View'){
     this.viewData.port = actionObj.object.PORT_OF_INSPECTION;
     this.getCommentsFromObs(actionObj.object['obs_id']);
      
    }
  }
  getCommentsFromObs(obsId){
    let filterParams = {}
    this.showSideBarLoader = true;
    this.openRightSidebar = true;
    this.commonService.sendRequestToNode({method :'get',path:'get-all-observation/'+obsId,queryParam:filterParams}).subscribe(result => {
      this.showSideBarLoader = false;
      if(result.status){
        result.observationArr.forEach(element => {
          if(element.TYPE == '1'){
            this.viewData.other_inspector_comments_array.push(element.COMMENTS)
          }
          else if(element.TYPE == '2'){
            this.viewData.operator_comments_array.push(element.COMMENTS)
          }
        });   
      }
      else{
        this.resetForm();
      }
    })
  } 
  
  // Export Both Excel and Pdf
  generatePdf(type = "pdf"){
    
    let filterParams:any = {export_type : type}

    if(this.template_type && this.template_type != 'undefined'){
      filterParams.template_type = this.template_type;
      filterParams.template_type_id = this.template_type_id;
    }

    if(this.question_no){
      filterParams.question_no = this.question_no;
    }
    const ret = [];
    Object.keys(filterParams).forEach(key=>{
      ret.push(encodeURIComponent(key) + '=' + encodeURIComponent(filterParams[key]));
    })
    let queryString = ret.join('&');
    
    window.location.href = this.commonService.getNodeApi()+'/observation-by-viqref/export?'+queryString;
      
  }

  resetForm(){
    this.openRightSidebar = false;
    this.viewData = {other_inspector_comments_array : [],operator_comments_array :[],port : ''};
  }

}
