import { Component, AfterViewInit,OnInit, createPlatformFactory,ElementRef,ViewChild } from '@angular/core';
import { NgbPaginationConfig, NgbModal, NgbModalRef, ModalDismissReasons } from '@ng-bootstrap/ng-bootstrap';
import { CommonService } from '../common-service.service';
import {Router,ActivatedRoute} from "@angular/router";
import {FormGroup,FormBuilder,Validators,FormControl} from '@angular/forms';
import swal from 'sweetalert2';

declare var $: any;
import { PerfectScrollbarConfigInterface } from 'ngx-perfect-scrollbar';

@Component({
  templateUrl: './action_campaign.component.html',
  styleUrls: ['./action_campaign.component.scss']
})
export class ActionCampaignComponent implements AfterViewInit,OnInit {

  public config: PerfectScrollbarConfigInterface = {};

  public actionCampaignForm:FormGroup;
  public actionCampaign_Data;
  public edit_id;
  public formSubmittedAttempt = false;
  public openRightSidebar = false;
  public showSideBarLoader = false;
  public showLoader = false;
  public filterObj:any = {};
  public sortFilter:any = {};
  public actionCampaign = [];
  modalReference: NgbModalRef;

  //for grid 
  public headerInformation;
  public actionButtons;

  //for pagination
  itemsPerPage: number = this.commonService.DefaultItemsPerPage;
  totalItems: number;
  currentPage: number = 1;
 
  @ViewChild('autofocus') el:ElementRef;

  constructor(private modalService: NgbModal,
    private commonService: CommonService,
    private router: Router,
    private formBuilder: FormBuilder,
    private route: ActivatedRoute){
      this.declareGridVariable()
  }


  // part of grid
  declareGridVariable(){
    this.headerInformation = [
      {
        title : 'Retention Campaign',// show title table header
        nameIcon : true,// show icon of First letter
        name:'ACTION_CAMPAIGN',// name of column in data source
        width : '20%',// width of column in table
        isSortable : true,// sort by column false or true
        isFilter:{ // filter 
          type : 'text',
          placeholder : 'Filter By Retention Campaign'
        }
      },
      {title : '',name:'',width : '70%'},
      {title : 'Action',name:'action',width : '10%'}
    ];
    this.actionButtons = [
      {title:'Edit',class : "far fa-edit"},
      {title:'Delete',class : "far fa-trash-alt"}
    ]
  }

  ngAfterViewInit(){
   
  }

  ngOnInit(){ 
    this.getData();
    this.addForm();   
  }
  addForm(){
    this.actionCampaignForm = this.formBuilder.group({
      ACTION_CAMPAIGN: ['',]      
    });  
  }
  resetForm(){
    this.formSubmittedAttempt = false;
    this.openRightSidebar = false;
    this.edit_id = '';
    this.actionCampaignForm.patchValue({
      ACTION_CAMPAIGN : '',      
    })
  }

  onSubmit(){ 

    this.formSubmittedAttempt = true;
    if(this.actionCampaignForm.valid){
      this.showSideBarLoader = true;
      if(this.edit_id){
        this.commonService.sendRequestToNode({method :'post',path:'action-campaign/edit/'+this.edit_id,postData:this.actionCampaignForm.value}).subscribe(
          data =>{
            var dialogueTitle = "Updated!";
            this.showSideBarLoader = false;
            if(data.status){
              swal({
                  title: dialogueTitle,
                  text: data.message,
                  type: 'success',
                  confirmButtonClass: "btn btn-success",
                  buttonsStyling: false
                })
              this.getData();
              this.resetForm();
            }else{
              alert(data.message);
            }
          })
      }else{
        this.commonService.sendRequestToNode({method :'post',path:'action-campaign/add',postData:this.actionCampaignForm.value}).subscribe(
          data =>{
          var dialogueTitle = "Inserted!";
         this.showSideBarLoader = false;            
          if(data.status){
            swal({
              title: dialogueTitle,
              text: data.message,
              type: 'success',
              confirmButtonClass: "btn btn-success",
              buttonsStyling: false
            })
            this.getData();
            this.resetForm();
          }else{
            alert(data.message);
          }
        })
      }
    }

  }
 

  getData()
  {

    let filterParams:any = {}
    
    //search filter 
    filterParams = JSON.parse(JSON.stringify(this.filterObj));
    //search filter -end

    // pagination
    filterParams.currentPage = this.currentPage-1;
    filterParams.itemsPerPage = this.itemsPerPage;
    // pagination - end

    //sorting 
    let sortKey = Object.keys(this.sortFilter);
    if(sortKey.length && this.sortFilter[sortKey[0]]){
      filterParams.sortBy = sortKey[0];
      filterParams.sortStatus = this.sortFilter[sortKey[0]];
    }
    //sorting - end

    this.showLoader = true;

    this.commonService.sendRequestToNode({method :'get',path:'action-campaign/list',queryParam:filterParams}).subscribe(result => {
    this.showLoader = false;      
      if(result.status)
        {          
          if(result.data.length > 0){
            this.totalItems = result.data[0].total_records;
            this.actionCampaign_Data = result.data;
          }else{
            this.actionCampaign_Data = [];
          }
        }
        else{
          this.actionCampaign_Data = [];
          alert(result.message)
        }
    })
  }

  edit(id){
    this.openRightSidebar = true;
    this.el.nativeElement.focus();
    this.commonService.sendRequestToNode({method :'get',path:'action-campaign/getById/'+id}).subscribe(
      data => {
        this.actionCampaignForm.patchValue(data.data[0]);
        this.edit_id = id;
    })
  }

  delete(id){
    if(id){
      swal({
        title: 'Are you sure?',
        text: "You won't be able to revert this!",
        type: 'warning',
        showCancelButton: true,
        confirmButtonClass: 'btn btn-success',
        cancelButtonClass: 'btn btn-danger',
        confirmButtonText: 'Yes, delete it!',
         buttonsStyling: false
      }).then((result) =>{
        if (result.value){
          this.commonService.sendRequestToNode({method :'delete',path:'action-campaign/delete/'+id}).subscribe(
            data => {
              if(data.status){
                var dialogueTitle = "Deleted!"
                if(this.actionCampaign.length == 1 && Math.ceil(this.totalItems / this.itemsPerPage) == this.currentPage){
                  if(this.currentPage>1){
                    this.currentPage--;
                  }
                }
                this.getData();
                swal({
                  title: dialogueTitle,
                  text: data.message,
                  type: 'success',
                  confirmButtonClass: "btn btn-success",
                  buttonsStyling: false
                })
              }         
            })
          }
        })
    }
  }

  //part of grid
  clickOnAction(actionObj){
    if(actionObj.actionName == 'Edit'){
      this.edit(actionObj.object.ID)
    }else if(actionObj.actionName == 'Delete'){
      this.delete(actionObj.object.ID)
    }
  }

  //part of grid
  //when change filter ,change page no . etc, 
  filter($event){
    let obj = $event;
    this.currentPage = obj.page;
    this.filterObj = obj.filter;
    this.sortFilter = obj.sort
    this.getData();
  }

  //part of grid
  funOpenRightSidebar(){
    this.openRightSidebar = true;
    this.el.nativeElement.focus();
  }


}

