import { Component, AfterViewInit,OnInit, createPlatformFactory,ElementRef,ViewChild } from '@angular/core';
import { NgbPaginationConfig, NgbModal, NgbModalRef, ModalDismissReasons } from '@ng-bootstrap/ng-bootstrap';
import { CommonService } from '../common-service.service';
import {Router,ActivatedRoute} from "@angular/router";
import {FormGroup,FormBuilder,Validators,FormControl} from '@angular/forms';
import swal from 'sweetalert2';
//import { parse } from 'path';

declare var $: any;
import { PerfectScrollbarConfigInterface } from 'ngx-perfect-scrollbar';

@Component({
  templateUrl: './configuration.component.html',
  styleUrls: ['./configuration.component.scss']
})
export class ConfigurationComponent implements AfterViewInit,OnInit {

  public config: PerfectScrollbarConfigInterface = {};
  public uploadImagesPath = this.commonService.getImagePath();;
  public ConfigurationForm:FormGroup; 
  public edit_id;
  public formSubmittedAttempt = false;
  public fileValue = "";
  
  
  @ViewChild('autofocus') el:ElementRef;
  @ViewChild('fileInput') fi:ElementRef;
  
  constructor(private modalService: NgbModal,
    private commonService: CommonService,
    private formBuilder: FormBuilder,
    ){
  }

  ngAfterViewInit(){
  }

  ngOnInit(){
    this.getData();
    this.addForm();    
  }

  addForm(){
    this.ConfigurationForm = this.formBuilder.group({
      KPI: [null],
      CRITICAL_DEFECT_SHOW: [false],// use in defect damage
      TARGET_RETENTION_RATE_SHORE: [null],
      TARGET_RETENTION_RATE_SHIP : [null],
    });   
  }
  onFileChange(event) {
    if(event.target.files.length > 0) {
      if(event.target.files[0].type == "image/png"){
        let file = event.target.files[0];
        this.fileValue = file;
      }
      else{
        alert('Only Png File Allowed');
        this.fi.nativeElement.value = ''
        this.fileValue = '';
      }
    }
    else{
      this.fileValue = ''
    }
  }
  onSubmit(){
    //console.log(this.edit_id);
    this.formSubmittedAttempt = true;
    if(this.ConfigurationForm.valid){
      let formData = new FormData();
      formData.append('FILE',this.fileValue );
      formData.append('postData',JSON.stringify(this.ConfigurationForm.value) );

      if(this.edit_id){
        this.commonService.sendRequestToNode({method :'post',path:'configuration/edit/'+this.edit_id,postData:formData}).subscribe(
          data =>{
            var dialogueTitle = "Updated!";
            if(data.status){
              this.fi.nativeElement.value = ''
              swal({
                title: dialogueTitle,
                text: data.message,
                type: 'success',
                confirmButtonClass: "btn btn-success",
                buttonsStyling: false
              })
              this.getData();
            }else{
              alert(data.message);
            }
        })
      }
    }  
  }

  getData(){
    let filterParams:any = {}
    this.commonService.sendRequestToNode({method :'get',path:'configuration/list',queryParam:filterParams}).subscribe(result => {
      if(result.status)
        {
          if(result.data.length > 0){ 
            this.edit_id = result.data[0].ID;  
            this.ConfigurationForm.patchValue({
              CRITICAL_DEFECT_SHOW : result.data[0].CRITICAL_DEFECT_SHOW,
              KPI : result.data[0].KPI,
              TARGET_RETENTION_RATE_SHORE: result.data[0].TARGET_RETENTION_RATE_SHORE,
              TARGET_RETENTION_RATE_SHIP: result.data[0].TARGET_RETENTION_RATE_SHIP
            })
          }else{
            this.edit_id = '';
          }
        }
        else{
          this.edit_id = '';
          alert(result.message);
        }
    })
  }

}
 
