import { Component, AfterViewInit,OnInit, createPlatformFactory,ElementRef,ViewChild } from '@angular/core';
import { NgbPaginationConfig, NgbModal, NgbModalRef, ModalDismissReasons } from '@ng-bootstrap/ng-bootstrap';
import { CommonService } from '../common-service.service';
import {Router,ActivatedRoute} from "@angular/router";
import {FormGroup,FormBuilder,Validators,FormControl} from '@angular/forms';
import swal from 'sweetalert2';

declare var $: any;
import { PerfectScrollbarConfigInterface } from 'ngx-perfect-scrollbar';

@Component({
  templateUrl: './cus-design.component.html',
  styleUrls: ['./cus-design.component.scss']
})
export class CusDesignComponent implements AfterViewInit,OnInit {
  
  public modalRef:NgbModalRef;

  public config: PerfectScrollbarConfigInterface = {};
  public uploadPath = this.commonService.getDocumentPath(); 
  public trainingData = [];
  public trainingForm:FormGroup;  
  public edit_id;
  public formSubmittedAttempt = false;
  public openRightSidebar = false;
  public filterObj:any = {};
  public sortFilter:any = {};
  public viewData = false;
  public showSideBarLoader = true;
  public OLD_USER_FK:any //this is for edit
  public user_dropdown = [];
  public trainingtype_dropdown = [];
  public training_viewData;
  public attachmentDisplayData:any = [];
  public showMainLoader = false;;
  public showLoader = false;;

  //this is for file select object 
  public userObjPerFile:any = {}

  //for grid 
  public headerInformation;
  public actionButtons;

  //for pagination
  itemsPerPage: number = this.commonService.DefaultItemsPerPage;
  totalItems: number;
  currentPage: number = 1;

  @ViewChild('content') content: ElementRef;
  @ViewChild('fileInput') fi:ElementRef;

  constructor(private modalService: NgbModal,
    private commonService: CommonService,
    private router: Router,
    private formBuilder: FormBuilder,
    private route: ActivatedRoute){
      this.declareGridVariable();
  }

  // part of grid
  declareGridVariable(){
    this.headerInformation = [
      {
        title : 'Trainer',// show title table header
        nameIcon : true,// show icon of First letter
        name:'TRAINER_NAME',// name of column in data source
        width : '20%',// width of column in table
        isSortable : true,// sort by column false or true
        isFilter:{ // filter 
          type : 'text',
          placeholder : 'Filter By Training Type'
        }
      },
      {
        title : 'Start Date',// show title table header
        name:'TRAINING_START_DATE',// name of column in data source
        width : '20%',// width of column in table
        isDate : 'yes'
      },
      {
        title : 'End Date',// show title table header
        name:'TRAINING_END_DATE',// name of column in data source
        width : '20%',// width of column in table
        isDate : 'yes'
      },
      {title : '',name:'',width : '20%'},
      {title : 'Action',name:'action',width : '20%'}
    ];
    this.actionButtons = [
      {title:'Attachment',class : "fa fa-paperclip"},
      {title:'View',class : "fa fa-eye"},
      {title:'Edit',class : "far fa-edit"},
      {title:'Delete',class : "far fa-trash-alt"}
    ]
  }

  ngAfterViewInit(){
  }

  ngOnInit(){
    this.getData();
    this.addForm();
    this.userDropDown();
    this.trainingTypeDropDown()
  }

  userDropDown(){
    this.commonService.sendRequestToNode({method :'get',path:'user-dropdown'}).subscribe(result => {
      if(result.status){
        this.user_dropdown = result.data;
      }
      else{
        this.user_dropdown = [];
        alert(result.message);
      }
    })
  }

  trainingTypeDropDown(){
    this.commonService.sendRequestToNode({method :'get',path:'trainingtype-dropDown'}).subscribe(result => {
      if(result.status){
        this.trainingtype_dropdown = result.data;
      }
      else{
        this.trainingtype_dropdown = [];
        alert(result.message);
      }
    })
  }
  
  getData()
  {
    this.showLoader = true;
    let filterParams:any = {}
    
    //search filter 
    filterParams = JSON.parse(JSON.stringify(this.filterObj));
    //search filter -end

    // pagination
    filterParams.currentPage = this.currentPage-1;
    filterParams.itemsPerPage = this.itemsPerPage;
    // pagination - end

    //sorting 
    let sortKey = Object.keys(this.sortFilter);
    if(sortKey.length && this.sortFilter[sortKey[0]]){
      filterParams.sortBy = sortKey[0];
      filterParams.sortStatus = this.sortFilter[sortKey[0]];
    }
    //sorting - end

    this.commonService.sendRequestToNode({method :'get',path:'training',queryParam:filterParams}).subscribe(
      result => {
        if(result.status)
        {
          this.showLoader = false;
          if(result.data.length > 0){
            this.totalItems = result.data[0].total_records;
            this.trainingData = result.data;
          }else{
            this.trainingData = [];
          }
        }
        else{
          this.trainingData = [];
          alert(result.message);
        }
    })
  }

  addForm(){

    // this.trainingForm = this.formBuilder.group({
      
    // }); 

    this.trainingForm = this.formBuilder.group({
      TRAINER_NAME: ['',[Validators.required]],
      USER_FK : null,
      TRAINING_TYPE_FK: null,
      NEXT_DONE_MONTH: 0,
      NEXT_DONE_YEAR: 0,
      TRAINING_START_DATE: '',
      TRAINING_END_DATE: '',
      LOCATION: '',
      REMARKS: '',
    });   
  }

  resetForm(){
    this.formSubmittedAttempt = false;
    this.openRightSidebar = false;
    this.viewData = false;
    this.edit_id = '';
    this.trainingForm.patchValue({
      TRAINER_NAME : '',
      USER_FK : '',
      TRAINING_TYPE_FK: '',
      NEXT_DONE_MONTH: 0,
      NEXT_DONE_YEAR: 0,
      TRAINING_START_DATE: '',
      TRAINING_END_DATE: '',
      LOCATION: '',
      REMARKS: '',
    })
  }

  edit(id){
    this.openRightSidebar = true;
    this.commonService.sendRequestToNode({method :'get',path:'training/'+id}).subscribe(
      data => { 
        let user_id = data.data.USER_FK ? data.data.USER_FK.split(",") : '';
        if(user_id && user_id.length > 0){
          user_id.forEach((element,key) => {
            user_id[key] = parseInt(element);
          });
        }
        this.OLD_USER_FK = user_id;
        this.trainingForm.patchValue({
          TRAINER_NAME : data.data.TRAINER_NAME ,
          USER_FK : user_id,
          TRAINING_TYPE_FK : data.data.TRAINING_TYPE_FK ,
          NEXT_DONE_MONTH : data.data.NEXT_DONE_MONTH ,
          NEXT_DONE_YEAR : data.data.NEXT_DONE_YEAR ,
          TRAINING_START_DATE : this.commonService.formatDate(new Date(data.data.TRAINING_START_DATE)) ,
          TRAINING_END_DATE : this.commonService.formatDate(new Date(data.data.TRAINING_END_DATE))  ,
          LOCATION : data.data.LOCATION ,
          REMARKS : data.data.REMARKS ,
        })
        this.edit_id = id;
      })
    }


  view(id){
    this.viewData = true;
    this.openRightSidebar = true;
    this.showSideBarLoader = true;
    //console.log(id);
    this.commonService.sendRequestToNode({method :'get',path:'training/'+id}).subscribe(result => {
    this.showSideBarLoader = false;      
      if(result.status)
        {
          this.training_viewData = result.data;
        }
        else{
          alert(result.message)
        }
    })
  }

  Attachment(id){
    this.showMainLoader = true;
   
    this.showSideBarLoader = true;
    //console.log(id);
    this.commonService.sendRequestToNode({method :'get',path:'training/getAttachment/'+id}).subscribe(result => {
    this.showSideBarLoader = false;      
      if(result.status)
      {
        this.showMainLoader = false;
        if(!this.edit_id){
          this.modalRef = this.modalService.open(this.content,{size:'lg'});
          this.modalRef.result.then((data) => {
            this.edit_id = ""// on close
          }, (reason) => {
            this.edit_id = ""
            // on dismiss
          });
        }
        this.edit_id = id;
        // this.training_viewData = result.data;
        this.attachmentDisplayData = result.data
      }
      else{
        alert(result.message)
      }
    })
  }
  

    delete(id){
      if(id){
        swal({
          title: 'Are you sure?',
          text: "You won't be able to revert this!",
          type: 'warning',
          showCancelButton: true,
          confirmButtonClass: 'btn btn-success',
          cancelButtonClass: 'btn btn-danger',
          confirmButtonText: 'Yes, delete it!',
          buttonsStyling: false
        }).then((result) => {
          if (result.value) {
            this.commonService.sendRequestToNode({method :'delete',path:'training/'+id}).subscribe(
            data => {
            if(data.status){
              var dialogueTitle = "Deleted!"
              if(this.trainingData.length == 1 && Math.ceil(this.totalItems / this.itemsPerPage) == this.currentPage){
                if(this.currentPage>1){
                  this.currentPage--;
                }
              }
              this.getData();
              swal({
                  title: dialogueTitle,
                  text: data.message,
                  type: 'success',
                  confirmButtonClass: "btn btn-success",
                  buttonsStyling: false
                })
            }         
            
        })
          }
        })      
      }
    }

    onSubmit(){ 
      this.formSubmittedAttempt = true;
    
      
      if(this.trainingForm.valid){
      if(this.edit_id){  
        let postData = this.trainingForm.value
        postData.OLD_USER_FK = this.OLD_USER_FK;
        this.commonService.sendRequestToNode({method :'put',path:'training/'+this.edit_id,postData:postData}).subscribe(
          data =>{
            var dialogueTitle = "Updated!"
            if(data.status){
              swal({
                  title: dialogueTitle,
                  text: data.message,
                  type: 'success',
                  confirmButtonClass: "btn btn-success",
                  buttonsStyling: false
                })
              this.getData();
              this.resetForm(); //after edit form is reset
            }
            else{
              alert(data.message);
            }
        })
      }else{
        this.commonService.sendRequestToNode({method :'post',path:'training',postData:this.trainingForm.value}).subscribe(
          data =>{
            var dialogueTitle = "Inserted!"
            if(data.status){
              swal({
                  title: dialogueTitle,
                  text: data.message,
                  type: 'success',
                  confirmButtonClass: "btn btn-success",
                  buttonsStyling: false
                })
              this.getData();
              this.resetForm(); //after edit form is reset

            }
            else{
              alert(data.message);
            }
        })
      }
      }
        
    } 

      //part of grid
    clickOnAction(actionObj){
      if(actionObj.actionName == 'Edit'){
        this.edit(actionObj.object.ID)
      }else if(actionObj.actionName == 'Delete'){
        this.delete(actionObj.object.ID)
      }else if(actionObj.actionName == 'View'){
        this.view(actionObj.object.ID)
      }
      else if(actionObj.actionName == 'Attachment'){
        this.Attachment(actionObj.object.ID)
      }
    }
  
    //part of grid
    //when change filter ,change page no . etc, 
    filter($event){
      let obj = $event;
      this.currentPage = obj.page;
      this.filterObj = obj.filter;
      this.sortFilter = obj.sort
      this.getData();
    }
  
    //part of grid
    funOpenRightSidebar(){
      this.openRightSidebar = true; 
    }

    onFileChange(event,userId) {
      let file = [];
      if(event.target.files.length > 0 && event.target.files.length <= 1) {
        this.userObjPerFile[userId] = event.target.files[0]
      }else{
        this.userObjPerFile[userId] = '';
        this.fi ? this.fi.nativeElement.value = "" : '';
      }
    }
  
    onSubmitAttachment(){
      let formData = new FormData();
      Object.keys(this.userObjPerFile).forEach((ele)=>{
        if(this.userObjPerFile[ele]){
          formData.append('USER_FK',ele );
          formData.append('FILE',this.userObjPerFile[ele] );
        }
      })
  
      this.commonService.sendRequestToNode({method :'post',path:'training/upload-attachment/'+this.edit_id,postData:formData}).subscribe(
        data =>{
          var dialogueTitle = "Uploaded!";
          this.showSideBarLoader = false;
          if(data.status){
            this.userObjPerFile = {};
            swal({
              title: dialogueTitle,
              text : data.message,
              type: 'success',
              confirmButtonClass: "btn btn-success",
              buttonsStyling: false
            })
            this.modalRef.close();
            // this.getData();
            // this.openRightSidebar = false;
            // this.resetForm();
          }
          else{
            alert(data.message)
          }
          
        })
      
    }

    removeUploadedFile(userId,fileName){
      swal({
        title: 'Are you sure?',
        text: "You won't be able to revert this!",
        type: 'warning',
        showCancelButton: true,
        confirmButtonClass: 'btn btn-success',
        cancelButtonClass: 'btn btn-danger',
        confirmButtonText: 'Yes, remove it!',
        buttonsStyling: false
      }).then((result) => {
        if (result.value) {
          this.commonService.sendRequestToNode({method :'post',path:'training/remove-attachment/'+this.edit_id,postData:{USER_FK : userId,file:fileName}}).subscribe(
            result =>{
              this.Attachment(this.edit_id)
              var dialogueTitle = "Success!";
              swal({
                title: dialogueTitle,
                text : result.message,
                type: 'success',
                confirmButtonClass: "btn btn-success",
                buttonsStyling: false
              })
            })
        }
      })
      
    }

    openModel(content) {
      this.modalRef = this.modalService.open(content, { size: 'lg' });
    }

}

