import { Component, AfterViewInit, OnInit, createPlatformFactory, ElementRef, ViewChild } from '@angular/core';
import { NgbPaginationConfig, NgbModal, NgbModalRef, ModalDismissReasons } from '@ng-bootstrap/ng-bootstrap';
import { CommonService } from '../../common-service.service';
import { Router, ActivatedRoute } from "@angular/router";
import { FormGroup, FormBuilder, Validators, FormControl } from '@angular/forms';
import swal from 'sweetalert2';
//import { parse } from 'path';

declare var $: any;
import { PerfectScrollbarConfigInterface } from 'ngx-perfect-scrollbar';

@Component({
  templateUrl: './addEdit.component.html',
  styleUrls: ['./addEdit.component.scss']
})
export class AddEditComponent implements OnInit {
  is_critical_show : boolean = false;
  public config: PerfectScrollbarConfigInterface = {};
  public defectDamageForm: FormGroup;
  public vessel_dropdown;
  public edit_id = "";
  public TypeOfDeficiencyData = []; 
  public InspectionType = [];  
  public DeficiencyCause = [];
  public PSCRefNumbers = []; 
  public ObserverCodes = []; 
  public Equipments = [];
  public PSCMou = [];
  public StatusCodes = [];
  public VIQNumbers = [];
  public AreaObservation = [];
  public formSubmittedAttempt = false;
  public showSideBarLoader = false;
  public modalRef:NgbModalRef;
  public isPscInspectionFlag = false;
  public risk_name_obj = {
    1: 'Low',
    2 : 'Medium',
    3 : 'High',
    4 : 'Very High'
  }
  // public filterObjForList:any = {};

  @ViewChild('content') content: ElementRef;
  @ViewChild('autofocus') el: ElementRef;

  constructor(private modalService: NgbModal,
    private commonService: CommonService,
    private formBuilder: FormBuilder,
    private route: ActivatedRoute,
    private router: Router
  ) {

  
    this.route.params.subscribe(params => {
      this.edit_id = params.id
    });
  }

  ngOnInit() {
    this.vessel();
    this.getDeficiencyCause();
    this.getPSCRefNumbers();
    this.getEquipments();
    this.getPSCMou();
    this.getStatusCodes();
    //this.getVIQNumbers();
    this.addForm();
    if(this.edit_id){
      this.edit(this.edit_id);
    } else {
      this.getTypeOfDeficiencyData();
      this.getInspectionType();
      this.getObserverCodes();
    }
    
    this.getAreaObservations();
    this.configuration()
  }
  configuration() {
    this.commonService.sendRequestToNode({method :'get',path:'configuration/list'}).subscribe(result => {
      if(result.status) {   
        if(result.data.length) {
          this.is_critical_show = result.data[0].CRITICAL_DEFECT_SHOW;
        }
      }
    })
  }

  addForm() {
    this.defectDamageForm = this.formBuilder.group({
      Audit_Type: [0, Validators.required],
      Ship_ID: [null, Validators.required],
      Record_Date: [null],
      Deficiency_Type: [null, Validators.required],
      Inspection_Type_ID: [null,Validators.required],
      Deficiency_Cause: [[]],
      Equipments: [[]],
      VIQ_QuestionNo: [],
      Sire_VersionNo: [],
      Risk_Value: [],
      PSC_Ref_ID: [],
      PSC_MOU_ID: [],
      Defciency_Descp: [],
      Observeration_code: [[], Validators.required],
      Action_Taken: [],
      Target_Date: [null],
      PO_Ref: [],
      Completion_Date: [],
      DryDock_Flag: [0],
      Info_Sharing_Flag: [0],
      Critical_Item_Flag: [0],
      Superident_Remarks: [],
      Status_ID: [null, Validators.required],
      Area_Observation_ID: []
    });
  
  }
  
  changeViqRef(e){
    this.defectDamageForm.patchValue({
      Risk_Value : e.RISK_PROFILE
    })
  }
  changeFlag_Audit(e){
        this.defectDamageForm.patchValue({
          Deficiency_Type: [],
          Inspection_Type_ID: [],
          Observeration_code: [],
        });

        this.getInspectionType(e);
        this.getObserverCodes(e);
        this.getTypeOfDeficiencyData(e);
  }

  viewinfo(opt){
    let content = 'test';
    this.modalRef = this.modalService.open(content,{size: 'sm'});
  }
  edit(id) {
    //this.el.nativeElement.focus(); 
    this.commonService.sendRequestToNode({method :'get',path:'defect-damage-compliance/'+id}).subscribe(
      data => {      
        if(data.data.Record_Date){
          let cdate = new Date(data.data.Record_Date);
          data.data.Record_Date = cdate.getFullYear()+'-'+('0' + (cdate.getMonth()+1)).slice(-2)+'-'+('0' + (cdate.getDate())).slice(-2);
        }else{
          data.data.Record_Date = '';
        }
        if(data.data.Target_Date){
          let cdate = new Date(data.data.Target_Date); 
          data.data.Target_Date = cdate.getFullYear()+'-'+('0' + (cdate.getMonth()+1)).slice(-2)+'-'+('0' + (cdate.getDate())).slice(-2);
        }else{
          data.data.Target_Date = '';
        }
        if(data.data.Completion_Date){
          let cdate = new Date(data.data.Completion_Date); 
          data.data.Completion_Date = cdate.getFullYear()+'-'+('0' + (cdate.getMonth()+1)).slice(-2)+'-'+('0' + (cdate.getDate())).slice(-2);
        }else{
          data.data.Completion_Date = '';
        }
      
        this.defectDamageForm.patchValue({
          Ship_ID : data.data.Ship_ID ,
          Audit_Type : data.data.Audit_Type,
          Record_Date : data.data.Record_Date,
          Deficiency_Type : data.data.Deficiency_Type,
          Inspection_Type_ID : data.data.Inspection_Type_ID,
          Deficiency_Cause : data.data.Deficiency_Cause,
          Equipments : data.data.Equipments,
          VIQ_Question_ID : data.data.VIQ_Question_ID,
          Risk_Value : data.data.Risk_Value,
          Area_Observation_ID : data.data.Area_Observation_ID,
          Observeration_code : data.data.Observeration_code[0],
          Target_Date : data.data.Target_Date,
          Status_ID : data.data.Status_ID,
          Defciency_Descp : data.data.Defciency_Descp,
          Action_Taken : data.data.Action_Taken,
          PO_Ref : data.data.PO_Ref,
          Completion_Date : data.data.Completion_Date,
          DryDock_Flag : data.data.DryDock_Flag,
          Info_Sharing_Flag : data.data.Info_Sharing_Flag,
          Critical_Item_Flag : data.data.Critical_Item_Flag,
          Superident_Remarks : data.data.Superident_Remarks,
          PSC_MOU_ID : data.data.PSC_MOU_ID
          //SHORE_ASSIGNMENT_KPI : data.data.SHORE_ASSIGNMENT_KPI
        })

        this.getTypeOfDeficiencyData(data.data.Audit_Type);
        this.getInspectionType(data.data.Audit_Type);
        this.getObserverCodes(data.data.Audit_Type);

        if(data.data.inspection_type == "PSC Inspection"){
          this.isPscInspectionFlag = true;
          this.defectDamageForm.patchValue({
            PSC_Ref_ID : data.data.PSC_Ref_ID
          })
        }
        this.edit_id = id;
        this.getVIQNumbers(JSON.stringify({ID : data.data.VIQ_Question_ID , QUESTION_NUMBER : data.data.VIQ_QuestionNo}));
    })
  }
  vessel() {
    this.commonService.sendRequestToNode({ method: 'get', path: 'vessel_master/vessel-dropdown',queryParam : {ACTIVE_FLAG : 1,with_non_tanker : true}}).subscribe(result => {
      if (result.status) {
        this.vessel_dropdown = result.data;
        //console.log(this.vessel_dropdown);
      }
      else {
        this.vessel_dropdown = [];
        alert(result.message);
      }
    })
  }
  getTypeOfDeficiencyData(e: any =false){
    let audit_type :any={};
    audit_type = ( true == e ) ? '2': '1';

    this.commonService.sendRequestToNode({method :'get',path:'typeof-defiency',queryParam : {sortBy : 'DESCRIPTION',sortStatus : 'asc',audit_type }}).subscribe(result => {
      if(result.status){   
        this.TypeOfDeficiencyData = result.data;
        this.TypeOfDeficiencyData.forEach(element => {
          // element.ID = JSON.stringify({ID : element.ID,TYPE_OF_DEFICIENCY : element.TYPE_OF_DEFICIENCY,DESCRIPTION : element.DESCRIPTION});
          element.ID = JSON.stringify({ID : element.ID,DESCRIPTION : element.TYPE_OF_DEFICIENCY});
        });
        //alert(JSON.stringify(this.TypeOfDeficiencyData))
      }else{  
        this.TypeOfDeficiencyData = [];
        alert(result.message);
      }
    })
  }
  getInspectionType(e : any = false) {
    let audit_type :any={};
    audit_type = ( true == e ) ? '2': '1';

    this.commonService.sendRequestToNode({method :'get',path:'inspection-type-dropdown',queryParam: {audit_type :audit_type ,ACTIVITY_TRAINING_FLAG : 0} }).subscribe(result => {
      if(result.status){   
        this.InspectionType = result.data;
      }else{
        this.InspectionType = [];
        alert(result.message);
      }
    })
  }
  getDeficiencyCause(){
    this.commonService.sendRequestToNode({method :'get',path:'deficiency-cause-dropdown'}).subscribe(result => {
      if(result.status){   
        this.DeficiencyCause = result.data;
        this.DeficiencyCause.forEach(element => {
          element.ID = JSON.stringify({ID : element.ID,DESCRIPTION : element.TITLE});
          // element.ID = JSON.stringify({ID : element.ID,TITLE : element.TITLE,DESCRIPTION : element.DESCRIPTION});
        });
      }else{
        this.DeficiencyCause = [];
        alert(result.message);
      }
    })
  }
  getPSCRefNumbers(){
    this.commonService.sendRequestToNode({method :'get',path:'psc-reference-numbers-dropdown'}).subscribe(result => {
      if(result.status){   
        this.PSCRefNumbers = result.data;
      }else{
        this.PSCRefNumbers = [];
        alert(result.message);
      }
    })
  }
  getObserverCodes(e:any = false){
    let audit_type :any={};
    audit_type = ( true == e ) ? '2': '1';
    this.commonService.sendRequestToNode({method :'get',path:'observer-codes',queryParam:{audit_type} }).subscribe(result => {
      if(result.status){   
        this.ObserverCodes = result.data;
        this.ObserverCodes.forEach(element => {
          // element.ID = JSON.stringify({ID : element.ID,OBSERVER_CODES : element.OBSERVER_CODES,DESCRIPTION : element.DESCRIPTION});
          element.ID = JSON.stringify({ID : element.ID,DESCRIPTION : element.OBSERVER_CODES});
        });
      } else {
        this.ObserverCodes = [];
        alert(result.message);
      }
    })
  }
  getEquipments(){
    this.commonService.sendRequestToNode({method :'get',path:'equipment-codes'}).subscribe(result => {
      if(result.status){   
        this.Equipments = result.data;
        this.Equipments.forEach(element => {
          // element.ID = JSON.stringify({ID : element.ID,EQUIPMENT_CODES : element.EQUIPMENT_CODES,DESCRIPTION : element.DESCRIPTION});
          element.ID = JSON.stringify({ID : element.ID,DESCRIPTION : element.EQUIPMENT_CODES});
        });
      }else{
        this.Equipments = [];
        alert(result.message);
      }
    })
  }
  getPSCMou(){
    this.commonService.sendRequestToNode({method :'get',path:'psc-mou-dropdown'}).subscribe(result => {
      if(result.status){   
        this.PSCMou = result.data;
      }else{
        this.PSCMou = [];
        alert(result.message);
      }
    })
  }
  getStatusCodes(){
    this.commonService.sendRequestToNode({method :'get',path:'status-codes'}).subscribe(result => {
      if(result.status){   
        this.StatusCodes = result.data;
      }else{
        this.StatusCodes = [];
        alert(result.message);
      }
    })
  }
  getVIQNumbers(vid=''){
    if(this.defectDamageForm.value.Ship_ID){
      this.commonService.sendRequestToNode({method :'get',path:'viq-numbers','queryParam':{'shipId'  :this.defectDamageForm.value.Ship_ID}}).subscribe(result => {
        if(result.status){ 
          this.defectDamageForm.patchValue({
            VIQ_QuestionNo : null,  
          })  
          this.VIQNumbers = result.data;
          this.VIQNumbers.forEach(element => {
            element.ID = JSON.stringify({ID : element.ID,QUESTION_NUMBER : element.QUESTION_NUMBER});
          });
          if(vid){
            this.defectDamageForm.patchValue({
              VIQ_QuestionNo : vid,
              
            })
          }
        }else{
          this.VIQNumbers = [];
         // alert(result.message);
        }
      })
    }
    
  }
  
  getAreaObservations(){
    this.commonService.sendRequestToNode({method :'get',path:'area-observation-dropdown'}).subscribe(result => {
      if(result.status){   
        this.AreaObservation = result.data;
      }else{
        this.AreaObservation = [];
        alert(result.message);
      }
    })
  }

  saveDefectForm(){ 
    this.formSubmittedAttempt = true;
    // alert(this.edit_id);
    if(this.defectDamageForm.valid){
      this.showSideBarLoader = true;
    if(this.edit_id){    
      this.commonService.sendRequestToNode({method :'put',path:'defect-damage-compliance/'+this.edit_id,postData:this.defectDamageForm.value}).subscribe(
        data => {
          var dialogueTitle = "Updated!";
          this.showSideBarLoader = false;
          if(data.status) {
            swal({
                title: dialogueTitle,
                text: data.message,
                type: 'success',
                confirmButtonClass: "btn btn-success",
                buttonsStyling: false
              })
              this.router.navigate(['/tmsa/defect_damage_compliance']);
            //this.getData();
            //this.resetForm(); //after edit form is reset
          } else {
            alert(data.message);
          }
      })
    } else {
      this.commonService.sendRequestToNode({method :'post',path:'defect-damage-compliance',postData:this.defectDamageForm.value}).subscribe(
        data =>{
          var dialogueTitle = "Damage Data Inserted!";
          this.showSideBarLoader = false;
          if(data.status){
            swal({
                title: dialogueTitle,
                text: data.message,
                type: 'success',
                confirmButtonClass: "btn btn-success",
                buttonsStyling: false
              })
              this.router.navigate(['/tmsa/defect_damage_compliance']);
            //this.getData();
            //this.resetForm(); //after edit form is reset

          }
          else{
            alert(data.message);
          }
      })
    }
    }
    
  }
  selectInspection(e){
    if(e.TITLE == "PSC Inspection"){
      this.isPscInspectionFlag = true;
    }
    else{
      this.defectDamageForm.patchValue({
        PSC_Ref_ID : null
      })
      this.isPscInspectionFlag = false;;
    }
  }

  Cancel(){
    this.router.navigate(['tmsa/defect_damage_compliance'])
  }
}
