import { NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';
import { FormsModule,ReactiveFormsModule } from '@angular/forms';
import { Routes, RouterModule } from '@angular/router';

import { NgbModule } from '@ng-bootstrap/ng-bootstrap';

import { AddEditComponent } from './addEdit/addEdit.component';
import { ListComponent } from './list/list.component';
import { AutoReportsViewComponent } from './view/auto_reports_view.component';

import { PerfectScrollbarModule } from 'ngx-perfect-scrollbar';
import { PERFECT_SCROLLBAR_CONFIG } from 'ngx-perfect-scrollbar';
import { PerfectScrollbarConfigInterface } from 'ngx-perfect-scrollbar';
import { UiSwitchModule } from 'ngx-toggle-switch';
import { NgSelectModule } from '@ng-select/ng-select';
import { TagInputModule } from 'ngx-chips';
import { GridViewModule} from '../shared/grid-view/grid-view.module';

const DEFAULT_PERFECT_SCROLLBAR_CONFIG: PerfectScrollbarConfigInterface = {
  suppressScrollX: true,
  wheelSpeed: 1,
  wheelPropagation: true,
  minScrollbarLength: 20
};

const routes: Routes = [
  {
    path: 'add',
    data: {
      title: 'Defect Damage Monitoring',
      urls: [
        { title: 'Dashboard', url: '/dashboard' },
        { title: 'Defect Damage Monitoring', url: '/tmsa/defect_damage_compliance' },
        { title: 'Add' }
      ]
    },
    component: AddEditComponent
  },
  {
    path: 'edit/:id',
    data: {
      title: 'Defect Damage Monitoring',
      urls: [
        { title: 'Dashboard', url: '/dashboard' },
        { title: 'Defect Damage Monitoring', url: '/tmsa/defect_damage_compliance' },
        { title: 'Edit' }
      ]
    },
    component: AddEditComponent
  },
  {
    path: 'view/:id',
    data: {
      title: 'Defect Damage Monitoring',
      urls: [
        { title: 'Dashboard', url: '/dashboard' },
        { title: 'Defect Damage Monitoring', url: '/tmsa/defect_damage_compliance' },
        { title: 'View' }
      ]
    },
    component: AutoReportsViewComponent
  },
  {
    path: '',
    data: {
      info_sharing : 0,
      title: 'Defect Damage Monitoring',
      urls: [
        { title: 'Dashboard', url: '/dashboard' },
        { title: 'Defect Damage Monitoring' }
      ]
    },
    component: ListComponent
  },
  {
    path: 'info-sharing',
    data: {
      info_sharing : 1,
      title: 'Info Sharing',
      urls: [
        { title: 'Dashboard', url: '/dashboard' },
        { title: 'Defect Damage Monitoring' }
      ]
    },
    component: ListComponent
  }
  
];

@NgModule({
  imports: [
    FormsModule,
    CommonModule,
    RouterModule.forChild(routes),
    NgbModule,
    ReactiveFormsModule,
    PerfectScrollbarModule,
    UiSwitchModule,
    NgSelectModule,
    TagInputModule,
    GridViewModule
  ],
  declarations: [
    AddEditComponent,
    ListComponent,
    AutoReportsViewComponent
  ],
  providers: [
    {
      provide: PERFECT_SCROLLBAR_CONFIG,
      useValue: DEFAULT_PERFECT_SCROLLBAR_CONFIG
    },
  ]
})
export class DefectDamageComplianceModule {}
