import { Component, AfterViewInit,OnInit, createPlatformFactory,ElementRef,ViewChild } from '@angular/core';
import { NgbPaginationConfig, NgbModal, NgbModalRef, ModalDismissReasons } from '@ng-bootstrap/ng-bootstrap';
import { CommonService } from '../../common-service.service';
import {Router,ActivatedRoute} from "@angular/router";
import {FormGroup,FormBuilder,Validators,FormControl} from '@angular/forms';
import swal from 'sweetalert2';
//import { parse } from 'path';

declare var $: any;
import { PerfectScrollbarConfigInterface } from 'ngx-perfect-scrollbar';

@Component({
  templateUrl: './auto_reports_view.component.html',
  styleUrls: ['./auto_reports_view.component.scss']
})
export class AutoReportsViewComponent implements AfterViewInit,OnInit {

  public config: PerfectScrollbarConfigInterface = {};

  public frequency ={
    'weekly' : 'Weekly',
    'monthly' : 'Monthly',
    'quaterly' : 'Quarterly',
    'sixth_month' : 'Six Monthly',
    'yearly' : 'Annually'
  } 
  
  public week_day = {
    0 : 'Sunday',
    1 : 'Monday',
    2 : 'Tuesday',
    3 : 'Wednesday',
    4 : 'Thursday',
    5 : 'Friday',
    6 : 'Saturday'
  }

  public timespan = {
    'last_week' : 'Last Week',
    'last_month' : 'Last Month',
    'last_quarter' : 'Last Quarter',
    'last_six_monthly' : 'Last Six Month',
    'last_year' : 'Last Year'
  }



  public sire_reports_format = {
    'fleet_x_avgObs' : 'Fleet Wise Average Number Of Observations',
    'fleet_x_avgRisk' : 'Fleet Wise Average Risk Value',
    'vessel_x_avgRisk' : 'Ship Wise Average Risk Value',
    'vessel_x_avgObs' : 'Ship Wise Average Number Of Observations',
    'marineSupr_x_avgObs' : 'Average Number Of Observations Of Marine Superintendents',
    'marineSupr_x_avgRisk' : 'Average Risk Value Of Observations Of Marine Superintendents',
    'technicalSupr_x_avgObs' : 'Average Number Of Observations Of Technical Superintendents',
    'technicalSupr_x_avgRisk' : 'Average Risk Value Of Observations Of Technical Superintendents',
    'top_10_repeated_obs' : 'Top 10 Most Repeated Observation',
    'high_veryHigh_obs' : 'Very High Risk and High Risk Observations',
    'oil_major_percentage' : 'Oil Major % chart',
    'upcoming_inspection' : 'Upcoming Inspections',
    'companyByMonths_x_totalObs' : 'The Average Number Of Observations For Company By Months', 
    'companyByMonths_x_avgRisk' : 'The Average Risk Value For Company By Months',
    'operator_response_due' : 'Operator Response Due',
    'vesselOwner_x_avgObs' : 'The Average Number Of Observations Of Vessel Owner', 
    'oilMajor_x_avgObs' : 'The Average Number Of Observations Of Oil Major', 
    'total_inspection' : 'Total Number Of Inspections'
  }
  
  public showLoader = false;
 
  public view_id = 0;
  public viewReportTemplateData = {
    // REPORTS_FORMAT : [],
    // REPORTS_FORMAT_TMSA : []
    REPORTS_FORMAT : [],
    REPORTS_FORMAT_TMSA : [],
    TEMPLATE_NAME : '',
    USER_IDS_EMAILS : [],
    USER_EMAILS : [],
    SEND_FREQUENCY : ''
  };
  constructor(private modalService: NgbModal,
    private commonService: CommonService,
    private formBuilder: FormBuilder,
    private route: ActivatedRoute,
    private router: Router
    ){
      this.route.params.subscribe(params => {
        this.view_id = params.id
     });
  }



  ngAfterViewInit(){
  }

  ngOnInit(){
    if(this.view_id){
      this.getDataFromId(this.view_id);
    } 
  }
  getDataFromId(autoReportID){
    this.showLoader = true;  
    this.commonService.sendRequestToNode({method :'get',path:'auto-report-template/' + autoReportID}).subscribe(
      result => {
        // alert(result.status)
        if(result.status){
          let data = result.data[0];
          data.REPORTS_FORMAT = data.REPORTS_FORMAT ? JSON.parse(data.REPORTS_FORMAT) : [],
          data.REPORTS_FORMAT_TMSA = data.REPORTS_FORMAT_TMSA ? JSON.parse(data.REPORTS_FORMAT_TMSA) : []
          this.viewReportTemplateData = data;
          this.showLoader = false;
        }
        else{
          
          alert(result.message);
          this.router.navigate(["/auto-reports"]);
        }
    })

  }

  Cancel(){
    this.router.navigate(["/auto-reports"])
  }
}
 
