import { Component, AfterViewInit,OnInit, createPlatformFactory,ElementRef,ViewChild } from '@angular/core';
import { NgbPaginationConfig, NgbModal, NgbModalRef, ModalDismissReasons } from '@ng-bootstrap/ng-bootstrap';
import { CommonService } from '../common-service.service';
import {Router,ActivatedRoute} from "@angular/router";
import {FormGroup,FormBuilder,Validators,FormControl} from '@angular/forms';
import swal from 'sweetalert2';
//import { parse } from 'path';

declare var $: any;
import { PerfectScrollbarConfigInterface } from 'ngx-perfect-scrollbar';

@Component({
  templateUrl: './departments.component.html',
  styleUrls: ['./departments.component.css']
})
export class DepartmentsComponent implements AfterViewInit,OnInit {
  public config: PerfectScrollbarConfigInterface = {};

  options = {
    theme: 'light', // two possible values: light, dark
    dir: 'ltr', // two possible values: ltr, rtl
    layout: 'vertical', // fixed value. shouldn't be changed.
    sidebartype: 'mini-sidebar', // four possible values: full, iconbar, overlay, mini-sidebar 
    sidebarpos: 'fixed', // two possible values: fixed, absolute
    headerpos: 'fixed', // two possible values: fixed, absolute
    boxed: 'full', // two possible values: full, boxed
    navbarbg: 'skin6', // six possible values: skin(1/2/3/4/5/6)
    sidebarbg: 'skin5', // six possible values: skin(1/2/3/4/5/6)
    logobg: 'skin5' // six possible values: skin(1/2/3/4/5/6)
  };

  public VesselOwnerForm:FormGroup;
  public vesselOwner_data = [];
  public vesselOwner_view;
  public edit_id;
  public formSubmittedAttempt = false;
  public openRightSidebar = false;
  public showSideBarLoader = false;
  public showLoader = false;
  public viewData = false;
  public filterObj:any = {};
  public sortFilter:any = {};

  //for grid 
  public headerInformation;
  public actionButtons;

  //for pagination
  itemsPerPage: number = this.commonService.DefaultItemsPerPage;
  totalItems: number;
  currentPage: number = 1;
  
  @ViewChild('autofocus') el:ElementRef;

  constructor(private modalService: NgbModal,
    private commonService: CommonService,
    private router: Router,
    private formBuilder: FormBuilder,
    private route: ActivatedRoute){
      this.declareGridVariable()
  }
  
  ngAfterViewInit(){
   
  }

  ngOnInit(){
    this.getData();
    this.addForm();
    //this.editForm();
  }

  addForm(){
    this.VesselOwnerForm = this.formBuilder.group({
      DEPARTMENT: [null, Validators.required],
      DEPT_CODE: [null],
    });   
  }

  edit(id){
    this.openRightSidebar = true;
    this.el.nativeElement.focus(); 
    this.commonService.sendRequestToNode({method :'get',path:'department/getById/'+id}).subscribe(
      data => { 
        console.log(data);
        this.VesselOwnerForm.patchValue({
          DEPARTMENT : data.data.DEPARTMENT,
          DEPT_CODE : data.data.DEPT_CODE,
        });
        this.edit_id = id;
    })
  }

  onSubmit(){
    //console.log(this.edit_id);
    this.formSubmittedAttempt = true;
    if(this.VesselOwnerForm.valid){
      this.showSideBarLoader = true;
      if(this.edit_id){
        this.commonService.sendRequestToNode({method :'put',path:'department/edit/'+this.edit_id,postData:this.VesselOwnerForm.value}).subscribe(
          data =>{
            var dialogueTitle = "Updated!";
            this.showSideBarLoader = false;
            if(data.status){
              swal({
                title: dialogueTitle,
                text: data.message,
                type: 'success',
                confirmButtonClass: "btn btn-success",
                buttonsStyling: false
              })
              this.getData();
              this.openRightSidebar = false;
              this.resetForm();
            }else{
              alert(data.message);
            }
        })
      }else{
        console.log(this.VesselOwnerForm.value);
        this.commonService.sendRequestToNode({method :'post',path:'department/add',postData:this.VesselOwnerForm.value}).subscribe(
          data =>{
            var dialogueTitle = "Inserted!";
            this.showSideBarLoader = false;
            if(data.status){
              swal({
                title: dialogueTitle,
                text: data.message,
                type: 'success',
                confirmButtonClass: "btn btn-success",
                buttonsStyling: false
              })
              this.getData();
              this.openRightSidebar = false;
              this.resetForm();
            }else{
              alert(data.message);
            }
        })
      }
    }  
  }

  getData()
  {
    let filterParams:any = {}
    
    //search filter 
    filterParams = JSON.parse(JSON.stringify(this.filterObj));
    //search filter -end

    // pagination
    filterParams.currentPage = this.currentPage-1;
    filterParams.itemsPerPage = this.itemsPerPage;
    // pagination - end

    //sorting 
    let sortKey = Object.keys(this.sortFilter);
    if(sortKey.length && this.sortFilter[sortKey[0]]){
      filterParams.sortBy = sortKey[0];
      filterParams.sortStatus = this.sortFilter[sortKey[0]];
    }
    //sorting - end

    this.showLoader = true;

    this.commonService.sendRequestToNode({method :'get',path:'department/data_list',queryParam:filterParams}).subscribe(result => {
    this.showLoader = false;        
      if(result.status)
        {
          if(result.data.length > 0){
            this.totalItems = result.data[0].total_records;
            this.vesselOwner_data = result.data;
            console.log(this.vesselOwner_data);
          }else{
            this.vesselOwner_data = [];
          }
        }
        else{
          this.vesselOwner_data = [];
          alert(result.message);
        }
    })
  }

  delete(id){
    console.log(id);
    if (id) {
      
      swal({
        title: 'Are you sure?',
        text: "You won't be able to revert this!",
        type: 'warning',
        showCancelButton: true,
        confirmButtonClass: 'btn btn-success',
        cancelButtonClass: 'btn btn-danger',
        confirmButtonText: 'Yes, delete it!',
        buttonsStyling: false
        
        }).then((result) => {
          if (result.value) {   
            this.commonService.sendRequestToNode({method :'delete',path:'department/delete/'+id}).subscribe(result => {
              if(result.status){
                var dialogueTitle = "Deleted!"
                if(this.vesselOwner_data.length == 1 && Math.ceil(this.totalItems / this.itemsPerPage) == this.currentPage){
                  if(this.currentPage>1){
                    this.currentPage--;
                  }
                }
                this.getData();
                swal({
                    title: dialogueTitle,
                    text: result.message,
                    type: 'success',
                    confirmButtonClass: "btn btn-success",
                    buttonsStyling: false
                  })
              }
            })
          }
        })
    }
  }

  view(id){
    this.viewData = true;
    this.openRightSidebar = true;
    this.showSideBarLoader = true;
    this.el.nativeElement.focus(); 
    //console.log(id);
    this.commonService.sendRequestToNode({method :'get',path:'department/getById/'+id}).subscribe(result => {
    this.showSideBarLoader = false;      
      if(result.status)
        {
          this.vesselOwner_view = result.data;
          console.log(this.vesselOwner_view);
        }
        else{
          alert(result.message)
        }
    })
  }

  resetForm(){
    this.formSubmittedAttempt = false;
    this.openRightSidebar = false;
    this.edit_id = '';
    this.viewData = false;
    this.VesselOwnerForm.patchValue({
      DEPARTMENT: null,
      DEPT_CODE: null,
      
    })
  }

  // part of grid
  declareGridVariable(){
    this.headerInformation = [
     
      
      {
        title : 'Department',
        name:'DEPARTMENT',
        width : '20%',
        isSortable : true,
        highlight:true,
        isFilter:{ // filter 
          type : 'text',
          placeholder : 'Filter By Department',
        }
      },
      {
        title : 'Department Code',
        name:'DEPT_CODE',
        width : '15%',
        
        isFilter:{ // filter 
          type : 'text',
          placeholder : 'Filter By Department Code',
        }
      },
      {title : '',width : '10%'},
      {title : 'Action',name:'action',width : '15%'}
    ];
    this.actionButtons = [
      {title:'View',class : "fas fa-eye"},
      {title:'Edit',class : "far fa-edit"},
      {title:'Delete',class : "far fa-trash-alt"}
    ]
  }

  //part of grid
  clickOnAction(actionObj){
    console.log('actionObj');console.log(actionObj);
    if(actionObj.actionName == 'View'){
      this.view(actionObj.object.ID);
    }else if(actionObj.actionName == 'Edit'){
      this.edit(actionObj.object.ID);
    }else if(actionObj.actionName == 'Delete'){
      this.delete(actionObj.object.ID);
    }else if(actionObj.actionName == 'Status'){
      this.statusChange(actionObj.object.ID,actionObj.object)
    }
  }

  statusChange(id,obj){
    if(obj.ACTIVE_FLAG == 1){
      obj.ACTIVE_FLAG = 0;
    }else{
      obj.ACTIVE_FLAG = 1;
    }

    this.commonService.sendRequestToNode({method :'put',path:'vesselowner-isactive/'+id,postData:{ACTIVE_FLAG:obj.ACTIVE_FLAG}}).subscribe(
      data =>{
        var dialogueTitle = "Updated!";
        if(data.status){
          swal({
            title: dialogueTitle,
            text: data.message,
            type: 'success',
            confirmButtonClass: "btn btn-success",
            buttonsStyling: false
          })
          this.getData();
          this.openRightSidebar = false;
          this.resetForm();
        }else{
          alert(data.message);
        }
    })

  }
  
  //part of grid
  //when change filter ,change page no . etc, 
  filter($event){
    let obj = $event;
    console.log(obj.sort)
    this.currentPage = obj.page;
    this.filterObj = obj.filter;
    this.sortFilter = obj.sort
    this.getData();
  }

  //part of grid
  funOpenRightSidebar(){
    this.openRightSidebar = true;
    this.el.nativeElement.focus(); 
  }




}
