import { Component, AfterViewInit,OnInit, createPlatformFactory,ElementRef,ViewChild } from '@angular/core';
import { NgbPaginationConfig, NgbModal, NgbModalRef, ModalDismissReasons } from '@ng-bootstrap/ng-bootstrap';
import { CommonService } from '../common-service.service';
import {Router,ActivatedRoute} from "@angular/router";
import {FormGroup,FormBuilder,Validators,FormControl} from '@angular/forms';
import swal from 'sweetalert2';
//import { parse } from 'path';

declare var $: any;
import { PerfectScrollbarConfigInterface,PerfectScrollbarDirective } from 'ngx-perfect-scrollbar';

@Component({
  templateUrl: './equipment-codes.component.html',
  styleUrls: ['./equipment-codes.component.scss']
})
export class EquipmentCodesComponent implements AfterViewInit,OnInit {

  public config: PerfectScrollbarConfigInterface = {};

  options = {
    theme: 'light', // two possible values: light, dark
    dir: 'ltr', // two possible values: ltr, rtl
    layout: 'vertical', // fixed value. shouldn't be changed.
    sidebartype: 'mini-sidebar', // four possible values: full, iconbar, overlay, mini-sidebar 
    sidebarpos: 'fixed', // two possible values: fixed, absolute
    headerpos: 'fixed', // two possible values: fixed, absolute
    boxed: 'full', // two possible values: full, boxed
    navbarbg: 'skin6', // six possible values: skin(1/2/3/4/5/6)
    sidebarbg: 'skin5', // six possible values: skin(1/2/3/4/5/6)
    logobg: 'skin5' // six possible values: skin(1/2/3/4/5/6)
  };

  public EquipmentCodesForm:FormGroup;
  public equipmentCodes_data = [];
  public vesselOwner_view;
  public edit_id;
  public formSubmittedAttempt = false;
  public openRightSidebar = false;
  public showSideBarLoader = false;
  public showLoader = false;
  public filterObj:any = {};
  public sortFilter:any = {};

  //for grid 
  public headerInformation;
  public actionButtons;

  //for pagination
  itemsPerPage: number = this.commonService.DefaultItemsPerPage;
  totalItems: number;
  currentPage: number = 1;
  
  @ViewChild('autofocus') el:ElementRef;
  @ViewChild(PerfectScrollbarDirective) directiveRef?: PerfectScrollbarDirective;

  constructor(private modalService: NgbModal,
    private commonService: CommonService,
    private router: Router,
    private formBuilder: FormBuilder,
    private route: ActivatedRoute){
      this.declareGridVariable()
  }
  
  ngAfterViewInit(){
   
  }

  ngOnInit(){
    this.getData();
    this.addForm();
    //this.editForm();
  }

  addForm(){
    this.EquipmentCodesForm = this.formBuilder.group({
      EQUIPMENT_CODES: [null,],
      DESCRIPTION: [null,],
    });   
  }

  edit(id){
    this.openRightSidebar = true;
    this.el.nativeElement.focus();
    this.directiveRef.scrollToTop();
    this.commonService.sendRequestToNode({method :'get',path:'equipment-codes/getById/'+id}).subscribe(
      data => { 
        this.EquipmentCodesForm.patchValue({
          EQUIPMENT_CODES : data.data.EQUIPMENT_CODES,
          DESCRIPTION : data.data.DESCRIPTION,
        });
        this.edit_id = id;
    })
  }

  onSubmit(){
    //console.log(this.edit_id);
    this.formSubmittedAttempt = true;
    if(this.EquipmentCodesForm.valid){
      this.showSideBarLoader = true;
      if(this.edit_id){
        swal({
          title: 'Are you sure?',
          text: "All past records will be effected by this change, are you sure you want to continue with the renaming?",
          type: 'warning',
          showCancelButton: true,
          confirmButtonClass: 'btn btn-success',
          cancelButtonClass: 'btn btn-danger',
          confirmButtonText: 'Yes, replace it!',
          buttonsStyling: false
          
          }).then((result) => {
            let postData = this.EquipmentCodesForm.value;
            if(result.value){
              postData.replaceName = true
              this.commonService.sendRequestToNode({method :'put',path:'equipment-codes/edit/'+this.edit_id,postData:postData}).subscribe(
                data =>{
                  var dialogueTitle = "Updated!";
                  this.showSideBarLoader = false;
                  if(data.status){
                    swal({
                      title: dialogueTitle,
                      text: data.message,
                      type: 'success',
                      confirmButtonClass: "btn btn-success",
                      buttonsStyling: false
                    })
                    this.getData();
                    this.openRightSidebar = false;
                    this.resetForm();
                  }else{
                    alert(data.message);
                  }
              })
            }
            else{
              swal({
                title: 'Note',
                text: 'you need to add new Data',
                type: 'warning',
                confirmButtonClass: "btn btn-success",
                buttonsStyling: false
              })
              this.showSideBarLoader = false;
            };
          
          });
        
      }else{
        this.commonService.sendRequestToNode({method :'post',path:'equipment-codes/add',postData:this.EquipmentCodesForm.value}).subscribe(
          data =>{
            var dialogueTitle = "Inserted!";
            this.showSideBarLoader = false;
            if(data.status){
              swal({
                title: dialogueTitle,
                text: data.message,
                type: 'success',
                confirmButtonClass: "btn btn-success",
                buttonsStyling: false
              })
              this.getData();
              this.openRightSidebar = false;
              this.resetForm();
            }else{
              alert(data.message);
            }
        })
      }
    }  
  }

  getData()
  {
    let filterParams:any = {}
    
    //search filter 
    filterParams = JSON.parse(JSON.stringify(this.filterObj));
    //search filter -end

    // pagination
    filterParams.currentPage = this.currentPage-1;
    filterParams.itemsPerPage = this.itemsPerPage;
    // pagination - end

    //sorting 
    let sortKey = Object.keys(this.sortFilter);
    if(sortKey.length && this.sortFilter[sortKey[0]]){
      filterParams.sortBy = sortKey[0];
      filterParams.sortStatus = this.sortFilter[sortKey[0]];
    }
    //sorting - end

    this.showLoader = true;

    this.commonService.sendRequestToNode({method :'get',path:'equipment-codes/data_list',queryParam:filterParams}).subscribe(result => {
    this.showLoader = false;        
      if(result.status)
        {
          if(result.data.length > 0){
            this.totalItems = result.data[0].total_records;
            this.equipmentCodes_data = result.data;
          }else{
            this.equipmentCodes_data = [];
          }
        }
        else{
          this.equipmentCodes_data = [];
          alert(result.message);
        }
    })
  }

  delete(id){
    if (id) {
      
      swal({
        title: 'Are you sure?',
        text: "You won't be able to revert this!",
        type: 'warning',
        showCancelButton: true,
        confirmButtonClass: 'btn btn-success',
        cancelButtonClass: 'btn btn-danger',
        confirmButtonText: 'Yes, delete it!',
        buttonsStyling: false
        
        }).then((result) => {
          if (result.value) {   
            this.commonService.sendRequestToNode({method :'delete',path:'equipment-codes/delete/'+id}).subscribe(result => {
              if(result.status){
                var dialogueTitle = "Deleted!"
                if(this.equipmentCodes_data.length == 1 && Math.ceil(this.totalItems / this.itemsPerPage) == this.currentPage){
                  if(this.currentPage>1){
                    this.currentPage--;
                  }
                }
                this.getData();
                swal({
                    title: dialogueTitle,
                    text: result.message,
                    type: 'success',
                    confirmButtonClass: "btn btn-success",
                    buttonsStyling: false
                  })
              }
            })
          }
        })
    }
  }

  resetForm(){
    this.formSubmittedAttempt = false;
    this.openRightSidebar = false;
    this.edit_id = '';
    this.EquipmentCodesForm.patchValue({
      EQUIPMENT_CODES: null,
      DESCRIPTION: null,
    })
  }

  // part of grid
  declareGridVariable(){
    this.headerInformation = [
      {
        title : 'Equipment Codes',// show title table header
        //nameIcon : true,// show icon of First letter
        name:'EQUIPMENT_CODES',// name of column in data source
        width : '20%',// width of column in table
        isSortable : true,// sort by column false or true
        highlight:true, // name highlight
        isFilter:{ // filter 
          type : 'text',
          placeholder : 'Filter By Equipment Codes'
        }
      },
      {
        title : 'Description',// show title table header
        //nameIcon : true,// show icon of First letter
        name:'DESCRIPTION',// name of column in data source
        width : '20%',// width of column in table
        isSortable : true,// sort by column false or true
        //highlight:true, // name highlight
        isFilter:{ // filter 
          type : 'text',
          placeholder : 'Filter By Description'
        }
      },
      {title : '',width : '50%'},
      {title : 'Action',name:'action',width : '10%'}
    ];
    this.actionButtons = [
      {title:'Edit',class : "far fa-edit"},
      {title:'Delete',class : "far fa-trash-alt"}
    ]
  }

  //part of grid
  clickOnAction(actionObj){
    if(actionObj.actionName == 'Edit'){
      this.edit(actionObj.object.ID);
    }else if(actionObj.actionName == 'Delete'){
      this.delete(actionObj.object.ID);
    }
  }

  //part of grid
  //when change filter ,change page no . etc, 
  filter($event){
    let obj = $event;
    this.currentPage = obj.page;
    this.filterObj = obj.filter;
    this.sortFilter = obj.sort
    this.getData();
  }

  //part of grid
  funOpenRightSidebar(){
    this.openRightSidebar = true;
    this.el.nativeElement.focus();
    this.directiveRef.scrollToTop(); 
  }




}
