import { Component, AfterViewInit,OnInit, createPlatformFactory,ElementRef,ViewChild } from '@angular/core';
import { NgbPaginationConfig, NgbModal, NgbModalRef, ModalDismissReasons } from '@ng-bootstrap/ng-bootstrap';
import { CommonService } from '../common-service.service';
import {Router,ActivatedRoute} from "@angular/router";
import {FormGroup,FormBuilder,Validators,FormControl} from '@angular/forms';
import swal from 'sweetalert2';
//import { parse } from 'path';

declare var $: any;
import { PerfectScrollbarConfigInterface } from 'ngx-perfect-scrollbar';

@Component({
  templateUrl: './group.component.html',
  styleUrls: ['./group.component.scss']
})
export class GroupComponent implements AfterViewInit,OnInit {

  public config: PerfectScrollbarConfigInterface = {};

  options = {
    theme: 'light', // two possible values: light, dark
    dir: 'ltr', // two possible values: ltr, rtl
    layout: 'vertical', // fixed value. shouldn't be changed.
    sidebartype: 'mini-sidebar', // four possible values: full, iconbar, overlay, mini-sidebar 
    sidebarpos: 'fixed', // two possible values: fixed, absolute
    headerpos: 'fixed', // two possible values: fixed, absolute
    boxed: 'full', // two possible values: full, boxed
    navbarbg: 'skin6', // six possible values: skin(1/2/3/4/5/6)
    sidebarbg: 'skin5', // six possible values: skin(1/2/3/4/5/6)
    logobg: 'skin5' // six possible values: skin(1/2/3/4/5/6)
  };

  public GroupForm:FormGroup;
  public groups = [];
  public groups_view;  
  public edit_id;
  public formSubmittedAttempt = false;
  public openRightSidebar = false;
  public showSideBarLoader = false; 
  public showLoader = false;
  public viewData = false;
  public filterObj:any = {};
  public sortFilter:any = {};

  //for grid 
  public headerInformation;
  public actionButtons;

  //for pagination
  itemsPerPage: number = this.commonService.DefaultItemsPerPage;
  totalItems: number;
  currentPage: number = 1;
  
  @ViewChild('autofocus') el:ElementRef;

  constructor(private modalService: NgbModal,
    private commonService: CommonService,
    private router: Router,
    private formBuilder: FormBuilder,
    private route: ActivatedRoute){
      this.declareGridVariable()
  }
  
  ngAfterViewInit(){
   
  }

  ngOnInit(){
    this.getData();
    this.addForm();    
    //this.editForm();
  }

  addForm(){
    this.GroupForm = this.formBuilder.group({
      
      GROUP_NAME: [null,],     
      DESCRIPTION: [null,],
    });   
  }

  onSubmit(){
    //console.log(this.edit_id);
    this.formSubmittedAttempt = true;
    if(this.GroupForm.valid){
      this.showSideBarLoader = true;
      if(this.edit_id){
        this.commonService.sendRequestToNode({method :'post',path:'group/edit/'+this.edit_id,postData:this.GroupForm.value}).subscribe(
          data =>{
            var dialogueTitle = "Updated!";
            this.showSideBarLoader = false;
            if(data.status){
              swal({
                title: dialogueTitle,
                text: data.message,
                type: 'success',
                confirmButtonClass: "btn btn-success",
                buttonsStyling: false
              })
              this.getData();
              this.openRightSidebar = false;
              this.resetForm();
            }else{
              alert(data.message);
            }
        })
      }else{
        
        this.commonService.sendRequestToNode({method :'post',path:'group/add',postData:this.GroupForm.value}).subscribe(
          data =>{
            var dialogueTitle = "Inserted!";
            this.showSideBarLoader = false;
            if(data.status){
              swal({
                title: dialogueTitle,
                text: data.message,
                type: 'success',
                confirmButtonClass: "btn btn-success",
                buttonsStyling: false
              })
              this.getData();
              this.openRightSidebar = false;
              this.resetForm();
            }else{
              alert(data.message);
            }
        })
      }
    }  
  }

  getData()
  {
    let filterParams:any = {}
    
    //search filter 
    filterParams = JSON.parse(JSON.stringify(this.filterObj));
    //search filter -end

    // pagination
    filterParams.currentPage = this.currentPage-1;
    filterParams.itemsPerPage = this.itemsPerPage;
    // pagination - end

    //sorting 
    let sortKey = Object.keys(this.sortFilter);
    if(sortKey.length && this.sortFilter[sortKey[0]]){
      filterParams.sortBy = sortKey[0];
      filterParams.sortStatus = this.sortFilter[sortKey[0]];
    }
    //sorting - end

    this.showLoader = true;

    this.commonService.sendRequestToNode({method :'get',path:'group/list',queryParam:filterParams}).subscribe(result => {
    this.showLoader = false;    
      if(result.status)
        {
          if(result.data.length > 0){
            this.totalItems = result.data[0].total_records;
            this.groups = result.data;            
          }else{
            this.groups = [];
          }
        }
        else{
          this.groups = [];
          alert(result.message);
        }
    })
  }
  
  edit(id){ 
    this.openRightSidebar = true;
    this.el.nativeElement.focus();
    this.commonService.sendRequestToNode({method :'get',path:'group/getById/'+id}).subscribe(
      data => {                 
        this.GroupForm.patchValue({
          GROUP_NAME : data.data[0].GROUP_NAME,
          DESCRIPTION : data.data[0].DESCRIPTION,
        })
        this.edit_id = id;
    })
  }

  view(id){
    this.viewData = true;
    this.openRightSidebar = true;
    this.showSideBarLoader = true;
    this.el.nativeElement.focus();
    //console.log(id);
    this.commonService.sendRequestToNode({method :'get',path:'group/getById/'+id}).subscribe(result => {
      this.showSideBarLoader = false;  
      if(result.status)
        {
          this.groups_view = result.data;         
        }
        else{
          alert(result.message)
        }
    })
  }
  delete(id){ 
    if(id){
      swal({
        title: 'Are you sure?',
        text: "You won't be able to revert this!",
        type: 'warning',
        showCancelButton: true,
        confirmButtonClass: 'btn btn-success',
        cancelButtonClass: 'btn btn-danger',
        confirmButtonText: 'Yes, delete it!',
         buttonsStyling: false
      }).then((result) => {
        if (result.value) {
          this.commonService.sendRequestToNode({method :'delete',path:'group/delete/'+id}).subscribe(
            data => {
              if(data.status){
                var dialogueTitle = "Deleted!";
                if(this.groups.length == 1 && Math.ceil(this.totalItems / this.itemsPerPage) == this.currentPage){
                  if(this.currentPage>1){
                    this.currentPage--;
                  }
                }
                this.getData();
                swal({
                  title: dialogueTitle,
                  text: data.message,
                  type: 'success',
                  confirmButtonClass: "btn btn-success",
                  buttonsStyling: false
                })
              }         
          })
        }
      })
    }
  }

  resetForm(){
    this.formSubmittedAttempt = false;
    this.openRightSidebar = false;
    this.viewData = false;
    this.edit_id = '';
    this.GroupForm.patchValue({
      GROUP_NAME: null,     
      DESCRIPTION: null, 
    })
  }

  // part of grid
  declareGridVariable(){
    this.headerInformation = [
      {
        title : 'Vessel Group',// show title table header
        //nameIcon : true,// show icon of First letter
        name:'GROUP_NAME',// name of column in data source
        width : '20%',// width of column in table
        isSortable : true,// sort by column false or true
        highlight:true, // name highlight
        isFilter:{ // filter 
          type : 'text',
          placeholder : 'Filter By Vessel Group'
        }
      },
      {title : 'Description',name:'DESCRIPTION',width : '20%'},
      {title : 'Vessel Name',name:'VESSEL_NAME',width : '50%'},
      {title : 'Action',name:'action',width : '10%'}
    ];
    this.actionButtons = [
      {title:'View',class : "fas fa-eye"},
      {title:'Edit',class : "far fa-edit"},
      {title:'Delete',class : "far fa-trash-alt"}
    ]
  }

  //part of grid
  clickOnAction(actionObj){
    if(actionObj.actionName == 'View'){
      this.view(actionObj.object.ID)
    }
    else if(actionObj.actionName == 'Edit'){
      this.edit(actionObj.object.ID)
    }else if(actionObj.actionName == 'Delete'){
      this.delete(actionObj.object.ID)
    }
  }
  filter($event){
    let obj = $event;
    this.currentPage = obj.page;
    this.filterObj = obj.filter;
    this.sortFilter = obj.sort
    this.getData();
  }

  //part of grid
  funOpenRightSidebar(){
    this.openRightSidebar = true;
    this.el.nativeElement.focus();
  }

}
 
