import { Component, AfterViewInit,OnInit, createPlatformFactory } from '@angular/core';
import { NgbPaginationConfig, NgbModal, NgbModalRef, ModalDismissReasons } from '@ng-bootstrap/ng-bootstrap';
import { CommonService } from '../common-service.service';
import {Router,ActivatedRoute} from "@angular/router";
import {FormGroup,FormBuilder,Validators,FormControl} from '@angular/forms';
import swal from 'sweetalert2';
//import { parse } from 'path';

declare var $: any;
import { PerfectScrollbarConfigInterface } from 'ngx-perfect-scrollbar';

@Component({
  templateUrl: './inspectionRequest.component.html',
  styleUrls: ['./inspectionRequest.component.scss']
})
export class InspectionRequestComponent implements AfterViewInit,OnInit {

  public docPath = this.commonService.getImagePath(true)+'/inspectionRequestUpload';
  public config: PerfectScrollbarConfigInterface = {};

  options = {
    theme: 'light', // two possible values: light, dark
    dir: 'ltr', // two possible values: ltr, rtl
    layout: 'vertical', // fixed value. shouldn't be changed.
    sidebartype: 'mini-sidebar', // four possible values: full, iconbar, overlay, mini-sidebar 
    sidebarpos: 'fixed', // two possible values: fixed, absolute
    headerpos: 'fixed', // two possible values: fixed, absolute
    boxed: 'full', // two possible values: full, boxed
    navbarbg: 'skin6', // six possible values: skin(1/2/3/4/5/6)
    sidebarbg: 'skin5', // six possible values: skin(1/2/3/4/5/6)
    logobg: 'skin5' // six possible values: skin(1/2/3/4/5/6)
  };

  public userData; 
  public InspectionRequestForm:FormGroup;
  public inspectionRequests = [];
  public inspection_request_view;  
  public edit_id;
  public formSubmittedAttempt = false;
  public openRightSidebar = false;
  public showLoader = false;
  public viewData = false;
  public filterObj:any = {};
  public sortFilter:any = {};
  public download_file_name=this.commonService.getImagePath(true)+'/oil-major/'; 
  //public defaultPreviewImage: string = "./assets/img/image_placeholder.jpg"
  //for grid 
  public headerInformation;
  public actionButtons;
  public emailButtons;

  //for pagination
  itemsPerPage: number = this.commonService.DefaultItemsPerPage;
  totalItems: number;
  currentPage: number = 1;
  
  constructor(private modalService: NgbModal,
    private commonService: CommonService,
    private router: Router,
    private formBuilder: FormBuilder,
    private route: ActivatedRoute){
      this.declareGridVariable()
  }
  
  ngAfterViewInit(){
   
  }

  ngOnInit(){
    this.getData();
    this.addForm();    
    //this.editForm();
    //this.userDropDown();
  }

  onFileChange(event) {
    if(event.target.files.length > 0) {
      let formData = new FormData();
      
      let file = event.target.files[0];
       this.InspectionRequestForm.get('FILE').setValue(file);
       formData.append('FILE', file);
    }
   
  }

  addForm(){
    this.InspectionRequestForm = this.formBuilder.group({
      TITLE:'',
      INSPECTION_FROM: '',
      WEBSITE_NAME:'' ,
      FILE:''   
    });   
  }  

  getData()
  {
    let filterParams:any = {}
    
    //search filter 
    filterParams = JSON.parse(JSON.stringify(this.filterObj));
    //search filter -end

    // pagination
    filterParams.currentPage = this.currentPage-1;
    filterParams.itemsPerPage = this.itemsPerPage;
    // pagination - end

    //sorting 
    let sortKey = Object.keys(this.sortFilter);
    if(sortKey.length && this.sortFilter[sortKey[0]]){
      filterParams.sortBy = sortKey[0];
      filterParams.sortStatus = this.sortFilter[sortKey[0]];
    }
    //sorting - end

    this.showLoader = true;

    this.commonService.sendRequestToNode({method :'get',path:'inspectionRequest/list',queryParam:filterParams}).subscribe(result => {
    this.showLoader = false;       
      if(result.status)
        {
          if(result.data.length > 0){
            this.totalItems = result.data[0].total_records;
            this.inspectionRequests = result.data;         
            
          }else{
            this.inspectionRequests = [];
          }
        }
        else{
          this.inspectionRequests = [];
          alert(result.message);
        }
    })
  }


  // part of grid
  declareGridVariable(){
    this.headerInformation = [
      {
        title : 'Official Name',// show title table header
        //nameIcon : true,// show icon of First letter
        name:'OFFICIAL_NAME',// name of column in data source
        width : '20%',// width of column in table
        isSortable : true,// sort by column false or true
        highlight:true, // name highlight
        isFilter:{ // filter
          type : 'text',
          placeholder : 'Filter By Title'
        }
      },
      // {title : 'Email',type:"email",email_field : 'test',name:'TITLE',width : '15%'},//email type for open in outlookexpress
      //{title : 'Description',name:'DESCRIPTION',width : '10%'},
      {title : 'Website',type : "link",target : "__blank",name:'WEBSITE',width : '20%'},
      {title : '',name:'',width : '50%'},
      {title : 'Action',name:'action',width : '10%'},
      
      // {title : 'Email',name:'emailButtons',width : '10%'}
    ];
    // let emailTemplate;
    // emailTemplate = "Dear%20Sir,%0A%0A1.We%20would%20like%20to%20request%20for%20a%20SIRE%20inspection%20to%20be%20carried%20out%20as%20per%20below%20details:%0A%0Ai.Vessel%20Name%20:%0A%0Aii.IMO.NO%20:%0A%0Aiii.Port:%0A%0Aiv.ETA:%0A%0Av.ETD:%0A%0Aiv.Operation:%0A%0A%0A%0A2.%20Agent's%20details:%0A%0A%0A%0A%0A%0A%0A%0A3.%20Please%20send%20all%20invoices%20to%20the%20following%20address:%0A%0AYour%20kind%20confirmation%20on%20this%20inspection%20request%20and%20attendance%20is%20appreciated.";


//this.download_file_name
    this.actionButtons = [
      {title:'Download',link : this.download_file_name,class : "fas fa-download"}, 
      {title:'Email',subject:'Request',class : "fas fa-envelope"}         
    ];
    // this.emailButtons = [      
    //   {title:'Email',email_field : 'test',class : "fas fa-envelope"}      
    // ]
    
  }

  //part of grid
  clickOnAction(actionObj){
  
  }
  filter($event){
    let obj = $event;
    this.currentPage = obj.page;
    this.filterObj = obj.filter;
    this.sortFilter = obj.sort
    this.getData();
  }

  //part of grid
  funOpenRightSidebar(){
    this.openRightSidebar = true; 
  }

}
 
