import { Component, AfterViewInit,OnInit, createPlatformFactory,ElementRef,ViewChild } from '@angular/core';
import { NgbPaginationConfig, NgbModal, NgbModalRef, ModalDismissReasons } from '@ng-bootstrap/ng-bootstrap';
import { CommonService } from '../common-service.service';
import {Router,ActivatedRoute} from "@angular/router";
import {FormGroup,FormBuilder,Validators,FormControl} from '@angular/forms';
import swal from 'sweetalert2';
//import { parse } from 'path';

declare var $: any;
import { PerfectScrollbarConfigInterface } from 'ngx-perfect-scrollbar';

@Component({
  templateUrl: './inspector.component.html',
  styleUrls: ['./inspector.component.scss']
})
export class InspectorComponent implements AfterViewInit,OnInit {

  public config: PerfectScrollbarConfigInterface = {};

  options = {
    theme: 'light', // two possible values: light, dark
    dir: 'ltr', // two possible values: ltr, rtl
    layout: 'vertical', // fixed value. shouldn't be changed.
    sidebartype: 'mini-sidebar', // four possible values: full, iconbar, overlay, mini-sidebar 
    sidebarpos: 'fixed', // two possible values: fixed, absolute
    headerpos: 'fixed', // two possible values: fixed, absolute
    boxed: 'full', // two possible values: full, boxed
    navbarbg: 'skin6', // six possible values: skin(1/2/3/4/5/6)
    sidebarbg: 'skin5', // six possible values: skin(1/2/3/4/5/6)
    logobg: 'skin5' // six possible values: skin(1/2/3/4/5/6)
  };

  public AVG_INSPECTOR_OBSERVATION = 0;
  public AVG_INSPECTOR_RISK_PROFILE = 0;
  public inspectorId = 0;  

  public Groupinspector:FormGroup;
  public inspectors = [];
  public inspectors_view;
  public oliMajor_dropdown = [];
  public inspector_dropdown = [];

  public edit_id;
  public formSubmittedAttempt = false;
  public openRightSidebar = false;
  public showSideBarLoader = false;
  public showLoader = false;
  public showLoaderInspectorSearch = false;
  public viewData = false;
  public filterObj:any = {};
  public sortFilter:any = {};

  public model_inspectorId = '';
  //for grid 
  public headerInformation;
  public actionButtons;

  //for pagination
  itemsPerPage: number = this.commonService.DefaultItemsPerPage;
  totalItems: number;
  currentPage: number = 1;
  
  @ViewChild('autofocus') el:ElementRef;

  constructor(private modalService: NgbModal,
    private commonService: CommonService,
    private router: Router,
    private formBuilder: FormBuilder,
    private route: ActivatedRoute){
      this.declareGridVariable()
  }
  
  ngAfterViewInit(){
   
  }

  ngOnInit(){
    this.getData();
    this.addForm();
    this.oliMajor();
    this.getInsectorDropDownData()
    //this.editForm();
  }

  addForm(){
    this.Groupinspector = this.formBuilder.group({
      OIL_MAJOR_MASTER_FK: [null,],
      FNAME: [null,],
      LNAME: [null,],
      INSPECTING_COMPANY: [null,],
      OFFICE_TELEPHONE: [null,],
      MOBILE_NO: [null,],
      EMAIL: [null,],
      COMMONLY_KNOWN: [null,],
      COMMENTS: [null,],
    });   
  }

  onSubmit(){
    //console.log(this.edit_id);
    this.formSubmittedAttempt = true;
    this.showSideBarLoader = true;
    if(this.Groupinspector.valid){
      if(this.edit_id){
        this.commonService.sendRequestToNode({method :'post',path:'inspector/edit/'+this.edit_id,postData:this.Groupinspector.value}).subscribe(
          data =>{
            var dialogueTitle = "Updated!";
            this.showSideBarLoader = false;            
            if(data.status){
              swal({
                title: dialogueTitle,
                text: data.message,
                type: 'success',
                confirmButtonClass: "btn btn-success",
                buttonsStyling: false
              })
              this.getData();
              this.openRightSidebar = false;
              this.resetForm();
            }else{
              alert(data.message);
            }
        })
      }else{
        //console.log(this.Groupinspector.value);
        this.commonService.sendRequestToNode({method :'post',path:'inspector/add',postData:this.Groupinspector.value}).subscribe(
          data =>{
            var dialogueTitle = "Inserted!";
            this.showSideBarLoader = false;            
            if(data.status){
              swal({
                title: dialogueTitle,
                text: data.message,
                type: 'success',
                confirmButtonClass: "btn btn-success",
                buttonsStyling: false
              })
              this.getData();
              this.openRightSidebar = false;
              this.resetForm();
            }else{
              alert(data.message);
            }
        })
      }
    }  
  }

  getData()
  {
    let filterParams:any = {}
    
    //search filter 
    filterParams = JSON.parse(JSON.stringify(this.filterObj));
    //search filter -end

    // pagination
    filterParams.currentPage = this.currentPage-1;
    filterParams.itemsPerPage = this.itemsPerPage;
    // pagination - end

    //sorting 
    let sortKey = Object.keys(this.sortFilter);
    if(sortKey.length && this.sortFilter[sortKey[0]]){
      filterParams.sortBy = sortKey[0];
      filterParams.sortStatus = this.sortFilter[sortKey[0]];
    }
    //sorting - end

    this.showLoader = true;

    this.commonService.sendRequestToNode({method :'get',path:'inspectors/data_list',queryParam:filterParams}).subscribe(result => {
    this.showLoader = false;      
      if(result.status)
        {
          if(result.data.length > 0){
            this.totalItems = result.data[0].total_records;
            this.inspectors = result.data;
            //console.log(this.inspectors);
          }else{
            this.inspectors = [];
          }
        }
        else{
          this.inspectors = [];
          alert(result.message);
        }
    })
  }

  view(id){
    this.viewData = true;
    this.openRightSidebar = true;
    this.showSideBarLoader = true;            
    this.el.nativeElement.focus();
    //console.log(id);
    this.commonService.sendRequestToNode({method :'get',path:'inspector/getById/'+id}).subscribe(result => {
      this.showSideBarLoader = false;                  
      if(result.status)
        {
          this.inspectors_view = result.data;
          //console.log(this.inspectors_view);
        }
        else{
          alert(result.message)
        }
    })
  }

  edit(id){
    this.openRightSidebar = true;
    // this.el.nativeElement.focus();
    this.commonService.sendRequestToNode({method :'get',path:'inspector/getById/'+id}).subscribe(
      data => { 
        let groupFk = [];
        if(data.data.OIL_MAJOR_MASTER_FK){
          groupFk = data.data.OIL_MAJOR_MASTER_FK.split(',').map(function (value) {
            return parseInt(value)
          });
        }
        data.data.OIL_MAJOR_MASTER_FK = groupFk;
        this.Groupinspector.patchValue(data.data);
        this.edit_id = id;
    })
  }

  oliMajor()
  {

    this.commonService.sendRequestToNode({method :'get',path:'inspectors/oliMajor-dropdown'}).subscribe(result => {
      if(result.status){
        this.oliMajor_dropdown = result.data;
        //console.log(this.oliMajor_dropdown);
      }
      else{
        this.oliMajor_dropdown = [];
        alert(result.message);
      }
    })
  }
  getInsectorDropDownData()
  {

    this.commonService.sendRequestToNode({method :'get',path:'inspectors/inspector-dropDown'}).subscribe(result => {
      if(result.status){
        this.inspector_dropdown = result.data;
        //console.log(this.oliMajor_dropdown);
      }
      else{
        this.inspector_dropdown = [];
        alert(result.message);
      }
    })
  }
  
  resetForm(){
    this.formSubmittedAttempt = false;
    this.openRightSidebar = false;
    this.viewData = false;
    this.edit_id = '';
    this.Groupinspector.patchValue({
      OIL_MAJOR_MASTER_FK: null,
      FNAME: null,
      LNAME: null,
      INSPECTING_COMPANY: null,
      OFFICE_TELEPHONE: null,
      MOBILE_NO: null,
      EMAIL: null,
      COMMONLY_KNOWN: null,
      COMMENTS: null, 
    })
  }

  // part of grid
  declareGridVariable(){
    this.headerInformation = [
      {
        title : 'Name',// show title table header
        //nameIcon : true,// show icon of First letter
        name:'FNAME',// name of column in data source
        width : '17%',// width of column in table
        isSortable : true,// sort by column false or true
        highlight:true, // name highlight
        isFilter:{ // filter 
          type : 'text',
          placeholder : 'Filter By Name'
        }
      },
      {
        title : 'Oil Major',// show title table header
        //nameIcon : true,// show icon of First letter
        name:'OIL_MAJOR_OFFICIAL_NAME',// name of column in data source
        width : '17%',// width of column in table
        isSortable : true,// sort by column false or true
        //highlight:true, // name highlight
        isFilter:{ // filter 
          type : 'text',
          placeholder : 'Filter By Oil Major'
        }
      },
      {
        title : 'Inspecting Company',
        name:'INSPECTING_COMPANY',
        width : '17%',
        isSortable : true,
        isFilter:{
          type : 'text',
          placeholder : 'Filter By Inspecting Company'
        }
      },
      {
        title : 'Email',
        name:'EMAIL',
        width : '17%',
        isSortable : true,
        isFilter:{
          type : 'text',
          placeholder : 'Filter By Email'
        }
      },
      {title : 'Mobile No',name:'MOBILE_NO',width : '17%',highlight:true},
      //{title : 'Commonly Known',name:'COMMONLY_KNOWN',width : '10%'},
      //{title : 'Comments',name:'COMMENTS',width : '10%'},
      {title : 'Action',name:'action',width : '15%'}
    ];
    this.actionButtons = [
      {title:'View',class : "fas fa-eye"},
      {title:'Edit',class : "far fa-edit"}
    ]
  }

  //part of grid
  clickOnAction(actionObj){
    if(actionObj.actionName == 'View'){
      this.view(actionObj.object.ID)
    }else if(actionObj.actionName == 'Edit'){
      this.edit(actionObj.object.ID)
    }
  }
  
  //part of grid
  //when change filter ,change page no . etc, 
  filter($event){
    let obj = $event;
    this.currentPage = obj.page;
    this.filterObj = obj.filter;
    this.sortFilter = obj.sort
    this.getData();
  }

  //part of grid
  funOpenRightSidebar(){
    this.openRightSidebar = true;
    this.el.nativeElement.focus();
    //$("autofoucs").scrollTop(0).perfectScrollbar('update');
  }

  getInspectorObservation(inspectorId){
    if(inspectorId){
      this.showLoaderInspectorSearch = true;
      this.commonService.sendRequestToNode({method :'post',path:'get-global-observation-of-inspector',postData : {'INSPECTOR_FK' : inspectorId}}).subscribe(result => {
        this.showLoaderInspectorSearch = false;
        if(result.status){
          this.inspectorId = inspectorId
          this.AVG_INSPECTOR_OBSERVATION = result.data[inspectorId] ? result.data[inspectorId].AVG_OBSERVATION.toFixed(2) : 0;
          this.AVG_INSPECTOR_RISK_PROFILE = result.data[inspectorId] ? result.data[inspectorId].AVG_RISK_PROFILE.toFixed(2) : 0   ;
        }
        else{
          alert(result.message);
        }
      })
    }
    else{
      alert('Please Select Inspector')
    }
  }

  clickOnInspector(){
    // let inspector_name = this.inspector_dropdown_name[this.formData[id].PLAN_INSPECTOR_FK];
    if(this.inspectorId && this.AVG_INSPECTOR_OBSERVATION){
      this.router.navigate(["/pastObservationForInspector", { inspector: this.inspectorId,fromData : 'global' }]);
    }
    
  }
    
}
