import { Component, AfterViewInit,OnInit, createPlatformFactory,ElementRef,ViewChild } from '@angular/core';
import { NgbPaginationConfig, NgbModal, NgbModalRef, ModalDismissReasons } from '@ng-bootstrap/ng-bootstrap';
import { CommonService } from '../common-service.service';
import {Router,ActivatedRoute} from "@angular/router";
import {FormGroup,FormBuilder,Validators,FormControl} from '@angular/forms';
import swal from 'sweetalert2';

declare var $: any;
import { PerfectScrollbarConfigInterface } from 'ngx-perfect-scrollbar';

@Component({
  templateUrl: './kpi-detail.component.html',
  styleUrls: ['./kpi-detail.component.scss']
})
export class KpiDetailComponent implements AfterViewInit,OnInit {

  public config: PerfectScrollbarConfigInterface = {};
  
  public kpidetailData = [];
  public kpidetailForm:FormGroup;  
  public edit_id;
  public formSubmittedAttempt = false;
  public openRightSidebar = false;
  public filterObj:any = {};
  public sortFilter:any = {};
  public showSideBarLoader = false;
  public showLoader = false;
  public kpicategory_dropdown = [];
  public withoutPaginationData = [];
  modalReference: NgbModalRef;

  //for grid 
  public headerInformation;
  public actionButtons;
  public pdfLogo;

  //for pagination
  itemsPerPage: number = this.commonService.DefaultItemsPerPage;
  totalItems: number;
  currentPage: number = 1;

  @ViewChild('autofocus') el:ElementRef;
  
 
  constructor(private modalService: NgbModal,
    private commonService: CommonService,
    private router: Router,
    private formBuilder: FormBuilder,
    private route: ActivatedRoute){
      this.declareGridVariable()
  }

  // part of grid
  declareGridVariable(){
    let goalUnitValue =['Total','Average'];
    let goalUnitOption =['Total','Average'];
    this.headerInformation = [
      {
        title : 'KPI Category',// show title table header
        nameIcon : true,// show icon of First letter
        name:'KPI_CATEGORY',// name of column in data source
        width : '20%',// width of column in table
        isSortable : true,// sort by column false or true
        isFilter:{ // filter 
          type : 'text',
          placeholder : 'Filter By KPI Category'
        }
      },
      {
        title : 'KPI',
        nameIcon : true,
        name:'KPI',
        width : '20%',// width of column in table
        isSortable : true,// sort by column false or true
        isFilter:{ // filter 
          type : 'text',
          placeholder : 'Filter By KPI'
        }
      },
      {
        title : 'Quantifier',
        nameIcon : true,
        name:'QUANTIFIER',
        width : '20%',// width of column in table
        isSortable : true,// sort by column false or true
        isFilter:{ // filter 
          type : 'text',
          placeholder : 'Filter By Quantifier'
        }
      },
      {
        title : 'Annual Goal',
        nameIcon : true,
        name:'ANNUAL_GOAL',
        width : '20%',// width of column in table
        isSortable : true,// sort by column false or true
        isFilter:{ // filter 
          type : 'text',
          placeholder : 'Filter By Annual Goal'
        }
      },
      {
        title : 'Goal Unit',
        nameIcon : true,
        name:'GOAL_UNIT',
        width : '10%',// width of column in table
        isSortable : true,// sort by column false or true
        isFilter:{ // filter 
          type : 'select',
          placeholder : 'Filter By Goal Unit',
          options_display:goalUnitValue,
          options_value:goalUnitOption  
        },
      },
      //{title : 'Shore Assignment Kpi',name:'SHORE_ASSIGNMENT_KPI',width : '30%'},
      
      {title : 'Action',name:'action',width : '20%'}
    ];
    this.actionButtons = [
      {title:'Edit',class : "far fa-edit"},
      {title:'Delete',class : "far fa-trash-alt"}
    ]
  }

  ngAfterViewInit(){
   
  }

  ngOnInit(){
    this.pdfLogo = location.origin+location.pathname+'assets/images';
    this.getData();
    this.addForm();
    this.kpidetailDropDown();
  }
  kpidetailDropDown(){
    this.commonService.sendRequestToNode({method :'get',path:'kpicategory-dropdown'}).subscribe(result => {
      if(result.status){
        this.kpicategory_dropdown = result.data;
      }
      else{
        this.kpicategory_dropdown = [];
        alert(result.message);
      }
    })
  }
  getData()
  {
    this.getDataWithoutPagination();
    let filterParams:any = {}
    let cate_name;
    let last;
    let holdLastObj:any = {}
    //search filter 
    filterParams = JSON.parse(JSON.stringify(this.filterObj));
    //search filter -end

    // pagination
    filterParams.currentPage = this.currentPage-1;
    filterParams.itemsPerPage = this.itemsPerPage;
    // pagination - end

    //sorting 
    let sortKey = Object.keys(this.sortFilter);
    if(sortKey.length && this.sortFilter[sortKey[0]]){
      filterParams.sortBy = sortKey[0];
      filterParams.sortStatus = this.sortFilter[sortKey[0]];
    }
    //sorting - end
    this.showLoader = true;
    this.commonService.sendRequestToNode({method :'get',path:'kpi-detail',queryParam:filterParams}).subscribe(result => {
      this.showLoader = false;        
        
      if(result.status)
        {
          if(result.data.length > 0){
            result.data.forEach(element => {
              element.rowspan  = 1
              cate_name = element.KPI_CATEGORY;
              // console.log(last);
              // console.log(element.KPI_CATEGORY)
              if(last == element.KPI_CATEGORY){
                element.rowspan = 0;
                holdLastObj.rowspan++;
              }
              else{
                holdLastObj = element;
                element.rowspan  = 1;
              }
              // element.vessel = this.filterObj.vessel;
              
              last = element.KPI_CATEGORY;
            });
            this.totalItems = result.data[0].total_records;
            this.kpidetailData = result.data;
          }else{
            this.kpidetailData = [];
          }
        }
        else{
          this.kpidetailData = [];
          alert(result.message);
        }
    })
  }
  getDataWithoutPagination()
  {
    let filterParams:any = {}
    let cate_name;
    let last;
    let holdLastObj:any = {}
    //search filter 
    filterParams = JSON.parse(JSON.stringify(this.filterObj));
    //search filter -end

    //sorting 
    let sortKey = Object.keys(this.sortFilter);
    if(sortKey.length && this.sortFilter[sortKey[0]]){
      filterParams.sortBy = sortKey[0];
      filterParams.sortStatus = this.sortFilter[sortKey[0]];
    }
    //sorting - end
    this.showLoader = true;
    this.commonService.sendRequestToNode({method :'get',path:'kpi-detail',queryParam:filterParams}).subscribe(result => {
      this.showLoader = false;        
        
      if(result.status)
        {
          if(result.data.length > 0){
            result.data.forEach(element => {
              element.rowspan  = 1
              cate_name = element.KPI_CATEGORY;
              // console.log(last);
              // console.log(element.KPI_CATEGORY)
              if(last == element.KPI_CATEGORY){
                element.rowspan = 0;
                holdLastObj.rowspan++;
              }
              else{
                holdLastObj = element;
                element.rowspan  = 1;
              }
              // element.vessel = this.filterObj.vessel;
              
              last = element.KPI_CATEGORY;
            });
            this.withoutPaginationData = result.data;
          }else{
            this.withoutPaginationData = [];
          }
        }
        else{
          this.withoutPaginationData = [];
          alert(result.message);
        }
    })
  } 
  addForm(){
    this.kpidetailForm = this.formBuilder.group({
      KPI_CATEGORY_FK: [undefined,[Validators.required]],
      KPI : ['',[Validators.required]],
      QUANTIFIER : [''],
      ANNUAL_GOAL : [''],
      GOAL_UNIT : ['Total']
      //SHORE_ASSIGNMENT_KPI : [0]
    });   
  }

  resetForm(){
    this.formSubmittedAttempt = false;
    this.openRightSidebar = false;
    this.edit_id = '';
    this.kpidetailForm.patchValue({
      KPI_CATEGORY_FK: undefined,
      KPI : '',
      QUANTIFIER : '',
      ANNUAL_GOAL : '',
      GOAL_UNIT : 'Total'
      //SHORE_ASSIGNMENT_KPI : 0
    })
  }

  edit(id){
    this.openRightSidebar = true;
    this.el.nativeElement.focus();
    this.commonService.sendRequestToNode({method :'get',path:'kpi-detail/'+id}).subscribe(
      data => {         
        this.kpidetailForm.patchValue({
          //KPI_CATEGORY : data.data.KPI_CATEGORY ,
          KPI_CATEGORY_FK: data.data.KPI_CATEGORY_FK,
          KPI : data.data.KPI,
          QUANTIFIER : data.data.QUANTIFIER,
          ANNUAL_GOAL : data.data.ANNUAL_GOAL,
          GOAL_UNIT : data.data.GOAL_UNIT
          //SHORE_ASSIGNMENT_KPI : data.data.SHORE_ASSIGNMENT_KPI
        })
        this.edit_id = id;
    })
  }

  delete(id){
    if(id){
      swal({
        title: 'Are you sure?',
        text: "You won't be able to revert this!",
        type: 'warning',
        showCancelButton: true,
        confirmButtonClass: 'btn btn-success',
        cancelButtonClass: 'btn btn-danger',
        confirmButtonText: 'Yes, delete it!',
         buttonsStyling: false
      }).then((result) => {
        if (result.value) {
          this.commonService.sendRequestToNode({method :'delete',path:'kpi-detail/'+id}).subscribe(
          data => {
          if(data.status){
            var dialogueTitle = "Deleted!"
            if(this.kpidetailData.length == 1 && Math.ceil(this.totalItems / this.itemsPerPage) == this.currentPage){
              if(this.currentPage>1){
                this.currentPage--;
              }
            }
            this.getData();
            swal({
                title: dialogueTitle,
                text: data.message,
                type: 'success',
                confirmButtonClass: "btn btn-success",
                buttonsStyling: false
              })
          }         
          
      })
         }
      })      
    }
  }

  onSubmit(){ 
    this.formSubmittedAttempt = true;
    if(this.kpidetailForm.valid){
    this.showSideBarLoader = true;
    if(this.edit_id){    
      this.commonService.sendRequestToNode({method :'put',path:'kpi-detail/'+this.edit_id,postData:this.kpidetailForm.value}).subscribe(
        data =>{
          var dialogueTitle = "Updated!";
          this.showSideBarLoader = false;
          if(data.status){
            swal({
                title: dialogueTitle,
                text: data.message,
                type: 'success',
                confirmButtonClass: "btn btn-success",
                buttonsStyling: false
              })
            this.getData();
            this.resetForm(); //after edit form is reset
          }
          else{
            alert(data.message);
          }
      })
    }else{
      this.commonService.sendRequestToNode({method :'post',path:'kpi-detail',postData:this.kpidetailForm.value}).subscribe(
        data =>{
          var dialogueTitle = "Inserted!";
          this.showSideBarLoader = false;
          if(data.status){
            swal({
                title: dialogueTitle,
                text: data.message,
                type: 'success',
                confirmButtonClass: "btn btn-success",
                buttonsStyling: false
              })
            this.getData();
            this.resetForm(); //after edit form is reset

          }
          else{
            alert(data.message);
          }
      })
    }
    }
      
  } 

    //part of grid
    clickOnAction(actionObj){
      if(actionObj.actionName == 'Edit'){
        this.edit(actionObj.object.ID)
      }else if(actionObj.actionName == 'Delete'){
        this.delete(actionObj.object.ID)
      }
    }
  
    //part of grid
    //when change filter ,change page no . etc, 
    filter($event){
      let obj = $event;
      this.currentPage = obj.page;
      this.filterObj = obj.filter;
      this.sortFilter = obj.sort
      this.getData();
    }
  
    //part of grid
    funOpenRightSidebar(){
      this.openRightSidebar = true;
      this.el.nativeElement.focus();
    }
  
    generatePdf(){
      var data = document.getElementById('htmlToString').innerHTML;
      // console.log(JSON.stringify(data));
      // console.log(data);
      var htmlData = {'data':data,};
      this.commonService.sendRequestToNode({ method: 'post', path: 'kpi-detail/generatePDFData',postData:htmlData }).subscribe(result => {
        if(result.status){  
          window.location.href = this.commonService.getNodeApi()+'/kpi-detail-exportPDF';
        }  
      })
    }
}

