import { Component, AfterViewInit, OnInit, createPlatformFactory, ElementRef, ViewChild } from '@angular/core';
import { NgbPaginationConfig, NgbModal, NgbModalRef, ModalDismissReasons } from '@ng-bootstrap/ng-bootstrap';
import { CommonService } from '../common-service.service';
import { Router, ActivatedRoute } from "@angular/router";
import { FormGroup, FormBuilder, Validators, FormControl } from '@angular/forms';
import swal from 'sweetalert2';
//import { parse } from 'path';

declare var $: any;
import { PerfectScrollbarConfigInterface } from 'ngx-perfect-scrollbar';

@Component({
  templateUrl: './linkVessel.component.html',
  styleUrls: ['./linkVessel.component.scss']
})
export class LinkVesselComponent implements AfterViewInit, OnInit {



  public config: PerfectScrollbarConfigInterface = {};

  options = {
    theme: 'light', // two possible values: light, dark
    dir: 'ltr', // two possible values: ltr, rtl
    layout: 'vertical', // fixed value. shouldn't be changed.
    sidebartype: 'mini-sidebar', // four possible values: full, iconbar, overlay, mini-sidebar 
    sidebarpos: 'fixed', // two possible values: fixed, absolute
    headerpos: 'fixed', // two possible values: fixed, absolute
    boxed: 'full', // two possible values: full, boxed
    navbarbg: 'skin6', // six possible values: skin(1/2/3/4/5/6)
    sidebarbg: 'skin5', // six possible values: skin(1/2/3/4/5/6)
    logobg: 'skin5' // six possible values: skin(1/2/3/4/5/6)
  };

  public GrouplinkVessel: FormGroup;
  public linkVessels = [];
  public linkVessels_view;
  public chapter_dropdown = [];
  public subtopic_dropdown = [];
  public edit_id;
  public id;
  public no_ships;
  public veesel = { 'LINK': {}, 'UNLINK': {}, 'IMO': {} };
  public selection_counter = Object.keys(this.veesel.LINK).length;
  public veesel_link_data = {};
  public template_name;
  public formSubmittedAttempt = false;
  public openRightSidebar = false;
  public viewData = false;
  public filterObj: any = {};
  public sortFilter: any = {};

  //for grid 
  public headerInformation;
  public actionButtons;

  //for pagination
  itemsPerPage: number = this.commonService.DefaultItemsPerPage;
  totalItems: number;
  currentPage: number = 1;

  @ViewChild('autofocus') el: ElementRef;

  constructor(private modalService: NgbModal,
    private commonService: CommonService,
    private router: Router,
    private formBuilder: FormBuilder,
    private route: ActivatedRoute) {
    // this.declareGridVariable()
  }

  ngAfterViewInit() {

  }

  ngOnInit() {

    this.route.params.subscribe(params => {
      this.id = params['id'];
      this.no_ships = params['ships'];
      this.veesel['SUB_ID'] = this.id;
    });

    this.commonService.sendRequestToNode({ method: 'get', path: 'linkVessel/getById/' + this.id }).subscribe(result => {
      if (result.status) {
        // this.inspectors_view = result.data;
        for (var i = 0; i < result.data.length; i++) {
          this.veesel['LINK'][result.data[i].ID] = true;
          this.veesel['IMO'][result.data[i].ID] = result.data[i].IMO_NO;
        }
       
        this.selection_counter = Object.keys(this.veesel.LINK).length
      }
      else {
        alert(result.message)
      }
    })

    this.getData();
    this.addForm();

  }


  addForm() {
    this.GrouplinkVessel = this.formBuilder.group({
      SUBSCRIPTION_START_DATE: ['', [Validators.required]],
      SUBSCRIPTION_END_DATE: ['', [Validators.required]],
      NUMBER_OF_SHIPS: ['', [Validators.required]],
      AMOUNT: [],
      USER_FK: []
    });
  }

  addLinkData(vessel_id, value, imo_number) {
    if (value == true) {
      this.veesel['LINK'][vessel_id] = true;
      this.veesel['IMO'][vessel_id] = imo_number;
      delete this.veesel['UNLINK'][vessel_id];
    } else {
      delete this.veesel['LINK'][vessel_id];
      delete this.veesel['IMO'][vessel_id];
      this.veesel['UNLINK'][vessel_id] = true;
    }
    this.selection_counter = Object.keys(this.veesel.LINK).length
  }
  saveLinkData() {
    if (this.no_ships < this.selection_counter) {
      swal({
        title: 'Quota exceeded',
        text: 'You exceed Quota of active vessels, Limit of Active Vessels is : ' + this.no_ships + ', You selected ' + this.selection_counter + ' vessels.',
        type: 'warning',
        confirmButtonClass: "btn btn-success",
        buttonsStyling: false
      })
    }else if(this.selection_counter < 1){
      swal({
        title: 'Missing Selection',
        text: 'You have not selectd any vessels.',
        type: 'warning',
        confirmButtonClass: "btn btn-success",
        buttonsStyling: false
      })
    } else {
      this.commonService.sendRequestToNode({ method: 'post', path: 'linkVessel/add', postData: this.veesel }).subscribe(
        data => {
          var dialogueTitle = "Inserted!";
          if (data.status) {
            swal({
              title: dialogueTitle,
              text: data.message,
              type: 'success',
              confirmButtonClass: "btn btn-success",
              buttonsStyling: false
            })
            this.getData();
            this.openRightSidebar = false;
            this.resetForm();
          } else {
            alert(data.message);
          }
        });
    }

  }
  // onSubmit(){
  //   //console.log(this.edit_id);
  //   this.formSubmittedAttempt = true;
  //   if(this.GrouplinkVessel.valid){
  //     if(this.edit_id){
  //       this.commonService.sendRequestToNode({method :'post',path:'linkVessel/edit/'+this.edit_id,postData:this.GrouplinkVessel.value}).subscribe(
  //         data =>{
  //           var dialogueTitle = "Updated!";
  //           if(data.status){
  //             swal({
  //               title: dialogueTitle,
  //               text: data.message,
  //               type: 'success',
  //               confirmButtonClass: "btn btn-success",
  //               buttonsStyling: false
  //             })
  //             this.getData();
  //             this.openRightSidebar = false;
  //             this.resetForm();
  //           }else{
  //             alert(data.message);
  //           }
  //       })
  //     }else{
  //       // console.log('test');
  //       this.GrouplinkVessel.patchValue({
  //         USER_FK : this.user_id
  //       });
  //       console.log(this.GrouplinkVessel.value);
  //       this.commonService.sendRequestToNode({method :'post',path:'linkVessel/add',postData:this.GrouplinkVessel.value}).subscribe(
  //         data =>{
  //           var dialogueTitle = "Inserted!";
  //           if(data.status){
  //             swal({
  //               title: dialogueTitle,
  //               text: data.message,
  //               type: 'success',
  //               confirmButtonClass: "btn btn-success",
  //               buttonsStyling: false
  //             })
  //             this.getData();
  //             this.openRightSidebar = false;
  //             this.resetForm();
  //           }else{
  //             alert(data.message);
  //           }
  //       })
  //     }
  //   }  
  // }

  getData() {
    // alert('test');
    let filterParams: any = {}

    //search filter 
    filterParams = JSON.parse(JSON.stringify(this.filterObj));
    //search filter -end

    // pagination
    filterParams.currentPage = this.currentPage - 1;
    filterParams.itemsPerPage = this.itemsPerPage;

    // pagination - end

    //sorting 
    let sortKey = Object.keys(this.sortFilter);
    if (sortKey.length && this.sortFilter[sortKey[0]]) {
      filterParams.sortBy = sortKey[0];
      filterParams.sortStatus = this.sortFilter[sortKey[0]];
    }
    //sorting - end

    this.commonService.sendRequestToNode({ method: 'get', path: 'linkVessel/data_list/'+this.id, queryParam: filterParams }).subscribe(result => {
      if (result.status) {

        if (result.data.length > 0) {
          this.totalItems = result.data[0].total_records;
          this.linkVessels = result.data;
          // console.log(this.linkVessels);
        } else {
          this.linkVessels = [];
        }
      }
      else {
        this.linkVessels = [];
        alert(result.message);
      }
    })
  }



  resetForm() {
    this.formSubmittedAttempt = false;
    this.openRightSidebar = false;
    this.viewData = false;
    this.edit_id = '';
    this.GrouplinkVessel.patchValue({
      SUBSCRIPTION_START_DATE: '',
      SUBSCRIPTION_END_DATE: '',
      NUMBER_OF_SHIPS: '',
      AMOUNT: ''

    })
  }

  filter($event) {
    let obj = $event;
    this.currentPage = obj.page;
    this.filterObj = obj.filter;
    this.sortFilter = obj.sort
    this.getData();
  }

  //part of grid
  funOpenRightSidebar() {
    this.openRightSidebar = true;
    this.el.nativeElement.focus();
  }




}
