import { Component, AfterViewInit,OnInit, createPlatformFactory,ElementRef,ViewChild } from '@angular/core';
import { NgbPaginationConfig, NgbModal, NgbModalRef, ModalDismissReasons } from '@ng-bootstrap/ng-bootstrap';
import { CommonService } from '../common-service.service';
import {Router,ActivatedRoute} from "@angular/router";
import {FormGroup,FormBuilder,Validators,FormControl} from '@angular/forms';
import swal from 'sweetalert2';
//import { parse } from 'path';

declare var $: any;
import { PerfectScrollbarConfigInterface } from 'ngx-perfect-scrollbar';

@Component({
  templateUrl: './observation.component.html',
  styleUrls: ['./observation.component.scss']
})
export class ObservationComponent implements AfterViewInit,OnInit {
  public docPath = this.commonService.getDocumentPath()+'/sireReport';
  public config: PerfectScrollbarConfigInterface = {};

  options = {
    theme: 'light', // two possible values: light, dark
    dir: 'ltr', // two possible values: ltr, rtl
    layout: 'vertical', // fixed value. shouldn't be changed.
    sidebartype: 'mini-sidebar', // four possible values: full, iconbar, overlay, mini-sidebar 
    sidebarpos: 'fixed', // two possible values: fixed, absolute
    headerpos: 'fixed', // two possible values: fixed, absolute
    boxed: 'full', // two possible values: full, boxed
    navbarbg: 'skin6', // six possible values: skin(1/2/3/4/5/6)
    sidebarbg: 'skin5', // six possible values: skin(1/2/3/4/5/6)
    logobg: 'skin5' // six possible values: skin(1/2/3/4/5/6)
  };
  public grid_title;
  public grid_subtitle;
  public VIQ_REFArray = [];
  public reportBasicInformation:any = {
    REPORT_NUMBER : null,
    IMO_NUMBER : null,
    PORT_OF_INSPECTION : null,
    DATE_OF_INSPECTION : null,
    INSPECTING_COMPANY : null,
  };
  public ObservationForm:FormGroup;
  public observationQuestionList = [];
  public observation_view:any = {};
  public edit_id;
  public file_upload;
  public formSubmittedAttempt = false;
  public openRightSidebar = false;
  public showSideBarLoader = false;
  public showLoader = false;
  public viewData = false;
  public viewObject = {};
  public filterObj:any = {};
  public sortFilter:any = {};
  public risk_profile = {
    1 : 'Low Risk',
    2 : 'Medium Risk',
    3 : 'High Risk',
    4 : 'Very High Risk'
  }

  public pdfLogo;
  public withoutPaginationData = [];

  public operator_comments_array:any = [{val:''}];
  public other_inspector_comments_array:any = [{val:''}];

  //for grid 
  public headerInformation;
  public actionButtons;
  public reportId;
  //for pagination
  itemsPerPage: number = this.commonService.DefaultItemsPerPage;
  totalItems: number;
  currentPage: number = 1;

  @ViewChild('autofocus') el:ElementRef;

  constructor(private modalService: NgbModal,
    private commonService: CommonService,
    private router: Router,
    private formBuilder: FormBuilder,
    private route: ActivatedRoute){

    this.route.params.subscribe(params => {
      this.reportId = params['reportId'];
      this.getReportDetail(this.reportId);
    });
    this.declareGridVariable();
  }
  
  ngAfterViewInit(){
   
  }

  ngOnInit(){
    this.pdfLogo = location.origin+location.pathname+'assets/images';
    this.getObservationList();
    this.getDataWithoutPagination();
    this.addForm();

    //this.editForm();
  }

  getReportDetail(reportId){
    this.commonService.sendRequestToNode({method :'get',path:'get-sire-report/'+reportId}).subscribe(result => {
      if(result.status)
      {
        if(result.data){
          this.reportBasicInformation = result.data;

          this.grid_title = this.reportBasicInformation.VESSEL_NAME;

          let dateoi = new Date(this.reportBasicInformation.DATE_OF_INSPECTION);
          this.reportBasicInformation.DATE_OF_INSPECTION = ('0' + (dateoi.getDate())).slice(-2)+'/'+('0' + (dateoi.getMonth()+1)).slice(-2)+'/'+dateoi.getFullYear();
          this.grid_subtitle = '<span>Report Number :</span><label class="label label-danger">'+(this.reportBasicInformation.REPORT_NUMBER ? this.reportBasicInformation.REPORT_NUMBER : "N/A")+'</label>';
          this.grid_subtitle += '<span>Vessel IMO :</span><label class="label label-info">'+(this.reportBasicInformation.IMO_NUMBER ? this.reportBasicInformation.IMO_NUMBER : "N/A")+'</label>';
          this.grid_subtitle += '<span>Port :</span><label class="label label-success">'+(this.reportBasicInformation.PORT_OF_INSPECTION ?  this.reportBasicInformation.PORT_OF_INSPECTION : "N/A")+'</label>';
          this.grid_subtitle += '<span>Date of Inspection :</span><label class="label label-warning">'+(this.reportBasicInformation.DATE_OF_INSPECTION ? this.reportBasicInformation.DATE_OF_INSPECTION : "N/A")+'</label>';
          this.grid_subtitle += '<span>Oil Major :</span><label class="label label-purple">'+(this.reportBasicInformation.INSPECTING_COMPANY ? this.reportBasicInformation.INSPECTING_COMPANY : "N/A")+'</label>'; 
          this.getQuestionList(this.reportBasicInformation.SIRE_FK)
        }
      }
      else{
        alert(result.message);
        this.router.navigate(['sire_report'])
      }
  })
  }

  addForm(){
    this.ObservationForm = this.formBuilder.group({
      REPORT_NUMBER: [null],
      REPORT_FK: [this.reportId],
      VESSEL_FK : [null],
      VIQ_REF: [null,[Validators.required]],
      INITIAL_RISK: [null,],
      FINAL_RISK: [null,],
      VIQ_QUESTIONS: [null,[Validators.required]],
      VIQ_QUESTIONS_ID: [null],
      INSPECTOR_OBSERVATION: [null,[Validators.required]],
      INSPECTOR_COMMENTS : [[]],
      OPERATOR_COMMENTS: [[]],
      FILE : [null]
    });   
  }

  onFileChange(event) {
    if(event.target.files.length > 0) {
      let file = event.target.files[0];
       this.ObservationForm.get('FILE').setValue(file);
    }
  }

  getQuestionList(sireId){
      this.commonService.sendRequestToNode({method :'get',path:'questionnaire/get-questionNo/'+sireId}).subscribe(result => {
        if(result.status)
        {
     
          this.VIQ_REFArray = result.data
        }
        else{
          alert(result.message)
        }
    })
  }

  getQuestionDetail(){
    let questionNo = this.ObservationForm.get('VIQ_REF').value;
    // alert(questionNo)
    let sireId = this.reportBasicInformation.SIRE_FK;
    if(questionNo && sireId ){
        this.commonService.sendRequestToNode({method :'get',path:'questionnaire/get-question-detail/'+questionNo+'/'+sireId}).subscribe(result => {
          if(result.status)
          {
         
            this.ObservationForm.patchValue({
              'VIQ_QUESTIONS_ID' : result.data.ID,
              'VIQ_QUESTIONS' : result.data.QUESTION_DESCRIPTION,
              'INITIAL_RISK' : result.data.RISK_PROFILE,
              'FINAL_RISK' : result.data.COMPANY_RISK_PROFILE
            })
          }
          else{
            alert(result.message)
          }
      })
    }
    
  }

  edit(obj){
      this.openRightSidebar = true;
      this.el.nativeElement.focus(); 
     
      this.edit_id = obj.ID;
      this.commonService.sendRequestToNode({method :'get',path:'get-all-observation/'+obj.ID}).subscribe(result => {
          if(result.status)
          {
            this.other_inspector_comments_array = [];
            this.operator_comments_array = [];

            let questionReportObj =  result.questionReport[0];
            // this.observation_view.inspector_comment = [];
            // this.observation_view.inspector_observation
            let inspector_observation = '';
            result.observationArr.forEach(element => {
              if(element.TYPE == '3'){
                inspector_observation = element.COMMENTS
              }
              else if(element.TYPE == '1'){
                this.other_inspector_comments_array.push({val:element.COMMENTS})
              }
              else{
                this.operator_comments_array.push({val:element.COMMENTS})
              }
            });
            if(this.other_inspector_comments_array.length == 0){
              this.other_inspector_comments_array = [{val:''}];
            }
            if(this.operator_comments_array.length == 0){
              this.operator_comments_array = [{val:''}];
            }
            
            this.ObservationForm.patchValue({
              REPORT_FK: questionReportObj.REPORT_FK,
              VIQ_REF: questionReportObj.QUESTION_NUMBER,
              INITIAL_RISK: questionReportObj.INITIAL_RISK_PROFILE,
              FINAL_RISK: questionReportObj.FINAL_RISK_PROFILE,
              VIQ_QUESTIONS: questionReportObj.QUESTION_DESCRIPTION,
              VIQ_QUESTIONS_ID: questionReportObj.QUESTIONNAIR_FK,
              INSPECTOR_OBSERVATION: inspector_observation,
              INSPECTOR_COMMENTS : [],
              OPERATOR_COMMENTS: [],
            });
            this.file_upload = questionReportObj.FILE;
          }
          else{
            alert(result.message)
          }
      })
    // this.openRightSidebar = true;
    // this.el.nativeElement.focus(); 
    // this.commonService.sendRequestToNode({method :'get',path:'vessel-owner/getById/'+id}).subscribe(
    //   data => { 
    //     console.log(data);
        
    //     this.edit_id = id;
    // })
  }

  onSubmit(){
    //console.log(this.edit_id);
   
    // console.log(this.ObservationForm.value);return false;
    this.formSubmittedAttempt = true;
    if(this.ObservationForm.valid){

    this.showSideBarLoader = true;

      this.ObservationForm.patchValue({
        REPORT_NUMBER : this.reportBasicInformation.REPORT_NUMBER,
        VESSEL_FK : this.reportBasicInformation.VESSEL_FK,
        OPERATOR_COMMENTS :this.operator_comments_array,
        INSPECTOR_COMMENTS : this.other_inspector_comments_array
      })

      let formData = new FormData();
      formData.append('FILE',this.ObservationForm.get('FILE').value );
      formData.append('postData',JSON.stringify(this.ObservationForm.value) );
      if(this.edit_id){
        
        this.commonService.sendRequestToNode({method :'put',path:'edit-observation/'+this.edit_id,postData:formData}).subscribe(
          data =>{
            
            var dialogueTitle = "Updated!";
            this.showSideBarLoader = false;
            if(data.status){
              swal({
                title: dialogueTitle,
                text: data.message,
                type: 'success',
                confirmButtonClass: "btn btn-success",
                buttonsStyling: false
              })
              this.getObservationList();
              this.openRightSidebar = false;
              this.resetForm();
            }else{
              alert(data.message);
            }
        })
      }else{
        this.commonService.sendRequestToNode({method :'post',path:'add-observation',postData:formData}).subscribe(
          data =>{
            var dialogueTitle = "Inserted!";
            this.showSideBarLoader = false;
            if(data.status){
              swal({
                title: dialogueTitle,
                text: data.message,
                type: 'success',
                confirmButtonClass: "btn btn-success",
                buttonsStyling: false
              })
              this.getObservationList();
              this.openRightSidebar = false;
              this.resetForm();
            }else{
              alert(data.message);
            }
        })
      }
      
    }  
  }

  getObservationList()
  {
    let filterParams:any = {}
    
    //search filter 
    filterParams = JSON.parse(JSON.stringify(this.filterObj));
    //search filter -end

    // pagination
    filterParams.currentPage = this.currentPage-1;
    filterParams.itemsPerPage = this.itemsPerPage;
    // pagination - end

    //sorting 
    let sortKey = Object.keys(this.sortFilter);
    if(sortKey.length && this.sortFilter[sortKey[0]]){
      filterParams.sortBy = sortKey[0];
      filterParams.sortStatus = this.sortFilter[sortKey[0]];
    }
    //sorting - end
    this.showLoader = true;
    this.commonService.sendRequestToNode({method :'get',path:'get-all-question/'+this.reportId,queryParam:filterParams}).subscribe(result => {
      this.showLoader = false;  
      if(result.status)
        {
          if(result.data.length > 0){
            this.totalItems = result.data[0].total_records;
            this.observationQuestionList = result.data;
          }else{
            this.observationQuestionList = [];
          }
        }
        else{
          this.observationQuestionList = [];
          alert(result.message);
        }
    })
  }

  delete(id){
    if (id) {
      
      swal({
        title: 'Are you sure?',
        text: "You won't be able to revert this!",
        type: 'warning',
        showCancelButton: true,
        confirmButtonClass: 'btn btn-success',
        cancelButtonClass: 'btn btn-danger',
        confirmButtonText: 'Yes, delete it!',
        buttonsStyling: false
        
        }).then((result) => {
          if (result.value) {   
            this.commonService.sendRequestToNode({method :'delete',path:'question_observation/delete/'+id,queryParam : {VESSEL_FK:this.reportBasicInformation.VESSEL_FK}}).subscribe(result => {
              if(result.status){
                var dialogueTitle = "Deleted!"
                if(this.observationQuestionList.length == 1 && Math.ceil(this.totalItems / this.itemsPerPage) == this.currentPage){
                  if(this.currentPage>1){
                    this.currentPage--;
                  }
                }
                this.getObservationList();
                swal({
                    title: dialogueTitle,
                    text: result.message,
                    type: 'success',
                    confirmButtonClass: "btn btn-success",
                    buttonsStyling: false
                  })
              }
            })
          }
        })
    }
  }

  view(obj){
    this.viewData = true;
    this.openRightSidebar = true;
    this.showSideBarLoader = true;
    this.el.nativeElement.focus(); 
    //console.log(id);
    
    this.commonService.sendRequestToNode({method :'get',path:'get-all-observation/'+obj.ID}).subscribe(result => {
    this.showSideBarLoader = false;      
      if(result.status)
        {
          this.viewObject =  result.questionReport[0];
          this.observation_view.inspector_observation = '';
          this.observation_view.inspector_comment = [];
          this.observation_view.operator_comments = [];
          
          result.observationArr.forEach(element => {
            if(element.TYPE == '3'){
              this.observation_view.inspector_observation = element.COMMENTS
            }
            else if(element.TYPE == '1'){
              this.observation_view.inspector_comment.push(element.COMMENTS)
            }
            else{
              this.observation_view.operator_comments.push(element.COMMENTS)
            }
          });
        }
        else{
          alert(result.message)
        }
    })
  }

  resetForm(){
    this.formSubmittedAttempt = false;
    this.openRightSidebar = false;
    this.viewData = false;
    this.edit_id = '';
    this.operator_comments_array = [{val:''}];
    this.other_inspector_comments_array = [{val:''}];
    this.ObservationForm.patchValue({
      VIQ_REF: null,
      INITIAL_RISK: null,
      FINAL_RISK : null,
      VIQ_QUESTIONS: null,
      VIQ_QUESTIONS_ID: null,
      INSPECTOR_OBSERVATION: null,
      INSPECTOR_COMMENTS : '',
      OPERATOR_COMMENTS: '', 
      
    })
  }

  // part of grid
  declareGridVariable(){
    
    this.headerInformation = [
      {
        title : 'VIQ Ref',// show title table header
        name:'QUESTION_NUMBER',// name of column in data source
        width : '10%',// width of column in table
        highlight:true, // name highlight
        isFilter:{ // filter 
          type : 'text',
          placeholder : 'Filter By VIQ Ref'
        }
      },
      {
        title : 'Question Description',// show title table header
        name:'QUESTION_DESCRIPTION',// name of column in data source
        width : '30%',// width of column in table
        isSortable : true,// sort by column false or true
        //highlight:true, // name highlight
        isFilter:{ // filter 
          type : 'text',
          placeholder : 'Filter By Question'
        }
      },
      {
        title : 'Inspector Observation',// show title table header
        name:'INSPECTOR_OBSERVATION',// name of column in data source
        width : '30%',// width of column in table
        isSortable : true,// sort by column false or true
        //highlight:true, // name highlight
        isFilter:{ // filter 
          type : 'text',
          placeholder : 'Filter By Observation'
        }
      },
      // {
      //   title : 'Initial Risk Profile',// show title table header
      //   name:'INITIAL_RISK_PROFILE',// name of column in data source
      //   width : '10%',// width of column in table
      //   display_value:this.risk_profile,
      // },
      {
        title : 'Risk Profile',// show title table header
        name:'FINAL_RISK_PROFILE',// name of column in data source
        width : '10%',// width of column in table
        display_value:this.risk_profile
      },
      // {title : '',name:'',width : '5%'},
      {title : 'Action',name:'action',width : '20%'}
    ];
    this.actionButtons = [
      {title:'View',class : "fas fa-eye"},
      {title:'Edit',class : "far fa-edit"},
      {title:'Delete',class : "far fa-trash-alt"}
    ]
  }

  //part of grid
  clickOnAction(actionObj){
    if(actionObj.actionName == 'View'){
      this.view(actionObj.object);
    }else if(actionObj.actionName == 'Edit'){
      this.edit(actionObj.object);
    }else if(actionObj.actionName == 'Delete'){
      this.delete(actionObj.object.ID);
    }
  }

  
  
  //part of grid
  //when change filter ,change page no . etc, 
  filter($event){
    let obj = $event;
    this.currentPage = obj.page;
    this.filterObj = obj.filter;
    this.sortFilter = obj.sort
    this.getObservationList();
  }

  //part of grid
  funOpenRightSidebar(){
    this.openRightSidebar = true;
    this.el.nativeElement.focus(); 
  }

  addMoreComment(){
    this.operator_comments_array.push({val:''});
  }

  removeMoreComment(i){
    this.operator_comments_array.forEach((val,key)=>{
      if((key+1) == this.operator_comments_array.length){
        this.operator_comments_array.pop();
        return false;  
      }
      if((key+1) > i){
        this.operator_comments_array[key].val =  this.operator_comments_array[key+1].val
      }
    })
  }

  addOtherInspector(){
    this.other_inspector_comments_array.push({val:''});
  }

  removeFromOtherInspector(i){
    this.other_inspector_comments_array.forEach((val,key)=>{
      if((key+1) == this.other_inspector_comments_array.length){
        this.other_inspector_comments_array.pop();
        return false;  
      }
      if((key+1) > i){
        this.other_inspector_comments_array[key].val =  this.other_inspector_comments_array[key+1].val
      }
    })
  }

  getDataWithoutPagination()
  {
    let filterParams:any = {}
    
    //search filter 
    filterParams = JSON.parse(JSON.stringify(this.filterObj));
    //search filter -end

    //sorting 
    let sortKey = Object.keys(this.sortFilter);
    if(sortKey.length && this.sortFilter[sortKey[0]]){
      filterParams.sortBy = sortKey[0];
      filterParams.sortStatus = this.sortFilter[sortKey[0]];
    }
    //sorting - end
    this.showLoader = true;
    this.commonService.sendRequestToNode({method :'get',path:'get-all-question/'+this.reportId,queryParam:filterParams}).subscribe(result => {
      this.showLoader = false;  
      if(result.status)
        {
          if(result.data.length > 0){
            this.totalItems = result.data[0].total_records;
            this.withoutPaginationData = result.data;
          }else{
            this.withoutPaginationData = [];
          }
        }
        else{
          this.withoutPaginationData = [];
          alert(result.message);
        }
    })
  }

  getDataforcsv() {
    this.generatcsv();
  }

  generatcsv(){
    let postObj = {
      data : this.withoutPaginationData,
      detail : {
        REPORT_NUMBER : this.reportBasicInformation.REPORT_NUMBER,
        IMO_NUMBER : this.reportBasicInformation.IMO_NUMBER,
        PORT_OF_INSPECTION : this.reportBasicInformation.PORT_OF_INSPECTION,
        DATE_OF_INSPECTION : this.reportBasicInformation.DATE_OF_INSPECTION,
        INSPECTING_COMPANY : this.reportBasicInformation.INSPECTING_COMPANY,
      }
    }
    this.commonService.sendRequestToNode({method :'post',path:'sireReport/generateCSVData',postData:postObj}).subscribe(result => {
      if(result.status){
        window.open(this.commonService.getNodeApi()+'/sireReport/exportCSVObs', '_blank' );
      }
    })
  }

  generatePdf(){
    var data = document.getElementById('htmlToString').innerHTML;
    // console.log(JSON.stringify(data));
    // console.log(data);
    var htmlData = {'data':data};
    this.commonService.sendRequestToNode({ method: 'post', path: 'observation/generatePDFData',postData:htmlData }).subscribe(result => {
      if(result.status){
        window.location.href = this.commonService.getNodeApi()+'/observation/exportPDF';
      }
    })
  }



}
