import { Component, AfterViewInit,OnInit, createPlatformFactory,ElementRef,ViewChild } from '@angular/core';
import { NgbPaginationConfig, NgbModal, NgbModalRef, ModalDismissReasons } from '@ng-bootstrap/ng-bootstrap';
import { CommonService } from '../common-service.service';
import {Router,ActivatedRoute} from "@angular/router";
import {FormGroup,FormBuilder,Validators,FormControl} from '@angular/forms';
import { saveAs } from 'file-saver';
import swal from 'sweetalert2';
import html2canvas from 'html2canvas';
declare var $: any;
import { PerfectScrollbarConfigInterface } from 'ngx-perfect-scrollbar';
import { element } from 'protractor';
import { json } from 'd3';
import { NUMBER_FORMAT_REGEXP } from '@angular/common/src/i18n/format_number';
import * as pluginAnnotations from 'chartjs-plugin-annotation';

@Component({
  selector: 'office-kpi-report',
  // selector: 'app-root',
  templateUrl: './office-kpi-report.component.html',
  styleUrls: ['./office-kpi-report.component.scss']
})
export class OfficeKpiReportComponent implements OnInit {

  public modalRef:NgbModalRef;
  public kpireportTypeForm:FormGroup;
  public kpireportTypeFormSubmittedAttempt = false;
  public config: PerfectScrollbarConfigInterface = {};
  public uploadPath = this.commonService.getDocumentPath(); 
  public kpireportData = [];
  public kpireportListPerMonth = [];
  public kpireportForm:FormGroup; 
  
  public edit_id;
  public editData;
  public formSubmittedAttempt = false;
  public openRightSidebar = false;
  public filterObj:any = {year : new Date().getFullYear(),type : []};
  public sortFilter:any = {};
  public viewData = false;
  public showSideBarLoader = false;
  public OLD_USER_FK:any //this is for edit
  public vessel_dropdown = [];
  public vessel_dropdown_name = {};
  public attachmentDisplayData:any = [];
  public showMainLoader = false;
  public showModalLoader = false;
  public showLoader = false;
  public monthArr = ['JANUARY','FEBRUARY','MARCH','APRIL','MAY','JUNE','JULY','AUGUST','SEPTEMBER','OCTOBER','NOVEMBER','DECEMBER'];
  //this is for file select object 
  public ObjPerFile:any = {}
  public withoutPaginationData = [];
  public pdfLogo;

  public lineChartData: Array<any> = [];
  public lineChartLabels: Array<any> = [];
  public lineChartLegend = true;
  public lineChartType = 'bar';
  public lineChartPlugins = [pluginAnnotations];
  // public yearFilter = new Date().getFullYear();
  public lineChartOptions: any = {
    title: {
      text: 'Office KPI Report ',
      display: true,
      position: 'bottom'
    },
    plugins: {
      labels: {
        // render 'label', 'value', 'percentage', 'image' or custom function, default is 'percentage'
        render: 'value',

        // precision for percentage, default is 0
        precision: 0,

        // identifies whether or not labels of value 0 are displayed, default is false
        showZero: false,

        // font size, default is defaultFontSize
        fontSize: 10,

        // font color, can be color array for each data or function for dynamic color, default is defaultFontColor
        fontColor: '#000',

        // font style, default is defaultFontStyle
        fontStyle: 'normal',

        // font family, default is defaultFontFamily
        fontFamily: "'Helvetica Neue', 'Helvetica', 'Arial', sans-serif",

        // draw text shadows under labels, default is false
      //   textShadow: true,

        // text shadow intensity, default is 6
      //   shadowBlur: 10,

        // text shadow X offset, default is 3
        shadowOffsetX: -5,

        // text shadow Y offset, default is 3
        shadowOffsetY: 5,

        // text shadow color, default is 'rgba(0,0,0,0.3)'
        shadowColor: 'rgba(255,0,0,0.75)',

        // draw label in arc, default is false
        // bar chart ignores this
        arc: true,

        // position to draw label, available value is 'default', 'border' and 'outside'
        // bar chart ignores this
        // default is 'default'
        position: 'default',

        // draw label even it's overlap, default is true
        // bar chart ignores this
        overlap: true,

        // show the real calculated percentages from the values and don't apply the additional logic to fit the percentages to 100 in total, default is false
        showActualPercentages: true,

        

        // add padding when position is `outside`
        // default is 2
        outsidePadding: 4,

        // add margin of text when position is `outside` or `border`
        // default is 2
        textMargin: 2
      }
    },
    scales: {
      xAxes: [{
        scaleLabel: {
          display: true,
          labelString: 'KPI'
        }
      }],
      yAxes: [{
        scaleLabel: {
            display: true,
            labelString: 'Annual Goal'
        }
      }]
    },
  }

  //this is for store ids when click on box
  public dataForIds :any = {};

  //for grid 
  public headerInformation;
  public actionButtons;
  
  public txt = '';
  
  //for pagination
  itemsPerPage: number = this.commonService.DefaultItemsPerPage;
  totalItems: number;
  currentPage: number = 1;

  @ViewChild('content') content: ElementRef;
  @ViewChild('fileInput') fi:ElementRef;
  @ViewChild('autofocus') el:ElementRef;

  @ViewChild('screen') screen: ElementRef;
  @ViewChild('canvas') canvas: ElementRef;
  @ViewChild('downloadLink') downloadLink: ElementRef;

  constructor(private modalService: NgbModal,
    private commonService: CommonService,
    private router: Router,
    private formBuilder: FormBuilder,
    private route: ActivatedRoute){
      // this.declareGridVariable();
  }


  ngOnInit(){
    this.pdfLogo = location.origin+location.pathname+'assets/images';
    this.vesselDropDown();
    this.getChartData();
  }

  vesselDropDown(){
    this.commonService.sendRequestToNode({method :'get',path:'department-dropdown'}).subscribe(result => {
      if(result.status){
        
        this.vessel_dropdown = [{DEPARTMENT : 'All Departments',ID : 'ALL'},...result.data];
        result.data.forEach((val) => {
          this.vessel_dropdown_name[val.ID] = val.DEPARTMENT;
        });

        console.log(this.vessel_dropdown);
      }
      else{
        this.vessel_dropdown = [];
        alert(result.message);
      }
    })
    
  }
  
  getData()
  {
    //this.getDataWithoutPagination();
    this.showLoader = true;
    let filterParams:any = {}
    
    //search filter 
    filterParams = JSON.parse( JSON.stringify(this.filterObj) );
    // alert(this.filterObj.vessel)
    let data = {};
    this.kpireportData = [];
    let cate_name;
    let pdf_cate_name;
    let pdf_last;
    let last;
    let lastDept;
    let dept_name;
    let holdLastObj:any = {}
    let holdLastDeptObj:any = {}
    let pdf_holdLastObj:any ={}

    if(this.filterObj.vessel){
      this.commonService.sendRequestToNode({method :'get',path:'office-kpi-report',queryParam:filterParams}).subscribe(
        result => {
          if(result.status)
          {
             console.log( result.data );
            this.showLoader = false;
            if(result.data.length > 0){
              // this.totalItems = result.data[0].total_records;
              result.data.forEach(element => {
                element.rowspan  = 1
                cate_name = element.OFFICE_KPI_CATEGORY;
                // console.log(last);
                // console.log(element.KPI_CATEGORY)
                if(last == element.OFFICE_KPI_CATEGORY){
                  element.rowspan = 0;
                  holdLastObj.rowspan++;
                }
                else{
                  holdLastObj = element;
                  element.rowspan  = 1;
                }
                element.vessel = this.filterObj.vessel;
                console.log(element.rowspan);
                last = element.OFFICE_KPI_CATEGORY;


                //................
                element.kpi_rowspan  = 1
                dept_name = element.KPI;
                console.log(lastDept);
                // console.log(element.KPI_CATEGORY)
                if(lastDept == element.KPI){
                  element.kpi_rowspan = 0;
                  holdLastDeptObj.kpi_rowspan++;
                }
                else{
                  holdLastDeptObj = element;
                  element.kpi_rowspan  = 1;
                }
                
                console.log(element.kpi_rowspan);
                lastDept = element.KPI;

              

              });
              console.log(result.data)
              //..........element.rowspan  = 1
                // this.filterObj.vessel.forEach((ele)=>{

                //         result.data.forEach(element => {
                //         if(ele == element.DEPARTMENT_FK) {
                //           if( pdf_last == element.OFFICE_KPI_CATEGORY ) {

                //           } else {
                           

                //           }
                //           pdf_last = element.OFFICE_KPI_CATEGORY;
                //         }
                //       })
                //   })
 console.log( this.filterObj)
              this.kpireportData =  result.data;
               console.log( this.kpireportData )
              this.change_comulative();
            } else {
              this.kpireportData = [];
            }
          } else {
            this.kpireportData = [];
            alert(result.message);
          }
      })
    }else{
      this.kpireportData = [];
      this.showLoader = false;
    }
    
  }
 
  getDataforcsv() {
    this.generatcsv();
  }

  
  generatcsv(){
    //console.log(this.withoutPaginationData);
    //search filter 
  
    let filterParams:any = {}
    filterParams = JSON.parse(JSON.stringify(this.filterObj));
    //alert(filterParams)
    let postObj = {
      data : this.withoutPaginationData
    }
    //var data = document.getElementById('htmlToString').innerHTML;
    this.commonService.sendRequestToNode({method :'post',path:'kpi-report/generateCSVData',queryParam:filterParams, postData:postObj}).subscribe(result => {
      if(result.status) {
        window.open(this.commonService.getNodeApi()+'/kpi-report/exportCSV', '_blank' );
      } 
    })
  }

    changeYear(i){
      this.filterObj.year = this.filterObj.year + (i)
      this.getData();
      this.getChartData();
    }
 
    generatePdf(){
      var data = document.getElementById('htmlToString').innerHTML;
      // console.log(JSON.stringify(data));
      // console.log(data);
      var htmlData = {'data':data};
      this.commonService.sendRequestToNode({ method: 'post', path: 'kpi-report/generatePDFData',postData:htmlData }).subscribe(result => {
        if(result.status){  
          console.log(  this.vessel_dropdown_name )
           
          this.filterObj.vessel_name = this.vessel_dropdown_name[ this.filterObj.vessel];
           console.log(  this.filterObj )
          window.location.href = this.commonService.getNodeApi()+'/kpi-report-exportPDF/' +  JSON.stringify( this.filterObj );
        }  
      })
    }

    downloadImage() {
      html2canvas(this.screen.nativeElement).then(canvas => {
        this.canvas.nativeElement.src = canvas.toDataURL();
        this.downloadLink.nativeElement.href = canvas.toDataURL('image/png');
        this.canvas.nativeElement.remove();
        this.downloadLink.nativeElement.download = 'kpi-report.png';
        this.downloadLink.nativeElement.click();
        
      });
    }

    changeFlag(e) {
      //console.log(e)
      this.filterObj.flag = e;
      this.getData();
    }
    filter(e,month,vessel,kpi_detail_id,kpi_report_id){
      let filterParams:any = {
        value : e,
        month,
        vessel,
        kpi_detail_id,
        kpi_report_id
      }
      // filterParams.ID = id;
      filterParams.value = e;
      filterParams.month = month;
      filterParams.vessel = vessel;
      filterParams.kpi_detail_id = kpi_detail_id;
      filterParams.kpi_report_id = kpi_report_id;
      filterParams.year = this.filterObj.year;
       console.log(e,month,vessel,kpi_detail_id,kpi_report_id,filterParams.year);//return false;
      if(e!=''){
        this.commonService.sendRequestToNode({method :'get',path:'office-kpi-report-update',queryParam:filterParams}).subscribe(
          data =>{
            var dialogueTitle = "Inserted!";
            this.showSideBarLoader = false;
            if(data.status){
              swal({
                  title: dialogueTitle,
                  text: data.message,
                  type: 'success',
                  confirmButtonClass: "btn btn-success",
                  buttonsStyling: false
              });
              // this.getData();
              // this.resetForm(); //after edit form is reset
             
              this.getData();
             
            }
            else{
              alert(data.message);
            }
        })
      }
    }
    change_comulative(){
      let devide_by = 0;
      let total=0;
      this.kpireportData.forEach(element => {
        if(element.GOAL_UNIT=="Total"){
            total = element.JANUARY + element.FEBRUARY + element.MARCH + element.APRIL + element.MAY + element.JUNE + element.JULY + element.AUGUST + element.SEPTEMBER + element.OCTOBER + element.NOVEMBER + element.DECEMBER;
            element.total = total
           
          // console.log(total)
        } else {
          total=0;
          this.monthArr.forEach(month => {
            // console.log(element[month])
            if(element[month]>=0 && element[month] != null ) {
              total = total+element[month];
              devide_by ++;
              
            }
          });
          // console.log(total)
          if(devide_by>0){
            element.total = total / devide_by;
            element.total = element.total.toFixed(2)
          }else{
            element.total = 0;
          }
          
        }
      });
      console.log(this.kpireportData);
    }


    change_vessel() {
      let arr = []
      
      this.filterObj.vessel.forEach(ele=>{
        if(ele == 'ALL'){
          arr = this.vessel_dropdown.map(e=>{
            return e.ID;
          })
          arr = arr.filter(e=>{
            return !(e == 'ALL');
          })
         
        }
      })
      if(arr.length > 0){
        this.filterObj.vessel = arr;
      }
      // console.log(arr);return false;
      this.filterVessel();
      this.getChartData();
    }
    filterVessel() {
      this.getData();
    }

    getChartData()
    { 
      this.lineChartData.length = 0;
      let filterParams:any = {year : this.filterObj.year}
      if( this.filterObj && this.filterObj.vessel ) {
        filterParams['vessel'] = this.filterObj.vessel;
      }
  
      this.showLoader = true;
      let dataArray   = [];
      let dataArray1  = [];
      let labelArray  = [];
      let devide_by   = 0;
      let total       = 0;
      this.commonService.sendRequestToNode({method :'get',path:'office-kpi-report/get-chart-data',queryParam:filterParams}).subscribe(
        result => {
          console.log( result.status)
        this.showLoader = false;              
          if(result.status)
          {
            if(result.data.length > 0){
                console.log( result.data )
                result.data.forEach(element => {
                //......................
                      if( element.GOAL_UNIT == "Total" ) {
                          total = element.JANUARY + element.FEBRUARY + element.MARCH + element.APRIL + element.MAY + element.JUNE + element.JULY + element.AUGUST + element.SEPTEMBER + element.OCTOBER + element.NOVEMBER + element.DECEMBER;
                          element.total = total
                        // console.log(total)
                      } else {
                          total = 0;
                          this.monthArr.forEach(month => {
                            // console.log(element[month])
                            if(element[month]>=0 && element[month] != null ){
                              total = total+element[month];
                              devide_by ++;
                            }
                          });
                          // console.log(total)
                          if(devide_by > 0){
                            element.total = total / devide_by;
                            element.total = element.total.toFixed(2)
                          } else {
                            element.total = 0;
                          }
                      }
              //....................
                dataArray.push(element.total);
                if(element.ANNUAL_GOAL){
                  dataArray1.push(element.ANNUAL_GOAL);
                } else{
                  dataArray1.push(0);
                }
                
                labelArray.push(element.KPI); 
              });
             
  
              this.lineChartData = [
                { data: dataArray, label: 'Cumulative',spanGaps:true  },
                { data: dataArray1, label: 'Anual Goal',spanGaps:true },
                
              ];
              console.log( this.lineChartData)
              this.lineChartLabels = labelArray;
            } else {
              // this.seaFarerData = [];
            }
          }
          else{
            // this.seaFarerData = [];
            alert(result.message);
          }
      })
    }

    retentionRateChart() {
      var canvas:any = document.getElementById("retentionRateChart");
      var image = canvas.toDataURL("image/png"); 
      var link = document.createElement('a');
          link.download =  this.filterObj.year + ' / Office Kpi Report.png';
          link.href = image;
          link.click();
    }
}

