import { Component, AfterViewInit,OnInit, createPlatformFactory,ElementRef,ViewChild } from '@angular/core';
import { NgbPaginationConfig, NgbModal, NgbModalRef, ModalDismissReasons } from '@ng-bootstrap/ng-bootstrap';
import { CommonService } from '../common-service.service';
import {Router,ActivatedRoute} from "@angular/router";
import {FormGroup,FormBuilder,Validators,FormControl} from '@angular/forms';
import swal from 'sweetalert2';

declare var $: any;
import { PerfectScrollbarConfigInterface } from 'ngx-perfect-scrollbar';

@Component({
  templateUrl: './office-location.component.html',
  styleUrls: ['./office-location.component.scss']
})
export class OfficeLocationComponent implements AfterViewInit,OnInit {

  public config: PerfectScrollbarConfigInterface = {};

  public officeLocationData = [];
  public officeLocationForm:FormGroup;
  public edit_id;
  public formSubmittedAttempt = false;
  public openRightSidebar = false;
  public filterObj:any = {};
  public sortFilter:any = {};
  public showSideBarLoader = false;
  public selectLocation = false;
  public showLoader = false;
  modalReference: NgbModalRef;

  //for grid
  public headerInformation;
  public actionButtons;

  //for pagination
  itemsPerPage: number = this.commonService.DefaultItemsPerPage;
  totalItems: number;
  currentPage: number = 1;

  @ViewChild('autofocus') el:ElementRef;

  constructor(private modalService: NgbModal,
    private commonService: CommonService,
    private router: Router,
    private formBuilder: FormBuilder,
    private route: ActivatedRoute){
      this.declareGridVariable()
  }

  // part of grid
  declareGridVariable(){
    this.headerInformation = [
      {
        title : 'Title',// show title table header
        name:'TITLE',// name of column in data source
        width : '20%',// width of column in table
        isSortable : true,// sort by column false or true
        highlight:true, // name highlight
        isFilter:{ // filter
          type : 'text',
          placeholder : 'Filter By Title'
        }
      },
      {
        title : 'Address',// show title table header
        name:'ADDRESS',// name of column in data source
        width : '30%',
      },
      {
        title : 'City',// show title table header
        name:'CITY',// name of column in data source
        width : '20%',// width of column in table
        isSortable : true,// sort by column false or true
        isFilter:{ // filter
          type : 'text',
          placeholder : 'Filter By City'
        }
      },
      {
        title : 'Location Type',// show title table header
        name:'IS_VESSEL',
        display_value: {1:'Vessel',0:'Office'},// name of column in data source
        width : '10%',// width of column in table
        //highlight:true, // name highlight
        isFilter:{ // filter
          type : 'select',
          placeholder : 'Filter By Location Type',
          options_value : [1,0],
          options_display : ['Vessel','Office']
        }
      },
      {
        title : 'Status',// show title table header
        nameIcon : true,// show icon of First letter
        name:'ACTIVE_FLAG',// name of column in data source
        width : '10%',
        display_value: {1:'Active',0:'Inactive'},
        isFilter:{ // filter
          type : 'select',
          placeholder : 'Filter By Status',
          options_value : [1,0],
          options_display : ['Active','Inactive']
        }
      },
      {title : 'Action',name:'action',width : '10%'}
    ];
    this.actionButtons = [
      {title:'Edit',class : "far fa-edit"},
      {title:'Delete',class : "far fa-trash-alt"}
    ]
  }

  ngAfterViewInit(){

  }

  ngOnInit(){
    this.getData();
    this.addForm();
  }

  getData()
  {
    let filterParams:any = {}

    console.log(this.filterObj);

    //search filter
    filterParams = JSON.parse(JSON.stringify(this.filterObj));
    //search filter -end

    // pagination
    filterParams.currentPage = this.currentPage-1;
    filterParams.itemsPerPage = this.itemsPerPage;
    // pagination - end

    //sorting
    let sortKey = Object.keys(this.sortFilter);
    if(sortKey.length && this.sortFilter[sortKey[0]]){
      filterParams.sortBy = sortKey[0];
      filterParams.sortStatus = this.sortFilter[sortKey[0]];
    }
    //sorting - end
    this.showLoader = true;
    this.commonService.sendRequestToNode({method :'get',path:'office-location',queryParam:filterParams}).subscribe(result => {
      this.showLoader = false;
      if(result.status)
        {
          if(result.data.length > 0){
            this.totalItems = result.data[0].total_records;
            this.officeLocationData = result.data;
             console.log( result.data)
          }else{
            this.officeLocationData = [];
          }
        }
        else{
          this.officeLocationData = [];
          alert(result.message);
        }
    })
  }

  addForm(){
    this.officeLocationForm = this.formBuilder.group({
      TITLE: [null, Validators.required],
      ADDRESS: ['',],
      CITY: ['',],
      IS_VESSEL: false,
      ACTIVE_FLAG: false
    });
  }

  resetForm(){
    this.formSubmittedAttempt = false;
    this.openRightSidebar = false;
    this.edit_id = '';
    this.officeLocationForm.patchValue({
      TITLE: '',
      ADDRESS: '',
      CITY: '',
      IS_VESSEL: false,
      ACTIVE_FLAG: false

    })
  }

  edit(id){
    this.openRightSidebar = true;
    this.el.nativeElement.focus();
    this.commonService.sendRequestToNode({method :'get',path:'office-location/'+id}).subscribe(
      data => {
        this.officeLocationForm.patchValue({
          TITLE : data.data.TITLE,
          ADDRESS : data.data.ADDRESS,
          CITY : data.data.CITY,
          IS_VESSEL: data.data.IS_VESSEL,
          ACTIVE_FLAG :data.data.ACTIVE_FLAG
        })
        this.edit_id = id;
    })
  }

  delete(id){
    if(id){
      swal({
        title: 'Are you sure?',
        text: "You won't be able to revert this!",
        type: 'warning',
        showCancelButton: true,
        confirmButtonClass: 'btn btn-success',
        cancelButtonClass: 'btn btn-danger',
        confirmButtonText: 'Yes, delete it!',
         buttonsStyling: false
      }).then((result) => {
        if (result.value) {
          this.commonService.sendRequestToNode({method :'delete',path:'office-location/'+id}).subscribe(
          data => {
          if(data.status){
            var dialogueTitle = "Deleted!"
            if(this.officeLocationData.length == 1 && Math.ceil(this.totalItems / this.itemsPerPage) == this.currentPage){
              if(this.currentPage>1){
                this.currentPage--;
              }
            }
            this.getData();
            swal({
                title: dialogueTitle,
                text: data.message,
                type: 'success',
                confirmButtonClass: "btn btn-success",
                buttonsStyling: false
              })
          }

      })
         }
      })
    }
  }

  onSubmit(){
    this.formSubmittedAttempt = true;
    if(this.officeLocationForm.valid){
    this.showSideBarLoader = true;
    if(this.edit_id){
      this.commonService.sendRequestToNode({method :'put',path:'office-location/'+this.edit_id,postData:this.officeLocationForm.value}).subscribe(
        data =>{
          var dialogueTitle = "Updated!";
          this.showSideBarLoader = false;
          if(data.status){
            swal({
                title: dialogueTitle,
                text: data.message,
                type: 'success',
                confirmButtonClass: "btn btn-success",
                buttonsStyling: false
              })
            this.getData();
            this.resetForm(); //after edit form is reset
          }
          else{
            alert(data.message);
          }
      })
    }else{
      this.commonService.sendRequestToNode({method :'post',path:'office-location',postData:this.officeLocationForm.value}).subscribe(
        data =>{
          var dialogueTitle = "Inserted!";
          this.showSideBarLoader = false;
          if(data.status){
            swal({
                title: dialogueTitle,
                text: data.message,
                type: 'success',
                confirmButtonClass: "btn btn-success",
                buttonsStyling: false
              })
            this.getData();
            this.resetForm(); //after edit form is reset

          }
          else{
            alert(data.message);
          }
      })
    }
    }

  }

    //part of grid
    clickOnAction(actionObj){
      if(actionObj.actionName == 'Edit'){
        this.edit(actionObj.object.ID)
      }else if(actionObj.actionName == 'Delete'){
        this.delete(actionObj.object.ID)
      }
    }

    //part of grid
    //when change filter ,change page no . etc,
    filter($event){
      let obj = $event;
      this.currentPage = obj.page;
      this.filterObj = obj.filter;
      this.sortFilter = obj.sort
      this.getData();
    }

    //part of grid
    funOpenRightSidebar(){
      this.el.nativeElement.focus();
      this.openRightSidebar = true;
    }

}

