import { Component, AfterViewInit,OnInit, createPlatformFactory,ElementRef,ViewChild } from '@angular/core';
import { NgbPaginationConfig, NgbModal, NgbModalRef, ModalDismissReasons } from '@ng-bootstrap/ng-bootstrap';
import { CommonService } from '../common-service.service';
import {Router,ActivatedRoute} from "@angular/router";
import {FormGroup,FormBuilder,Validators,FormControl} from '@angular/forms';
import swal from 'sweetalert2';
declare var $: any;
import { PerfectScrollbarConfigInterface } from 'ngx-perfect-scrollbar';

@Component({
  selector: 'officekpi-category',

  templateUrl: './officekpi-category.component.html',
  styleUrls: ['./officekpi-category.component.css']
})
export class OfficeKpiCategoryComponent implements AfterViewInit,OnInit {

  public config: PerfectScrollbarConfigInterface = {};
  
  public kpicategoryData = [];
  public kpicategoryForm:FormGroup;  
  public edit_id;
  public formSubmittedAttempt = false;
  public openRightSidebar = false;
  public filterObj:any = {};
  public sortFilter:any = {};
  public showSideBarLoader = false;
  public showLoader = false;
  public vessel_dropdown =[];
  public vessel_dropdown_name= [];
  public lineChartData: Array<any> = [];

  modalReference: NgbModalRef;

  //for grid 
  public headerInformation;
  public actionButtons;

  //for pagination
  itemsPerPage: number = this.commonService.DefaultItemsPerPage;
  totalItems: number;
  currentPage: number = 1;

  @ViewChild('autofocus') el:ElementRef;
 
  constructor(private modalService: NgbModal,
    private commonService: CommonService,
    private router: Router,
    private formBuilder: FormBuilder,
    private route: ActivatedRoute){
      this.declareGridVariable()
  }

  // part of grid
  declareGridVariable(){
    this.headerInformation = [
      {
        title : 'Office KPI CATEGORY',// show title table header
        nameIcon : true,// show icon of First letter
        name:'OFFICE_KPI_CATEGORY',// name of column in data source
        width : '20%',// width of column in table
        isSortable : true,// sort by column false or true
        isFilter:{ // filter 
          type : 'text',
          placeholder : 'Filter By Office KPI Category'
        }
      },
      {
        title : 'DEPARTMENT',// show title table header
        nameIcon : true,// show icon of First letter
        name:'DEPARTMENT',// name of column in data source
        width : '20%',// width of column in table
        // isSortable : true,// sort by column false or true
       
      },
      //{title : 'Shore Assignment Kpi',name:'SHORE_ASSIGNMENT_KPI',width : '30%'},
      {title : '',name:'',width : '40%'},
      {title : 'Action',name:'action',width : '10%'}
    ];
    this.actionButtons = [
      {title:'Edit',class : "far fa-edit"},
      {title:'Delete',class : "far fa-trash-alt"}
    ]
  }

  ngAfterViewInit(){
   
  }

  ngOnInit(){
    this.getData();
    this.addForm();
    this.departmentDropDown();
  }
  
  departmentDropDown(){
    this.commonService.sendRequestToNode({method :'get',path:'department-dropdown'}).subscribe(result => {
      if(result.status){
        
        this.vessel_dropdown = [{DEPARTMENT : 'All Departments',ID : 'ALL'},...result.data];
        result.data.forEach((val) => {
          this.vessel_dropdown_name[val.ID] = val.DEPARTMENT;
        });

        console.log(this.vessel_dropdown);
      }
      else{
        this.vessel_dropdown = [];
        alert(result.message);
      }
    })
    
  }

  getData()
  {
    let filterParams:any = {}
    
    //search filter 
    filterParams = JSON.parse(JSON.stringify(this.filterObj));
    //search filter -end

    // pagination
    filterParams.currentPage = this.currentPage-1;
    filterParams.itemsPerPage = this.itemsPerPage;
    // pagination - end

    //sorting 
    let sortKey = Object.keys(this.sortFilter);
    if(sortKey.length && this.sortFilter[sortKey[0]]){
      filterParams.sortBy = sortKey[0];
      filterParams.sortStatus = this.sortFilter[sortKey[0]];
    }
    //sorting - end
    this.showLoader = true;
    this.commonService.sendRequestToNode({method :'get',path:'officekpi-category',queryParam:filterParams}).subscribe(result => {
      this.showLoader = false;        
        
      if(result.status)
        {
          if(result.data.length > 0){
            this.totalItems = result.data[0].total_records;
            this.kpicategoryData = result.data;
          }else{
            this.kpicategoryData = [];
          }
        }
        else{
          this.kpicategoryData = [];
          alert(result.message);
        }
    })
  }

  addForm(){
    this.kpicategoryForm = this.formBuilder.group({
      OFFICE_KPI_CATEGORY: ['',[Validators.required]],
      DEPARTMENT : [null,[Validators.required]]
    });   
  }

  resetForm(){
    this.formSubmittedAttempt = false;
    this.openRightSidebar = false;
    this.edit_id = '';
    this.kpicategoryForm.patchValue({
      OFFICE_KPI_CATEGORY : '',
      DEPARTMENT : []

    })
  }

  edit(id){ 
    let tempArr = [ ];
    this.openRightSidebar = true;
    this.el.nativeElement.focus();
    this.commonService.sendRequestToNode({method :'get',path:'officekpi-category/'+id}).subscribe(
      data => {         

         console.log( data.data )
        this.commonService.sendRequestToNode({method :'get',path:'officekpi-category/department/'+id}).subscribe(result => {
           if( result.status ) {
              console.log( result)
              if( result.data.length >0 ) {
                result.data.forEach((ele)=>{
                    tempArr.push( ele.DEPARTMENT_ID )
                })
                this.kpicategoryForm.patchValue({
                  DEPARTMENT : tempArr
                })
              }
           }
        });
        this.kpicategoryForm.patchValue({
          OFFICE_KPI_CATEGORY : data.data.OFFICE_KPI_CATEGORY,
        })
         console.log( this.kpicategoryForm.value )
        
        this.edit_id = id;
    })
  }

  delete(id){
    if(id){
      swal({
        title: 'Are you sure?',
        text: "You won't be able to revert this!",
        type: 'warning',
        showCancelButton: true,
        confirmButtonClass: 'btn btn-success',
        cancelButtonClass: 'btn btn-danger',
        confirmButtonText: 'Yes, delete it!',
         buttonsStyling: false
      }).then((result) => {
        if (result.value) {
          this.commonService.sendRequestToNode({method :'delete',path:'officekpi-category/'+id}).subscribe(
          data => {
          if(data.status){
            var dialogueTitle = "Deleted!"
            if(this.kpicategoryData.length == 1 && Math.ceil(this.totalItems / this.itemsPerPage) == this.currentPage){
              if(this.currentPage>1){
                this.currentPage--;
              }
            }
            this.getData();
            swal({
                title: dialogueTitle,
                text: data.message,
                type: 'success',
                confirmButtonClass: "btn btn-success",
                buttonsStyling: false
              })
          }         
          
      })
         }
      })      
    }
  }

  onSubmit(){ 
    this.formSubmittedAttempt = true;
    console.log(this.kpicategoryForm)
    if(this.kpicategoryForm.valid){
    this.showSideBarLoader = true;
    if(this.edit_id){    
      this.commonService.sendRequestToNode({method :'put',path:'officekpi-category/'+this.edit_id,postData:{OFFICE_KPI_CATEGORY: this.kpicategoryForm.value.OFFICE_KPI_CATEGORY,DepartmentIds : this.kpicategoryForm.value.DEPARTMENT}}).subscribe(
        data =>{
          var dialogueTitle = "Updated!";
          this.showSideBarLoader = false;
          if(data.status){
              // if( data.data.length > 0 ) {
              //   console.log( data.data )
              // }
            swal({
                title: dialogueTitle,
                text: data.message,
                type: 'success',
                confirmButtonClass: "btn btn-success",
                buttonsStyling: false
              })
            this.getData();
            this.resetForm(); //after edit form is reset
          }
          else{
            alert(data.message);
          }
      })
    }else{
      this.commonService.sendRequestToNode({method :'post',path:'officekpi-category',postData:{OFFICE_KPI_CATEGORY: this.kpicategoryForm.value.OFFICE_KPI_CATEGORY, DepartmentIds : this.kpicategoryForm.value.DEPARTMENT}}).subscribe(
        data =>{
          var dialogueTitle = "Inserted!";
          this.showSideBarLoader = false;
          if(data.status){
            swal({
                title: dialogueTitle,
                text: data.message,
                type: 'success',
                confirmButtonClass: "btn btn-success",
                buttonsStyling: false
              })
            this.getData();
            this.resetForm(); //after edit form is reset

          }
          else{
            alert(data.message);
          }
      })
    }
    }
      
  } 

    //part of grid
    clickOnAction(actionObj){
      console.log('actionObj');console.log(actionObj);
      if(actionObj.actionName == 'Edit'){
        this.edit(actionObj.object.ID)
      }else if(actionObj.actionName == 'Delete'){
        this.delete(actionObj.object.ID)
      }
    }
  
    //part of grid
    //when change filter ,change page no . etc, 
    filter($event){
      let obj = $event;
      console.log(obj.sort)
      this.currentPage = obj.page;
      this.filterObj = obj.filter;
      this.sortFilter = obj.sort
      this.getData();
    }
  
    //part of grid
    funOpenRightSidebar(){
      this.openRightSidebar = true;
      this.el.nativeElement.focus();
    }
    change_department() {
      let arr = []
      
      this.kpicategoryForm.value.DEPARTMENT.forEach(ele=>{
        if(ele == 'ALL'){
          arr = this.vessel_dropdown.map(e=>{
            return e.ID;
          })
          arr = arr.filter(e=>{
            return !(e == 'ALL');
          })
         
        }
      })
      if(arr.length > 0){
         this.kpicategoryForm.patchValue({
           DEPARTMENT:arr
         })
      }
      // console.log(arr);return false;
      // this.filterVessel();
    }

   
}

