import { Component, AfterViewInit,OnInit, createPlatformFactory,ElementRef,ViewChild } from '@angular/core';
import { NgbPaginationConfig, NgbModal, NgbModalRef, ModalDismissReasons } from '@ng-bootstrap/ng-bootstrap';
import { CommonService } from '../common-service.service';
import {Router,ActivatedRoute} from "@angular/router";
import {FormGroup,FormBuilder,Validators,FormControl} from '@angular/forms';
import swal from 'sweetalert2';

declare var $: any;
import { PerfectScrollbarConfigInterface } from 'ngx-perfect-scrollbar';
import { fail } from 'assert';

@Component({
  templateUrl: './oilMajorMaster.component.html',
  styleUrls: ['./oilMajorMaster.component.scss']
})
export class OilMajorMasterComponent implements AfterViewInit,OnInit {  
 
  public docPath = this.commonService.getImagePath(true)+'/oil-major';
  public config: PerfectScrollbarConfigInterface = {};

  options = {
    theme: 'light', // two possible values: light, dark
    dir: 'ltr', // two possible values: ltr, rtl
    layout: 'vertical', // fixed value. shouldn't be changed.
    sidebartype: 'mini-sidebar', // four possible values: full, iconbar, overlay, mini-sidebar 
    sidebarpos: 'fixed', // two possible values: fixed, absolute
    headerpos: 'fixed', // two possible values: fixed, absolute
    boxed: 'full', // two possible values: full, boxed
    navbarbg: 'skin6', // six possible values: skin(1/2/3/4/5/6)
    sidebarbg: 'skin5', // six possible values: skin(1/2/3/4/5/6)
    logobg: 'skin5' // six possible values: skin(1/2/3/4/5/6)
  };
  
  public oilMajorMaterData = [];
  public openRightSidebar = false;
  public showSideBarLoader = false;
  public showLoader = false;
  public filterObj:any = {};
  public sortFilter:any = {};
  // public isViewData = false;
  public viewData:any = false;
  //for grid 
  public headerInformation;
  public actionButtons;

  //for pagination
  itemsPerPage: number = this.commonService.DefaultItemsPerPage;
  totalItems: number;
  currentPage: number = 1;
  
  @ViewChild('autofocus') el:ElementRef;

  constructor(private modalService: NgbModal,
    private commonService: CommonService,
    private router: Router,
    private formBuilder: FormBuilder,
    private route: ActivatedRoute){
      this.declareGridVariable()
  }

  // part of grid
  declareGridVariable(){
    this.headerInformation = [
      {
        title : 'Company',// show title table header
        nameIcon : true,// show icon of First letter
        name:'COMPANY_NAME',// name of column in data source
        width : '20%',// width of column in table
        isSortable : true,// sort by column false or true
        isFilter:{ // filter 
          type : 'text',
          placeholder : 'Filter By Company'
        }
      },
      {title : 'Category',name:'CATEGORY',width : '10%'},
      {title : 'Official Name',name:'OFFICIAL_NAME',width : '15%'},
      {title : 'Description',name:'DESCRIPTION',width : '15%'},
      {title : 'Email',type:"email",email_field : 'EMAIL_NOTE',name:'EMAIL',width : '15%'},//email type for open in outlookexpress
      {title : 'Website',name:'WEBSITE',width : '15%'},
      // {title : 'EMAIL_NOTE',name:'EMAIL_NOTE',width : '15%'},
      {title : 'Action',name:'action',width : '10%'}
    ];
    this.actionButtons = [
      {title:'View',class : "fas fa-eye"}
    ]
  }


  ngAfterViewInit(){
   
  }

  ngOnInit(){
    this.getOilMajorMasterData();
  }
  
  getOilMajorMasterData(){

    let filterParams:any = {}
    
    //search filter 
    filterParams = JSON.parse(JSON.stringify(this.filterObj));
    //search filter -end

    // pagination
    filterParams.currentPage = this.currentPage-1;
    filterParams.itemsPerPage = this.itemsPerPage;
    // pagination - end

    //sorting 
    let sortKey = Object.keys(this.sortFilter);
    if(sortKey.length && this.sortFilter[sortKey[0]]){
      filterParams.sortBy = sortKey[0];
      filterParams.sortStatus = this.sortFilter[sortKey[0]];
    }
    //sorting - end

    this.showLoader = true;

    this.commonService.sendRequestToNode({method :'get',path:'oilMajorMater',queryParam:filterParams}).subscribe(result => {
    this.showLoader = false;
      if(result.status)
        {
          if(result.data.length > 0){
            this.totalItems = result.data[0].total_records;
            this.oilMajorMaterData = result.data;
          }else{
            this.oilMajorMaterData = [];
          }
        }
        else{
          this.oilMajorMaterData = [];
          alert(result.message);
        }
    })
  }

  

  resetForm(){
    this.openRightSidebar = false;
  }

  view(id){
    this.openRightSidebar = true;
    this.showSideBarLoader = true;
    if(this.el){
      this.el.nativeElement.focus();
    }
      //console.log(id);
    this.commonService.sendRequestToNode({method :'get',path:'oilMajorMater/'+id}).subscribe(result => {
    this.showSideBarLoader = false;    
      if(result.status)
        {
          this.viewData = result.data;
        }
        else{
          alert(result.message)
        }
    })
  }

  //part of grid
  clickOnAction(actionObj){
    if(actionObj.actionName == 'View'){
      this.view(actionObj.object.ID)
    }
  }
  
  //part of grid
  //when change filter ,change page no . etc, 
  filter($event){
    let obj = $event;
    this.currentPage = obj.page;
    this.filterObj = obj.filter;
    this.sortFilter = obj.sort
    this.getOilMajorMasterData();
  }

  //part of grid
  funOpenRightSidebar(){
    this.openRightSidebar = true;
    this.el.nativeElement.focus(); 
  }

}

