import { Component, AfterViewInit, OnInit, createPlatformFactory, ElementRef, ViewChild } from '@angular/core';
import { NgbPaginationConfig, NgbModal, NgbModalRef, ModalDismissReasons } from '@ng-bootstrap/ng-bootstrap';
import { CommonService } from '../common-service.service';
import { Router, ActivatedRoute } from "@angular/router";
import { FormGroup, FormBuilder, Validators, FormControl } from '@angular/forms';
import swal from 'sweetalert2';
//import { parse } from 'path';

declare var $: any;
import { PerfectScrollbarConfigInterface } from 'ngx-perfect-scrollbar';
import { e } from '@angular/core/src/render3';

@Component({
  selector: 'app-pc-master',
  templateUrl: './pc-master.component.html',
  styleUrls: ['./pc-master.component.css']
})
export class PcMasterComponent implements AfterViewInit, OnInit {

  public config: PerfectScrollbarConfigInterface = {};

  options = {
    theme: 'light', // two possible values: light, dark
    dir: 'ltr', // two possible values: ltr, rtl
    layout: 'vertical', // fixed value. shouldn't be changed.
    sidebartype: 'mini-sidebar', // four possible values: full, iconbar, overlay, mini-sidebar
    sidebarpos: 'fixed', // two possible values: fixed, absolute
    headerpos: 'fixed', // two possible values: fixed, absolute
    boxed: 'full', // two possible values: full, boxed
    navbarbg: 'skin6', // six possible values: skin(1/2/3/4/5/6)
    sidebarbg: 'skin5', // six possible values: skin(1/2/3/4/5/6)
    logobg: 'skin5' // six possible values: skin(1/2/3/4/5/6)
  };

  public VesselOwnerForm: FormGroup;
  public officeLocationForm: FormGroup;
  public vesselOwner_data = [];
  public VesselData = [];
  public vesselOwner_view;
  public edit_id;
  public selectLocation = false;
  public formSubmittedAttempt = false;
  public openRightSidebar = false;
  public showSideBarLoader = false;
  public showLoader = false;
  public viewData = false;
  public filterObj: any = {};
  public sortFilter: any = {};
  public officeLocationData = [];
  public modalRef: NgbModalRef;
  public officeLocationFormSubmittedAttempt = false;
  public office_location_id = [];
  public office_location_value = [];

  //for grid
  public headerInformation;
  public actionButtons;

  //for pagination
  itemsPerPage: number = this.commonService.DefaultItemsPerPage;
  totalItems: number;
  currentPage: number = 1;

  @ViewChild('autofocus') el: ElementRef;

  constructor(private modalService: NgbModal,
    private commonService: CommonService,
    private router: Router,
    private formBuilder: FormBuilder,
    private route: ActivatedRoute) {
    this.declareGridVariable()
  }

  ngAfterViewInit() {

  }

  ngOnInit() {
    this.getData();
    this.addForm();
    this.officeDropdown();
    this.getVesselData();
    //this.locationDD();

    //this.editForm();
  }

  addForm() {
    this.VesselOwnerForm = this.formBuilder.group({
      NAME: [null, Validators.required],
      IS_OFFICE: 0,
      LOCATION: [null],
      ACTIVE_FLAG: false
    });
    this.officeLocationForm = this.formBuilder.group({
      TITLE: [null, Validators.required],
      ADDRESS: [''],
      CITY: [''],
    });
  }

  edit(id) {
    this.openRightSidebar = true;
    this.el.nativeElement.focus();
    this.commonService.sendRequestToNode({ method: 'get', path: 'pc-master/getById/' + id }).subscribe(
      data => {
        console.log(data);
        this.selectLocation = data.data.IS_OFFICE;
        this.VesselOwnerForm.patchValue({
          NAME: data.data.NAME,
          IS_OFFICE: data.data.IS_OFFICE,
          LOCATION: data.data.LOCATION,
          ACTIVE_FLAG: data.data.ACTIVE_FLAG,
        });
        this.edit_id = id;
      })
  }

  onSubmit() {
    console.log(this.VesselOwnerForm.value);

    this.formSubmittedAttempt = true;
    if (this.VesselOwnerForm.valid) {
      if (this.VesselOwnerForm.value.IS_OFFICE == true) {
        this.VesselOwnerForm.patchValue({
          LOCATION: null
        })
      }
      this.showSideBarLoader = true;
      if (this.edit_id) {
        this.commonService.sendRequestToNode({ method: 'put', path: 'pc-master/edit/' + this.edit_id, postData: this.VesselOwnerForm.value }).subscribe(
          data => {
            var dialogueTitle = "Updated!";
            this.showSideBarLoader = false;
            if (data.status) {
              swal({
                title: dialogueTitle,
                text: data.message,
                type: 'success',
                confirmButtonClass: "btn btn-success",
                buttonsStyling: false
              })
              this.getData();
              this.openRightSidebar = false;
              this.resetForm();
            } else {
              alert(data.message);
            }
          })
      } else {
        console.log(this.VesselOwnerForm.value);
        this.commonService.sendRequestToNode({ method: 'post', path: 'pc-master/add', postData: this.VesselOwnerForm.value }).subscribe(
          data => {
            var dialogueTitle = "Inserted!";
            this.showSideBarLoader = false;
            if (data.status) {
              swal({
                title: dialogueTitle,
                text: data.message,
                type: 'success',
                confirmButtonClass: "btn btn-success",
                buttonsStyling: false
              })
              this.getData();
              this.openRightSidebar = false;
              this.resetForm();
            } else {
              alert(data.message);
            }
          })
      }
    }
  }

  getData() {
    let filterParams: any = {}

    //search filter
    filterParams = JSON.parse(JSON.stringify(this.filterObj));
    //search filter -end

    // pagination
    filterParams.currentPage = this.currentPage - 1;
    filterParams.itemsPerPage = this.itemsPerPage;
    // pagination - end

    //sorting
    let sortKey = Object.keys(this.sortFilter);
    if (sortKey.length && this.sortFilter[sortKey[0]]) {
      filterParams.sortBy = sortKey[0];
      filterParams.sortStatus = this.sortFilter[sortKey[0]];
    }
    //sorting - end
    this.showLoader = true;

    this.commonService.sendRequestToNode({ method: 'get', path: 'pc-master/data_list', queryParam: filterParams }).subscribe(result => {
      this.showLoader = false;
      if (result.status) {
        if (result.data.length > 0) {
          this.totalItems = result.data[0].total_records;
          this.vesselOwner_data = result.data;
          console.log(this.vesselOwner_data);


          this.vesselOwner_data.forEach(vesselOwner => {

            if (this.office_location_id.length > 0) {
              var found = this.office_location_id.filter(function (data) {
                return (data === vesselOwner.OFFICE_ID) ? true : false;
              });
            }
            if (!found || found.length <= 0) {
              if (vesselOwner.OFFICE_ID && vesselOwner.OFFICE_LOCATION) {
                this.office_location_id.push(vesselOwner.OFFICE_ID)
                this.office_location_value.push(vesselOwner.OFFICE_LOCATION)
              }
            }
          });
        } else {
          this.vesselOwner_data = [];
        }
      }
      else {
        this.vesselOwner_data = [];
        alert(result.message);
      }
    })
  }

  // locationDD() {
  //   console.log(this.vesselOwner_data);
  //   if (this.vesselOwner_data) {
  //     this.vesselOwner_data.forEach(vesselOwner => {
  //       if (vesselOwner.OFFICE_ID && vesselOwner.OFFICE_LOCATION) {
  //         this.office_location_id.push(vesselOwner.OFFICE_ID)
  //         this.office_location_value.push(vesselOwner.OFFICE_LOCATION)
  //       }
  //     });
  //   }
  // }

  delete(id) {
    console.log(id);
    if (id) {

      swal({
        title: 'Are you sure?',
        text: "You won't be able to revert this!",
        type: 'warning',
        showCancelButton: true,
        confirmButtonClass: 'btn btn-success',
        cancelButtonClass: 'btn btn-danger',
        confirmButtonText: 'Yes, delete it!',
        buttonsStyling: false

      }).then((result) => {
        if (result.value) {
          this.commonService.sendRequestToNode({ method: 'delete', path: 'pc-master/delete/' + id }).subscribe(result => {
            if (result.status) {
              var dialogueTitle = "Deleted!"
              if (this.vesselOwner_data.length == 1 && Math.ceil(this.totalItems / this.itemsPerPage) == this.currentPage) {
                if (this.currentPage > 1) {
                  this.currentPage--;
                }
              }
              this.getData();
              swal({
                title: dialogueTitle,
                text: result.message,
                type: 'success',
                confirmButtonClass: "btn btn-success",
                buttonsStyling: false
              })
            }
          })
        }
      })
    }
  }

  view(id) {
    this.viewData = true;
    this.openRightSidebar = true;
    this.showSideBarLoader = true;
    this.el.nativeElement.focus();
    //console.log(id);
    this.commonService.sendRequestToNode({ method: 'get', path: 'pc-master/getById/' + id }).subscribe(result => {
      this.showSideBarLoader = false;
      if (result.status) {
        this.vesselOwner_view = result.data;
        console.log(this.vesselOwner_view);
      }
      else {
        alert(result.message)
      }
    })
  }

  resetForm() {
    this.formSubmittedAttempt = false;
    this.openRightSidebar = false;
    this.edit_id = '';
    this.viewData = false;
    this.VesselOwnerForm.patchValue({
      NAME: null,
      IS_OFFICE: 0,
      LOCATION: null,
      ACTIVE_FLAG: false

    })
  }

  // part of grid
  declareGridVariable() {
    this.headerInformation = [
      {
        title: 'PC Name',
        name: 'NAME',
        width: '20%',
        isSortable: true,
        highlight: true,
        isFilter: { // filter
          type: 'text',
          placeholder: 'Filter By NAME',
        }
      },
      // {
      //   title : 'Location',
      //   name:'OFFICE_LOCATION',
      //   isSortable : true,
      //   width : '15%',
      //   isFilter:{ // filter
      //     type : 'text',
      //     placeholder : 'Filter By Location Code',
      //   }
      // },
      {
        title: 'Location',
        name: 'OFFICE_LOCATION',
        width: '15%',
        // isSortable : true,
        //highlight:true,
        isFilter: { // filter
          type: 'select',
          placeholder: 'Filter By PC',
          options_display: this.office_location_value,
          options_value: this.office_location_id
        }
      },
      {
        title: 'Location Type',// show title table header
        nameIcon: true,// show icon of First letter
        name: 'IS_OFFICE',// name of column in data source
        width: '10%',
        display_value: { 1: 'Vessel', 0: 'Office' },
        isFilter: { // filter
          type: 'select',
          placeholder: 'Filter By Location Type',
          options_value: [1, 0],
          options_display: ['Vessel', 'Office']
        }
      },
      {
        title: 'Status',// show title table header
        nameIcon: true,// show icon of First letter
        name: 'ACTIVE_FLAG',// name of column in data source
        width: '10%',
        display_value: { 1: 'Active', 0: 'Inactive' },
        isFilter: { // filter
          type: 'select',
          placeholder: 'Filter By Status',
          options_value: [1, 0],
          options_display: ['Active', 'Inactive']
        }
      },

      { title: 'Action', name: 'action', width: '15%' }
    ];
    this.actionButtons = [
      { title: 'View', class: "fas fa-eye" },
      { title: 'Edit', class: "far fa-edit" },
      { title: 'Delete', class: "far fa-trash-alt" }
    ]
  }

  //part of grid
  clickOnAction(actionObj) {
    console.log('actionObj'); console.log(actionObj);
    if (actionObj.actionName == 'View') {
      this.view(actionObj.object.ID);
    } else if (actionObj.actionName == 'Edit') {
      this.edit(actionObj.object.ID);
    } else if (actionObj.actionName == 'Delete') {
      this.delete(actionObj.object.ID);
    } else if (actionObj.actionName == 'Status') {
      this.statusChange(actionObj.object.ID, actionObj.object)
    }
  }

  statusChange(id, obj) {
    if (obj.ACTIVE_FLAG == 1) {
      obj.ACTIVE_FLAG = 0;
    } else {
      obj.ACTIVE_FLAG = 1;
    }

    this.commonService.sendRequestToNode({ method: 'put', path: 'vesselowner-isactive/' + id, postData: { ACTIVE_FLAG: obj.ACTIVE_FLAG } }).subscribe(
      data => {
        var dialogueTitle = "Updated!";
        if (data.status) {
          swal({
            title: dialogueTitle,
            text: data.message,
            type: 'success',
            confirmButtonClass: "btn btn-success",
            buttonsStyling: false
          })
          this.getData();
          this.openRightSidebar = false;
          this.resetForm();
        } else {
          alert(data.message);
        }
      })

  }

  //part of grid
  //when change filter ,change page no . etc,
  filter($event) {
    let obj = $event;
    console.log(obj.sort)
    this.currentPage = obj.page;
    this.filterObj = obj.filter;
    this.sortFilter = obj.sort
    this.getData();
  }

  //part of grid
  funOpenRightSidebar() {
    this.openRightSidebar = true;
    this.el.nativeElement.focus();
  }

  officeDropdown() {
    this.commonService.sendRequestToNode({ method: 'get', path: 'office-location-dropDown', queryParam: { IS_VESSEL: 0 } }).subscribe(result => {
      if (result.status) {
        this.officeLocationData = result.data;
      }
      else {
        this.officeLocationData = [];
        alert(result.message);
      }
    })
  }

  addOfficeLocation(content) {
    this.modalRef = this.modalService.open(content, { size: 'sm' });
  }

  resetOfficeLocationForm() {
    this.officeLocationFormSubmittedAttempt = false;
    this.officeLocationForm.patchValue({
      TITLE: '',
      ADDRESS: '',
      CITY: ''
    })
  }

  onSubmitOfficeLocation() {
    //console.log(this.edit_id);
    this.officeLocationFormSubmittedAttempt = true;
    if (this.officeLocationForm.valid) {
      //console.log(this.Groupinspector.value);
      this.commonService.sendRequestToNode({ method: 'post', path: 'office-location', postData: this.officeLocationForm.value }).subscribe(
        data => {
          var dialogueTitle = "Inserted!";
          if (data.status) {
            swal({
              title: dialogueTitle,
              text: data.message,
              type: 'success',
              confirmButtonClass: "btn btn-success",
              buttonsStyling: false
            }).then(() => {
              this.modalRef.close();
              // this.office(data.insertId);
              this.officeDropdown();
              this.resetOfficeLocationForm();
            })
            // this.modal.close()
          } else {
            alert(data.message);
          }
        })
    }
  }

  getVesselData() {

    this.commonService.sendRequestToNode({ method: 'get', path: 'vessel_master/vessel-dropdown', queryParam: { ACTIVE_FLAG: 1 } }).subscribe(result => {
      if (result.status) {
        if (result.data.length > 0) {
          this.VesselData = result.data;
        }
      } else {
        this.VesselData = [];
        alert(result.message);
      }
    })
  }

  changeFlag_Audit(e) {

    if (e == true) {

      this.selectLocation = true;
    } else {
      this.selectLocation = false;
    }
  }

}
