import { Component, AfterViewInit,OnInit, createPlatformFactory,ElementRef,ViewChild } from '@angular/core';
import { NgbPaginationConfig, NgbModal, NgbModalRef, ModalDismissReasons } from '@ng-bootstrap/ng-bootstrap';
import { CommonService } from '../common-service.service';
import {Router,ActivatedRoute} from "@angular/router";
import {FormGroup,FormBuilder,Validators,FormControl} from '@angular/forms';
import swal from 'sweetalert2';

declare var $: any;
import { PerfectScrollbarConfigInterface } from 'ngx-perfect-scrollbar';

@Component({
  templateUrl: './port.component.html',
  styleUrls: ['./port.component.scss']
})
export class PortComponent implements AfterViewInit,OnInit {

  public config: PerfectScrollbarConfigInterface = {};

  options = {
    theme: 'light', // two possible values: light, dark
    dir: 'ltr', // two possible values: ltr, rtl
    layout: 'vertical', // fixed value. shouldn't be changed.
    sidebartype: 'mini-sidebar', // four possible values: full, iconbar, overlay, mini-sidebar 
    sidebarpos: 'fixed', // two possible values: fixed, absolute
    headerpos: 'fixed', // two possible values: fixed, absolute
    boxed: 'full', // two possible values: full, boxed
    navbarbg: 'skin6', // six possible values: skin(1/2/3/4/5/6)
    sidebarbg: 'skin5', // six possible values: skin(1/2/3/4/5/6)
    logobg: 'skin5' // six possible values: skin(1/2/3/4/5/6)
  };
  
  public portData = [];
  public CountryData = [];
  public portForm:FormGroup;  
  public edit_id = '';
  public formSubmittedAttempt = false;
  public openRightSidebar = false;
  public showSideBarLoader = false;
  public showLoader = false;
  public filterObj:any = {};
  public sortFilter:any = {};

  //for grid 
  public headerInformation;
  public actionButtons;

  //for pagination
  itemsPerPage: number = this.commonService.DefaultItemsPerPage;
  totalItems: number;
  currentPage: number = 1;
  
  @ViewChild('autofocus') el:ElementRef;

  constructor(private modalService: NgbModal,
    private commonService: CommonService,
    private router: Router,
    private formBuilder: FormBuilder,
    private route: ActivatedRoute){
      this.declareGridVariable()
  }

    // part of grid
    declareGridVariable(){
      this.headerInformation = [
        {
          title : 'Port Name',// show title table header
          //nameIcon : true,// show icon of First letter
          name:'PORT_NAME',// name of column in data source
          width : '20%',// width of column in table
          isSortable : true,// sort by column false or true
          isFilter:{ // filter 
            type : 'text',
            placeholder : 'Filter By Port Name'
          }
        },
        {title : 'Port Code',name:'PORT_CODE',width : '20%'},
        {
          title : 'Country',// show title table header
          //nameIcon : true,// show icon of First letter
          name:'COUNTRY_NAME',// name of column in data source
          width : '20%',// width of column in table
          isSortable : true,// sort by column false or true
          isFilter:{ // filter 
            type : 'text',
            placeholder : 'Filter By Country'
          }
        },
        {title : 'Longitude',name:'LONGITUDE',width : '20%'},
        {title : 'Latitude',name:'LATITUDE',width : '20%'},
      ];
    }
  

  ngAfterViewInit(){
   
  }

  ngOnInit(){
    this.getPortData();
    this.addForm();
    this.getCountryData();
  }
  
  getCountryData(){
    this.commonService.sendRequestToNode({method :'get',path:'country/dropdown'}).subscribe(result => {
      if(result.status){   
        this.CountryData = result.data;
      }else{
        this.CountryData = [];
        alert(result.message);
      }
    })
  }

  getPortData()
  {
    let filterParams:any = {}
    
    //search filter 
    filterParams = JSON.parse(JSON.stringify(this.filterObj));
    //search filter -end

    // pagination
    filterParams.currentPage = this.currentPage-1;
    filterParams.itemsPerPage = this.itemsPerPage;
    // pagination - end

    //sorting 
    let sortKey = Object.keys(this.sortFilter);
    if(sortKey.length && this.sortFilter[sortKey[0]]){
      filterParams.sortBy = sortKey[0];
      filterParams.sortStatus = this.sortFilter[sortKey[0]];
    }
    //sorting - end

    this.showLoader = true;

    this.commonService.sendRequestToNode({method :'get',path:'port',queryParam:filterParams}).subscribe(result => {
    this.showLoader = false;
      if(result.status)
        {
          if(result.data.length > 0){
            this.totalItems = result.data[0].total_records;
            this.portData = result.data;
          }else{
            this.portData = [];
          }
        }
        else{
          this.portData = [];
          alert(result.message);
        }
    })
  }

  addForm(){
    this.portForm = this.formBuilder.group({
      PORT_NAME: [null,],
      PORT_CODE: [null,],
      COUNTRY_MST_FK: [null,],
      LATITUDE : [null,],
      LONGITUDE : [null,]
    });   
  }

  resetForm(){
    this.formSubmittedAttempt = false;
    this.openRightSidebar = false;
    this.edit_id = '';
    this.portForm.patchValue({
      PORT_NAME : null,
      PORT_CODE : null,
      COUNTRY_MST_FK : null,
      LATITUDE : null,
      LONGITUDE : null,                     
    })
  }

  onSubmit(){ 
    this.formSubmittedAttempt = true;
    this.showSideBarLoader = true;
    if(this.portForm.valid){
      if(this.edit_id){    
        this.commonService.sendRequestToNode({method :'put',path:'port/'+this.edit_id,postData:this.portForm.value}).subscribe(
          data =>{
            var dialogueTitle = "Updated!";
            this.showSideBarLoader = false;
            if(data.status){
                swal({
                    title: dialogueTitle,
                    text: data.message,
                    type: 'success',
                    confirmButtonClass: "btn btn-success",
                    buttonsStyling: false
                  })
                this.getPortData();
                this.openRightSidebar = false;
                this.resetForm(); //after edit form is reset
              
              }else{
                alert(data.message);
              }
          })
      }else{
        this.commonService.sendRequestToNode({method :'post',path:'port',postData:this.portForm.value}).subscribe(
          data =>{
          var dialogueTitle = "Inserted!";
          this.showSideBarLoader = false;
          if(data.status){
            swal({
              title: dialogueTitle,
              text: data.message,
              type: 'success',
              confirmButtonClass: "btn btn-success",
              buttonsStyling: false
            })
            this.getPortData();
            this.resetForm(); //after edit form is reset
          }else{
            alert(data.message);
          }
        })
      }
    }  
  } 
  
  //part of grid
  //when change filter ,change page no . etc, 
  filter($event){
    let obj = $event;
    this.currentPage = obj.page;
    this.filterObj = obj.filter;
    this.sortFilter = obj.sort
    this.getPortData();
  }

  //part of grid
  funOpenRightSidebar(){
    this.openRightSidebar = true;
    this.el.nativeElement.focus(); 
  }

}

