import { Component, AfterViewInit,OnInit, createPlatformFactory } from '@angular/core';
import { NgbPaginationConfig, NgbModal, NgbModalRef, ModalDismissReasons } from '@ng-bootstrap/ng-bootstrap';
import { CommonService } from '../common-service.service';
import {Router,ActivatedRoute} from "@angular/router";
import {FormGroup,FormBuilder,Validators,FormControl} from '@angular/forms';
import swal from 'sweetalert2';
//import { parse } from 'path';

declare var $: any;
import { PerfectScrollbarConfigInterface } from 'ngx-perfect-scrollbar';

@Component({
  templateUrl: './questionnaire.component.html',
  styleUrls: ['./questionnaire.component.scss']
})
export class QuestionnaireComponent implements AfterViewInit,OnInit {

  public config: PerfectScrollbarConfigInterface = {};

  options = {
    theme: 'light', // two possible values: light, dark
    dir: 'ltr', // two possible values: ltr, rtl
    layout: 'vertical', // fixed value. shouldn't be changed.
    sidebartype: 'mini-sidebar', // four possible values: full, iconbar, overlay, mini-sidebar 
    sidebarpos: 'fixed', // two possible values: fixed, absolute
    headerpos: 'fixed', // two possible values: fixed, absolute
    boxed: 'full', // two possible values: full, boxed
    navbarbg: 'skin6', // six possible values: skin(1/2/3/4/5/6)
    sidebarbg: 'skin5', // six possible values: skin(1/2/3/4/5/6)
    logobg: 'skin5' // six possible values: skin(1/2/3/4/5/6)
  };

  public Groupquestionnaire:FormGroup;
  public questionnaires = [];
  public questionnaires_view;
  public chapter_dropdown = [];
  public edit_id;
  public sire_id;
  public template_name;
  public formSubmittedAttempt = false;
  public openRightSidebar = false;
  public viewData = false;
  public filterObj:any = {};
  public sortFilter:any = {};

  //for grid 
  public headerInformation;
  public actionButtons;

  //for pagination
  itemsPerPage: number = this.commonService.DefaultItemsPerPage;
  totalItems: number;
  currentPage: number = 1;
  
  constructor(private modalService: NgbModal,
    private commonService: CommonService,
    private router: Router,
    private formBuilder: FormBuilder,
    private route: ActivatedRoute){
      this.declareGridVariable()
  }
  
  ngAfterViewInit(){
   
  }

  ngOnInit(){

   this.route.params.subscribe(params => {
      this.sire_id = params['sire_id'];
   });

    this.getData();
    this.addForm();
    this.chapter();
    this.sireData();
    //this.editForm();
  }

  sireData(){
    this.commonService.sendRequestToNode({method :'get',path:'sire/getById/'+this.sire_id}).subscribe(
      data => { 
        this.template_name = data.data[0]['TEMPLATE_NAME'];
    })
  }
  addForm(){
    this.Groupquestionnaire = this.formBuilder.group({
      CHAPTER_FK: ['',[Validators.required]],
      QUESTION_NUMBER: ['',[Validators.required]],
      QUESTION_DESCRIPTION: ['',[Validators.required]],
      RISK_PROFILE: ['',[Validators.required]],
      QUESTION_COMMENTS: ['',[Validators.required]],
      SIRE_FK:[]
    });   
  }

  edit(id){
    this.openRightSidebar = true;
    this.commonService.sendRequestToNode({method :'get',path:'questionnaire/getById/'+id}).subscribe(
      data => { 
        this.Groupquestionnaire.patchValue(data.data[0]);
        this.edit_id = id;
    })
  }

  // onSubmit(){
  //   //console.log(this.edit_id);
  //   this.formSubmittedAttempt = true;
  //   if(this.Groupquestionnaire.valid){
  //     if(this.edit_id){
  //       this.commonService.sendRequestToNode({method :'post',path:'questionnaire/edit/'+this.edit_id,postData:this.Groupquestionnaire.value}).subscribe(
  //         data =>{
  //           var dialogueTitle = "Updated!";
  //           if(data.status){
  //             swal({
  //               title: dialogueTitle,
  //               text: data.message,
  //               type: 'success',
  //               confirmButtonClass: "btn btn-success",
  //               buttonsStyling: false
  //             })
  //             this.getData();
  //             this.openRightSidebar = false;
  //             this.resetForm();
  //           }else{
  //             alert(data.message);
  //           }
  //       })
  //     }else{
  //       // console.log('test');
  //       this.Groupquestionnaire.patchValue({
  //         SIRE_FK : this.sire_id
  //       });
  //       console.log(this.Groupquestionnaire.value);
  //       this.commonService.sendRequestToNode({method :'post',path:'questionnaire/add',postData:this.Groupquestionnaire.value}).subscribe(
  //         data =>{
  //           var dialogueTitle = "Inserted!";
  //           if(data.status){
  //             swal({
  //               title: dialogueTitle,
  //               text: data.message,
  //               type: 'success',
  //               confirmButtonClass: "btn btn-success",
  //               buttonsStyling: false
  //             })
  //             this.getData();
  //             this.openRightSidebar = false;
  //             this.resetForm();
  //           }else{
  //             alert(data.message);
  //           }
  //       })
  //     }
  //   }  
  // }

  getData()
  {
    let filterParams:any = {}
    
    //search filter 
    filterParams = JSON.parse(JSON.stringify(this.filterObj));
    //search filter -end

    // pagination
    filterParams.currentPage = this.currentPage-1;
    filterParams.itemsPerPage = this.itemsPerPage;
    filterParams.sire_id  =this.sire_id;
    // pagination - end

    //sorting 
    let sortKey = Object.keys(this.sortFilter);
    if(sortKey.length && this.sortFilter[sortKey[0]]){
      filterParams.sortBy = sortKey[0];
      filterParams.sortStatus = this.sortFilter[sortKey[0]];
    }
    //sorting - end

    this.commonService.sendRequestToNode({method :'get',path:'questionnaire/data_list',queryParam:filterParams}).subscribe(result => {
        if(result.status)
        {
          if(result.data.length > 0){
            this.totalItems = result.data[0].total_records;
            this.questionnaires = result.data;
            
          }else{
            this.questionnaires = [];
          }
        }
        else{
          this.questionnaires = [];
          alert(result.message);
        }
    })
  }

  view(id){
    this.viewData = true;
    this.openRightSidebar = true;
    //console.log(id);
    this.commonService.sendRequestToNode({method :'get',path:'questionnaire/getById/'+id}).subscribe(result => {
        if(result.status)
        {
          this.questionnaires_view = result.data[0];
          //console.log(this.questionnaires_view);
        }
        else{
          alert(result.message)
        }
    })
  }

  chapter()
  {

    this.commonService.sendRequestToNode({method :'get',path:'questionnaire/chapter-dropdown'}).subscribe(result => {
      if(result.status){
        this.chapter_dropdown = result.data;
        //console.log(this.chapter_dropdown);
      }
      else{
        this.chapter_dropdown = [];
        alert(result.message);
      }
    })
  }

  resetForm(){
    this.formSubmittedAttempt = false;
    this.openRightSidebar = false;
    this.viewData = false;
    this.edit_id = '';
    this.Groupquestionnaire.patchValue({
      CHAPTER_FK: '',
      QUESTION_COMMENTS: '' ,
      QUESTION_NUMBER : '',
      QUESTION_DESCRIPTION:'',
      RISK_PROFILE : ''
    })
  }

  // part of grid
  declareGridVariable(){
    let risk_profile = {
      1 : 'Low Risk',
      2 : 'Medium Risk',
      3 : 'High Risk',
      4 : 'Very High Risk'
    }
    let optionForRisk = [
      {display_name:'Low Risk',value :1 },
      {display_name:'Medium Risk',value :2 },
      {display_name:'High Risk',value :3 },
      {display_name:'Very High Risk',value :4 }
    ]
    
    this.headerInformation = [
      {
        title : 'Chapter',// show title table header
        //nameIcon : true,// show icon of First letter
        name:'CHAPTER_NAME',// name of column in data source
        width : '18%',// width of column in table
        isSortable : true,// sort by column false or true
        highlight:true, // name highlight
        isFilter:{ // filter 
          type : 'text',
          placeholder : 'Filter By Chapter'
        }
      },
      {title : 'Question Number',name:'QUESTION_NUMBER',width : '18%',isSortable : true,isFilter:{ // filter 
        type : 'text',
        placeholder : 'Filter By Question Number'
      }},
      {title : 'Question Description',name:'QUESTION_DESCRIPTION',width : '18%',isSortable : true,isFilter:{ // filter 
        type : 'text',
        placeholder : 'Filter By Question Description'
      }},
      //{title : 'Risk Profile',name:'RISK_PROFILE',display_value:risk_profile,width : '18%',isSortable : true},
      {title : 'Risk Profile',type:'select',name:'COMPANY_RISK_PROFILE',options : optionForRisk,option_display : 'display_name',option_value : 'value',width : '18%',isSortable : true,placeholder : 'Select Risk'},
      {title : 'View',name:'action',width : '10%'}
    ];
    this.actionButtons = [
      {title:'View',class : "fas fa-eye"},
      //{title:'Edit Risk Profile',class : "far fa-edit"},
    //  {title:'Delete',class : "far fa-trash-alt"}
    ]
  }

getRiskName(id){
  let risk;
  if(id == 1){

  }else if(id == 2){

  }else if(id == 3){

  }else if(id == 4){

  }
}
  //part of grid
  clickOnAction(actionObj){
    if(actionObj.actionName == 'View'){
      this.view(actionObj.object.ID)
    }else if(actionObj.actionName == 'Edit Risk Profile'){
      this.edit(actionObj.object.ID)
    }else if(actionObj.actionName == 'risk'){
      this.updateData(actionObj.object)
    }
  }
  updateData(questionObj){
    this.commonService.sendRequestToNode({method :'post',path:'questionnaire/edit/'+questionObj.ID,postData:questionObj}).subscribe((result)=>{
      //alert(result);
    })
  }
  
  //part of grid
  //when change filter ,change page no . etc, 
  filter($event){
    let obj = $event;
    this.currentPage = obj.page;
    this.filterObj = obj.filter;
    this.sortFilter = obj.sort
    this.getData();
  }

  //part of grid
  funOpenRightSidebar(){
    this.openRightSidebar = true; 
  }




}
