import { Component, AfterViewInit,OnInit, createPlatformFactory,ElementRef,ViewChild } from '@angular/core';
import { NgbPaginationConfig, NgbModal, NgbModalRef, ModalDismissReasons } from '@ng-bootstrap/ng-bootstrap';
import { CommonService } from '../common-service.service';
import {Router,ActivatedRoute} from "@angular/router";
import {FormGroup,FormBuilder,Validators,FormControl} from '@angular/forms';
import swal from 'sweetalert2';

declare var $: any;
import { PerfectScrollbarConfigInterface } from 'ngx-perfect-scrollbar';

@Component({
  templateUrl: './rank.component.html',
  styleUrls: ['./rank.component.scss']
})
export class RankComponent implements AfterViewInit,OnInit {

  public config: PerfectScrollbarConfigInterface = {};
  
  public rankData = [];
  public rankForm:FormGroup;  
  public edit_id;
  public formSubmittedAttempt = false;
  public openRightSidebar = false;
  public filterObj:any = {};
  public sortFilter:any = {};
  public showSideBarLoader = false;
  public showLoader = false;
  modalReference: NgbModalRef;
  public valueOfYear = [];
  public viewData = false;
  //for grid 
  public headerInformation;
  public actionButtons;

  //for pagination
  itemsPerPage: number = this.commonService.DefaultItemsPerPage;
  totalItems: number;
  currentPage: number = 1;

  @ViewChild('autofocus') el:ElementRef;
 
  constructor(private modalService: NgbModal,
    private commonService: CommonService,
    private router: Router,
    private formBuilder: FormBuilder,
    private route: ActivatedRoute){
      this.declareGridVariable();
      let year = 2014;
      while(year <= new Date().getFullYear()){
        this.valueOfYear.push({'ID' : year,'year' : year});
        year++;
      }
  }

  // part of grid
  declareGridVariable(){
    this.headerInformation = [
      {
        title : 'Rank',// show title table header
        nameIcon : true,// show icon of First letter
        name:'RANK',// name of column in data source
        width : '20%',// width of column in table
        isSortable : true,// sort by column false or true
        isFilter:{ // filter 
          type : 'text',
          placeholder : 'Filter By Rank'
        }
      },
      // {title : 'Shore Assignment Kpi',name:'SHORE_ASSIGNMENT_KPI',width : '30%'},
      {title : '',name:'',width : '70%'},
      {title : 'Action',name:'action',width : '10%'}
    ];
    this.actionButtons = [
      {title:'View',class : "fas fa-eye"},
      {title:'Edit',class : "far fa-edit"},
      {title:'Delete',class : "far fa-trash-alt"}
    ]
  }

  ngAfterViewInit(){
   
  }

  ngOnInit(){
    this.getData();
    this.addForm();
  }
  
  getData()
  {
    let filterParams:any = {}
    
    //search filter 
    filterParams = JSON.parse(JSON.stringify(this.filterObj));
    //search filter -end

    // pagination
    filterParams.currentPage = this.currentPage-1;
    filterParams.itemsPerPage = this.itemsPerPage;
    // pagination - end

    //sorting 
    let sortKey = Object.keys(this.sortFilter);
    if(sortKey.length && this.sortFilter[sortKey[0]]){
      filterParams.sortBy = sortKey[0];
      filterParams.sortStatus = this.sortFilter[sortKey[0]];
    }
    //sorting - end
    this.showLoader = true;
    this.commonService.sendRequestToNode({method :'get',path:'rank',queryParam:filterParams}).subscribe(result => {
      this.showLoader = false;        
        
      if(result.status)
        {
          if(result.data.length > 0){
            this.totalItems = result.data[0].total_records;
            this.rankData = result.data;
          }else{
            this.rankData = [];
          }
        }
        else{
          this.rankData = [];
          alert(result.message);
        }
    })
  }

  addForm(){
    this.rankForm = this.formBuilder.group({
      RANK: ['',[Validators.required]],
      SHORE_ASSIGNMENT_KPI : [0]
    });   
  }

  resetForm(){
    this.viewData = false;
    this.formSubmittedAttempt = false;
    this.openRightSidebar = false;
    this.edit_id = '';
    this.valueOfYear = [];
    let year = 2014;
    while(year <= new Date().getFullYear()){
      this.valueOfYear.push({'year' : year,'value' : 0});
      year++;
    }

    this.rankForm.patchValue({
      RANK : '',
      SHORE_ASSIGNMENT_KPI : 0
    })
  }

  edit(id){
    this.openRightSidebar = true;
    this.el.nativeElement.focus();
    this.commonService.sendRequestToNode({method :'get',path:'rank/'+id}).subscribe(
      data => {         
        if(data.data.SHORE_ASSIGNMENT_KPI){
          this.valueOfYear = [];
          let obj = JSON.parse(data.data.SHORE_ASSIGNMENT_KPI);
          Object.keys(obj).forEach(ele=>{
            this.valueOfYear.push({'year':ele,value:obj[ele]})
          })
          
        }
        this.rankForm.patchValue({
          RANK : data.data.RANK
        })
        this.edit_id = id;
    })
  }

  view(id){
    this.viewData = true;
    this.openRightSidebar = true;
    this.el.nativeElement.focus();
    this.commonService.sendRequestToNode({method :'get',path:'rank/'+id}).subscribe(
      data => {         
        if(data.data.SHORE_ASSIGNMENT_KPI){
          let obj = JSON.parse(data.data.SHORE_ASSIGNMENT_KPI);
          this.valueOfYear = [];
          Object.keys(obj).forEach(ele=>{
            this.valueOfYear.push({'year':ele,value:obj[ele]})
          })
          
        }
        this.rankForm.patchValue({
          RANK : data.data.RANK
        })
        this.edit_id = id;
    })
  }
  

  delete(id){
    if(id){
      swal({
        title: 'Are you sure?',
        text: "You won't be able to revert this!",
        type: 'warning',
        showCancelButton: true,
        confirmButtonClass: 'btn btn-success',
        cancelButtonClass: 'btn btn-danger',
        confirmButtonText: 'Yes, delete it!',
         buttonsStyling: false
      }).then((result) => {
        if (result.value) {
          this.commonService.sendRequestToNode({method :'delete',path:'rank/'+id}).subscribe(
          data => {
          if(data.status){
            var dialogueTitle = "Deleted!"
            if(this.rankData.length == 1 && Math.ceil(this.totalItems / this.itemsPerPage) == this.currentPage){
              if(this.currentPage>1){
                this.currentPage--;
              }
            }
            this.getData();
            swal({
                title: dialogueTitle,
                text: data.message,
                type: 'success',
                confirmButtonClass: "btn btn-success",
                buttonsStyling: false
              })
          }         
          
      })
         }
      })      
    }
  }

  onSubmit(){ 
    this.formSubmittedAttempt = true;
    if(this.valueOfYear.length){
      let obj={};
      this.valueOfYear.forEach(e=>{
        obj[e.year] = e.value; 
      });
      this.rankForm.patchValue({
        SHORE_ASSIGNMENT_KPI : JSON.stringify(obj)
      });
    }

    if(this.rankForm.valid){
    this.valueOfYear = [];
    this.showSideBarLoader = true;
    if(this.edit_id){    
      this.commonService.sendRequestToNode({method :'put',path:'rank/'+this.edit_id,postData:this.rankForm.value}).subscribe(
        data =>{
          var dialogueTitle = "Updated!";
          this.showSideBarLoader = false;
          if(data.status){
            swal({
                title: dialogueTitle,
                text: data.message,
                type: 'success',
                confirmButtonClass: "btn btn-success",
                buttonsStyling: false
              })
            this.getData();
            this.resetForm(); //after edit form is reset
          }
          else{
            alert(data.message);
          }
      })
    }else{
      this.commonService.sendRequestToNode({method :'post',path:'rank',postData:this.rankForm.value}).subscribe(
        data =>{
          var dialogueTitle = "Inserted!";
          this.showSideBarLoader = false;
          if(data.status){
            swal({
                title: dialogueTitle,
                text: data.message,
                type: 'success',
                confirmButtonClass: "btn btn-success",
                buttonsStyling: false
              })
            this.getData();
            this.resetForm(); //after edit form is reset

          }
          else{
            alert(data.message);
          }
      })
    }
    }
      
  } 

    //part of grid
    clickOnAction(actionObj){
      if(actionObj.actionName == 'Edit'){
        this.edit(actionObj.object.ID)
      }else if(actionObj.actionName == 'Delete'){
        this.delete(actionObj.object.ID)
      }
      else if(actionObj.actionName == "View"){
        this.view(actionObj.object.ID);
      }
      
    }
  
    //part of grid
    //when change filter ,change page no . etc, 
    filter($event){
      let obj = $event;
      this.currentPage = obj.page;
      this.filterObj = obj.filter;
      this.sortFilter = obj.sort
      this.getData();
    }
  
    //part of grid
    funOpenRightSidebar(){
      this.openRightSidebar = true;
      this.el.nativeElement.focus();
    }
  

}

