import { Component, AfterViewInit, OnInit, createPlatformFactory, ElementRef, ViewChild } from '@angular/core';
import { NgbPaginationConfig, NgbModal, NgbModalRef, ModalDismissReasons } from '@ng-bootstrap/ng-bootstrap';
import { CommonService } from '../common-service.service';
import { Router, ActivatedRoute } from "@angular/router";
import { FormGroup, FormBuilder, Validators, FormControl } from '@angular/forms';
import swal from 'sweetalert2';
import * as pluginAnnotations from 'chartjs-plugin-annotation';
declare var $: any;
import { PerfectScrollbarConfigInterface } from 'ngx-perfect-scrollbar';
import 'chartjs-plugin-labels';
import { ConsoleService } from '@ng-select/ng-select/ng-select/console.service';
import { log } from 'util';
import { saveAs } from 'file-saver';

@Component({
  templateUrl: './retention_rate_calculator.component.html',
  styleUrls: ['./retention_rate_calculator.component.scss']
})
export class RetentionRateCalculatorComponent implements AfterViewInit, OnInit {

  public config: PerfectScrollbarConfigInterface = {};

  tabStatus = 'justified';
  public documentPath = this.commonService.getDocumentPath();

  public courseData = [];
  public courseForm: FormGroup;
  public actionForm: FormGroup;
  public subscription;
  public retationRateData = [];
  public retationRateForm: FormGroup;
  public edit_id;
  public action_edit_id;
  public formSubmittedAttempt = false;
  public openRightSidebar_tab1 = false;
  public openRightSidebar_tab2 = false;
  public filterObj: any = {};
  public sortFilter: any = {};
  public actionFilterObj: any = {};
  public actionSortFilter: any = {};
  public actionCompaignList = [];
  public actionRetentionData = [];
  public enableDownloadPdfBtn = true;
  public viewActionData: any = '';
  public editImageDisplay = "";
  modalReference: NgbModalRef;
  public target_retention_rate_ship = 0;
  public target_retention_rate_shore = 0;
  public showSideBarLoader_tab1 = false;
  public showLoader_tab1 = false;
  public showSideBarLoader_tab2 = false;
  public showLoader_tab2 = false;
  public labelArray = [];
  public filterObjChart: any = { isShip : false,shipFlag : 'company' ,start_date: this.commonService.formatDate(new Date().setMonth(-6)), end_date: this.commonService.formatDate(new Date()) };
  public oldFilterObjChart: any = { isShip : false ,shipFlag : 'company',start_date: this.commonService.formatDate(new Date().setMonth(-6)), end_date: this.commonService.formatDate(new Date()) };
  public target_retention_rate = 0;

  public shipFlagDropdown = [
    {ID: 'company', label: 'Company'},
    {ID: 'all_officer', label: 'All Officer'},
    {ID: 'senior_officer', label: 'Senior Officer'},
  ]

  //for grid 
  public Action_headerInformation;
  public headerInformation;
  public actionButtons;
  public actionButtonsForAction;
  //for pagination
  itemsPerPage: number = this.commonService.DefaultItemsPerPage;
  totalItems: number;
  currentPage: number = 1;
  actionCurrentPage: number = 1;
  actionTotalItems: number;
  public fileAllowType = [
    'application/zip',
    'application/octet-stream',
    'application/x-zip-compressed',
    'multipart/x-zip' 
  ]
  
  @ViewChild('autofocus') el: ElementRef;
  @ViewChild('Actionautofocus') el1: ElementRef;
  @ViewChild('fileInput') fi: ElementRef;

  constructor(private modalService: NgbModal,
    private commonService: CommonService,
    private router: Router,
    private formBuilder: FormBuilder,
    private route: ActivatedRoute) {
    this.declareGridVariable();
  }

  // part of grid
  declareGridVariable() {
    this.Action_headerInformation = [
      {
        title: 'Campaign Date',// show title table header
        nameIcon: true,// show icon of First letter
        name: 'ACTION_RETATION_DATE',// name of column in data source
        width: '20%',// width of column in table
        isDate: 'yes',
        isSortable: true,// sort by column false or true
        highlight:true,
      },
      {
        title: 'Campaign Name',// show title table header
        nameIcon: true,// show icon of First letter
        name: 'ACTION_CAMPAIGN',// name of column in data source
        width: '20%',// width of column in table
        isSortable: true,// sort by column false or true
        isFilter:{ // filter 
          type : 'text',
          placeholder : 'Filter By Campaign Name'
        }
      },
      {
        title: 'Campaign Remarks',// show title table header
        nameIcon: true,// show icon of First letter
        name: 'ACTION_REMARKS',// name of column in data source
        width: '40%',// width of column in table
        isSortable: true,// sort by column false or true
        isFilter:{ // filter 
          type : 'text',
          placeholder : 'Filter By Campaign Remark'
        }
      },

      // { title: '', name: '', width: '45%' },
      { title: 'Action', name: 'action', width: '20%' }
    ]
    this.headerInformation = [
      { title: 'Date', name: 'RETATION_DATE', width: '10%', isDate: 'yes', isSortable: true, highlight:true},
      { title: 'Unavoidable Terminations (UT)', name: 'UT', width: '7%', isSortable: true },
      { title: 'Beneficial Terminations  (BT)  ', name: 'BT', width: '7%', isSortable: true },
      { title: 'AE', name: 'AE', width: '7%', isSortable: true },
      { title: 'S', name: 'S', width: '7%', isSortable: true },
      { title: 'Calculated Retention Rate(%)', name: 'CALCULTED_RETENTION_RATE', width: '15%', isSortable: true },
      { title: 'Target Retention Rate(%)', name: 'TARGET_RETENTION_RATE', width: '10%', isSortable: true },
      { title: 'Location',
        name: 'TYPE',
        width: '10%',
        isSortable: true,
        isFilter:{ // filter 
          type : 'select',
          placeholder : 'Filter By Type',
          options_value : ['shore','ship'],
          options_display : ['Shore','Ship']
        }
      },  
      { title: 'Data Type',
        name: 'SHIP_FLAG',
        width: '12%',
        display_value : {'company' : 'Company' ,'all_officer' : 'All Officer','senior_officer' : 'Senior Officer'},
        isSortable: true,
        isFilter:{ // filter 
          type : 'select',
          placeholder : 'Filter By SHIP_FLAG',
          options_value : ['company','all_officer','senior_officer'],
          options_display : ['Company','All Officer','Senior Officer']
        }
      },      
      { title: 'Action', name: 'action', width: '15%' }
    ];
    this.actionButtons = [
      { title: 'Edit', class: "far fa-edit" },
      { title: 'Delete', class: "far fa-trash-alt" }
    ]
    this.actionButtonsForAction = [
      { title: 'View', class: "fa fa-eye" },
      { title: 'Edit', class: "far fa-edit" },
      { title: 'Delete', class: "far fa-trash-alt" },
      { title: 'Download-Report',class : "fas fa-download"}
    ]
  }

  ngAfterViewInit() {
  }

  ngOnInit() {
    this.getActionData();
    this.getActionCompaignDropDown()
    this.getData();
    this.getChartData();
    this.addForm();
    this.targetRetentionRate();
  }

  // lineChart
  public lineChartData: Array<any> = [];
  public lineChartLabels: Array<any> = [];
  // public lineChartOptions: any = {
  //   responsive: true,
  //   annotation: {
  //     drawTime: 'afterDatasetsDraw',
  //     annotations: []
  //     // [
  //     //   {
  //     //     type: "line",
  //     //     mode: "vertical",
  //     //     scaleID: "x-axis-0",
  //     //     value: '12/05/2019',
  //     //     borderWidth: 5,
  //     //     borderColor: "red",
  //     //     label: {
  //     //       content: "TODAY",
  //     //       enabled: true,
  //     //       position: "middle"
  //     //     }
  //     //   },
  //     //   {
  //     //     type: "line",
  //     //     mode: "vertical",
  //     //     scaleID: "x-axis-0",
  //     //     value: '17/07/2019',
  //     //     borderWidth: 5,
  //     //     borderColor: "red",
  //     //     label: {
  //     //       content: "TODAY",
  //     //       enabled: true,
  //     //       position: "top"
  //     //     }
  //     //   }
  //     // ]
  //   },
  //   scales: {
  //     xAxes: [{
  //       ticks: {
  //         autoSkip: false
  //       },
  //     }],
  //   },
  // };
 public isStrShip = ( this.oldFilterObjChart.isShip ) ? "Ship Staff " : " Shore Staff"; 
 public selectedOfficer = "Company";
 public filterStr = "Form Date:" + this.oldFilterObjChart.start_date + " End Date:" + this.oldFilterObjChart.end_date + " " + this.isStrShip + " " + this.selectedOfficer;
  public lineChartOptions: any = {
    title: {
      text: this.filterStr,
      display: true,
      position: 'bottom'
    },
    scaleShowVerticalLines: true,
    responsive: true,
    barThickness: 1,
    annotation: {
      drawTime: 'afterDatasetsDraw',
      annotations: []
      // [
      //   {
      //     type: "line",
      //     mode: "vertical",
      //     scaleID: "x-axis-0",
      //     value: '12/05/2019',
      //     borderWidth: 5,
      //     borderColor: "red",
      //     label: {
      //       content: "TODAY",
      //       enabled: true,
      //       position: "middle"
      //     }
      //   },
      //   {
      //     type: "line",
      //     mode: "vertical",
      //     scaleID: "x-axis-0",
      //     value: '17/07/2019',
      //     borderWidth: 5,
      //     borderColor: "red",
      //     label: {
      //       content: "TODAY",
      //       enabled: true,
      //       position: "top"
      //     }
      //   }
      // ]
    },
    scales: {
      xAxes: [{
          ticks: {
              autoSkip : true,
          },
         
      }],
      yAxes: [{
        scaleLabel: {
            display: true,
            labelString: 'Retension Rate'
        }
      }]
    },
    
    plugins: {
      labels: {
        // render 'label', 'value', 'percentage', 'image' or custom function, default is 'percentage'
        render: 'value',

        // precision for percentage, default is 0
        precision: 0,

        // identifies whether or not labels of value 0 are displayed, default is false
        showZero: false,

        // font size, default is defaultFontSize
        fontSize: 10,

        // font color, can be color array for each data or function for dynamic color, default is defaultFontColor
        fontColor: '#000',

        // font style, default is defaultFontStyle
        fontStyle: 'normal',

        // font family, default is defaultFontFamily
        fontFamily: "'Helvetica Neue', 'Helvetica', 'Arial', sans-serif",

        // draw text shadows under labels, default is false
      //   textShadow: true,

        // text shadow intensity, default is 6
      //   shadowBlur: 10,

        // text shadow X offset, default is 3
        shadowOffsetX: -5,

        // text shadow Y offset, default is 3
        shadowOffsetY: 5,

        // text shadow color, default is 'rgba(0,0,0,0.3)'
        shadowColor: 'rgba(255,0,0,0.75)',

        // draw label in arc, default is false
        // bar chart ignores this
        arc: true,

        // position to draw label, available value is 'default', 'border' and 'outside'
        // bar chart ignores this
        // default is 'default'
        position: 'default',

        // draw label even it's overlap, default is true
        // bar chart ignores this
        overlap: true,

        // show the real calculated percentages from the values and don't apply the additional logic to fit the percentages to 100 in total, default is false
        showActualPercentages: true,

        

        // add padding when position is `outside`
        // default is 2
        outsidePadding: 4,

        // add margin of text when position is `outside` or `border`
        // default is 2
        textMargin: 2
      }
    }
  };


  public lineChartColors: Array<any> = [
    {
      // grey
      backgroundColor: 'rgba(54,190,166,.1)',
      borderColor: '#36bea6',
      pointBackgroundColor: '#36bea6',
      pointBorderColor: '#fff',
      pointHoverBackgroundColor: '#fff',
      pointHoverBorderColor: '#36bea6'
    },
  ];
  public lineChartLegend = true;
  public lineChartType = 'line';
  public barChartType = 'bar';
  public lineChartPlugins = [pluginAnnotations];

  getChartData() {

    this.labelArray = [];
    this.lineChartData.length = 0;
    this.lineChartOptions.annotation.annotations = [];
    this.oldFilterObjChart = {...this.filterObjChart};
    this.isStrShip = ( this.oldFilterObjChart.isShip ) ? "Ship Staff " : " Shore Staff"; 
    if( this.oldFilterObjChart.shipFlag == 'all_officer') {
         this.selectedOfficer =  'All Officer';
    } else if( this.oldFilterObjChart.shipFlag == 'senior_officer' ) {
      this.selectedOfficer =  'Senior Officer';
    } else {
      this.selectedOfficer =  'Company';
    }
    this.filterStr = "Form Date:" + this.oldFilterObjChart.start_date + " /  End Date:" + this.oldFilterObjChart.end_date + " / " + this.isStrShip + " /  " + this.selectedOfficer;
    let dataArray = []
    this.commonService.sendRequestToNode({ method: 'post', path: 'retention-rate/getChartData',postData: this.filterObjChart }).subscribe(result => {
      if (result.status) {
        let arrayOfAction = [];
        if(result.data.length){
          result.data.forEach((element,key) => {
            this.labelArray.push(element.DATE);
            dataArray.push(element.CALCULTED_RETENTION_RATE);

            if(element.RETATION_DATE && result.data[key+1]){
              result.actionData.forEach(ele => {
                
                let dateOfRetention = new Date(element.RETATION_DATE).getTime();
                let dateOfNextRetention = new Date(result.data[key+1].RETATION_DATE).getTime();
                let DateOfActonRetention = new Date(ele.DATE).getTime();
                if(dateOfRetention < DateOfActonRetention && DateOfActonRetention <  dateOfNextRetention){
                  this.labelArray.push(this.commonService.formatDate(DateOfActonRetention,'d/m/y'));
                  dataArray.push(null)
                }
                arrayOfAction.push({
                  type: "line",
                  mode: "vertical",
                  scaleID: "x-axis-0",
                  value: this.commonService.formatDate(DateOfActonRetention,'d/m/y'),
                  borderWidth: 1,
                  borderColor: "red",
                  label: {
                    content: ele.ACTION_CAMPAIGN,
                    enabled: true,
                    position: ""
                  }
                });
              });
            }
          });
          this.lineChartData = [
            { data: dataArray, label: 'Retention Rate',spanGaps:true,type:'line', options: {
              scales: {
                  yAxes: [{
                      display: true,
                      ticks: {
                          beginAtZero: true
                      }
                  }]
              },
              title: {
                text: this.filterStr,
                display: true,
                position: 'bottom'
              },
              
            },  }
          ];
          this.lineChartLabels = this.labelArray;

          // console.log(arrayOfAction);

          // console.log(this.lineChartOptions.annotation.annotations)
          arrayOfAction.forEach(ele=>{
            this.lineChartOptions.annotation.annotations.push(ele);
          })
          //horizontal line (target retention rate)
          this.lineChartOptions.title.text = this.filterStr;
          this.lineChartOptions.annotation.annotations.push({type: "line",
            mode: "horizontal",
            scaleID: "y-axis-0",
            value: (this.filterObjChart.isShip) ? result.TARGET_RETENTION_RATE_SHIP : result.TARGET_RETENTION_RATE_SHORE,// this value dynamic after target retention module complete
            borderWidth: 2,
            borderColor: "green",
            label: {
              content: 'Target Retention',
              enabled: true,
              position: "top", 
              class: "targetPosition",
              id:"targetPositionId"
            }});
        }
        // console.log(this.labelArray);
        // console.log(this.dataArray);
        // this.lineChartOptions.annotation.annotations.length = 0;
      }
      else {
        //this.rank_dropdown = [];
        alert(result.message);
      }
    })
  }

  targetRetentionRate() {
    this.commonService.sendRequestToNode({ method: 'get', path: 'getTargetRetentionRate' }).subscribe(result => {
      if (result.status) {
        this.target_retention_rate_ship = result.TARGET_RETENTION_RATE_SHIP ;
        this.target_retention_rate_shore = result.TARGET_RETENTION_RATE_SHORE;
        this.retationRateForm.patchValue({
          TARGET_RETENTION_RATE: result.TARGET_RETENTION_RATE_SHIP
        })
      }
      else {
        this.retationRateForm.patchValue({
          TARGET_RETENTION_RATE: ''
        })
      }
    })
  }
  changeTargetRetention(type = "ship") {
    if(type == 'shore') {
      this.retationRateForm.patchValue({
        TARGET_RETENTION_RATE: this.target_retention_rate_shore
      });
    }
    else{
      this.retationRateForm.patchValue({
        TARGET_RETENTION_RATE: this.target_retention_rate_ship
      });
    }
  }

  //krunal
  getActionCompaignDropDown() {
    this.commonService.sendRequestToNode({ method: 'get', path: 'get-action-campaign-dropdown' }).subscribe(
      result => {
        this.actionCompaignList = result.data;
      })
  }

  getData() {
    let filterParams: any = {}

    //search filter 
    filterParams = JSON.parse(JSON.stringify(this.filterObj));
    //search filter -end

    // pagination
    filterParams.currentPage = this.currentPage - 1;
    filterParams.itemsPerPage = this.itemsPerPage;
    // pagination - end

    //sorting 
    let sortKey = Object.keys(this.sortFilter);
    if (sortKey.length && this.sortFilter[sortKey[0]]) {
      filterParams.sortBy = sortKey[0];
      filterParams.sortStatus = this.sortFilter[sortKey[0]];
    }
    //sorting - end
    this.showLoader_tab1 = true;
    this.commonService.sendRequestToNode({ method: 'get', path: 'retation-rate', queryParam: filterParams }).subscribe(result => {
    this.showLoader_tab1 = false;        
        if (result.status) {
          if (result.data.length > 0) {
            this.totalItems = result.data[0].total_records;
            this.retationRateData = result.data;
          } else {
            this.retationRateData = [];
          }
        }
        else {
          this.retationRateData = [];
          alert(result.message);
        }
      })
  }

  getActionData() {
   
    let filterParams: any = {}

    //search filter 
    filterParams = JSON.parse(JSON.stringify(this.actionFilterObj));
    //search filter -end

    // pagination
    filterParams.currentPage = this.actionCurrentPage - 1;
    filterParams.itemsPerPage = this.itemsPerPage;
    // pagination - end8

    //sorting 
    let sortKey = Object.keys(this.actionSortFilter);
    if (sortKey.length && this.actionSortFilter[sortKey[0]]) {
      filterParams.sortBy = sortKey[0];
      filterParams.sortStatus = this.actionSortFilter[sortKey[0]];
    }
    //sorting - end
    this.showLoader_tab2 = true;
    this.commonService.sendRequestToNode({ method: 'get', path: 'actionRetention', queryParam: filterParams }).subscribe(result => {
    this.showLoader_tab2 = false;
        if (result.status) {
          if (result.data.length > 0) {
            this.actionTotalItems = result.data[0].total_records;
            this.actionRetentionData = result.data;
          } else {
            this.actionRetentionData = [];
          }
        }
        else {
          this.actionRetentionData = [];
          alert(result.message);
        }
      })
  }

  addForm() {
    this.actionForm = this.formBuilder.group({
      ACTION_RETATION_DATE: [''],
      ACTION_REMARKS: '',
      ACTION_CAMPAIGN_FK: null,
      FILE: ''
    });
    this.retationRateForm = this.formBuilder.group({
      RETATION_DATE: ['',],
      UT: ['',],
      BT: ['',],
      AE: ['',],
      S: ['',],
      TARGET_RETENTION_RATE: ['',],
      TYPE: ['ship',],
      SHIP_FLAG : ['company'] // if select TYPE = 'ship' then use This Flag 
    });
  }

  resetForm_tab1() {
    this.formSubmittedAttempt = false;
    this.openRightSidebar_tab1 = false;
    this.edit_id = '';
    this.targetRetentionRate();
    this.retationRateForm.patchValue({
      RETATION_DATE: '',
      UT: '',
      BT: '',
      AE: '',
      S: '',
      TYPE: 'ship',
    })
  }

  resetForm_tab2() {
    this.openRightSidebar_tab2 = false;

    this.viewActionData = '';
    this.action_edit_id = '';
    this.actionForm.patchValue({
      ACTION_RETATION_DATE: '',
      ACTION_REMARKS: '',
      ACTION_CAMPAIGN_FK: null,
      FILE: ''
    })
  }

  editActionForm(id) {
    this.el1.nativeElement.focus();
    this.openRightSidebar_tab2 = true;
    this.commonService.sendRequestToNode({ method: 'get', path: 'actionRetention/' + id }).subscribe(
      data => {
        this.actionForm.patchValue({
          ACTION_RETATION_DATE: this.commonService.formatDate(new Date(data.data.ACTION_RETATION_DATE)),
          ACTION_REMARKS: data.data.ACTION_REMARKS,
          ACTION_CAMPAIGN_FK: data.data.ACTION_CAMPAIGN_FK ? parseInt(data.data.ACTION_CAMPAIGN_FK) : null,
        })
        this.editImageDisplay = data.data.ATTACHMENT;
        this.action_edit_id = id;
      })
  }
  edit(id) {
    this.el.nativeElement.focus();
    this.openRightSidebar_tab1 = true;
    this.commonService.sendRequestToNode({ method: 'get', path: 'retation-rate/' + id }).subscribe(
      data => {
        this.retationRateForm.patchValue({
          RETATION_DATE: (data.data.RETATION_DATE && data.data.RETATION_DATE != '00/00/0000') ? this.commonService.formatDate(new Date(data.data.RETATION_DATE)) : null,
          UT: data.data.UT,
          BT: data.data.BT,
          AE: data.data.AE,
          S: data.data.S,
          TARGET_RETENTION_RATE: data.data.TARGET_RETENTION_RATE,
          TYPE: data.data.TYPE,
          SHIP_FLAG: data.data.SHIP_FLAG,
        }),
          this.edit_id = id;
      })
  }

  onSubmit() {
    this.formSubmittedAttempt = true;
    
    if (this.retationRateForm.valid) {
      this.showSideBarLoader_tab1 = true;
      if (this.edit_id) {
        this.commonService.sendRequestToNode({ method: 'put', path: 'retation-rate/' + this.edit_id, postData: this.retationRateForm.value }).subscribe(
          data => {
            var dialogueTitle = "Updated!";
            this.showSideBarLoader_tab1 = false;
            if (data.status) {
              swal({
                title: dialogueTitle,
                text: data.message,
                type: 'success',
                confirmButtonClass: "btn btn-success",
                buttonsStyling: false
              })
              this.getData();
              this.getChartData();
              this.resetForm_tab1();
            }
            else {
              alert(data.message);
            }
          })
      } else {
        this.commonService.sendRequestToNode({ method: 'post', path: 'retation-rate', postData: this.retationRateForm.value }).subscribe(
          data => {
            var dialogueTitle = "Inserted!";
            this.showSideBarLoader_tab1 = false;
            if (data.status) {
              swal({
                title: dialogueTitle,
                text: data.message,
                type: 'success',
                confirmButtonClass: "btn btn-success",
                buttonsStyling: false
              })
              this.getData();
              this.getChartData();
              this.resetForm_tab1();

            }
            else {
              alert(data.message);
            }
          })
      }
    }

  }

  onActionSubmit() {
    if (this.actionForm.valid) {
      let formData = new FormData();//this.oilMajorForm.value
      formData.append("FILE", this.actionForm.get('FILE').value);
      formData.append("ACTION_RETATION_DATE", this.actionForm.get('ACTION_RETATION_DATE').value);
      formData.append("ACTION_REMARKS", this.actionForm.get('ACTION_REMARKS').value);
      formData.append("ACTION_CAMPAIGN_FK", this.actionForm.get('ACTION_CAMPAIGN_FK').value);
      
      this.showSideBarLoader_tab2 = true;
      
      if (this.action_edit_id) {
        this.commonService.sendRequestToNode({ method: 'put', path: 'actionRetention/' + this.action_edit_id, postData: formData }).subscribe(
          data => {
            var dialogueTitle = "Updated!";
            this.showSideBarLoader_tab2 = false;
            if (data.status) {
              swal({
                title: dialogueTitle,
                text: data.message,
                type: 'success',
                confirmButtonClass: "btn btn-success",
                buttonsStyling: false
              })
              this.getActionData();
              this.getChartData();
              this.resetForm_tab2(); //after edit form is reset
            }
            else {
              alert(data.message);
            }
          })
      } else {
        this.commonService.sendRequestToNode({ method: 'post', path: 'actionRetention', postData: formData }).subscribe(
          data => {
            var dialogueTitle = "Inserted!";
            this.showSideBarLoader_tab2 = false;
            if (data.status) {
              swal({
                title: dialogueTitle,
                text: data.message,
                type: 'success',
                confirmButtonClass: "btn btn-success",
                buttonsStyling: false
              })
              this.getActionData();
              this.getChartData();
              this.resetForm_tab2(); //after edit form is reset

            }
            else {
              alert(data.message);
            }
          })
      }
    }

  }

  clickOnAction(actionObj) {
    if (actionObj.actionName == 'Edit') {
      this.edit(actionObj.object.ID)
    } else if (actionObj.actionName == 'Delete') {
      this.delete(actionObj.object.ID)
    }
  }

  clickOnAction_tab2(actionObj) {
    console.log( actionObj.object );
    if (actionObj.actionName == 'Edit') {
      this.editActionForm(actionObj.object.ID)
    } else if (actionObj.actionName == 'Delete') {
      this.deleteActionForm(actionObj.object.ID)
    } else if (actionObj.actionName == 'View') {
      this.viewActionForm(actionObj.object.ID)
    }  else if( actionObj.actionName == 'Download-Report' ) {
            this.downloadActionPdf( actionObj.object.ATTACHMENT );      
    } 
  }

  downloadActionPdf( attachment ) {          
           window.location.href = this.documentPath +'/retention/' + attachment;
      }

  viewActionForm(id) {
    this.viewActionData = {};
    this.openRightSidebar_tab2 = true;
    this.showSideBarLoader_tab2 = true;
    this.commonService.sendRequestToNode({ method: 'get', path: 'actionRetention/' + id }).subscribe(data => {
      this.showSideBarLoader_tab2 = false;
      this.viewActionData = data.data;
    })
  }

  delete(id) {
    if (id) {
      swal({
        title: 'Are you sure?',
        text: "You won't be able to revert this!",
        type: 'warning',
        showCancelButton: true,
        confirmButtonClass: 'btn btn-success',
        cancelButtonClass: 'btn btn-danger',
        confirmButtonText: 'Yes, delete it!',
        buttonsStyling: false
      }).then((result) => {
        if (result.value) {
          this.commonService.sendRequestToNode({ method: 'delete', path: 'retation-rate/' + id }).subscribe(
            data => {
              if (data.status) {
                var dialogueTitle = "Deleted!"
                if (this.retationRateData.length == 1 && Math.ceil(this.totalItems / this.itemsPerPage) == this.currentPage) {
                  if (this.currentPage > 1) {
                    this.currentPage--;
                  }
                }
                this.getData();
                this.getChartData();
                swal({
                  title: dialogueTitle,
                  text: data.message,
                  type: 'success',
                  confirmButtonClass: "btn btn-success",
                  buttonsStyling: false
                })
              }
            })
        }
      })
    }
  }

  deleteActionForm(id) {
    if (id) {
      swal({
        title: 'Are you sure?',
        text: "You won't be able to revert this!",
        type: 'warning',
        showCancelButton: true,
        confirmButtonClass: 'btn btn-success',
        cancelButtonClass: 'btn btn-danger',
        confirmButtonText: 'Yes, delete it!',
        buttonsStyling: false
      }).then((result) => {
        if (result.value) {
          this.commonService.sendRequestToNode({ method: 'delete', path: 'actionRetention/' + id }).subscribe(
            data => {
              if (data.status) {
                var dialogueTitle = "Deleted!"

                this.getActionData();
                this.getChartData();
                swal({
                  title: dialogueTitle,
                  text: data.message,
                  type: 'success',
                  confirmButtonClass: "btn btn-success",
                  buttonsStyling: false
                })
              }

            })
        }
      })
    }
  }



  //when change filter ,change page no . etc, 
  filter($event) {
    let obj = $event;
    this.currentPage = obj.page;
    this.filterObj = obj.filter;
    this.sortFilter = obj.sort
    this.getData();
    
  }
  filter_tabs2($event) {
    let obj = $event;
    this.actionCurrentPage = obj.page;
    this.actionFilterObj = obj.filter;
    this.actionSortFilter = obj.sort
    this.getActionData();
    
  }

  //part of grid
  OpenRightSidebar_tab1() {
    this.el.nativeElement.focus();
    this.openRightSidebar_tab1 = true;
  }

  OpenRightSidebar_tab2() {
    this.el1.nativeElement.focus();
    this.openRightSidebar_tab2 = true;
  }

  onFileChange(event) {
    if (event.target.files.length) {
      if(this.fileAllowType.indexOf(event.target.files[0].type) > -1 ){
        // let fileSize = .toFixed(2)
        if(5 >= (event.target.files[0].size / 1024 / 1024)){
          this.actionForm.get('FILE').setValue(event.target.files[0]);
        }
        else{
          alert('File Size Must Be Less Than 5mb ');
          this.fi ? this.fi.nativeElement.value = "" : '';  
        }
        
      }
      else{
        alert('File Type Is Invalid');
        this.fi ? this.fi.nativeElement.value = "" : '';
      }
    } else {
      this.fi ? this.fi.nativeElement.value = "" : '';
    }
  }

  openModel(content) {
    this.modalReference = this.modalService.open(content, { size: 'sm' });
  }

  retentionRateChart() {
    var canvas:any = document.getElementById("retentionRateChart");
    var image = canvas.toDataURL("image/png"); 
    var link = document.createElement('a');
        link.download =  this.isStrShip + " / " + this.selectedOfficer + ' / Retention Rate Chart.png';
        link.href = image;
        link.click();
  }
  assignOldFilterObj(){
    this.filterObjChart = {...this.oldFilterObjChart}
  }

  Download_Pdf_Retension() {
    this.commonService.sendRequestToNode({ method: 'post', path: 'actionRetention/generateRetentionReportPdf', postData: this.retationRateData },{ responseType: 'blob' }).subscribe(result => {
      saveAs(result, `RetentionData.pdf`)
  })
  }

  Download_Pdf_Campign() {
      this.commonService.sendRequestToNode({ method: 'post', path: 'actionRetention/generateReportPdf', postData: this.actionRetentionData },{ responseType: 'blob' }).subscribe(result => {
        saveAs(result, `CampignData.pdf`)
    })
  }

}

