import { Component, AfterViewInit,OnInit,ElementRef,ViewChild } from '@angular/core';
import { NgbPaginationConfig, NgbModal, NgbModalRef, ModalDismissReasons } from '@ng-bootstrap/ng-bootstrap';
import { CommonService } from '../common-service.service';
import {Router,ActivatedRoute} from "@angular/router";
import {FormGroup,FormBuilder,Validators,FormControl} from '@angular/forms';
import swal from 'sweetalert2';
import { saveAs } from 'file-saver';
import * as pluginAnnotations from 'chartjs-plugin-annotation';
import 'chartjs-plugin-labels';

declare var $: any;
import { PerfectScrollbarConfigInterface } from 'ngx-perfect-scrollbar';

@Component({
  templateUrl: './sea-farer.component.html',
  styleUrls: ['./sea-farer.component.scss']
})
export class SeaFarerComponent implements AfterViewInit,OnInit {

  public config: PerfectScrollbarConfigInterface = {};
  public modalRef:NgbModalRef;
  public rankForm:FormGroup; 
  public rankFormSubmittedAttempt = false;
  public officeLocationForm:FormGroup; 
  public officeLocationFormSubmittedAttempt = false;
  public seaFarerData = [];
  public seaFarerForm:FormGroup; 
  public enableDownloadPdfBtn = true;
  public edit_id;
  public formSubmittedAttempt = false;
  public openRightSidebar = false;
  public filterObj:any = {};
  public enableDownloadExcelBtn = true;
  public yearFilter = new Date().getFullYear();
  public sortFilter:any = {};
  modalReference: NgbModalRef;

  public rank_dropdown = [];
  public officeLocation_dropdown = [];
  public viewData = false;
  public seaFater_view;
  public showSideBarLoader = false;
  public showLoader = false;

  //for grid 
  public headerInformation;
  public actionButtons;

  //for pagination
  itemsPerPage: number = this.commonService.DefaultItemsPerPage;
  totalItems: number;
  currentPage: number = 1;

  public lineChartData: Array<any> = [];
  public lineChartLabels: Array<any> = [];
  // public lineChartOptions: any = {
  //   responsive: true,
  //   scales: {
  //     xAxes: [{
  //       ticks: {
  //         autoSkip: false,
  //       },
  //     }],
  //     yAxes: [{
  //       ticks: {
  //           beginAtZero: true
  //       }
  //   }]
  //   },
  // };
  public lineChartOptions: any = {
    title: {
      text: 'Shore Assignments',
      display: true,
      position: 'bottom'
    },
    plugins: {
      labels: {
        // render 'label', 'value', 'percentage', 'image' or custom function, default is 'percentage'
        render: 'value',

        // precision for percentage, default is 0
        precision: 0,

        // identifies whether or not labels of value 0 are displayed, default is false
        showZero: false,

        // font size, default is defaultFontSize
        fontSize: 10,

        // font color, can be color array for each data or function for dynamic color, default is defaultFontColor
        fontColor: '#000',

        // font style, default is defaultFontStyle
        fontStyle: 'normal',

        // font family, default is defaultFontFamily
        fontFamily: "'Helvetica Neue', 'Helvetica', 'Arial', sans-serif",

        // draw text shadows under labels, default is false
      //   textShadow: true,

        // text shadow intensity, default is 6
      //   shadowBlur: 10,

        // text shadow X offset, default is 3
        shadowOffsetX: -5,

        // text shadow Y offset, default is 3
        shadowOffsetY: 5,

        // text shadow color, default is 'rgba(0,0,0,0.3)'
        shadowColor: 'rgba(255,0,0,0.75)',

        // draw label in arc, default is false
        // bar chart ignores this
        arc: true,

        // position to draw label, available value is 'default', 'border' and 'outside'
        // bar chart ignores this
        // default is 'default'
        position: 'default',

        // draw label even it's overlap, default is true
        // bar chart ignores this
        overlap: true,

        // show the real calculated percentages from the values and don't apply the additional logic to fit the percentages to 100 in total, default is false
        showActualPercentages: true,

        

        // add padding when position is `outside`
        // default is 2
        outsidePadding: 4,

        // add margin of text when position is `outside` or `border`
        // default is 2
        textMargin: 2
      }
    },
    scales: {
      xAxes: [{
        scaleLabel: {
          display: true,
          labelString: 'Retention Rank'
        }
      }],
      yAxes: [{
        scaleLabel: {
            display: true,
            labelString: 'Total Days'
        }
      }]
    },
  }

  public lineChartLegend = true;
  public lineChartType = 'bar';
  public lineChartPlugins = [pluginAnnotations];
  public valueOfYear = [];
  @ViewChild('autofocus') el:ElementRef;

  constructor(private modalService: NgbModal,
    private commonService: CommonService,
    private router: Router,
    private formBuilder: FormBuilder,
    private route: ActivatedRoute){
      this.declareGridVariable();
      let year = 2014;
      while(year <= new Date().getFullYear()){
        this.valueOfYear.push(year);
        year++;
      }
  }

  // part of grid
  declareGridVariable(){
    this.headerInformation = [
      {
        title : 'Name',// show title table header
        name:'NAME',// name of column in data source
        width : '15%',// width of column in table
        isSortable : true,// sort by column false or true
        isFilter:{ // filter 
          type : 'text',
          placeholder : 'Filter By Name'
        }
      },
      {
        title : 'Rank',// show title table header
        name:'RANK_NAME',// name of column in data source
        width : '10%',// width of column in table
        isSortable : true,// sort by column false or true
        isFilter:{ // filter 
          type : 'text',
          placeholder : 'Filter By Rank'
        }
      },
      {
        title : 'From Date',
        name:'FROM_DATE',
        width : '10%',
        isDate:'yes',
        isFilter:{ // filter 
          type : 'date',
          placeholder : 'From Date'
        },
        isSortable : true
      },
      {
        title : 'To Date',
        name:'TO_DATE',
        width : '10%',
        isFilter:{ // filter 
          type : 'date',
          placeholder : 'To Date'
        },
        isDate:'yes',
        isSortable : true
      },
      {title : 'Total Days',name:'TOTAL_DAYS',width : '10%',},
      {
        title : ' Location',// show title table header
        name:'LOCATION_TITLE',// name of column in data source
        width : '15%',// width of column in table
        isSortable : true,// sort by column false or true
        isFilter:{ // filter 
          type : 'text',
          placeholder : 'Filter By  Location'
        }
      },
      {
        title : 'Assignment Details',// show title table header
        name:'ASSIGNMENT',// name of column in data source
        width : '10%',// width of column in table
      },
      {title : 'Action',name:'action',width : '20%'}
    ];
    this.actionButtons = [
      {title:'View',class : "fas fa-eye"},
      {title:'Edit',class : "far fa-edit"},
      {title:'Delete',class : "far fa-trash-alt"}
    ]
  }

  ngAfterViewInit(){
   
  }

  ngOnInit(){
    this.getData();
    this.getChartData();
    this.addForm();
    this.rankDropDown();
    this.officeLocationDropDown();
  }

  rankDropDown(id=0){
    this.commonService.sendRequestToNode({method :'get',path:'rank-dropDown'}).subscribe(result => {
      if(result.status){
        this.rank_dropdown = result.data;
        if(id){
          this.seaFarerForm.patchValue({
            RANK_FK : id 
          })
        }
      }
      else{
        this.rank_dropdown = [];
        alert(result.message);
      }
    })
  }

  officeLocationDropDown(id=0){
    this.commonService.sendRequestToNode({method :'get',path:'office-location-dropDown'}).subscribe(result => {
      if(result.status){
        this.officeLocation_dropdown = result.data;
        if(id){
          this.seaFarerForm.patchValue({
            OFFICE_LOCATION_FK : id 
          })
        }
      }
      else{
        this.officeLocation_dropdown = [];
        alert(result.message);
      }
    })
  }
  
  getData()
  {
    let filterParams:any = {}
    
    //search filter 
    filterParams = JSON.parse(JSON.stringify(this.filterObj));
    //search filter -end

    // pagination
    filterParams.currentPage = this.currentPage-1;
    filterParams.itemsPerPage = this.itemsPerPage;
    // pagination - end

    //sorting 
    let sortKey = Object.keys(this.sortFilter);
    if(sortKey.length && this.sortFilter[sortKey[0]]){
      filterParams.sortBy = sortKey[0];
      filterParams.sortStatus = this.sortFilter[sortKey[0]];
    }
    //sorting - end

    this.showLoader = true;
    
    this.commonService.sendRequestToNode({method :'get',path:'sea-farer',queryParam:filterParams}).subscribe(
      result => {
      this.showLoader = false;              
        if(result.status)
        {
          if(result.data.length > 0){
            this.totalItems = result.data[0].total_records;
            this.seaFarerData = result.data;
          }else{
            this.seaFarerData = [];
          }
        }
        else{
          this.seaFarerData = [];
          alert(result.message);
        }
    })
  }

  getChartData()
  {
    this.lineChartData.length = 0;
    let filterParams:any = {year : this.yearFilter}

    this.showLoader = true;
    let dataArray = [];
    let dataArray1 = [];
    let labelArray = [];
    this.commonService.sendRequestToNode({method :'get',path:'get-chart-data-sea-farer',queryParam:filterParams}).subscribe(
      result => {
      this.showLoader = false;              
        if(result.status)
        {
          if(result.data.length > 0){
            result.data.forEach(element => {
              dataArray.push(element.COUNT);
              if(element.SHORE_ASSIGNMENT_KPI){
                dataArray1.push(JSON.parse(element.SHORE_ASSIGNMENT_KPI)[this.yearFilter]);
              }
              else{
                dataArray1.push(0);
              }
              
              labelArray.push(element.RANK_NAME); 
            });
           

            this.lineChartData = [
              { data: dataArray, label: 'Total Days',spanGaps:true },
              { data: dataArray1, label: 'Shore Assignment KPI',spanGaps:true }
            ];
            this.lineChartLabels = labelArray;
          }else{
            // this.seaFarerData = [];
          }
        }
        else{
          // this.seaFarerData = [];
          alert(result.message);
        }
    })
  }

  addForm(){
    this.seaFarerForm = this.formBuilder.group({
      NAME: ['',],
      RANK_FK: [null,],
      FROM_DATE: ['',],
      TO_DATE: ['',],
      OFFICE_LOCATION_FK: [null,],
      ASSIGNMENT: ['',],
    });
    
    this.rankForm = this.formBuilder.group({
      RANK: [''],
    });
    
    this.officeLocationForm = this.formBuilder.group({
      TITLE: [''],
      ADDRESS: [''],
      CITY: ['']
    });

  }

  resetForm(){
    this.formSubmittedAttempt = false;
    this.openRightSidebar = false;
    this.viewData = false
    this.edit_id = '';
    this.seaFarerForm.patchValue({
      NAME: '',
      RANK_FK: null,
      FROM_DATE: '',
      TO_DATE: '',
      OFFICE_LOCATION_FK: null,
      ASSIGNMENT: '',
    })
  }

  edit(id){
    this.el.nativeElement.focus();
    this.openRightSidebar = true;
    this.commonService.sendRequestToNode({method :'get',path:'sea-farer/'+id}).subscribe(
      data => {
        this.seaFarerForm.patchValue({
          NAME : data.data.NAME,
          RANK_FK : data.data.RANK_FK,
          FROM_DATE : this.commonService.formatDate(new Date(data.data.FROM_DATE)),
          TO_DATE : this.commonService.formatDate(new Date(data.data.TO_DATE)),
          OFFICE_LOCATION_FK : data.data.OFFICE_LOCATION_FK,
          ASSIGNMENT : data.data.ASSIGNMENT,
        })
        this.edit_id = id;
    })
  }

  delete(id){
    if(id){
      swal({
        title: 'Are you sure?',
        text: "You won't be able to revert this!",
        type: 'warning',
        showCancelButton: true,
        confirmButtonClass: 'btn btn-success',
        cancelButtonClass: 'btn btn-danger',
        confirmButtonText: 'Yes, delete it!',
         buttonsStyling: false
      }).then((result) => {
        if (result.value) {
          this.commonService.sendRequestToNode({method :'delete',path:'sea-farer/'+id}).subscribe(
          data => {
          if(data.status){
            var dialogueTitle = "Deleted!"
            if(this.seaFarerData.length == 1 && Math.ceil(this.totalItems / this.itemsPerPage) == this.currentPage){
              if(this.currentPage>1){
                this.currentPage--;
              }
            }
            this.getData();
            swal({
                title: dialogueTitle,
                text: data.message,
                type: 'success',
                confirmButtonClass: "btn btn-success",
                buttonsStyling: false
              })
          }         
          
      })
         }
      })      
    }
  }

  onSubmit(){ 
    this.formSubmittedAttempt = true;
    if(this.seaFarerForm.valid){
    this.showSideBarLoader = true;
    if(this.edit_id){    
      this.commonService.sendRequestToNode({method :'put',path:'sea-farer/'+this.edit_id,postData:this.seaFarerForm.value}).subscribe(
        data =>{
          var dialogueTitle = "Updated!";
          this.showSideBarLoader = false;
          if(data.status){
            swal({
                title: dialogueTitle,
                text: data.message,
                type: 'success',
                confirmButtonClass: "btn btn-success",
                buttonsStyling: false
              })
            this.getData();
            this.resetForm(); //after edit form is reset
          }
          else{
            alert(data.message);
          }
      })
    }else{
      this.commonService.sendRequestToNode({method :'post',path:'sea-farer',postData:this.seaFarerForm.value}).subscribe(
        data =>{
          var dialogueTitle = "Inserted!";
          this.showSideBarLoader = false;
          if(data.status){
            swal({
                title: dialogueTitle,
                text: data.message,
                type: 'success',
                confirmButtonClass: "btn btn-success",
                buttonsStyling: false
              })
            this.getData();
            this.resetForm(); //after edit form is reset

          }
          else{
            alert(data.message);
          }
      })
    }
    }
      
  }

  view(id){
    this.viewData = true;
    this.showSideBarLoader = true;
    this.openRightSidebar = true; 
    this.commonService.sendRequestToNode({method :'get',path:'sea-farer/'+id}).subscribe(result => {      
      this.showSideBarLoader = false;
      if(result.status)
        {
          this.seaFater_view = result.data;
        }else{
          alert(result.message)
        }
    })
  }

  //part of grid
    clickOnAction(actionObj){
      if(actionObj.actionName == 'Edit'){
        this.edit(actionObj.object.ID)
      }else if(actionObj.actionName == 'Delete'){
        this.delete(actionObj.object.ID)
      }else if(actionObj.actionName == 'View'){
        this.view(actionObj.object.ID)
      }
    }
  
    //part of grid
    //when change filter ,change page no . etc, 
    filter($event){
      let obj = $event;
      this.currentPage = obj.page;
      this.filterObj = obj.filter;
      this.sortFilter = obj.sort
      this.getData();
    }
  
    //part of grid
    funOpenRightSidebar(){
      this.el.nativeElement.focus();
      this.openRightSidebar = true; 
    }

    addRank(content){
      this.modalRef = this.modalService.open(content,{size: 'sm'});
    }

    resetRankForm(){
      this.rankFormSubmittedAttempt = false;
      this.rankForm.patchValue({
        RANK: null,
      })
    }

    onSubmitRank(){
      //console.log(this.edit_id);
      this.rankFormSubmittedAttempt = true;
      if(this.rankForm.valid){
        //console.log(this.Groupinspector.value);
        this.commonService.sendRequestToNode({method :'post',path:'rank',postData:this.rankForm.value}).subscribe(
          data =>{
            var dialogueTitle = "Inserted!";
            if(data.status){
              swal({
                title: dialogueTitle,
                text: data.message,
                type: 'success',
                confirmButtonClass: "btn btn-success",
                buttonsStyling: false
              }).then(()=>{
                this.modalRef.close();
                this.rankDropDown(data.insertId);
                this.resetRankForm();
              })
              // this.modal.close()
            }else{
              alert(data.message);
            }
        })
      }  
    }

    addOfficeLocation(content){
      this.modalRef = this.modalService.open(content,{size: 'sm'});
    }

    resetOfficeLocationForm(){
      this.officeLocationFormSubmittedAttempt = false;
      this.officeLocationForm.patchValue({
        TITLE: '',
        ADDRESS: '',
        CITY: ''
      })
    }

    onSubmitOfficeLocation(){
      //console.log(this.edit_id);
      this.officeLocationFormSubmittedAttempt = true;
      if(this.officeLocationForm.valid){
        //console.log(this.Groupinspector.value);
        this.commonService.sendRequestToNode({method :'post',path:'office-location',postData:this.officeLocationForm.value}).subscribe(
          data =>{
            var dialogueTitle = "Inserted!";
            if(data.status){
              swal({
                title: dialogueTitle,
                text: data.message,
                type: 'success',
                confirmButtonClass: "btn btn-success",
                buttonsStyling: false
              }).then(()=>{
                this.modalRef.close();
                this.officeLocationDropDown(data.insertId);
                this.resetOfficeLocationForm();
              })
              // this.modal.close()
            }else{
              alert(data.message);
            }
        })
      }  
    }

    Download_Pdf_Sea_farer() {
        this.commonService.sendRequestToNode({ method: 'post', path: 'sea-farer/generateReportPdf', postData: this.seaFarerData },{ responseType: 'blob' }).subscribe(result => {
          saveAs(result, `SeaFarer.pdf`)
      })
    }

    retentionRateChart() {
      var canvas:any = document.getElementById("retentionRateChart");
      var image = canvas.toDataURL("image/png"); 
      var link = document.createElement('a');
          link.download =  this.yearFilter + ' / Retention Rate Chart.png';
          link.href = image;
          link.click();
    }

    Download_Excel_Campign() {
      console.log( 'download excel' )
       this.commonService.sendRequestToNode({ method: 'post', path: 'sea-farer/generateReportExcel', postData: this.filterObj },{ responseType: 'blob' }).subscribe(result => {
           saveAs(result, `CampignData.xlsx`)
       })
   }
}

