import { Component, AfterViewInit,OnInit, createPlatformFactory } from '@angular/core';
import { NgbPaginationConfig, NgbModal, NgbModalRef, ModalDismissReasons } from '@ng-bootstrap/ng-bootstrap';
import { CommonService } from '../common-service.service';
import {Router,ActivatedRoute} from "@angular/router";
import {FormGroup,FormBuilder,Validators,FormControl} from '@angular/forms';
import swal from 'sweetalert2';
//import { parse } from 'path';

declare var $: any;
import { PerfectScrollbarConfigInterface } from 'ngx-perfect-scrollbar';

@Component({
  templateUrl: './sire.component.html',
  styleUrls: ['./sire.component.scss']
})
export class SireComponent implements AfterViewInit,OnInit {

  public config: PerfectScrollbarConfigInterface = {};

  options = {
    theme: 'light', // two possible values: light, dark
    dir: 'ltr', // two possible values: ltr, rtl
    layout: 'vertical', // fixed value. shouldn't be changed.
    sidebartype: 'mini-sidebar', // four possible values: full, iconbar, overlay, mini-sidebar 
    sidebarpos: 'fixed', // two possible values: fixed, absolute
    headerpos: 'fixed', // two possible values: fixed, absolute
    boxed: 'full', // two possible values: full, boxed
    navbarbg: 'skin6', // six possible values: skin(1/2/3/4/5/6)
    sidebarbg: 'skin5', // six possible values: skin(1/2/3/4/5/6)
    logobg: 'skin5' // six possible values: skin(1/2/3/4/5/6)
  };

  public Groupsire:FormGroup;
  public sires = [];
  public sires_view;
  public template_dropdown = [];
  public edit_id;
  public formSubmittedAttempt = false;
  public openRightSidebar = false;
  public viewData = false;
  public filterObj:any = {};
  public sortFilter:any = {};

  //for grid 
  public headerInformation;
  public actionButtons;

  //for pagination
  itemsPerPage: number = this.commonService.DefaultItemsPerPage;
  totalItems: number;
  currentPage: number = 1;
  
  constructor(private modalService: NgbModal,
    private commonService: CommonService,
    private router: Router,
    private formBuilder: FormBuilder,
    private route: ActivatedRoute){
      this.declareGridVariable()
  }
  
  ngAfterViewInit(){
   
  }

  ngOnInit(){
    this.getData();
    this.addForm();
    this.template();
    //this.editForm();
  }

  addForm(){
    this.Groupsire = this.formBuilder.group({
      TEMPLATE_FK: ['',[Validators.required]],
      VERSION: ['',[Validators.required]]
    });   
  }

  edit(id){
    this.openRightSidebar = true;
    this.commonService.sendRequestToNode({method :'get',path:'sire/getById/'+id}).subscribe(
      data => { 
        this.Groupsire.patchValue(data.data[0]);
        this.edit_id = id;
    })
  }

  onSubmit(){
    //console.log(this.edit_id);
    this.formSubmittedAttempt = true;
    if(this.Groupsire.valid){
      if(this.edit_id){
        this.commonService.sendRequestToNode({method :'post',path:'sire/edit/'+this.edit_id,postData:this.Groupsire.value}).subscribe(
          data =>{
            var dialogueTitle = "Updated!";
            if(data.status){
              swal({
                title: dialogueTitle,
                text: data.message,
                type: 'success',
                confirmButtonClass: "btn btn-success",
                buttonsStyling: false
              })
              this.getData();
              this.openRightSidebar = false;
              this.resetForm();
            }else{
              alert(data.message);
            }
        })
      }else{
        //console.log(this.Groupsire.value);
        this.commonService.sendRequestToNode({method :'post',path:'sire/add',postData:this.Groupsire.value}).subscribe(
          data =>{
            var dialogueTitle = "Inserted!";
            if(data.status){
              swal({
                title: dialogueTitle,
                text: data.message,
                type: 'success',
                confirmButtonClass: "btn btn-success",
                buttonsStyling: false
              })
              this.getData();
              this.openRightSidebar = false;
              this.resetForm();
            }else{
              alert(data.message);
            }
        })
      }
    }  
  }

  getData()
  {
    let filterParams:any = {}
    
    //search filter 
    filterParams = JSON.parse(JSON.stringify(this.filterObj));
    //search filter -end

    // pagination
    filterParams.currentPage = this.currentPage-1;
    filterParams.itemsPerPage = this.itemsPerPage;
    // pagination - end

    //sorting 
    let sortKey = Object.keys(this.sortFilter);
    if(sortKey.length && this.sortFilter[sortKey[0]]){
      filterParams.sortBy = sortKey[0];
      filterParams.sortStatus = this.sortFilter[sortKey[0]];
    }
    //sorting - end

    this.commonService.sendRequestToNode({method :'get',path:'sire/data_list',queryParam:filterParams}).subscribe(result => {
        if(result.status)
        {
          if(result.data.length > 0){
            this.totalItems = result.data[0].total_records;
            this.sires = result.data;
            //console.log(this.sires);
          }else{
            this.sires = [];
          }
        }
        else{
          this.sires = [];
          alert(result.message);
        }
    })
  }

  delete(id){
    if (id) {
      
      swal({
        title: 'Are you sure?',
        text: "You won't be able to revert this!",
        type: 'warning',
        showCancelButton: true,
        confirmButtonClass: 'btn btn-success',
        cancelButtonClass: 'btn btn-danger',
        confirmButtonText: 'Yes, delete it!',
        buttonsStyling: false
        
        }).then((result) => {
          if (result.value) {   
            this.commonService.sendRequestToNode({method :'get',path:'sire/delete/'+id}).subscribe(result => {
              if(result.status){
                var dialogueTitle = "Deleted!"
                if(this.sires.length == 1 && Math.ceil(this.totalItems / this.itemsPerPage) == this.currentPage){
                  if(this.currentPage>1){
                    this.currentPage--;
                  }
                }
                this.getData();
                swal({
                    title: dialogueTitle,
                    text: result.message,
                    type: 'success',
                    confirmButtonClass: "btn btn-success",
                    buttonsStyling: false
                  })
              }
            })
          }
        })
    }
  }

  view(id){
    this.viewData = true;
    this.openRightSidebar = true;
    //console.log(id);
    this.commonService.sendRequestToNode({method :'get',path:'sire/getById/'+id}).subscribe(result => {
        if(result.status)
        {
          this.sires_view = result.data[0];
          //console.log(this.sires_view);
        }
        else{
          alert(result.message)
        }
    })
  }

  questionnaire(id){
    // alert(id);
    this.router.navigate(["/questionnaire/"+id]);
  }

  template()
  {

    this.commonService.sendRequestToNode({method :'get',path:'sire/template-dropdown'}).subscribe(result => {
      if(result.status){
        this.template_dropdown = result.data;
        //console.log(this.template_dropdown);
      }
      else{
        this.template_dropdown = [];
        alert(result.message);
      }
    })
  }

  resetForm(){
    this.formSubmittedAttempt = false;
    this.openRightSidebar = false;
    this.viewData = false;
    this.edit_id = '';
    this.Groupsire.patchValue({
      TEMPLATE_FK: '',
      VERSION: '' 
    })
  }

  // part of grid
  declareGridVariable(){
    this.headerInformation = [
      {
        title : 'Template',// show title table header
        //nameIcon : true,// show icon of First letter
        name:'TEMPLATE_NAME',// name of column in data source
        width : '18%',// width of column in table
        isSortable : true,// sort by column false or true
        highlight:true, // name highlight
        isFilter:{ // filter 
          type : 'text',
          placeholder : 'Filter By Template'
        }
      },
      {title : 'Version',name:'VERSION',width : '18%',isSortable : true, isFilter:{ // filter 
        type : 'text',
        placeholder : 'Filter By Version'
      }},
      
      
      {title : 'Action',name:'action',width : '10%'}
    ];
    this.actionButtons = [
      {title:'View',class : "fas fa-eye"},
       {title:'Questionnaire',class : "fas fa-file-alt"},
//      {title:'Edit',class : "far fa-edit"},
  //    {title:'Delete',class : "far fa-trash-alt"},
    //  {title:'Questionnaire',class : "fas fa-file-alt"}
    ]
  }

  //part of grid
  clickOnAction(actionObj){
    if(actionObj.actionName == 'View'){
      this.view(actionObj.object.ID)
    }else if(actionObj.actionName == 'Edit'){
      this.edit(actionObj.object.ID)
    }else if(actionObj.actionName == 'Delete'){
      this.delete(actionObj.object.ID)
    }else if(actionObj.actionName == 'Questionnaire'){
      this.questionnaire(actionObj.object.ID)
    }
  }
  
  //part of grid
  //when change filter ,change page no . etc, 
  filter($event){
    let obj = $event;
    this.currentPage = obj.page;
    this.filterObj = obj.filter;
    this.sortFilter = obj.sort
    this.getData();
  }

  //part of grid
  funOpenRightSidebar(){
    this.openRightSidebar = true; 
  }




}
