// import { Component, AfterViewInit, ViewEncapsulation, OnInit } from '@angular/core';
// import { CommonService } from '../common-service.service';

// import {Router,ActivatedRoute} from "@angular/router";
// import {FormGroup,FormBuilder,Validators,FormControl} from '@angular/forms';
// import swal from 'sweetalert2';

import { Component, AfterViewInit, OnInit, createPlatformFactory, ElementRef, ViewChild } from '@angular/core';
import { NgbPaginationConfig, NgbModal, NgbModalRef, ModalDismissReasons } from '@ng-bootstrap/ng-bootstrap';
import { CommonService } from '../common-service.service';
import { Router, ActivatedRoute } from "@angular/router";
import { FormGroup, FormBuilder, Validators, FormControl } from '@angular/forms';
import { Routes, RouterModule } from '@angular/router';
import swal from 'sweetalert2';
import { WindowService } from '@ng-select/ng-select/ng-select/window.service';

declare var require: any;

@Component({
  selector: 'sireHighRiskObservation',
  templateUrl: './sireHighRiskObservation.component.html',
  styleUrls: ['./sireHighRiskObservation.component.scss']
})
export class SireHighRiskObservationComponent implements AfterViewInit, OnInit {

  public showLoader = false;
  //for pagination
  itemsPerPage: number = this.commonService.DefaultItemsPerPage;
  totalItems: number;
  currentPage: number = 1;
  isDisabled = true;

  public expanded = [];
  public NEXT_DUE;
  public filterObj = {};
  public formData = {};
  public formDataOperatorDate = {};
  public vesselGroup_dropdown = [];
  public vesselFleet_dropdown = [];
  public vesselOwner_dropdown = [];
  public port_dropdown = [];
  public perCompanyObservation;
  public perCompanyRisk;
  public modalRef: NgbModalRef;
  public oilMajor_dropdown = [];
  public inspector_dropdown = [];
  public sireHighRiskObservationData = [];
  public withoutPaginationData = [];
  public sireHighRiskObservationDatacsv = [];
  public configData = [];
  public sortFilter: any = {};
  public current_template;
  public link_template;
  public forData;
  public risk_params;
  public filterObjObsChart: any = { start_date: this.commonService.formatDate(new Date(new Date().setFullYear(new Date().getFullYear() - 1))), end_date: this.commonService.formatDate(new Date()) };

  public pdfLogo;


  public questions_curr = [];
  public questions_prev = [];
  private fieldArray = {};
  private dataArray = {};
  public linkData = {};
  //for grid 
  public headerInformation;
  public actionButtons;
  public title;

  // public VesselMasterForm:FormGroup;
  // public groupSireReportUpload:FormGroup;

  constructor(private modalService: NgbModal,
    private commonService: CommonService, private route: ActivatedRoute) {
    this.route.params.subscribe(params => {
      this.forData = params['type'];
      this.risk_params = params['risk'];
    });
    this.declareGridVariable();
    this.title = 'SIRE High Risk Observations';
    if (this.risk_params) {

      if (this.risk_params == 1) {
        this.title = 'SIRE Low Risk Observations';

      }
      else if (this.risk_params == 2) {
        this.title = 'SIRE Medium Risk Observations';

      } else if (this.risk_params == 3) {
        this.title = 'SIRE High Risk Observations';

      } else if (this.risk_params == 4) {
        this.title = 'SIRE Very High Risk Observations';

      }

    }
  }

  ngOnInit() {
    //console.log(location);
    this.pdfLogo = location.origin+location.pathname+'assets/images';

    this.route.params.subscribe(params => {
      this.forData = params['type'];
      this.risk_params = params['risk'];
    });
    this.getData( this.filterObjObsChart );
    this.getDataWithoutPagination( this.filterObjObsChart );
  }

  ngAfterViewInit() {
  }

  changePage(page) {
    this.currentPage = page;
    this.sendFilterObjectForUpdateData();
    window.scroll(0, 0);
  }

  sendFilterObjectForUpdateData() {
    let makeFilterObj = {}
    Object.keys(this.filterObj).forEach((key) => {
      makeFilterObj[key] = this.filterObj[key].replace(/'/g, "\\\'").replace(/"/g, '\\\"')
    });
    let filter = {
      filter: makeFilterObj,
      page: this.currentPage,
      sort: this.sortFilter
    }
    this.getData(  this.filterObjObsChart);
  }


  // generatcsv(){
  //   console.log(this.sireHighRiskObservationDatacsv);
  //   this.commonService.sendRequestToNode({method :'post',path:'sireHighRiskObservation/exportObj',postData:this.sireHighRiskObservationDatacsv}).subscribe(result => {
  //     window.location.href = this.commonService.getNodeApi()+'/sireHighRiskObservation/export';
  //   })
  // }


  getData( filter :any= {} ) {
    let filterParams: any = {}
    //search filter 
    filterParams = JSON.parse(JSON.stringify(this.filterObj));
    //search filter -end
    // pagination
    filterParams.currentPage  = this.currentPage - 1;
    filterParams.itemsPerPage = this.itemsPerPage;
    filterParams.start_date   = filter.start_date;
    filterParams.end_date     = filter.end_date;
    filterParams.risk         = this.risk_params;

    if (Object.keys(this.sortFilter).length > 0) {
      filterParams.sortBy = Object.keys(this.sortFilter)[0];
      filterParams.sortStatus = this.sortFilter[Object.keys(this.sortFilter)[0]]
    }

    this.commonService.sendRequestToNode({ method: 'get', path: 'sireHighRiskObservation/getData', queryParam: filterParams }).subscribe(result => {
      if (result.status) {
        var index = 0;
        var finalData = [];
        var dataGlob = result.data;
        var dataCom = result.dataCom;
        // alert(this.forData);
        if (dataGlob && this.forData == 'glob') {
          this.sireHighRiskObservationData = dataGlob;
          this.totalItems = dataGlob[0].total_records;
        }
        if (dataCom && this.forData == 'com') {
          this.sireHighRiskObservationData = dataCom;
          this.totalItems = dataCom[0].total_records;
        }
 
      }
      else {
        this.sireHighRiskObservationData = [];
        alert(result.message);
      }
    })
  }
  // navigate(name,id){
  //   //this.withoutPaginationData; 

  // }
  addMonths(month) {
    let months = this.sireHighRiskObservationData;
    for (let m of months) {

      var lastSireDate = new Date(m.LAST_INSPECTION_DATE);
      var dd = lastSireDate.getDate();
      var mm = lastSireDate.getMonth() + parseInt('1') + parseInt(month);
      var yyyy;
      if (mm > 12) {
        yyyy = lastSireDate.getFullYear() + 1;
        mm = mm - 12;
      } else {
        yyyy = lastSireDate.getFullYear();
      }


      m.NEXT_DUE_DATE = ('0' + (dd)).slice(-2) + '/' + ('0' + (mm)).slice(-2) + '/' + yyyy;

      m.NEXT_DUE_DATE1 = yyyy + '/' + mm + '/' + dd;
      var today1 = new Date();



      let color;
      let dueDate = new Date(m.NEXT_DUE_DATE1);

      //this is for NEXT DUE TO Today date diff
      let isPrevFromNextdueDate = false;
      if (dueDate.getTime() - today1.getTime() > 0) {
        var timeDiff = Math.abs(dueDate.getTime() - today1.getTime());
        var diffDays = Math.ceil(timeDiff / (1000 * 3600 * 24));
        // console.log(diffDays); 
      }
      else {
        var timeDiff = Math.abs(dueDate.getTime() - today1.getTime());
        var diffDays = Math.ceil(timeDiff / (1000 * 3600 * 24));
        isPrevFromNextdueDate = true;
        // console.log('-'+diffDays); 
      }

      //this is for Last Sire Date TO Today date diff
      let isPrevFromLastSireDate = false;
      if (lastSireDate.getTime() - today1.getTime() > 0) {
        var timeDiff = Math.abs(lastSireDate.getTime() - today1.getTime());
        var diffDaysOFLastSire = Math.ceil(timeDiff / (1000 * 3600 * 24));
      }
      else {
        var timeDiff = Math.abs(lastSireDate.getTime() - today1.getTime());
        var diffDaysOFLastSire = Math.ceil(timeDiff / (1000 * 3600 * 24));
        isPrevFromLastSireDate = true;
      }

      if (isPrevFromNextdueDate) {
        m.BG_COLOR = 'bg-myred';
      } else if (!isPrevFromNextdueDate && diffDays <= 30) {
        m.BG_COLOR = 'bg-myorange';
      } else if (isPrevFromLastSireDate && diffDaysOFLastSire <= 30) {
        m.BG_COLOR = 'bg-mygreen';
      } else {
        m.BG_COLOR = 'bg-myyellow';
      }


      let mmm = parseInt(month);
      this.commonService.sendRequestToNode({ method: 'post', path: 'sireHighRiskObservation/addMonth/' + mmm }).subscribe(
        data => {
        })
    }
  }

  calculate(lastSireDate, currentDate) {
    var fromDate = lastSireDate;
    var toDate = currentDate;
    // console.log(fromDate);
    // console.log(toDate);
    try { //alert();
      // document.getElementById('result').innerHTML = '';

      var result = this.getDateDifference(new Date(fromDate), new Date(toDate));
      //console.log(result);
      if (result && !isNaN(result.years)) {
        // console.log(result);
        // document.getElementById('result').innerHTML =
        //   result.years + ' year' + (result.years == 1 ? ' ' : 's ') +
        //   result.months + ' month' + (result.months == 1 ? ' ' : 's ') + 'and ' +
        //   result.days + ' day' + (result.days == 1 ? '' : 's');

        return { 'Year': result.years, 'Month': result.months, 'Day': result.days };
      }
    } catch (e) {
      console.error(e);
    }
  }

  getDateDifference(startDate, endDate) {
    //console.log(startDate);
    //console.log(endDate)
    if (startDate > endDate) {
      //    console.error('Start date must be before end date');
      return null;
    }
    var startYear = startDate.getFullYear();
    var startMonth = startDate.getMonth();
    var startDay = startDate.getDate();

    var endYear = endDate.getFullYear();
    var endMonth = endDate.getMonth();
    var endDay = endDate.getDate();

    // We calculate February based on end year as it might be a leep year which might influence the number of days.
    var february = (endYear % 4 == 0 && endYear % 100 != 0) || endYear % 400 == 0 ? 29 : 28;
    var daysOfMonth = [31, february, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31];

    var startDateNotPassedInEndYear = (endMonth < startMonth) || endMonth == startMonth && endDay < startDay;
    var years = endYear - startYear - (startDateNotPassedInEndYear ? 1 : 0);

    var months = (12 + endMonth - startMonth - (endDay < startDay ? 1 : 0)) % 12;

    // (12 + ...) % 12 makes sure index is always between 0 and 11
    var days = startDay <= endDay ? endDay - startDay : daysOfMonth[(12 + endMonth - 1) % 12] - startDay + endDay;
    //console.log(years+':'+months+':'+days)
    return {
      years: years,
      months: months,
      days: days
    };
  }

  onSubmit(ID, data) {

    this.commonService.sendRequestToNode({ method: 'post', path: 'sireHighRiskObservation/edit/' + ID, postData: data }).subscribe(
      data => {
        var dialogueTitle = "Updated!";

        if (data.status) {
          swal({
            title: dialogueTitle,
            text: data.message,
            type: 'success',
            confirmButtonClass: "btn btn-success",
            buttonsStyling: false
          })
      
        } else {
          alert(data.message);
        }
      })
  }

  resetForm(ID) {

    //this.formData[ID] = {};
    // this.formDataOperatorDate[ID].OPERATOR_RESPONSE_DUE_DATE = '';



    swal({
      title: 'Are you sure?',
      text: "You won't be able to revert this!",
      type: 'warning',
      showCancelButton: true,
      confirmButtonClass: 'btn btn-success',
      cancelButtonClass: 'btn btn-danger',
      confirmButtonText: 'Yes, Reset it!',
      buttonsStyling: false
    }).then((result) => {

      if (result.value) {

        this.formData[ID].PLAN_DATE = '';
        this.formData[ID].PLAN_INSPECTOR_FK = '';
        this.formData[ID].PLAN_OIL_MAJOR_FK = '';
        this.formData[ID].PLAN_PORT_FK = '';
        this.formData[ID].PLAN_REMARKS = '';
        this.onSubmit(ID, this.formDataOperatorDate[ID]);
        this.commonService.sendRequestToNode({ method: 'post', path: 'sireHighRiskObservation/edit/' + ID, postData: this.formData[ID] }).subscribe(
          data => {
            if (data.status) {
              var dialogueTitle = "Reset!";
              this.getData( this.filterObjObsChart );
              swal({
                title: dialogueTitle,
                text: data.message,
                type: 'success',
                confirmButtonClass: "btn btn-success",
                buttonsStyling: false
              })
            }
          })
      }
    })

    //this.formData[ID] = {};
    //this.formDataOperatorDate[ID].OPERATOR_RESPONSE_DUE_DATE = '';

  }
  resetDateForm(ID) {

    swal({
      title: 'Are you sure?',
      text: "You won't be able to revert this!",
      type: 'warning',
      showCancelButton: true,
      confirmButtonClass: 'btn btn-success',
      cancelButtonClass: 'btn btn-danger',
      confirmButtonText: 'Yes, Reset it!',
      buttonsStyling: false
    }).then((result) => {

      if (result.value) {
        this.formData[ID].PLAN_DATE = '';
        this.formData[ID].PLAN_INSPECTOR_FK = '';
        this.formData[ID].PLAN_OIL_MAJOR_FK = '';
        this.formData[ID].PLAN_PORT_FK = '';
        this.formData[ID].PLAN_REMARKS = '';
        this.formDataOperatorDate[ID].OPERATOR_RESPONSE_DUE_DATE = '';
        this.onSubmit(ID, this.formDataOperatorDate[ID]);
        this.commonService.sendRequestToNode({ method: 'post', path: 'sireHighRiskObservation/edit/' + ID, postData: this.formData[ID] }).subscribe(
          data => {
            if (data.status) {
              var dialogueTitle = "Reset!";
              this.getData( this.filterObjObsChart );
              swal({
                title: dialogueTitle,
                text: data.message,
                type: 'success',
                confirmButtonClass: "btn btn-success",
                buttonsStyling: false
              })
            }
          })
      }
    })

  }

  filter($event) {
    let obj = $event;
    this.currentPage = obj.page;
    this.filterObj = obj.filter;
    this.sortFilter = obj.sort
    this.getData( this.filterObjObsChart );
  } 

  declareGridVariable() {


    this.headerInformation = [
      {
        title: 'Date',// show title table header
        isDate: 'yes',
        name: 'INSPECTION_DATE',// name of column in data source
        width: '10%',// width of column in table
        isSortable: true,// sort by column false or true
        // isFilter:{ // filter 
        //   type : 'text',
        //   placeholder : 'Filter By Date'
        // }
      },
      {
        title: 'Vessel',// show title table header
        //nameIcon : true,// show icon of First letter
        highlight: true,
        name: 'VESSEL_NAME',// name of column in data source
        width: '12%',// width of column in table
        isSortable: true,// sort by column false or true
        isFilter: { // filter 
          type: 'text',
          placeholder: 'Filter By Vessel'
        }
      },
      {
        title: 'Risk',// show title table header
        //nameIcon : true,// show icon of First letter
        name: 'RISK_PROFILE',// name of column in data source
        width: '12%',// width of column in table

        display_value: (this.risk_params) ? { '1': 'Low', '2': 'Medium', '3': 'High Risk', '4': 'Very High Risk' } : { '3': 'High Risk', '4': 'Very High Risk' },
        isFilter: { // filter 
          type: 'select',
          placeholder: 'Filter By Vessel',
          options_value: (this.risk_params) ? [] : [3, 4],
          options_display: (this.risk_params) ? [] : ['High Risk', 'Very High Risk']
        }
      },

      {
        title: 'VIQ Ref No.',// show title table header
        //nameIcon : true,// show icon of First letter
        name: 'QUESTION_NUMBER',// name of column in data source
        width: '15%',// width of column in table
        isSortable: true,// sort by column false or true
        isFilter: { // filter 
          type: 'text',
          placeholder: 'Filter By VIQ Ref No'
        }
      },
      {
        title: 'VIQ Questions',// show title table header
        //nameIcon : true,// show icon of First letter
        name: 'QUESTION_DESCRIPTION',// name of column in data source
        width: '25%',// width of column in table
        isSortable: true,// sort by column false or true
        isFilter: { // filter 
          type: 'text',
          placeholder: 'Filter By VIQ Questions'
        }
      },
      { title: 'Inspector Observation', name: 'INSPECTION_OBSERVATION', width: '5%', },
      {
        title: 'Port Of Inspection', name: 'PORT_OF_INSPECTION', width: '5%',
        isFilter: { // filter 
          type: 'text',
          placeholder: 'Filter By Port Of Inspection'
        }
      },
      {
        title: 'Oil Major', name: 'OIL_MAJOR', width: '15%', isFilter: { // filter 
          type: 'text',
          placeholder: 'Filter By Oil Major'
        }
      }
    ];

  }

  getDataWithoutPagination(filter :any={}) {
    let filterParams: any = {}
    //search filter 
    filterParams = JSON.parse(JSON.stringify(this.filterObj));
    //search filter -end
    filterParams.risk = this.risk_params;
    filterParams.start_date  = this.commonService.formatDate(new Date(new Date().setFullYear(new Date().getFullYear() - 1)));
    filterParams.end_date    = this.commonService.formatDate(new Date());
    filterParams.start_date  = filter.start_date;
    filterParams.end_date    = filter.end_date;

    if (Object.keys(this.sortFilter).length > 0) {
      filterParams.sortBy = Object.keys(this.sortFilter)[0];
      filterParams.sortStatus = this.sortFilter[Object.keys(this.sortFilter)[0]]
    }

    this.commonService.sendRequestToNode({ method: 'get', path: 'sireHighRiskObservation/getData', queryParam: filterParams }).subscribe(result => {
      if (result.status) {
        var index = 0;
        var finalData = [];
        var dataGlob = result.data;
        var dataCom = result.dataCom;
        // alert(this.forData);
        if (dataGlob && this.forData == 'glob') {
          this.withoutPaginationData = dataGlob;
          this.totalItems = dataGlob[0].total_records;
        }

        if (dataCom && this.forData == 'com') {
          this.withoutPaginationData = dataCom;
          this.totalItems = dataCom[0].total_records;
        }
      }
      else {
        this.withoutPaginationData = [];
        alert( result.message );
      }
    })
  }

  getDataforcsv() {
    this.generatcsv();
  }

  generatcsv(){
    let postObj = {
      data : this.withoutPaginationData
    }
    this.commonService.sendRequestToNode({method :'post',path:'sireHighRiskObservation/generateCSVData',postData:postObj}).subscribe(result => {
      if(result.status){
        window.open(this.commonService.getNodeApi()+'/sireHighRiskObservation/exportCSV', '_blank' );
      }
    })
  }
  openModel(content) {
    this.modalRef = this.modalService.open(content, { size: 'sm' });
  }

  generatePdf(){
    var data = document.getElementById('htmlToString').innerHTML;
    // console.log(JSON.stringify(data));
    // console.log(data);
    var htmlData = {'data':data};
    this.commonService.sendRequestToNode({ method: 'post', path: 'sireHighRiskObservation/generatePDFData',postData:htmlData }).subscribe(result => {
      if(result.status){
        window.location.href = this.commonService.getNodeApi()+'/sireHighRiskObservation/exportPDF';
      }
    })
  }

  applyFilterForObservationChart() {
    if(this.filterObjObsChart.start_date > this.filterObjObsChart.end_date){
      alert('Please Enter Valid Date');
    } else {
      this.getData( this.filterObjObsChart );
      this.modalRef.close();
    }
   }
  // getkey(obj){
  //   if(obj.RISK_PROFILE == 3){
  //     obj.RISK_PROFILE = 'High Risk';
  //   }else if(obj.RISK_PROFILE == 4){
  //     obj.RISK_PROFILE = 'Very High Risk';
  //   }
  //   return Object.keys(obj);
  // }

}
