import { Component, AfterViewInit,OnInit, createPlatformFactory,ElementRef,ViewChild } from '@angular/core';
import { NgbPaginationConfig, NgbModal, NgbModalRef, ModalDismissReasons } from '@ng-bootstrap/ng-bootstrap';
import { CommonService } from '../common-service.service';
import {Router,ActivatedRoute} from "@angular/router";
import {FormGroup,FormBuilder,Validators,FormControl} from '@angular/forms';
import swal from 'sweetalert2';

declare var $: any;
import { PerfectScrollbarConfigInterface } from 'ngx-perfect-scrollbar';

@Component({
  // selector: 'software-version',
  templateUrl: './software-version.component.html',
  styleUrls: ['./software-version.component.css']
})
export class SoftwareVersionComponent implements AfterViewInit,OnInit {
  public docPath = this.commonService.getDocumentPath()+'/sireReport';
  public config: PerfectScrollbarConfigInterface = {};
  options = {
    theme: 'light', // two possible values: light, dark
    dir: 'ltr', // two possible values: ltr, rtl
    layout: 'vertical', // fixed value. shouldn't be changed.
    sidebartype: 'mini-sidebar', // four possible values: full, iconbar, overlay, mini-sidebar 
    sidebarpos: 'fixed', // two possible values: fixed, absolute
    headerpos: 'fixed', // two possible values: fixed, absolute
    boxed: 'full', // two possible values: full, boxed
    navbarbg: 'skin6', // six possible values: skin(1/2/3/4/5/6)
    sidebarbg: 'skin5', // six possible values: skin(1/2/3/4/5/6)
    logobg: 'skin5' // six possible values: skin(1/2/3/4/5/6)
  };
  public grid_title;
  public grid_subtitle;
  public VIQ_REFArray = [];
  public reportBasicInformation:any = {
    REPORT_NUMBER : null,
    IMO_NUMBER : null,
    PORT_OF_INSPECTION : null,
    DATE_OF_INSPECTION : null,
    INSPECTING_COMPANY : null,
  };
  public SoftwareVersionForm:FormGroup;
  public SoftwareVersionList = [];
  public observation_view:any = {};
  public edit_id;
  public file_upload;
  public formSubmittedAttempt = false;
  public openRightSidebar = false;
  public showSideBarLoader = false;
  public showLoader = false;
  public viewData = false;
  public viewObject = {};
  public filterObj:any = {};
  public sortFilter:any = {};
  public pdfLogo;
  public withoutPaginationData = [];
  public operator_comments_array:any = [{val:''}];
  public other_inspector_comments_array:any = [{val:''}];
  //for grid 
  public headerInformation;
  public actionButtons;
  public softwareId;
  //for pagination
  itemsPerPage: number = this.commonService.DefaultItemsPerPage;
  totalItems: number;
  currentPage: number = 1;

  @ViewChild('autofocus') el:ElementRef;

  constructor( private modalService: NgbModal,
    private commonService: CommonService,
    private router: Router,
    private formBuilder: FormBuilder,
    private route: ActivatedRoute ) {
    this.route.params.subscribe(params => {
      this.softwareId = params['softwareId'];
      this.getSoftwareDetail(this.softwareId);
    });
    this.declareGridVariable();
    // this.addForm();
  }
  
  ngAfterViewInit(){
  }

  ngOnInit(){
    this.pdfLogo = location.origin+location.pathname+'assets/images';
    this.getSoftwareVersionList();
    this.addForm();
  }

  getSoftwareDetail(softwareId){
    this.commonService.sendRequestToNode({method :'get',path:'software/'+ softwareId }).subscribe(result => {
      if(result.status)
      {
        if(result.data){
          this.reportBasicInformation = result.data;

          this.grid_title = this.reportBasicInformation.SOFTWARE_TITLE;
          // let dateoi = new Date(this.reportBasicInformation.DATE_OF_INSPECTION);
          // this.reportBasicInformation.DATE_OF_INSPECTION = ('0' + (dateoi.getDate())).slice(-2)+'/'+('0' + (dateoi.getMonth()+1)).slice(-2)+'/'+dateoi.getFullYear();
          // this.grid_subtitle = '<span>Report Number :</span><label class="label label-danger">'+(this.reportBasicInformation.SOFTWARE_TITLE ? this.reportBasicInformation.SOFTWARE_TITLE : "N/A")+'</label>';
          // this.grid_subtitle += '<span>Vessel IMO :</span><label class="label label-info">'+(this.reportBasicInformation.IMO_NUMBER ? this.reportBasicInformation.IMO_NUMBER : "N/A")+'</label>';
          // this.grid_subtitle += '<span>Port :</span><label class="label label-success">'+(this.reportBasicInformation.PORT_OF_INSPECTION ?  this.reportBasicInformation.PORT_OF_INSPECTION : "N/A")+'</label>';
          // this.grid_subtitle += '<span>Date of Inspection :</span><label class="label label-warning">'+(this.reportBasicInformation.DATE_OF_INSPECTION ? this.reportBasicInformation.DATE_OF_INSPECTION : "N/A")+'</label>';
          // this.grid_subtitle += '<span>Oil Major :</span><label class="label label-purple">'+(this.reportBasicInformation.INSPECTING_COMPANY ? this.reportBasicInformation.INSPECTING_COMPANY : "N/A")+'</label>'; 
          // this.getQuestionList(this.reportBasicInformation.SIRE_FK)
        }
      }
      else{
        alert(result.message);
        this.router.navigate(['sire_report'])
      }
  })
  }

  addForm(){ 
    this.SoftwareVersionForm = this.formBuilder.group({
      SOFTWARE_FK: [this.softwareId],
      VERSION: [null,[Validators.required]],
      DESCRIPTION: [null],
      IS_LATEST: "0",
      ACTIVE_FLAG :false
      });   
  }

  getSoftwareVersionList() {
    let filterParams:any = {}
    
    //search filter 
    filterParams = JSON.parse(JSON.stringify(this.filterObj));
    //search filter -end

    // pagination
    filterParams.currentPage = this.currentPage-1;
    filterParams.itemsPerPage = this.itemsPerPage;
    // pagination - end

    //sorting 
    let sortKey = Object.keys(this.sortFilter);
    if(sortKey.length && this.sortFilter[sortKey[0]]){
      filterParams.sortBy = sortKey[0];
      filterParams.sortStatus = this.sortFilter[sortKey[0]];
    }
    //sorting - end
    this.showLoader = true;
    this.commonService.sendRequestToNode({method :'get',path:'software/software-version/'+ this.softwareId,queryParam:filterParams}).subscribe(result => {
      this.showLoader = false;  
      if(result.status)
        {
          if(result.data.length > 0){
            this.totalItems = result.data[0].total_records;
            this.SoftwareVersionList = result.data;
          }else{
            this.SoftwareVersionList = [];
          }
        }
        else{
          this.SoftwareVersionList = [];
          alert(result.message);
        }
    })
  }


  edit( obj ) {
      this.openRightSidebar = true;
      this.el.nativeElement.focus(); 
     
      this.edit_id = obj.ID;
      this.commonService.sendRequestToNode({method :'get',path:'software-version/'+obj.ID}).subscribe(result => {
          if(result.status)
          {
            let questionReportObj =  result.data;
            this.SoftwareVersionForm.patchValue({
              SOFTWARE_FK: this.softwareId,
              VERSION: questionReportObj.VERSION,
              DESCRIPTION: questionReportObj.DESCRIPTION,
              ACTIVE_FLAG :questionReportObj.ACTIVE_FLAG
            });
            if( questionReportObj.IS_LATEST == 1 ) {
              this.SoftwareVersionForm.patchValue({
                IS_LATEST: "1",
              });
            } else {
              this.SoftwareVersionForm.patchValue({
                IS_LATEST: "0",
              });
            }
          }
          else{
            alert(result.message)
          }
      })
  }

  onSubmit(){
    this.formSubmittedAttempt = true;
    if(this.SoftwareVersionForm.valid) {
      this.showSideBarLoader = true;
      
      if(this.edit_id) {
        this.commonService.sendRequestToNode({method :'put',path:'software-version/'+this.edit_id,postData:this.SoftwareVersionForm.value}).subscribe(
          data =>{
            var dialogueTitle = "Updated!";
            this.showSideBarLoader = false;
            if(data.status){
              swal({
                title: dialogueTitle,
                text: data.message,
                type: 'success',
                confirmButtonClass: "btn btn-success",
                buttonsStyling: false
              })
              this.getSoftwareVersionList();
              this.openRightSidebar = false;
              this.resetForm();
            }else{
              alert(data.message);
            }
        })
      } else {
        this.commonService.sendRequestToNode({method :'post',path:'software-version',postData:this.SoftwareVersionForm.value}).subscribe(
          data =>{
            var dialogueTitle = "Inserted!";
            this.showSideBarLoader = false;
            if(data.status){
              swal({
                title: dialogueTitle,
                text: data.message,
                type: 'success',
                confirmButtonClass: "btn btn-success",
                buttonsStyling: false
              })
              this.getSoftwareVersionList();
              this.openRightSidebar = false;
              this.resetForm();
            }else{
              alert(data.message);
            }
        })
      }
      
    }  
  }

  delete( id ) {
    if (id) {
      
      swal({
        title: 'Are you sure?',
        text: "You won't be able to revert this!",
        type: 'warning',
        showCancelButton: true,
        confirmButtonClass: 'btn btn-success',
        cancelButtonClass: 'btn btn-danger',
        confirmButtonText: 'Yes, delete it!',
        buttonsStyling: false
        
        }).then((result) => {
          if (result.value) {   
            this.commonService.sendRequestToNode({method :'delete',path:'software-version/'+id,queryParam : {} }).subscribe(result => {
              if(result.status){
                var dialogueTitle = "Deleted!"
                if(this.SoftwareVersionList.length == 1 && Math.ceil(this.totalItems / this.itemsPerPage) == this.currentPage){
                  if(this.currentPage>1){
                    this.currentPage--;
                  }
                }
                this.getSoftwareVersionList();
                swal({
                    title: dialogueTitle,
                    text: result.message,
                    type: 'success',
                    confirmButtonClass: "btn btn-success",
                    buttonsStyling: false
                  })
              }
            })
          }
        })
    }
  }

  view( obj ){
    this.viewData = true;
    this.openRightSidebar = true;
    this.showSideBarLoader = true;
    this.el.nativeElement.focus(); 
    //console.log(id);
    
    this.commonService.sendRequestToNode({method :'get',path:'software-version/'+obj.ID}).subscribe(result => {
    this.showSideBarLoader = false;      
      if(result.status)
        {
          this.viewObject =  result.data;
        } else {
          alert(result.message)
        }
    })
  }

  changeFlag_audit( e ) {
    this.SoftwareVersionForm.patchValue({
      IS_LATEST : e.target.value,
   });
 }

  resetForm() {
    this.formSubmittedAttempt = false;
    this.openRightSidebar = false;
    this.viewData = false;
    this.edit_id = '';
    this.operator_comments_array = [{val:''}];
    this.other_inspector_comments_array = [{val:''}];
    this.SoftwareVersionForm.patchValue({
          VERSION: null,
          DESCRIPTION: null,
          IS_LATEST: "0",
          ACTIVE_FLAG:false

      });  
      
  }

  // part of grid
  declareGridVariable() {
    
    this.headerInformation = [
      {
        title : 'Version',// show title table header
        name:'VERSION',// name of column in data source
        width : '20%',// width of column in table
        highlight:true, // name highlight
        isFilter:{ // filter 
          type : 'text',
          placeholder : 'Filter By Version'
        }
      },
      {
        title : 'Description',// show title table header
        name:'DESCRIPTION',// name of column in data source
        width : '30%',// width of column in table
        isSortable : true,// sort by column false or true
        //highlight:true, // name highlight
        isFilter:{ // filter 
          type : 'text',
          placeholder : 'Filter By Description'
        }
      },
      {
        title : 'Latest Version',// show title table header
        name:'IS_LATEST',
        display_value: {1:'Latest Version',0:'-'},// name of column in data source
        width : '30%',// width of column in table
        //highlight:true, // name highlight
     
      },
      {
        title : 'Status',// show title table header
        nameIcon : true,// show icon of First letter
        name:'ACTIVE_FLAG',// name of column in data source
        width : '10%',
        display_value: {1:'Active',0:'Inactive'},
        isFilter:{ // filter 
          type : 'select',
          placeholder : 'Filter By Status',
          options_value : [1,0],
          options_display : ['Active','Inactive']
        }
      },
      {title : 'Action',name:'action',width : '20%'}
    ];
    this.actionButtons = [
      {title:'View',class : "fas fa-eye"},
      {title:'Edit',class : "far fa-edit"},
      {title:'Delete',class : "far fa-trash-alt"}
    ]
  }

  //part of grid
  clickOnAction( actionObj ) {
    if(actionObj.actionName == 'View'){
      this.view(actionObj.object);
    }else if(actionObj.actionName == 'Edit'){
      this.edit(actionObj.object);
    }else if(actionObj.actionName == 'Delete'){
      this.delete(actionObj.object.ID);
    }
  }
  
  //part of grid
  //when change filter ,change page no . etc, 
  filter( $event ){
    let obj = $event;
    this.currentPage = obj.page;
    this.filterObj = obj.filter;
    this.sortFilter = obj.sort
    this.getSoftwareVersionList();
  }

  //part of grid
  funOpenRightSidebar(){
    this.openRightSidebar = true;
    this.el.nativeElement.focus(); 
  }

}
