import { Component, AfterViewInit,OnInit, createPlatformFactory,ElementRef,ViewChild } from '@angular/core';
import { NgbPaginationConfig, NgbModal, NgbModalRef, ModalDismissReasons } from '@ng-bootstrap/ng-bootstrap';
import { CommonService } from '../common-service.service';
import {Router,ActivatedRoute} from "@angular/router";
import {FormGroup,FormBuilder,Validators,FormControl} from '@angular/forms';
import swal from 'sweetalert2';

declare var $: any;
import { PerfectScrollbarConfigInterface } from 'ngx-perfect-scrollbar';

@Component({
  templateUrl: './software.component.html',
  styleUrls: ['./software.component.scss']
})
export class SoftwareComponent implements AfterViewInit,OnInit {

  public config: PerfectScrollbarConfigInterface = {};
  
  public softwareData = [];
  public softwareForm:FormGroup;  
  public edit_id;
  public formSubmittedAttempt = false;
  public openRightSidebar = false;
  public filterObj:any = {};
  public sortFilter:any = {};
  public showSideBarLoader = false;
  public showLoader = false;
  public vesselOwner_view = [];
  public viewData = true;
  modalReference: NgbModalRef;

  //for grid 
  public headerInformation;
  public actionButtons;

  //for pagination
  itemsPerPage: number = this.commonService.DefaultItemsPerPage;
  totalItems: number;
  currentPage: number = 1;

  @ViewChild('autofocus') el:ElementRef;
 
  constructor(private modalService: NgbModal,
    private commonService: CommonService,
    private router: Router,
    private formBuilder: FormBuilder,
    private route: ActivatedRoute){
      this.declareGridVariable()
  }

  // part of grid
  declareGridVariable(){
    this.headerInformation = [
      {
        title : 'Software',// show title table header
        nameIcon : true,// show icon of First letter
        name:'SOFTWARE_TITLE',// name of column in data source
        width : '20%',// width of column in table
        isSortable : true,// sort by column false or true
        isFilter:{ // filter 
          type : 'text',
          placeholder : 'Filter By Software'
        }
      },
      {
        title : 'Remark',// show title table header
        nameIcon : true,// show icon of First letter
        name:'REMARK',// name of column in data source
        width : '20%',// width of column in table
        isSortable : true,// sort by column false or true
        isFilter:{ // filter 
          type : 'text',
          placeholder : 'Filter By Remark'
        }
      },
      {
        title : 'Status',// show title table header
        nameIcon : true,// show icon of First letter
        name:'ACTIVE_FLAG',// name of column in data source
        width : '10%',
        display_value: {1:'Active',0:'Inactive'},
        isFilter:{ // filter 
          type : 'select',
          placeholder : 'Filter By Status',
          options_value : [1,0],
          options_display : ['Active','Inactive']
        }
      },
      {title : '',name:'',width : '35%'},
      {title : 'Action',name:'action',width : '15%'}
    ];
    this.actionButtons = [
      {title:'Version',class : "fas fa-file-alt"},
      {title:'View',class : "fas fa-eye"},
      {title:'Edit',class : "far fa-edit"},
      {title:'Delete',class : "far fa-trash-alt"}
    ]
  }

  ngAfterViewInit(){
   
  }

  ngOnInit(){
    this.getData();
    this.addForm();
  }
  
  getData()
  {
    let filterParams:any = {}
    
    //search filter 
    filterParams = JSON.parse(JSON.stringify(this.filterObj));
    //search filter -end

    // pagination
    filterParams.currentPage = this.currentPage-1;
    filterParams.itemsPerPage = this.itemsPerPage;
    // pagination - end

    //sorting 
    let sortKey = Object.keys(this.sortFilter);
    if(sortKey.length && this.sortFilter[sortKey[0]]){
      filterParams.sortBy = sortKey[0];
      filterParams.sortStatus = this.sortFilter[sortKey[0]];
    }
    //sorting - end
    this.showLoader = true;
    this.commonService.sendRequestToNode({method :'get',path:'software',queryParam:filterParams}).subscribe(result => {
    this.showLoader = false;                
      if(result.status)
        {
          if(result.data.length > 0){
            this.totalItems = result.data[0].total_records;
            this.softwareData = result.data;
          }else{
            this.softwareData = [];
          }
        }
        else{
          this.softwareData = [];
          alert(result.message);
        }
    })
  }

  addForm(){
    this.softwareForm = this.formBuilder.group({
      SOFTWARE_TITLE: ['',[Validators.required]],
      REMARK: [''],
      ACTIVE_FLAG: false


    });   
  }

  resetForm(){
    this.formSubmittedAttempt = false;
    this.openRightSidebar = false;
    this.edit_id = '';
    this.softwareForm.patchValue({
      SOFTWARE_TITLE : '',
      REMARK : '',
      ACTIVE_FLAG: false


    })
  }

  edit(id){
     this.viewData = false
    this.openRightSidebar = true;
    this.el.nativeElement.focus();
    this.commonService.sendRequestToNode({method :'get',path:'software/'+id}).subscribe(
      data => {         
        this.softwareForm.patchValue({
          SOFTWARE_TITLE : data.data.SOFTWARE_TITLE ,
          REMARK : data.data.REMARK ,
          ACTIVE_FLAG: data.data.ACTIVE_FLAG
        })
        this.edit_id = id;
    })
  }

  delete(id){
    this.viewData =false
    if(id){
      swal({
        title: 'Are you sure?',
        text: "You won't be able to revert this!",
        type: 'warning',
        showCancelButton: true,
        confirmButtonClass: 'btn btn-success',
        cancelButtonClass: 'btn btn-danger',
        confirmButtonText: 'Yes, delete it!',
         buttonsStyling: false
      }).then((result) => {
        if (result.value) {
          this.commonService.sendRequestToNode({method :'delete',path:'software/'+id}).subscribe(
          data => {
          if(data.status){
            var dialogueTitle = "Deleted!"
            if(this.softwareData.length == 1 && Math.ceil(this.totalItems / this.itemsPerPage) == this.currentPage){
              if(this.currentPage>1){
                this.currentPage--;
              }
            }
            this.getData();
            swal({
                title: dialogueTitle,
                text: data.message,
                type: 'success',
                confirmButtonClass: "btn btn-success",
                buttonsStyling: false
              })
          }         
          
      })
         }
      })      
    }
  }

  view(id){
    this.viewData = true;
    this.openRightSidebar = true;
    this.showSideBarLoader = true;
    this.el.nativeElement.focus(); 
    //console.log(id);
    this.commonService.sendRequestToNode({method :'get',path:'software/'+id}).subscribe(result => {
    this.showSideBarLoader = false;      
      if(result.status)
        {
          this.vesselOwner_view = result.data;
          console.log(this.vesselOwner_view);
        }
        else{
          alert(result.message)
        }
    })
  }

  onSubmit(){ 
    this.formSubmittedAttempt = true;
    if(this.softwareForm.valid){
    this.showSideBarLoader = true;
    if(this.edit_id){    
      this.commonService.sendRequestToNode({method :'put',path:'software/'+this.edit_id,postData:this.softwareForm.value}).subscribe(
        data =>{
          var dialogueTitle = "Updated!";
          this.showSideBarLoader = false;
          if(data.status){
            swal({
                title: dialogueTitle,
                text: data.message,
                type: 'success',
                confirmButtonClass: "btn btn-success",
                buttonsStyling: false
              })
            this.getData();
            this.resetForm(); //after edit form is reset
          }
          else{
            alert(data.message);
          }
      })
    }else{
      this.commonService.sendRequestToNode({method :'post',path:'software',postData:this.softwareForm.value}).subscribe(
        data =>{
          var dialogueTitle = "Inserted!";
          this.showSideBarLoader = false;
          if(data.status){
            swal({
                title: dialogueTitle,
                text: data.message,
                type: 'success',
                confirmButtonClass: "btn btn-success",
                buttonsStyling: false
              })
            this.getData();
            this.resetForm(); //after edit form is reset

          }
          else{
            alert(data.message);
          }
      })
    }
    }
      
  } 

    //part of grid
    clickOnAction(actionObj){
      if(actionObj.actionName == 'View'){
        this.view(actionObj.object.ID);
      } else  if(actionObj.actionName == 'Edit'){
        this.edit(actionObj.object.ID)
      }else if(actionObj.actionName == 'Delete'){
        this.delete(actionObj.object.ID)
      } else if( actionObj.actionName == 'Version') {
        this.addVersion(actionObj.object.ID);
      }
    }
  
    addVersion(id) {
      // this.commonService.setRouteData('sire_report_filter_data',this.filterObj);
      // this.router.navigate(["/observation/"+id]); 

    //this.commonService.setRouteData('sire_report_filter_data',this.filterObj);
    this.router.navigate(["/software-version/"+id]); 
    }
    //part of grid
    //when change filter ,change page no . etc, 
    filter($event){
      let obj = $event;
      this.currentPage = obj.page;
      this.filterObj = obj.filter;
      this.sortFilter = obj.sort
      this.getData();
    }
  
    //part of grid
    funOpenRightSidebar(){
      this.viewData =false
      this.openRightSidebar = true; 
      this.el.nativeElement.focus();
    }
  

}

