import { Component, AfterViewInit,OnInit, createPlatformFactory,ElementRef,ViewChild } from '@angular/core';
import { NgbPaginationConfig, NgbModal, NgbModalRef, ModalDismissReasons } from '@ng-bootstrap/ng-bootstrap';
import { CommonService } from '../common-service.service';
import {Router,ActivatedRoute} from "@angular/router";
import {FormGroup,FormBuilder,Validators,FormControl} from '@angular/forms';
import swal from 'sweetalert2';
//import { parse } from 'path';

declare var $: any;
import { PerfectScrollbarConfigInterface } from 'ngx-perfect-scrollbar';
import { t } from '@angular/core/src/render3';

@Component({
  templateUrl: './softwareManagement.component.html',
  styleUrls: ['./softwareManagement.component.scss']
})
export class SoftwareManagementComponent implements AfterViewInit,OnInit {

  public config: PerfectScrollbarConfigInterface = {};
  public modalRef:NgbModalRef;

  public officeLocationForm:FormGroup; 
  public officeLocationFormSubmittedAttempt = false;

  public softwareForm:FormGroup; 
  public softwareFormSubmittedAttempt = false;

  public GroupsoftwareManagement:FormGroup;
  public softwareManagement = [];
  public softwareManagement_view;
  public vessel_dropdown = [];
  public office_dropdown = [];
  public software_dropdown = [];

  public edit_id;
  public formSubmittedAttempt = false;
  public openRightSidebar = false;
  public showSideBarLoader = false;
  public showLoader = false;
  public viewData = false;
  public filterObj:any = {};
  public sortFilter:any = {};

  //for grid 
  public headerInformation;
  public actionButtons;

  //for pagination
  itemsPerPage: number = this.commonService.DefaultItemsPerPage;
  totalItems: number;
  currentPage: number = 1;
  
  @ViewChild('autofocus') el:ElementRef;

  constructor(private modalService: NgbModal,
    private commonService: CommonService,
    private router: Router,
    private formBuilder: FormBuilder,
    private route: ActivatedRoute){
      this.declareGridVariable()
  }
  
  ngAfterViewInit(){
   
  }

  ngOnInit(){
    this.getData();
    this.addForm();
    this.vessel();
    this.office();
    this.getSoftwareDropDownData()
  }

  addForm(){
    this.GroupsoftwareManagement = this.formBuilder.group({
      SOFTWARE_FK: [null,],
      VERSION: [null,],
      INSPECTION_DATE: [null,],
      NEW_VERSION: [null,],
      INSTALLATION_DATE: [null,],
      CAPABILITY_TEST_DATE: [null,],
      PERFORMANCE_TESTING_DATE: [null,],
      OFFICE_FK: [null,],
      VESSEL_FK: [null,],
    });  
    
    this.officeLocationForm = this.formBuilder.group({
      TITLE: [''],
      ADDRESS: [''],
      CITY: ['']
    });

    this.softwareForm = this.formBuilder.group({
      SOFTWARE_TITLE: [''],
    });
    
  }

  onSubmit(){
    //console.log(this.edit_id);
    this.formSubmittedAttempt = true;
    this.showSideBarLoader = true;
    if(this.GroupsoftwareManagement.valid){
      if(this.edit_id){
        this.commonService.sendRequestToNode({method :'post',path:'softwareManagement/edit/'+this.edit_id,postData:this.GroupsoftwareManagement.value}).subscribe(
          data =>{
            var dialogueTitle = "Updated!";
            this.showSideBarLoader = false;            
            if(data.status){
              swal({
                title: dialogueTitle,
                text: data.message,
                type: 'success',
                confirmButtonClass: "btn btn-success",
                buttonsStyling: false
              })
              this.getData();
              this.openRightSidebar = false;
              this.resetForm();
            }else{
              alert(data.message);
            }
        })
      }else{
        //console.log(this.GroupsoftwareManagement.value);
        this.commonService.sendRequestToNode({method :'post',path:'softwareManagement/add',postData:this.GroupsoftwareManagement.value}).subscribe(
          data =>{
            var dialogueTitle = "Inserted!";
            this.showSideBarLoader = false;            
            if(data.status){
              swal({
                title: dialogueTitle,
                text: data.message,
                type: 'success',
                confirmButtonClass: "btn btn-success",
                buttonsStyling: false
              })
              this.getData();
              this.openRightSidebar = false;
              this.resetForm();
            }else{
              alert(data.message);
            }
        })
      }
    }  
  }

  getData()
  {
    let filterParams:any = {}
    
    //search filter 
    filterParams = JSON.parse(JSON.stringify(this.filterObj));
    //search filter -end

    // pagination
    filterParams.currentPage = this.currentPage-1;
    filterParams.itemsPerPage = this.itemsPerPage;
    // pagination - end

    //sorting 
    let sortKey = Object.keys(this.sortFilter);
    if(sortKey.length && this.sortFilter[sortKey[0]]){
      filterParams.sortBy = sortKey[0];
      filterParams.sortStatus = this.sortFilter[sortKey[0]];
    }
    //sorting - end

    this.showLoader = true;

    this.commonService.sendRequestToNode({method :'get',path:'softwareManagement/data_list',queryParam:filterParams}).subscribe(result => {
    this.showLoader = false;      
      if(result.status)
        {
          if(result.data.length > 0){
            this.totalItems = result.data[0].total_records;
            this.softwareManagement = result.data;
            //console.log(this.softwareManagement);
          }else{
            this.softwareManagement = [];
          }
        }
        else{
          this.softwareManagement = [];
          alert(result.message);
        }
    })
  }

  view(id){
    this.viewData = true;
    this.openRightSidebar = true;
    this.showSideBarLoader = true;            
    this.el.nativeElement.focus();
    //console.log(id);
    this.commonService.sendRequestToNode({method :'get',path:'softwareManagement/getById/'+id}).subscribe(result => {
      this.showSideBarLoader = false;                  
      if(result.status)
        {
          this.softwareManagement_view = result.data;
        }
        else{
          alert(result.message)
        }
    })
  }

  edit(id){
    this.openRightSidebar = true;
    // this.el.nativeElement.focus();
    this.commonService.sendRequestToNode({method :'get',path:'softwareManagement/getById/'+id}).subscribe(
      data => { 
        // console.log(data);
        let ins_date = new Date(data.data.INSPECTION_DATE);
        data.data.INSPECTION_DATE = ins_date.getFullYear()+'-'+('0' + (ins_date.getMonth()+1)).slice(-2)+'-'+('0' + (ins_date.getDate())).slice(-2);
        let inst_date = new Date(data.data.INSTALLATION_DATE);
        data.data.INSTALLATION_DATE = inst_date.getFullYear()+'-'+('0' + (inst_date.getMonth()+1)).slice(-2)+'-'+('0' + (inst_date.getDate())).slice(-2);
        let comp_date = new Date(data.data.CAPABILITY_TEST_DATE);
        data.data.CAPABILITY_TEST_DATE = comp_date.getFullYear()+'-'+('0' + (comp_date.getMonth()+1)).slice(-2)+'-'+('0' + (comp_date.getDate())).slice(-2);
        let per_date = new Date(data.data.PERFORMANCE_TESTING_DATE);
        data.data.PERFORMANCE_TESTING_DATE = per_date.getFullYear()+'-'+('0' + (per_date.getMonth()+1)).slice(-2)+'-'+('0' + (per_date.getDate())).slice(-2);
        data.data.NEW_VERSION = (data.data.NEW_VERSION == 1) ? '1' : '0';
        this.GroupsoftwareManagement.patchValue(data.data);
        this.edit_id = id;
    })
  }

  vessel()
  {

    this.commonService.sendRequestToNode({method :'get',path:'softwareManagement/vessel-dropdown'}).subscribe(result => {
      if(result.status){
        this.vessel_dropdown = result.data;
        //console.log(this.vessel_dropdown);
        
      }
      else{
        this.vessel_dropdown = [];
        alert(result.message);
      }
    })
  }

  office(id=0)
  {

    this.commonService.sendRequestToNode({method :'get',path:'softwareManagement/office-dropdown'}).subscribe(result => {
      if(result.status){
        this.office_dropdown = result.data;
        //console.log(this.office_dropdown);
        if(id){
          this.GroupsoftwareManagement.patchValue({
            OFFICE_FK : id 
          })
        }
      }
      else{
        this.office_dropdown = [];
        alert(result.message);
      }
    })
  }

  getSoftwareDropDownData(id=0)
  {

    this.commonService.sendRequestToNode({method :'get',path:'softwareManagement/software-dropDown'}).subscribe(result => {
      if(result.status){
        this.software_dropdown = result.data;
        //console.log(this.software_dropdown);
        if(id){
          this.GroupsoftwareManagement.patchValue({
            SOFTWARE_FK : id 
          })
        }
      }
      else{
        this.software_dropdown = [];
        alert(result.message);
      }
    })
  }
  
  resetForm(){
    this.formSubmittedAttempt = false;
    this.openRightSidebar = false;
    this.viewData = false;
    this.edit_id = '';
    this.GroupsoftwareManagement.patchValue({
      SOFTWARE_FK: null,
      VERSION: null,
      INSPECTION_DATE: null,
      NEW_VERSION: null,
      INSTALLATION_DATE: null,
      CAPABILITY_TEST_DATE: null,
      PERFORMANCE_TESTING_DATE: null,
      OFFICE_FK: null,
      VESSEL_FK: null, 
    })
  }

  // part of grid
  declareGridVariable(){
    this.headerInformation = [
      {
        title : 'Software',
        name:'SOFTWARE_TITLE',
        width : '17%',
        isSortable : true,
        isFilter:{ // filter 
          type : 'text',
          placeholder : 'Filter By Software'
        }
      },
      {
        title : 'Version',
        name:'VERSION',
        width : '17%',
        isSortable : true,
        isFilter:{ // filter 
          type : 'text',
          placeholder : 'Filter By Version'
        }
      },
      {
        title : 'Date of Inspection',
        isDate:'yes',
        name:'INSPECTION_DATE',
        width : '17%',
        isSortable : true,
      },
      {
        title : 'Office',
        name:'OFFICE_TITLE',
        width : '17%',
        isSortable : true,
        isFilter:{
          type : 'text',
          placeholder : 'Filter By Office'
        }
      },
      {
        title : 'Vessel',
        name:'VESSEL_NAME',
        width : '17%',
        isSortable : true,
        isFilter:{
          type : 'text',
          placeholder : 'Filter By Vessel'
        }
      },
      {title : 'Action',name:'action',width : '15%'}
    ];
    this.actionButtons = [
      {title:'View',class : "fas fa-eye"},
      {title:'Edit',class : "far fa-edit"},
      {title:'Delete',class : "far fa-trash-alt"}
    ]
  }

  //part of grid
  clickOnAction(actionObj){
    if(actionObj.actionName == 'View'){
      this.view(actionObj.object.ID)
    }else if(actionObj.actionName == 'Edit'){
      this.edit(actionObj.object.ID)
    }else if(actionObj.actionName == 'Delete'){
      this.delete(actionObj.object.ID)
    }
  }
  
  //part of grid
  //when change filter ,change page no . etc, 
  filter($event){
    let obj = $event;
    this.currentPage = obj.page;
    this.filterObj = obj.filter;
    this.sortFilter = obj.sort
    this.getData();
  }

  changeVersion(dta){
    if(dta == 0){
      this.GroupsoftwareManagement.patchValue({
        
        INSTALLATION_DATE: null,
        CAPABILITY_TEST_DATE: null,
        PERFORMANCE_TESTING_DATE: null
      })
    }

  }
  delete(id){
    if(id){
      swal({
        title: 'Are you sure?',
        text: "You won't be able to revert this!",
        type: 'warning',
        showCancelButton: true,
        confirmButtonClass: 'btn btn-success',
        cancelButtonClass: 'btn btn-danger',
        confirmButtonText: 'Yes, delete it!',
         buttonsStyling: false
      }).then((result) => {
        if (result.value) {
          this.commonService.sendRequestToNode({method :'delete',path:'softwareManagement/'+id}).subscribe(
          data => {
          if(data.status){
            var dialogueTitle = "Deleted!"
            if(this.softwareManagement.length == 1 && Math.ceil(this.totalItems / this.itemsPerPage) == this.currentPage){
              if(this.currentPage>1){
                this.currentPage--;
              }
            }
            this.getData();
            swal({
                title: dialogueTitle,
                text: data.message,
                type: 'success',
                confirmButtonClass: "btn btn-success",
                buttonsStyling: false
              })
          }         
          
      })
         }
      })      
    }
  }


  //part of grid
  funOpenRightSidebar(){
    this.openRightSidebar = true;
    this.el.nativeElement.focus();
    //$("autofoucs").scrollTop(0).perfectScrollbar('update');
  }



  addOfficeLocation(content){
    this.modalRef = this.modalService.open(content,{size: 'sm'});
  }

  resetOfficeLocationForm(){
    this.officeLocationFormSubmittedAttempt = false;
    this.officeLocationForm.patchValue({
      TITLE: '',
      ADDRESS: '',
      CITY: ''
    })
  }

  onSubmitOfficeLocation(){
    //console.log(this.edit_id);
    this.officeLocationFormSubmittedAttempt = true;
    if(this.officeLocationForm.valid){
      //console.log(this.Groupinspector.value);
      this.commonService.sendRequestToNode({method :'post',path:'office-location',postData:this.officeLocationForm.value}).subscribe(
        data =>{
          var dialogueTitle = "Inserted!";
          if(data.status){
            swal({
              title: dialogueTitle,
              text: data.message,
              type: 'success',
              confirmButtonClass: "btn btn-success",
              buttonsStyling: false
            }).then(()=>{
              this.modalRef.close();
              this.office(data.insertId);
              this.resetOfficeLocationForm();
            })
            // this.modal.close()
          }else{
            alert(data.message);
          }
      })
    }  
  }


  addSoftware(content){
    this.modalRef = this.modalService.open(content,{size: 'sm'});
  }

  resetSoftwareForm(){
    this.softwareFormSubmittedAttempt = false;
    this.softwareForm.patchValue({
      SOFTWARE_TITLE: '',
    })
  }

  onSubmitSoftware(){
    //console.log(this.edit_id);
    this.softwareFormSubmittedAttempt = true;
    if(this.softwareForm.valid){
      //console.log(this.Groupinspector.value);
      this.commonService.sendRequestToNode({method :'post',path:'software',postData:this.softwareForm.value}).subscribe(
        data =>{
          var dialogueTitle = "Inserted!";
          if(data.status){
            swal({
              title: dialogueTitle,
              text: data.message,
              type: 'success',
              confirmButtonClass: "btn btn-success",
              buttonsStyling: false
            }).then(()=>{
              this.modalRef.close();
              this.getSoftwareDropDownData(data.insertId);
              this.resetSoftwareForm();
            })
            // this.modal.close()
          }else{
            alert(data.message);
          }
      })
    }  
  }

}
