import { Component, AfterViewInit,OnInit, createPlatformFactory,ElementRef,ViewChild } from '@angular/core';
import { NgbPaginationConfig, NgbModal, NgbModalRef, ModalDismissReasons } from '@ng-bootstrap/ng-bootstrap';
import { CommonService } from '../common-service.service';
import {Router,ActivatedRoute} from "@angular/router";
import {FormGroup,FormBuilder,Validators,FormControl} from '@angular/forms';
import swal from 'sweetalert2';
//import { parse } from 'path';

declare var $: any;
import { PerfectScrollbarConfigInterface } from 'ngx-perfect-scrollbar';

@Component({
  templateUrl: './subscription.component.html',
  styleUrls: ['./subscription.component.scss']
})
export class SubscriptionComponent implements AfterViewInit,OnInit {

   

  public config: PerfectScrollbarConfigInterface = {};

  options = {
    theme: 'light', // two possible values: light, dark
    dir: 'ltr', // two possible values: ltr, rtl
    layout: 'vertical', // fixed value. shouldn't be changed.
    sidebartype: 'mini-sidebar', // four possible values: full, iconbar, overlay, mini-sidebar 
    sidebarpos: 'fixed', // two possible values: fixed, absolute
    headerpos: 'fixed', // two possible values: fixed, absolute
    boxed: 'full', // two possible values: full, boxed
    navbarbg: 'skin6', // six possible values: skin(1/2/3/4/5/6)
    sidebarbg: 'skin5', // six possible values: skin(1/2/3/4/5/6)
    logobg: 'skin5' // six possible values: skin(1/2/3/4/5/6)
  };

  public Groupsubscription:FormGroup;
  public subscriptions = [];
  public subscriptions_view;
  public chapter_dropdown = [];
  public subtopic_dropdown = [];
  public edit_id;
  public user_id;
  public template_name;
  public formSubmittedAttempt = false;
  public openRightSidebar = false;
  public showSideBarLoader = false;
  public showLoader = false;
  public viewData = false;
  public filterObj:any = {};
  public sortFilter:any = {};

  //for grid 
  public headerInformation;
  public actionButtons;

  //for pagination
  itemsPerPage: number = this.commonService.DefaultItemsPerPage;
  totalItems: number;
  currentPage: number = 1;
  
  @ViewChild('autofocus') el:ElementRef;

  constructor(private modalService: NgbModal,
    private commonService: CommonService,
    private router: Router,
    private formBuilder: FormBuilder,
    private route: ActivatedRoute){
      this.declareGridVariable()
  }
  
  ngAfterViewInit(){
   
  }

  ngOnInit(){

   this.route.params.subscribe(params => {
      this.user_id = params['user_id'];
   });

    this.getData();
    this.addForm();
 
  }


  addForm(){
    this.Groupsubscription = this.formBuilder.group({
      SUBSCRIPTION_START_DATE: ['',[Validators.required]],
      SUBSCRIPTION_END_DATE: ['',[Validators.required]],
      NUMBER_OF_SHIPS: ['',[Validators.required]],
      AMOUNT: [],
      USER_FK:[]
    });   
  }

 

  onSubmit(){
    //console.log(this.edit_id);
    this.formSubmittedAttempt = true;
    if(this.Groupsubscription.valid){
      this.showSideBarLoader = true;
      if(this.edit_id){
        this.commonService.sendRequestToNode({method :'post',path:'subscription/edit/'+this.edit_id,postData:this.Groupsubscription.value}).subscribe(
          data =>{
            var dialogueTitle = "Updated!";
            this.showSideBarLoader = false;
            if(data.status){
              swal({
                title: dialogueTitle,
                text: data.message,
                type: 'success',
                confirmButtonClass: "btn btn-success",
                buttonsStyling: false
              })
              this.getData();
              this.openRightSidebar = false;
              this.resetForm();
            }else{
              alert(data.message);
            }
        })
      }else{
        // console.log('test');
        this.Groupsubscription.patchValue({
          USER_FK : this.user_id
        });
        this.commonService.sendRequestToNode({method :'post',path:'subscription/add',postData:this.Groupsubscription.value}).subscribe(
          data =>{
            var dialogueTitle = "Inserted!";
            this.showSideBarLoader = false;
            if(data.status){
              swal({
                title: dialogueTitle,
                text: data.message,
                type: 'success',
                confirmButtonClass: "btn btn-success",
                buttonsStyling: false
              })
              this.getData();
              this.openRightSidebar = false;
              this.resetForm();
            }else{
              alert(data.message);
            }
        })
      }
    }  
  }

  getData()
  {
    // alert('test');
    let filterParams:any = {}
    
    //search filter 
    filterParams = JSON.parse(JSON.stringify(this.filterObj));
    //search filter -end

    // pagination
    filterParams.currentPage = this.currentPage-1;
    filterParams.itemsPerPage = this.itemsPerPage;
    filterParams.user_id  =this.user_id;
    // pagination - end

    //sorting 
    let sortKey = Object.keys(this.sortFilter);
    if(sortKey.length && this.sortFilter[sortKey[0]]){
      filterParams.sortBy = sortKey[0];
      filterParams.sortStatus = this.sortFilter[sortKey[0]];
    }
    //sorting - end

    //this.showLoader = true;

    this.commonService.sendRequestToNode({method :'get',path:'subscription/data_list',queryParam:filterParams}).subscribe(result => {
    this.showLoader = false;
      if(result.status)
        {
         
          if(result.data.data.length > 0){
            // this.totalItems = result.data[0].total_records;
            this.subscriptions = result.data.data;
          }else{
            this.subscriptions = [];
          }
        }
        else{
          this.subscriptions = [];
          alert(result.message);
        }
    })
  }

   

  resetForm(){
    this.formSubmittedAttempt = false;
    this.openRightSidebar = false;
    this.viewData = false;
    this.edit_id = '';
    this.Groupsubscription.patchValue({
      SUBSCRIPTION_START_DATE: '',
      SUBSCRIPTION_END_DATE: '' ,
      NUMBER_OF_SHIPS : '',
      AMOUNT:''
     
    })
  }
  linkVessel(id,ships){
    this.router.navigate(["/link_vessel/"+id+"/"+ships]);
  }
  // part of grid
  declareGridVariable(){
    
    this.headerInformation = [
      {
        title : 'Subscription Start Date',// show title table header
        //nameIcon : true,// show icon of First letter
        isDate:'yes',
        name:'SUBSCRIPTION_START_DATE',// name of column in data source
        width : '18%',// width of column in table
        isSortable : true,// sort by column false or true
        highlight:true // name highlight
        
      },
      {title : 'Subscription End Date',isDate:'yes',name:'SUBSCRIPTION_END_DATE',width : '18%',highlight:true,isSortable : true},
      {title : 'Active Vessels',name:'NUMBER_OF_SHIPS',width : '18%',isSortable : true},
      {title : 'Amount',name:'AMOUNT',width : '18%',isSortable : true},
      
      
      {title : 'Action',name:'action',width : '10%'}
    ];
    this.actionButtons = [
     
       {title:'Link Vessel',class : "fas fa-link"},
      
    ]
  }


  //part of grid
  clickOnAction(actionObj){
    if(actionObj.actionName == 'Link Vessel'){
      this.linkVessel(actionObj.object.ID,actionObj.object.NUMBER_OF_SHIPS)
    }
    
  }
  
  //part of grid
  //when change filter ,change page no . etc, 
  filter($event){
    let obj = $event;
    this.currentPage = obj.page;
    this.filterObj = obj.filter;
    this.sortFilter = obj.sort
    this.getData();
  }

  //part of grid
  funOpenRightSidebar(){
    this.openRightSidebar = true;
    this.el.nativeElement.focus(); 
  }




}
