import { Component, AfterViewInit,OnInit, createPlatformFactory,ElementRef,ViewChild } from '@angular/core';
import { NgbPaginationConfig, NgbModal, NgbModalRef, ModalDismissReasons } from '@ng-bootstrap/ng-bootstrap';
import { CommonService } from '../../common-service.service';
import {Router,ActivatedRoute} from "@angular/router";
import {FormGroup,FormBuilder,Validators,FormControl} from '@angular/forms';
import swal from 'sweetalert2';
//import { parse } from 'path';

declare var $: any;
import { PerfectScrollbarConfigInterface,PerfectScrollbarDirective } from 'ngx-perfect-scrollbar';

@Component({
  templateUrl: './flag_state_inspection.component.html',
  styleUrls: ['./flag_state_inspection.component.scss']
})
export class FlagStateInspectionComponent implements AfterViewInit,OnInit {

  public config: PerfectScrollbarConfigInterface = {};

  options = {
    theme: 'light', // two possible values: light, dark
    dir: 'ltr', // two possible values: ltr, rtl
    layout: 'vertical', // fixed value. shouldn't be changed.
    sidebartype: 'mini-sidebar', // four possible values: full, iconbar, overlay, mini-sidebar 
    sidebarpos: 'fixed', // two possible values: fixed, absolute
    headerpos: 'fixed', // two possible values: fixed, absolute
    boxed: 'full', // two possible values: full, boxed
    navbarbg: 'skin6', // six possible values: skin(1/2/3/4/5/6)
    sidebarbg: 'skin5', // six possible values: skin(1/2/3/4/5/6)
    logobg: 'skin5' // six possible values: skin(1/2/3/4/5/6)
  };

  public FlagStateInspectionForm:FormGroup;
  public flagStateInspection = [];
  public flagStateInspection_view;  
  public edit_id;
  public formSubmittedAttempt = false;
  public openRightSidebar = false;
  public showSideBarLoader = false; 
  public showLoader = false;
  public viewData = false;
  public filterObj:any = {};
  public sortFilter:any = {};
  public VesselData = [];
  public TypeOfDeficiencyData = [];  
  public EquipmentData = [];
  public ObserverCodeData = [];
  public StatusCodeData = [];
  public FlagData = [{ID:'CRITICAL',NAME:'CRITICAL'},{ID:'ROUTINE',NAME:'ROUTINE'}];
  //for grid 
  public headerInformation;
  public actionButtons;

  //for pagination
  itemsPerPage: number = this.commonService.DefaultItemsPerPage;
  totalItems: number;
  currentPage: number = 1;
  
  @ViewChild('autofocus') el:ElementRef;
  @ViewChild(PerfectScrollbarDirective) directiveRef?: PerfectScrollbarDirective;

  constructor(private modalService: NgbModal,
    private commonService: CommonService,
    private router: Router,
    private formBuilder: FormBuilder,
    private route: ActivatedRoute){
      this.declareGridVariable()
  }
  
  ngAfterViewInit(){
   
  }

  ngOnInit(){
    this.getData();
    this.addForm();    
    this.getVesselData();
    this.getTypeOfDeficiencyData();
    this.getEquipmentData();
    this.getObserverCodeData();
    this.getStatusCodeData();
    //this.editForm();
  }

  addForm(){
    this.FlagStateInspectionForm = this.formBuilder.group({      
      
      VESSEL_FK: [null,],
      DATE_RECORDED:[null,],
      TYPE_OF_DEFICIENCY_FK:[null,],      
      EQUIPMENT_FK: [null,],
      VIQ_REF_NUMBER:[null,],
      DESCRIPTION_OF_DEFICIENCY:[null,],
      OBSERVER_CODE_FK: [null,],
      ACTION_TAKEN_OR_REQUIRED:[null,],
      TARGET_DATE:[null,],
      PO_REF_NO:[null,],
      STATUS_CODE_FK:[null,],
      DATE_COMPLETED:[null,],
      FORM_FLAG: [null,]
    });   
  }

  getVesselData(){
    this.commonService.sendRequestToNode({method :'get',path:'vessel_master/vessel-dropdown'}).subscribe(result => {
      if(result.status){   
        this.VesselData = result.data;
      }else{
        this.VesselData = [];
        alert(result.message);
      }
    })
  }

  getTypeOfDeficiencyData(){
    this.commonService.sendRequestToNode({method :'get',path:'typeof-defiency/data_list'}).subscribe(result => {
      if(result.status){   
        this.TypeOfDeficiencyData = result.data;
      }else{
        this.TypeOfDeficiencyData = [];
        alert(result.message);
      }
    })
  }

  getEquipmentData(){
    this.commonService.sendRequestToNode({method :'get',path:'equipment-codes/data_list'}).subscribe(result => {
      if(result.status){   
        this.EquipmentData = result.data;
      }else{
        this.EquipmentData = [];
        alert(result.message);
      }
    })
  }

  getObserverCodeData(){
    this.commonService.sendRequestToNode({method :'get',path:'observer-codes/data_list'}).subscribe(result => {
      if(result.status){   
        this.ObserverCodeData = result.data;
      }else{
        this.ObserverCodeData = [];
        alert(result.message);
      }
    })
  }

  getStatusCodeData(){
    this.commonService.sendRequestToNode({method :'get',path:'status-codes/data_list'}).subscribe(result => {
      if(result.status){   
        this.StatusCodeData = result.data;
      }else{
        this.StatusCodeData = [];
        alert(result.message);
      }
    })
  } 
  
  onSubmit(){
    //console.log(this.edit_id);
    this.formSubmittedAttempt = true;
    if(this.FlagStateInspectionForm.valid){
      this.showSideBarLoader = true;
      if(this.edit_id){
        this.commonService.sendRequestToNode({method :'post',path:'flag_state_inspection/edit/'+this.edit_id,postData:this.FlagStateInspectionForm.value}).subscribe(
          data =>{
            var dialogueTitle = "Updated!";
            this.showSideBarLoader = false;
            if(data.status){
              swal({
                title: dialogueTitle,
                text: data.message,
                type: 'success',
                confirmButtonClass: "btn btn-success",
                buttonsStyling: false
              })
              this.getData();
              this.openRightSidebar = false;
              this.resetForm();
            }else{
              alert(data.message);
            }
        })
      }else{
        
        this.commonService.sendRequestToNode({method :'post',path:'flag_state_inspection/add',postData:this.FlagStateInspectionForm.value}).subscribe(
          data =>{
            var dialogueTitle = "Inserted!";
            this.showSideBarLoader = false;
            if(data.status){
              swal({
                title: dialogueTitle,
                text: data.message,
                type: 'success',
                confirmButtonClass: "btn btn-success",
                buttonsStyling: false
              })
              this.getData();
              this.openRightSidebar = false;
              this.resetForm();
            }else{
              alert(data.message);
            }
        })
      }
    }  
  }

  getData()
  {
    let filterParams:any = {}
    
    //search filter 
    filterParams = JSON.parse(JSON.stringify(this.filterObj));
    //search filter -end

    // pagination
    filterParams.currentPage = this.currentPage-1;
    filterParams.itemsPerPage = this.itemsPerPage;
    // pagination - end

    //sorting 
    let sortKey = Object.keys(this.sortFilter);
    if(sortKey.length && this.sortFilter[sortKey[0]]){
      filterParams.sortBy = sortKey[0];
      filterParams.sortStatus = this.sortFilter[sortKey[0]];
    }
    //sorting - end

    this.showLoader = true;

    this.commonService.sendRequestToNode({method :'get',path:'flag_state_inspection/list',queryParam:filterParams}).subscribe(result => {
    this.showLoader = false;    
      if(result.status)
        {
          if(result.data.length > 0){
            this.totalItems = result.data[0].total_records;
            this.flagStateInspection = result.data;            
          }else{
            this.flagStateInspection = [];
          }
        }
        else{
          this.flagStateInspection = [];
          alert(result.message);
        }
    })
  }
  
  edit(id){ 
    this.openRightSidebar = true;
    this.el.nativeElement.focus();
    this.directiveRef.scrollToTop();
    this.commonService.sendRequestToNode({method :'get',path:'flag_state_inspection/getById/'+id}).subscribe(
      data => {                 
        
        if(data.data[0].DATE_RECORDED && data.data[0].DATE_RECORDED != '0000-00-00 00:00:00'){
          let dateRecorded = new Date(data.data[0].DATE_RECORDED);
          data.data[0].DATE_RECORDED = dateRecorded.getFullYear()+'-'+('0' + (dateRecorded.getMonth()+1)).slice(-2)+'-'+('0' + (dateRecorded.getDate())).slice(-2); 
        }        

        if(data.data[0].TARGET_DATE && data.data[0].TARGET_DATE != '0000-00-00 00:00:00'){
          let tdate = new Date(data.data[0].TARGET_DATE);
          data.data[0].TARGET_DATE = tdate.getFullYear()+'-'+('0' + (tdate.getMonth()+1)).slice(-2)+'-'+('0' + (tdate.getDate())).slice(-2); 
        }        

        if(data.data[0].DATE_COMPLETED && data.data[0].DATE_COMPLETED != '0000-00-00 00:00:00'){
          let cdate = new Date(data.data[0].DATE_COMPLETED);
          data.data[0].DATE_COMPLETED = cdate.getFullYear()+'-'+('0' + (cdate.getMonth()+1)).slice(-2)+'-'+('0' + (cdate.getDate())).slice(-2); 
        }     

        this.FlagStateInspectionForm.patchValue({

          VESSEL_FK : data.data[0].VESSEL_FK,
          DATE_RECORDED : data.data[0].DATE_RECORDED,
          TYPE_OF_DEFICIENCY_FK : data.data[0].TYPE_OF_DEFICIENCY_FK,
          EQUIPMENT_FK : data.data[0].EQUIPMENT_FK,
          VIQ_REF_NUMBER : data.data[0].VIQ_REF_NUMBER,
          DESCRIPTION_OF_DEFICIENCY : data.data[0].DESCRIPTION_OF_DEFICIENCY,
          OBSERVER_CODE_FK : data.data[0].OBSERVER_CODE_FK,
          ACTION_TAKEN_OR_REQUIRED : data.data[0].ACTION_TAKEN_OR_REQUIRED,
          TARGET_DATE : data.data[0].TARGET_DATE,
          PO_REF_NO : data.data[0].PO_REF_NO,
          STATUS_CODE_FK : data.data[0].STATUS_CODE_FK,
          DATE_COMPLETED : data.data[0].DATE_COMPLETED,
          FORM_FLAG : data.data[0].FORM_FLAG
        })
        this.edit_id = id;
    })
  }

  view(id){
    this.viewData = true;
    this.openRightSidebar = true;
    this.showSideBarLoader = true;
    this.directiveRef.scrollToTop();
    //console.log(id);
    this.commonService.sendRequestToNode({method :'get',path:'flag_state_inspection/getById/'+id}).subscribe(result => {
      this.showSideBarLoader = false;  
      //console.log(result.data);
      let dateRecorded = new Date(result.data[0].DATE_RECORDED);
      result.data[0].DATE_RECORDED = dateRecorded.getFullYear()+'-'+('0' + (dateRecorded.getMonth()+1)).slice(-2)+'-'+('0' + (dateRecorded.getDate())).slice(-2); 
      if(result.status)
        {
          this.flagStateInspection_view = result.data;         
        }
        else{
          alert(result.message)
        }
    })
  }

  delete(id){ 
    if(id){
      swal({
        title: 'Are you sure?',
        text: "You won't be able to revert this!",
        type: 'warning',
        showCancelButton: true,
        confirmButtonClass: 'btn btn-success',
        cancelButtonClass: 'btn btn-danger',
        confirmButtonText: 'Yes, delete it!',
         buttonsStyling: false
      }).then((result) => {
        if (result.value) {
          this.commonService.sendRequestToNode({method :'delete',path:'flag_state_inspection/delete/'+id}).subscribe(
            data => {
              if(data.status){
                var dialogueTitle = "Deleted!";
                if(this.flagStateInspection.length == 1 && Math.ceil(this.totalItems / this.itemsPerPage) == this.currentPage){
                  if(this.currentPage>1){
                    this.currentPage--;
                  }
                }
                this.getData();
                swal({
                  title: dialogueTitle,
                  text: data.message,
                  type: 'success',
                  confirmButtonClass: "btn btn-success",
                  buttonsStyling: false
                })
              }         
          })
        }
      })
    }
  }

  resetForm(){
    this.formSubmittedAttempt = false;
    this.openRightSidebar = false;
    this.viewData = false;
    this.edit_id = '';
    this.FlagStateInspectionForm.patchValue({
      
      VESSEL_FK : null,
      DATE_RECORDED : null,
      TYPE_OF_DEFICIENCY_FK : null,
      EQUIPMENT_FK : null,
      VIQ_REF_NUMBER : null,
      DESCRIPTION_OF_DEFICIENCY : null,
      OBSERVER_CODE_FK : null,
      ACTION_TAKEN_OR_REQUIRED : null,
      TARGET_DATE : null,
      PO_REF_NO : null,
      STATUS_CODE_FK : null,
      DATE_COMPLETED : null,
      FORM_FLAG : null
    })
  }

  // part of grid
  declareGridVariable(){
    this.headerInformation = [
      {
        title : 'Vessel Name',// show title table header
        //nameIcon : true,// show icon of First letter
        name:'VESSEL_NAME',// name of column in data source
        width : '20%',// width of column in table
        isSortable : true,// sort by column false or true
        highlight:true, // name highlight
        isFilter:{ // filter 
          type : 'text',
          placeholder : 'Filter By Vessel Name'
        }
      },      
      {title : 'Date Recorded',name:'DATE_RECORDED',isDate:'yes',width : '15%'},
      {title : 'Target Date',name:'TARGET_DATE',isDate:'yes',width : '15%'},
      {title : 'Completed Date',name:'DATE_COMPLETED',isDate:'yes',width : '15%'},
      {title : 'OBS Type',name:'FORM_FLAG',width : '20%'},
      {title : 'Action',name:'action',width : '15%'}
    ];
    this.actionButtons = [
      {title:'View',class : "fas fa-eye"},
      {title:'Edit',class : "far fa-edit"},
      {title:'Delete',class : "far fa-trash-alt"}
    ]
  }

  //part of grid
  clickOnAction(actionObj){
    if(actionObj.actionName == 'View'){
      this.view(actionObj.object.ID)
    }
    else if(actionObj.actionName == 'Edit'){
      this.edit(actionObj.object.ID)
    }else if(actionObj.actionName == 'Delete'){
      this.delete(actionObj.object.ID)
    }
  }

  filter($event){
    let obj = $event;
    this.currentPage = obj.page;
    this.filterObj = obj.filter;
    this.sortFilter = obj.sort
    this.getData();
  }

  //part of grid
  funOpenRightSidebar(){
    this.openRightSidebar = true;
    this.el.nativeElement.focus();
    this.directiveRef.scrollToTop();
  }

}
 
