import { Component, AfterViewInit,OnInit, createPlatformFactory,ViewChild,ElementRef } from '@angular/core';
import { NgbPaginationConfig, NgbModal, NgbModalRef,NgbTabset, NgbActiveModal,ModalDismissReasons } from '@ng-bootstrap/ng-bootstrap';
import { CommonService } from '../common-service.service';
import {Router,ActivatedRoute} from "@angular/router";
import {FormGroup,FormBuilder,Validators,FormControl} from '@angular/forms';
import swal from 'sweetalert2';
import * as html2canvas from "html2canvas";
import { saveAs } from 'file-saver';

import * as jsPDF from 'jspdf';  
(window as any).html2canvas = html2canvas;

declare var $: any;
import { PerfectScrollbarConfigInterface } from 'ngx-perfect-scrollbar';
import { json } from 'd3';



@Component({
  templateUrl: './training-planning.component.html',
  styleUrls: ['./training-planning.component.scss']
})
export class TrainingPlanningComponent implements AfterViewInit,OnInit {
  @ViewChild('content') pdfContent: ElementRef;

  public config: PerfectScrollbarConfigInterface = {};
  public docPath = this.commonService.getImagePath()+'/office-audit';

  public trainingPlanForm:FormGroup; 
  public addPortForm:FormGroup; 
  
  public formSubmittedAttempt = false;
  
  public trainingPlanData = [];
  public PortDropdown =[];
  public openRightSidebar = false;
  public SelectedVesselName ="";
  //public filterObj:any = {};
  public filterObj:any = {year : new Date().getFullYear(),type : []};
  public sortFilter:any = {};
  modalRef: NgbModalRef;

  public viewData:any = {};
  public vessel_id = null;
  public officeAudit_view:any = {};
  public showSideBarLoader = false;
  public showLoader = false;
  public vesselDetail = [];
  public country_dropdown = [];
  public monthArr = ['01','02','03','04','05','06','07','08','09','10','11','12'];
  public sortNameOfMonth = ['Jan', 'Feb', 'Mar', 'Apr', 'May', 'June', 'July', 'Aug', 'Sept', 'Oct', 'Nov', 'Dec'];;

  public file_upload;
  public auditor = 'internal_auditor';
  //for grid 
  public headerInformation;
  public actionButtons;

  //for pagination
  itemsPerPage: number = this.commonService.DefaultItemsPerPage;
  totalItems: number;
  currentPage: number = 1;

  // new 
  user_dropdown = [];
  InspectionType = [];
  pdfLogo = location.origin+location.pathname+'assets/images';

  @ViewChild('autofocus') el:any;
  @ViewChild('fileInput') fi:ElementRef;

  constructor(private modalService: NgbModal,
    private commonService: CommonService,
    private router: Router,
    private formBuilder: FormBuilder,
    private route: ActivatedRoute){
  }

get f(){
  return this.trainingPlanForm.controls
}
  ngAfterViewInit(){
   
  }

  ngOnInit(){

    this.route.params.subscribe(params => {
      this.vessel_id = params['vessel_id'];
   });

   this.getDetailsByVesselId();
    this.getData();
    this.addForm();
    this.userDropDown();
    this.getPortDropdown();
    this.getInspectionType();
    this.countryDropDown();
  }
  countryDropDown() {
    this.commonService.sendRequestToNode({ method: 'get', path: 'country/dropdown' }).subscribe(result => {
      if (result.status) {
        this.country_dropdown = result.data;
      }
      else {
        this.country_dropdown = [];
        alert(result.message);
      }
    })
  }

  addForm(){
    
    this.trainingPlanForm = this.formBuilder.group({
      EDIT_ID : null, 
      VESSEL_FK: [this.vessel_id,[Validators.required]],
      USER_FK: [null,[Validators.required]],
      INSPECTION_TYPE_FK : [null,[Validators.required]],
      PLAN_DATE  :[null,[Validators.required]],
      PORT: [null, [Validators.required]]
    });   
    
    this.addPortForm = this.formBuilder.group({
      PORT_NAME: [null, Validators.required],
      PORT_CODE: [null, Validators.required],
      COUNTRY_MST_FK: [null,],
      LATITUDE: [null,],
      LONGITUDE: [null,]
    });
  }

  userDropDown(){
    this.commonService.sendRequestToNode({method :'get',path:'user-dropdown',queryParam:{'USER_TYPE_FILTER':'1'}}).subscribe(result => {
      if(result.status){
        this.user_dropdown = result.data;
      }
      else{
        this.user_dropdown = [];
        alert(result.message);
      }
    })
  }
  
  getInspectionType(){
    this.commonService.sendRequestToNode({method :'get',path:'inspection-type-dropdown',queryParam : {ACTIVITY_TRAINING_FLAG : 1}}).subscribe(result => {
      if(result.status){   
        this.InspectionType = result.data;
        this.getData();
      }else{
        this.InspectionType = [];
        alert(result.message);
      }
    })
  }
  
  onSubmit(){
    this.formSubmittedAttempt = true;
    
    if( this.trainingPlanForm.valid) {
      this.showSideBarLoader = true;
      if( this.trainingPlanForm.value.EDIT_ID ) {
        this.commonService.sendRequestToNode({method :'put',path:'training-plan/'+this.trainingPlanForm.value.EDIT_ID ,postData:this.trainingPlanForm.value }).subscribe(result => {
          if(result.status){   
            this.showSideBarLoader = false;
            this.formSubmittedAttempt = false;

            let dialogueTitle = "Updated!";
            swal({
              title: dialogueTitle,
              text: result.message,
              type: 'success',
              confirmButtonClass: "btn btn-success",
              buttonsStyling: false
            })
            this.getData();
            this.resetForm();
            this.addPortForm = this.formBuilder.group({
              PORT_NAME: [null, Validators.required],
              PORT_CODE: [null, Validators.required],
              COUNTRY_MST_FK: [null,],
              LATITUDE: [null,],
              LONGITUDE: [null,]
            });
          }else{
            alert(result.message);
          }
        })
      } else {
        this.commonService.sendRequestToNode({method :'post',path:'training-plan',postData:this.trainingPlanForm.value }).subscribe(result => {
          if(result.status){   
            this.showSideBarLoader = false;
            this.formSubmittedAttempt = false;

            let dialogueTitle = "Inserted!";
            swal({
              title: dialogueTitle,
              text: result.message,
              type: 'success',
              confirmButtonClass: "btn btn-success",
              buttonsStyling: false
            });
  
            this.getData();
            this.resetForm()
            this.addPortForm = this.formBuilder.group({
              PORT_NAME: [null, Validators.required],
              PORT_CODE: [null, Validators.required],
              COUNTRY_MST_FK: [null,],
              LATITUDE: [null,],
              LONGITUDE: [null,]
            });
          }else{
            alert(result.message);
          }
        })
      }
    }
  }
  
  open(content){
    this.modalRef = this.modalService.open(content,{size: 'lg'});
  }
  funOpenRightSidebar(){
    // this.el.focus();
    this.addForm();
    // console.log(this.viewData) 
     this.viewData = {};
    this.openRightSidebar = true; 
  }
  funCloseRightSidebar(){
    // this.el.focus();
    this.openRightSidebar = false; 
  }

  changeYear(i){
    this.filterObj.year = this.filterObj.year + (i)
    this.getData() 
  }

  getData()
  {
    
    this.trainingPlanData = [];
    let filterParams:any = {}
    this.filterObj.vessel_id = this.vessel_id;
    
    //search filter 
    filterParams = JSON.parse(JSON.stringify(this.filterObj));
    //search filter -end

    this.showLoader = true;
    let data = {};
    this.InspectionType.forEach(ele=>{
      data[ele.ID] = {
        planMonthWise : {},
        ActivityId : ele.ID, 
        Activity : ele.TITLE
      }
    })
   
    this.commonService.sendRequestToNode({method :'get',path:'training-plan',queryParam:filterParams}).subscribe(
      result => {
      this.showLoader = false;              
        if(result.status)
        {
          // console.log(result.data);return false;
          if(result.data.length > 0){
            this.totalItems = result.data[0].total_records;
            result.data.forEach(element => {

            var target_date_format = this.commonService.formatDate(element.PLAN_DATE,'d-m-y') 
            var completion_month;
            
            
            if(data[element.INSPECTION_TYPE_FK]){
                data[element.INSPECTION_TYPE_FK].planMonthWise[element.month] = {
                  'color' : 'bg-success',
                  'pdfcolor' : '#45b649',
                  'TARGET_MONTH' : element.month,
                  'NAME' : element.FULL_NAME,
                  'PLAN_DATE' : element.PLAN_DATE,
                  'target_date' : target_date_format,
                  'planningId' : element.ID,
                  ...element
                }
              }
            });

          }
          Object.keys(data).forEach(key=>{
            this.trainingPlanData.push(data[key]);  
          })
        }
        else{
          this.trainingPlanData = [];
          alert(result.message);
        }
    })
  }

  // generatePdf() {
  //   this.filterObj.USER_TYPE = this.filterObj.user_type;
  //   this.commonService.sendRequestToNode({ method: 'post', path: 'training-plan/generateReportPdf', postData: { trainingPlanData: this.trainingPlanData ,monthArr: this.monthArr} },{ responseType: 'blob' }).subscribe( result => {
  //     saveAs(result, `TrainingPlanningReport.pdf`)
  //   })
  // }

  generatePdf(){
    var data = document.getElementById('htmlToString').innerHTML;
    // console.log(JSON.stringify(data));
    // console.log(data);
    var htmlData = {'data':data};
    this.commonService.sendRequestToNode({ method: 'post', path: 'training-plan/generateReportPdf',postData:htmlData }).subscribe(result => {
      if(result.status){
          window.location.href = this.commonService.getNodeApi()+'/training-plan/exportPDF';
      }
    })
}

  delete(id){
    if(id){
      swal({
        title: 'Are you sure?',
        text: "You won't be able to revert this!",
        type: 'warning',
        showCancelButton: true,
        confirmButtonClass: 'btn btn-success',
        cancelButtonClass: 'btn btn-danger',
        confirmButtonText: 'Yes, delete it!',
        buttonsStyling: false
      }).then((result) => {
        if (result.value) {
          this.commonService.sendRequestToNode({method :'delete',path:'training-plan/'+id}).subscribe(
          data => {
          if(data.status){
            this.viewData = {}; 
            var dialogueTitle = "Deleted!"
           
            this.getData();
            swal({
                title: dialogueTitle,
                text: data.message,
                type: 'success',
                confirmButtonClass: "btn btn-success",
                buttonsStyling: false
              })
          }         
          
      })
        }
      })      
    }
  }

  edit( obj,month ) {
  this.funOpenRightSidebar();

    this.trainingPlanForm.patchValue({
      EDIT_ID : obj.planMonthWise[month].planningId,
      USER_FK: obj.planMonthWise[month].USER_FK,
      INSPECTION_TYPE_FK : obj.planMonthWise[month].INSPECTION_TYPE_FK,
      PORT : obj.planMonthWise[month].PORT,
      PLAN_DATE  : this.commonService.formatDate(obj.planMonthWise[month].PLAN_DATE)
    });

    
  }
  view(obj,month) {
    this.funOpenRightSidebar();

    this.viewData = {
      ID : obj.planMonthWise[month].planningId,
      VESSEL_NAME: '',
      FULL_NAME: obj.planMonthWise[month].NAME,
      Activity_Name : obj.Activity,
      PLAN_DATE  : obj.planMonthWise[month].target_date,
      PORT_NAME : obj.planMonthWise[month].PORT_NAME,

    }

  }
  
  resetForm(){
    this.funCloseRightSidebar();
    this.viewData = {}; //obj
    this.trainingPlanForm.patchValue({
      EDIT_ID : null,
      USER_FK: null,
      INSPECTION_TYPE_FK : null,
      PLAN_DATE  :null,
      PORT: null
    })

    this.addPortForm.patchValue({
      PORT_NAME: [null],
      PORT_CODE: [null],
      COUNTRY_MST_FK: [null,],
      LATITUDE: [null,],
      LONGITUDE: [null,]
    });
  }
  makePdf() { 
    let doc = new jsPDF({
      orientation: 'landscape'
    });
    doc.addHTML(document.getElementById('pdfContent'),function() {
      doc.save('pdfTable.pdf');
    });
    

    // var doc = new jsPDF({
    //   orientation: 'landscape',
    //   unit: 'in',
    //   format: [4, 2]
    // })
    
    // doc.text('Hello world!', 1, 1)
    // doc.save('two-by-four.pdf')
  }
  
  getPortDropdown(){
    this.commonService.sendRequestToNode({method :'get',path:'training-vessel-report/port-dropdown'}).subscribe(result => {
      if(result.status){   
        this.PortDropdown = result.data;

      } else {
        this.PortDropdown = [];
        alert(result.message);
      }
    })
  }

  getDetailsByVesselId() {

    this.commonService.sendRequestToNode({method :'get',path:'vessel_master/getById/' + this.vessel_id}).subscribe(result => {
      this.showSideBarLoader = false;    
      if(result.status)
      {
        this.vesselDetail = result.data;
       
        this.SelectedVesselName =  result.data.VESSEL_NAME;
      }
      else{
        alert(result.message)
      }
    })
  }
  
  openModel(content) {
    this.modalRef = this.modalService.open(content, { size: 'lg' });
  }

  addPort() {
    this.formSubmittedAttempt = true;
    if (this.addPortForm.valid) {
      this.showSideBarLoader = true;
      this.commonService.sendRequestToNode({ method: 'post', path: 'training-vessel-report/port', postData: this.addPortForm.value }).subscribe(
        data => {
          var dialogueTitle = "Inserted!";
          this.showSideBarLoader = false;
          if (data.status) {
            swal({
              title: dialogueTitle,
              text: data.message,
              type: 'success',
              confirmButtonClass: "btn btn-success",
              buttonsStyling: false
            })
            this.addPortForm = this.formBuilder.group({
              PORT_NAME: [null, Validators.required],
              PORT_CODE: [null, Validators.required],
              COUNTRY_MST_FK: [null,],
              LATITUDE: [null,],
              LONGITUDE: [null,]
            });
            this.modalRef.close();
            this.getPortDropdown();
            // this.resetForm();
          } else {
            alert(data.message);
          }
        })
    }
  }
}

