import { Component, AfterViewInit,OnInit, createPlatformFactory,ElementRef,ViewChild } from '@angular/core';
import { NgbPaginationConfig, NgbModal, NgbModalRef, ModalDismissReasons } from '@ng-bootstrap/ng-bootstrap';
import { CommonService } from '../common-service.service';
import {Router,ActivatedRoute} from "@angular/router";
import {FormGroup,FormBuilder,Validators,FormControl} from '@angular/forms';
import swal from 'sweetalert2';

declare var $: any;
import { PerfectScrollbarConfigInterface } from 'ngx-perfect-scrollbar';

@Component({
  templateUrl: './training-type.component.html',
  styleUrls: ['./training-type.component.scss']
})
export class TrainingTypeComponent implements AfterViewInit,OnInit {

  public config: PerfectScrollbarConfigInterface = {};
  
  public trainingTypeData = [];
  public trainingTypeForm:FormGroup;  
  public edit_id;
  public formSubmittedAttempt = false;
  public openRightSidebar = false;
  public filterObj:any = {};
  public sortFilter:any = {};
  public showSideBarLoader = false;
  public showLoader = false;
  modalReference: NgbModalRef;
  public trainingtype_dropdown = [];
  public trainingtype_dropdown_name = [];
  //for grid 
  public headerInformation;
  public actionButtons;

  //for pagination
  itemsPerPage: number = this.commonService.DefaultItemsPerPage;
  totalItems: number;
  currentPage: number = 1;

  @ViewChild('autofocus') el:ElementRef;
 
  constructor(private modalService: NgbModal,
    private commonService: CommonService,
    private router: Router,
    private formBuilder: FormBuilder,
    private route: ActivatedRoute){
      this.declareGridVariable()
  }


  trainingTypeDropDown(id=0){
    this.commonService.sendRequestToNode({method :'get',path:'trainingtype-dropDown'}).subscribe(result => {
      if(result.status){
        this.trainingtype_dropdown = result.data;
        this.trainingtype_dropdown.forEach(ele=>{
          this.trainingtype_dropdown_name[ele.ID] = ele.TRAINING_TYPE;
        })
        // if(id){
        //   this.trainingForm.patchValue({
        //     TRAINING_TYPE_FK : id 
        //   })
        // }
      }
      else{
        this.trainingtype_dropdown = [];
        alert(result.message);
      }
    })
  }
  // part of grid
  declareGridVariable(){
    let flagValue =['ship','shore'];
    let flagOption =['Ship','Shore'];
    this.headerInformation = [
      {
        title : 'Training Type',// show title table header
        nameIcon : true,// show icon of First letter
        name:'TRAINING_TYPE',// name of column in data source
        width : '20%',// width of column in table
        isSortable : true,// sort by column false or true
        isFilter:{ // filter 
          type : 'text',
          placeholder : 'Filter By Training Type'
        }
      },
      {
        title : 'Flag',
        name:'FLAG',
        width : '20%',
        isSortable : true,
        highlight:true,
        isFilter:{ // filter 
          type : 'select',
          placeholder : 'Filter By Flag',
          options_display:flagValue,
          options_value:flagOption  
        },
        
        
      },
      {title : '',name:'',width : '50%'},
      {title : 'Action',name:'action',width : '10%'}
    ];
    this.actionButtons = [
      {title:'Edit',class : "far fa-edit"},
      {title:'Delete',class : "far fa-trash-alt"}
    ]
  }

  ngAfterViewInit(){
   
  }

  ngOnInit(){
    this.getData();
    this.addForm();
  }
  
  getData()
  {
    let filterParams:any = {}
    
    //search filter 
    filterParams = JSON.parse(JSON.stringify(this.filterObj));
    //search filter -end

    // pagination
    filterParams.currentPage = this.currentPage-1;
    filterParams.itemsPerPage = this.itemsPerPage;
    // pagination - end

    //sorting 
    let sortKey = Object.keys(this.sortFilter);
    if(sortKey.length && this.sortFilter[sortKey[0]]){
      filterParams.sortBy = sortKey[0];
      filterParams.sortStatus = this.sortFilter[sortKey[0]];
    }
    //sorting - end
    this.showLoader = true;
    this.commonService.sendRequestToNode({method :'get',path:'training-type',queryParam:filterParams}).subscribe(result => {
      this.showLoader = false;  
      if(result.status)
        {
          if(result.data.length > 0){
            this.totalItems = result.data[0].total_records;
            this.trainingTypeData = result.data;
          }else{
            this.trainingTypeData = [];
          }
        }
        else{
          this.trainingTypeData = [];
          alert(result.message);
        }
    })
  }

  addForm(){
    this.trainingTypeForm = this.formBuilder.group({
      TRAINING_TYPE: ['',[Validators.required]],
      FLAG: ['both'],
    });   
  }

  resetForm(){
    this.formSubmittedAttempt = false;
    this.openRightSidebar = false;
    this.edit_id = '';
    this.trainingTypeForm.patchValue({
      TRAINING_TYPE : '',
      FLAG: 'both', 
    })
  }

  edit(id){
    this.openRightSidebar = true;
    this.el.nativeElement.focus();
    this.commonService.sendRequestToNode({method :'get',path:'training-type/'+id}).subscribe(
      data => {         
        this.trainingTypeForm.patchValue({
          TRAINING_TYPE : data.data.TRAINING_TYPE ,
          FLAG : data.data.FLAG
        })
        this.edit_id = id;
    })
  }

  delete(id){
    if(id){
      swal({
        title: 'Are you sure?',
        text: "You won't be able to revert this!",
        type: 'warning',
        showCancelButton: true,
        confirmButtonClass: 'btn btn-success',
        cancelButtonClass: 'btn btn-danger',
        confirmButtonText: 'Yes, delete it!',
         buttonsStyling: false
      }).then((result) => {
        if (result.value) {
          this.commonService.sendRequestToNode({method :'delete',path:'training-type/'+id}).subscribe(
          data => {
          if(data.status){
            var dialogueTitle = "Deleted!"
            if(this.trainingTypeData.length == 1 && Math.ceil(this.totalItems / this.itemsPerPage) == this.currentPage){
              if(this.currentPage>1){
                this.currentPage--;
              }
            }
            this.getData();
            swal({
                title: dialogueTitle,
                text: data.message,
                type: 'success',
                confirmButtonClass: "btn btn-success",
                buttonsStyling: false
              })
          }         
          
      })
         }
      })      
    }
  }

  onSubmit(){ 
    this.formSubmittedAttempt = true;
    if(this.trainingTypeForm.valid){
    this.showSideBarLoader = true;
    if(this.edit_id){    
      this.commonService.sendRequestToNode({method :'put',path:'training-type/'+this.edit_id,postData:this.trainingTypeForm.value}).subscribe(
        data =>{
          var dialogueTitle = "Updated!";
          this.showSideBarLoader = false;
          if(data.status){
            swal({
                title: dialogueTitle,
                text: data.message,
                type: 'success',
                confirmButtonClass: "btn btn-success",
                buttonsStyling: false
              })
            this.getData();
            this.resetForm(); //after edit form is reset
          }
          else{
            alert(data.message);
          }
      })
    }else{
      this.commonService.sendRequestToNode({method :'post',path:'training-type',postData:this.trainingTypeForm.value}).subscribe(
        data =>{
          var dialogueTitle = "Inserted!";
          this.showSideBarLoader = false;
          if(data.status){
            swal({
                title: dialogueTitle,
                text: data.message,
                type: 'success',
                confirmButtonClass: "btn btn-success",
                buttonsStyling: false
              })
            this.getData();
            this.resetForm(); //after edit form is reset

          }
          else{
            alert(data.message);
          }
      })
    }
    }
      
  } 

    //part of grid
    clickOnAction(actionObj){
      if(actionObj.actionName == 'Edit'){
        this.edit(actionObj.object.ID)
      }else if(actionObj.actionName == 'Delete'){
        this.delete(actionObj.object.ID)
      }
    }
  
    //part of grid
    //when change filter ,change page no . etc, 
    filter($event){
      let obj = $event;
      this.currentPage = obj.page;
      this.filterObj = obj.filter;
      this.sortFilter = obj.sort
      this.getData();
    }
  
    //part of grid
    funOpenRightSidebar(){
      this.el.nativeElement.focus();
      this.openRightSidebar = true; 
    }
  

}

