import { Component, AfterViewInit,OnInit, createPlatformFactory } from '@angular/core';
import { NgbPaginationConfig, NgbModal, NgbModalRef, ModalDismissReasons } from '@ng-bootstrap/ng-bootstrap';
import { CommonService } from '../common-service.service';
import {Router,ActivatedRoute} from "@angular/router";
import {FormGroup,FormBuilder,Validators,FormControl} from '@angular/forms';
import swal from 'sweetalert2';

declare var $: any;
import { PerfectScrollbarConfigInterface } from 'ngx-perfect-scrollbar';

@Component({
  templateUrl: './users.component.html',
  styleUrls: ['./users.component.scss']
})
export class UsersComponent implements AfterViewInit,OnInit {  
 
  public docPath = this.commonService.getImagePath()+'/user';
  public config: PerfectScrollbarConfigInterface = {};
  public showLoader = false;
  options = {
    theme: 'light', // two possible values: light, dark
    dir: 'ltr', // two possible values: ltr, rtl
    layout: 'vertical', // fixed value. shouldn't be changed.
    sidebartype: 'mini-sidebar', // four possible values: full, iconbar, overlay, mini-sidebar 
    sidebarpos: 'fixed', // two possible values: fixed, absolute
    headerpos: 'fixed', // two possible values: fixed, absolute
    boxed: 'full', // two possible values: full, boxed
    navbarbg: 'skin6', // six possible values: skin(1/2/3/4/5/6)
    sidebarbg: 'skin5', // six possible values: skin(1/2/3/4/5/6)
    logobg: 'skin5' // six possible values: skin(1/2/3/4/5/6)
  };
  public userData_local = null;
  
  public roleList = [];
  public userData = [];
  public userForm:FormGroup;  
  public edit_id;
  public formSubmittedAttempt = false;
  public openRightSidebar = false;
  public filterObj:any = {};
  public sortFilter:any = {};
  // public isViewData = false;
  public viewData:any = false;
  //for grid 
  public headerInformation;
  public actionButtons;
  public userType_dropdown = [];
  public OLD_ACTIVE_FLAG = null

  //for pagination
  itemsPerPage: number = this.commonService.DefaultItemsPerPage;
  totalItems: number;
  currentPage: number = 1;
  
  constructor(private modalService: NgbModal,
    private commonService: CommonService,
    private router: Router,
    private formBuilder: FormBuilder,
    private route: ActivatedRoute){
      this.userData_local = JSON.parse(localStorage.getItem(this.commonService.prefix+'userData'));
      this.declareGridVariable()
  }

  // part of grid
  declareGridVariable(){
    this.headerInformation = [
      {
        title : 'Name',// show title table header
        nameIcon : true,// show icon of First letter
        name:'FULL_NAME',// name of column in data source
        isSortable : true,// sort by column false or true
        isFilter:{ // filter 
          type : 'text',
          placeholder : 'Filter By Name'
        }
      },
      {
        title : 'Email',// show title table header
        nameIcon : true,// show icon of First letter
        name:'EMAIL',// name of column in data source
        isSortable : true,// sort by column false or true
        isFilter:{ // filter 
          type : 'text',
          placeholder : 'Filter By Email'
        }
      },
      {
        title : 'Company',// show title table header
        nameIcon : true,// show icon of First letter
        name:'COMPANY',// name of column in data source
        isSortable : true,// sort by column false or true
        isFilter:{ // filter 
          type : 'text',
          placeholder : 'Filter By Company'
        }
      },
      // {
      //   title : 'Role',// show title table header
      //   nameIcon : true,// show icon of First letter
      //   name:'ROLE_NAME',// name of column in data source
      //   isSortable : true,// sort by column false or true
      //   isFilter:{ // filter 
      //     type : 'text',
      //     placeholder : 'Filter By Role'
      //   }
      // },
      {
        title : 'Mobile',// show title table header
        nameIcon : true,// show icon of First letter
        name:'MOBILE',// name of column in data source
        isSortable : true,// sort by column false or true
        isFilter:{ // filter 
          type : 'text',
          placeholder : 'Filter By Mobile'
        }
      },
      {
        title : 'Status',// show title table header
        nameIcon : true,// show icon of First letter
        name:'ACTIVE_FLAG',// name of column in data source
        display_value: {1:'Active',0:'Inactive'},
        isFilter:{ // filter 
          type : 'select',
          placeholder : 'Filter By Status',
          options_value : [1,0],
          options_display : ['Active','Inactive']
        }
      },
      {title : 'Action',name:'action',width : '10%'}
    ];

    if(this.userData_local.role_id != '0'){
      this.actionButtons = [
        {title:'View',class : "fas fa-eye"}
      ]
    }
    else{
      this.actionButtons = [
        {title:'View',class : "fas fa-eye"},
        {title:'Edit',class : "far fa-edit"},
      //  {title:'Delete',class : "far fa-trash-alt"}

      ]
    }

   
  }

  ngAfterViewInit(){
   
  }

  ngOnInit(){
    this.getuserData();
    this.addForm();
    this.loadRoleList();
    this.userType();
  }

  userType(){
    this.userType_dropdown = [
      {ID:'marine_superintendent',NAME:'Marine Superintendent'},
      {ID:'technical_superintendent',NAME:'Technical Superintendent'},
      {ID:'other',NAME:'Other'},
    ];

  }
  
  getuserData(){

    let filterParams:any = {}
    
    //search filter 
    filterParams = JSON.parse(JSON.stringify(this.filterObj));
    //search filter -end

    // pagination
    filterParams.currentPage = this.currentPage-1;
    filterParams.itemsPerPage = this.itemsPerPage;
    // pagination - end

    //sorting 
    let sortKey = Object.keys(this.sortFilter);
    if(sortKey.length && this.sortFilter[sortKey[0]]){
      filterParams.sortBy = sortKey[0];
      filterParams.sortStatus = this.sortFilter[sortKey[0]];
    }
    //sorting - end
    this.showLoader = true;
    this.commonService.sendRequestToNode({method :'get',path:'user',queryParam:filterParams}).subscribe(result => {
      this.showLoader = false;  
      if(result.status)
        {
          
          if(result.data.length > 0){
            this.totalItems = result.data[0].total_records;
            this.userData = result.data;
          }else{
            this.userData = [];
          }
        }
        else{
          this.userData = [];
          alert(result.message);
        }
    })
  }

  loadRoleList(){
    this.commonService.sendRequestToNode({method :'get',path:'roledropdown'}).subscribe(result => {
        if(result.status)
        {
          if(result.data.length > 0){
            this.roleList = result.data;
          }else{
            this.roleList = [];
          }
        }
        else{
          this.roleList = [];
        }
    })
  }

  addForm(){
    this.userForm = this.formBuilder.group({
      COMPANY: ['',[]],
      ROLE_ID: ['',[]],
      FIRST_NAME: ['',[]],
      MIDDLE_NAME: ['',[]],
      LAST_NAME: ['',[]],
      EMPLOYEE_ID: ['',[]],
      DESIGNATION: ['',[]],
      EMAIL: ['',[Validators.required]],
      PHONE: ['',[]],
      MOBILE: ['',[]],
      USER_TYPE : [null,[]],
      ON_BOARD_TRAINING_FLAG : [0],
      ACTIVE_FLAG: [0],
    });   
  }

  resetForm(){
    this.formSubmittedAttempt = false;
    this.openRightSidebar = false;
    this.viewData = false;
    this.edit_id = '';
    this.userForm.patchValue({
      COMPANY:'',
      ROLE_ID:'',
      FIRST_NAME:'',
      MIDDLE_NAME:'',
      LAST_NAME:'',
      EMPLOYEE_ID:'',
      DESIGNATION:'',
      EMAIL:'',
      PHONE:'',
      MOBILE:'',
      ON_BOARD_TRAINING_FLAG : 0,
      USER_TYPE : null,
    })
  }


  edit(id){
    this.openRightSidebar = true;
    this.commonService.sendRequestToNode({method :'get',path:'user/'+id}).subscribe(
      data => {      
        
       

        this.userForm.patchValue(data.data)
        this.edit_id = id;
        this.OLD_ACTIVE_FLAG = data.data.ACTIVE_FLAG;
    })
  }

  view(id){
    this.openRightSidebar = true;
    //console.log(id);
    this.commonService.sendRequestToNode({method :'get',path:'user/'+id}).subscribe(result => {
        if(result.status)
        {
          this.viewData = result.data;
        }
        else{
          alert(result.message)
        }
    })
  }


  delete(id){
    if(id){
      swal({
        title: 'Are you sure?',
        text: "You won't be able to revert this!",
        type: 'warning',
        showCancelButton: true,
        confirmButtonClass: 'btn btn-success',
        cancelButtonClass: 'btn btn-danger',
        confirmButtonText: 'Yes, delete it!',
         buttonsStyling: false
      }).then((result) => {
        if (result.value) {
          this.commonService.sendRequestToNode({method :'delete',path:'user/'+id}).subscribe(
            data => {
              if(data.status){
                var dialogueTitle = "Deleted!";
                if(this.userData.length == 1 && Math.ceil(this.totalItems / this.itemsPerPage) == this.currentPage){
                  if(this.currentPage>1){
                    this.currentPage--;
                  }
                }
                this.getuserData();
                swal({
                  title: dialogueTitle,
                  text: data.message,
                  type: 'success',
                  confirmButtonClass: "btn btn-success",
                  buttonsStyling: false
                })
              }         
          })
        }
      })
    }
  }

  onSubmit(){ 
    this.formSubmittedAttempt = true;
    if(this.userForm.valid){
      if(this.edit_id){

        let passPostData = this.userForm.value;
        passPostData.OLD_ACTIVE_FLAG = this.OLD_ACTIVE_FLAG;

        this.commonService.sendRequestToNode({method :'put',path:'user/'+this.edit_id,postData:this.userForm.value}).subscribe(
          data =>{
            var dialogueTitle = "Updated!"
            if(data.status){
                swal({
                  title: dialogueTitle,
                  text: data.message,
                  type: 'success',
                  confirmButtonClass: "btn btn-success",
                  buttonsStyling: false
                })
                this.getuserData();
                this.openRightSidebar = false;
                this.resetForm(); //after edit form is reset
              }
              else{
                alert(data.message);
              }
        })
      }else{
        this.commonService.sendRequestToNode({method :'post',path:'user',postData:this.userForm.value}).subscribe(
          data =>{
            var dialogueTitle = "Inserted!"
            if(data.status){
              swal({
                  title: dialogueTitle,
                  text: data.message,
                  type: 'success',
                  confirmButtonClass: "btn btn-success",
                  buttonsStyling: false
                })
              this.getuserData();
              this.openRightSidebar = false;
              this.resetForm(); //after edit form is reset
            }else{
              alert(data.message);
            }
        })
      }
    }  
  }


  //part of grid
  clickOnAction(actionObj){
    if(actionObj.actionName == 'View'){
      this.view(actionObj.object.ID)
    }
    else if(actionObj.actionName == 'Edit'){
      this.edit(actionObj.object.ID)
    }else if(actionObj.actionName == 'Delete'){
      this.delete(actionObj.object.ID)
    }
  }
  
  //part of grid
  //when change filter ,change page no . etc, 
  filter($event){
    let obj = $event;
    this.currentPage = obj.page;
    this.filterObj = obj.filter;
    this.sortFilter = obj.sort
    this.getuserData();
  }

  //part of grid
  funOpenRightSidebar(){
    this.openRightSidebar = true; 
  }

}

