import { Component, AfterViewInit, OnInit, createPlatformFactory, ElementRef, ViewChild } from '@angular/core';
import { NgbPaginationConfig, NgbModal, NgbModalRef, ModalDismissReasons } from '@ng-bootstrap/ng-bootstrap';
import { CommonService } from '../common-service.service';
import { Router, ActivatedRoute } from "@angular/router";
import { FormGroup, FormBuilder, Validators, FormControl } from '@angular/forms';
import swal from 'sweetalert2';
//import { parse } from 'path';
import { saveAs } from 'file-saver';

import * as pluginAnnotations from 'chartjs-plugin-annotation';
import html2canvas from 'html2canvas';


declare var $: any;
import { PerfectScrollbarConfigInterface } from 'ngx-perfect-scrollbar';
import { forEach } from '@angular/router/src/utils/collection';

@Component({
  // templateUrl: './departments.component.html',
  // styleUrls: ['./departments.component.css']
  // selector: 'app-vessal-pc-software-report',
  templateUrl: './vessal-pc-software-report.component.html',
  styleUrls: ['./vessal-pc-software-report.component.css']
})
export class VessalPcSoftwareReportComponent implements AfterViewInit, OnInit {
  public config: PerfectScrollbarConfigInterface = {};

  options = {
    theme: 'light', // two possible values: light, dark
    dir: 'ltr', // two possible values: ltr, rtl
    layout: 'vertical', // fixed value. shouldn't be changed.
    sidebartype: 'mini-sidebar', // four possible values: full, iconbar, overlay, mini-sidebar
    sidebarpos: 'fixed', // two possible values: fixed, absolute
    headerpos: 'fixed', // two possible values: fixed, absolute
    boxed: 'full', // two possible values: full, boxed
    navbarbg: 'skin6', // six possible values: skin(1/2/3/4/5/6)
    sidebarbg: 'skin5', // six possible values: skin(1/2/3/4/5/6)
    logobg: 'skin5' // six possible values: skin(1/2/3/4/5/6)
  };

  public modalRef: NgbModalRef;
  public softwareForm: FormGroup;
  public VesselSoftwareReportForm: FormGroup;
  public vesselForm: FormGroup;
  public fileObj; //use for importXls Data
  public mainLoader = false;

  public vessel_dropdown_export = [];
  public vessel_dropdown_name = [];
  public softwareFormSubmittedAttempt = false;
  public vesselOwner_data = [];
  public softwareVersionDropdown = [];
  public officeLocationData = [];
  public vesselOwner_view;
  public selectVessel = false;
  public edit_id;
  public formSubmittedAttempt = false;
  public openRightSidebar = false;
  public showSideBarLoader = false;
  public showLoader = false;
  public viewData = false;
  public filterObj: any = {};
  public sortFilter: any = {};
  public VesselData = [];
  public softwareDropdown = [];
  public PcDropdown = [];
  public selectedLocation = '';
  public SoftwareVersion = '';
  public enableExportFileBtn = true;
  public enableImportFileBtn = true;
  public fileExportPlaceholder = 'Import File'
  public fileImportPlaceholder = 'Export File'


  //for grid
  public headerInformation;
  public actionButtons;
  public PC_VALUE_DATA = [];
  public PC_ID_Data = [];
  public OFFICE_VALUE_DATA = [];
  public OFFICE_ID_DATA = [];
  public Software_id_data = [];
  public Software_value_data = [];
  public Current_Version_value = []
  public Current_Version_id = []
  public Latest_Version_value = []
  public Latest_Version_id = []
  public vessel_office_id = [];
  public vessel_office_value = []
  public colorFilterdata = '';

  //for pagination
  itemsPerPage: number = this.commonService.DefaultItemsPerPage;
  totalItems: number;
  currentPage: number = 1;

  @ViewChild('content') content: ElementRef;
  @ViewChild('autofocus') el: ElementRef;
  @ViewChild('fileInput') fi: ElementRef;

  constructor(private modalService: NgbModal,
    private commonService: CommonService,
    private router: Router,
    private formBuilder: FormBuilder,
    private route: ActivatedRoute) {
    this.getFilterDetails()
    this.declareGridVariable()
  }

  ngAfterViewInit() {
  }

  ngOnInit() {
    this.getData();
    this.addForm();
    this.getVesselDropdown();
    this.getPCDropdown();
    this.officeDropdown();
    this.getSoftwareDropdown();
    this.vesselDropDown();
  }

  addForm() {
    this.vesselForm = this.formBuilder.group({
      Vessel_ID: [null, [Validators.required]],
    });

    this.VesselSoftwareReportForm = this.formBuilder.group({
      IS_VESSEL: false,
      VESSEL_FK: [null],
      PC_ID: [null, Validators.required],
      VESSEL_LOCATION: null,
      SOFTWARE_ID: [null, Validators.required],
      CURRENT_VESRION: [null],
      MONTH: [null, Validators.required],
      YEAR: [null, Validators.required]
    });
    this.softwareForm = this.formBuilder.group({
      SOFTWARE_TITLE: [''],
    });
  }

  vesselTypeAddForm() {
    this.VesselSoftwareReportForm = this.formBuilder.group({
      IS_VESSEL: true,
      VESSEL_FK: [null, Validators.required],
      PC_ID: [null, Validators.required],
      VESSEL_LOCATION: null,
      SOFTWARE_ID: [null, Validators.required],
      CURRENT_VESRION: [null],
      MONTH: [null, Validators.required],
      YEAR: [null, Validators.required]
    });
  }

  edit(id) {
    this.openRightSidebar = true;
    this.el.nativeElement.focus();
    this.commonService.sendRequestToNode({ method: 'get', path: 'vessal-pc-software-report/getById/' + id }).subscribe(
      data => {
        this.getPCDropdown((data.data.IS_VESSEL == 1) ? true : false);
        console.log(data.data);

        var date = this.commonService.formatDate(data.data.REPORT_DATE);
        var dateArray = date.split('-');
        // console.log(dateArray[0]);
        // console.log(dateArray[1]);

        this.selectVessel = (data.data.VESSEL_LOCATION || data.data.IS_VESSEL == 1) ? true : false;
        this.VesselSoftwareReportForm.patchValue({
          IS_VESSEL: data.data.IS_VESSEL,
          VESSEL_LOCATION: data.data.VESSEL_LOCATION,
          VESSEL_FK: data.data.VESSEL_FK,
          PC_ID: data.data.PC_ID,
          SOFTWARE_ID: data.data.SOFTWARE_ID,
          CURRENT_VESRION: data.data.CURRENT_VESRION,
          MONTH: dateArray[1],
          YEAR: dateArray[0],
        });

        this.getSoftwareLatestVesrionDetail();
        this.getPcDetailsById();
        this.edit_id = id;
      })
  }

  onSubmit() {
    //console.log(this.edit_id);
    this.formSubmittedAttempt = true;




    if (this.VesselSoftwareReportForm.valid) {

      var insertObj = {
        CURRENT_VESRION: this.VesselSoftwareReportForm.value.CURRENT_VESRION,
        IS_VESSEL: this.VesselSoftwareReportForm.value.IS_VESSEL,
        PC_ID: this.VesselSoftwareReportForm.value.PC_ID,
        SOFTWARE_ID: this.VesselSoftwareReportForm.value.SOFTWARE_ID,
        VESSEL_FK: this.VesselSoftwareReportForm.value.VESSEL_FK,
        VESSEL_LOCATION: this.VesselSoftwareReportForm.value.VESSEL_LOCATION,
        REPORT_DATE: this.VesselSoftwareReportForm.value.YEAR + '-' + this.VesselSoftwareReportForm.value.MONTH + '-' + '01 00:00:00',
      }

      console.log(insertObj);

      this.showSideBarLoader = true;
      if (this.edit_id) {
        this.commonService.sendRequestToNode({ method: 'put', path: 'vessal-pc-software-report/edit/' + this.edit_id, postData: insertObj }).subscribe(
          data => {
            var dialogueTitle = "Updated!";
            this.showSideBarLoader = false;
            if (data.status) {
              swal({
                title: dialogueTitle,
                text: data.message,
                type: 'success',
                confirmButtonClass: "btn btn-success",
                buttonsStyling: false
              })
              this.getData();
              this.openRightSidebar = false;
              this.resetForm();
            } else {
              alert(data.message);
            }
          })
      } else {

        this.commonService.sendRequestToNode({ method: 'post', path: 'vessal-pc-software-report/add', postData: insertObj }).subscribe(
          data => {
            var dialogueTitle = "Inserted!";
            this.showSideBarLoader = false;
            if (data.status) {
              swal({
                title: dialogueTitle,
                text: data.message,
                type: 'success',
                confirmButtonClass: "btn btn-success",
                buttonsStyling: false
              })
              this.getData();
              this.openRightSidebar = false;
              this.resetForm();

            } else {
              alert(data.message);
            }
          })
      }
    }
  }

  colorFilter(color) {
    this.colorFilterdata = color;
    this.getData();
  }

  getData() {

    //console.log(this.colorFilterdata);

    let filterParams: any = {}

    this.filterObj = {
      ...this.filterObj,
      color: this.colorFilterdata
    }

    //search filter
    filterParams = JSON.parse(JSON.stringify(this.filterObj));
    //search filter -end

    // pagination
    filterParams.currentPage = this.currentPage - 1;
    filterParams.itemsPerPage = this.itemsPerPage;
    // pagination - end

    //sorting
    let sortKey = Object.keys(this.sortFilter);
    if (sortKey.length && this.sortFilter[sortKey[0]]) {
      filterParams.sortBy = sortKey[0];
      filterParams.sortStatus = this.sortFilter[sortKey[0]];
    }
    //sorting - end

    this.showLoader = true;
    console.log(filterParams)
    this.commonService.sendRequestToNode({ method: 'get', path: 'vessal-pc-software-report/data_list', queryParam: filterParams }).subscribe(result => {
      this.showLoader = false;
      if (result.status) {
        if (result.data.length > 0) {
          this.totalItems = result.data[0].total_records;
          this.vesselOwner_data = result.data;
          console.log(this.vesselOwner_data);
          for (let ele of this.vesselOwner_data) {
            // console.log(ele.CURRENT_VESRION);
            // console.log(ele.LATEST_VERSION_ID);

            console.log(ele.REPORT_DATE)

            // if (ele.LATEST_VERSION_ID == null || ele.CURRENT_VESRION == null) {
            //   ele.COLOR = '#ccefc8';
            // }
            // if (ele.LATEST_VERSION_ID >= ele.CURRENT_VESRION) {
            //   ele.COLOR = '#f7c3c3';
            // }
            // if (ele.LATEST_VERSION_ID == ele.CURRENT_VESRION) {
            //   ele.COLOR = '#ccefc8';
            // }


            if (this.Current_Version_id.length > 0) {
              var found = this.Current_Version_id.filter(function (data) {
                return (data === ele.SELECTED_CURRENT_ID) ? true : false;
              });
            }
            if (!found || found.length <= 0) {
              this.Current_Version_id.push(ele.SELECTED_CURRENT_ID)
              this.Current_Version_value.push(ele.SELECTED_CURRENT_VERSION)
            }
            // vessel  dropdown
            if (this.vessel_office_id.length > 0) {
              var found = this.vessel_office_id.filter(function (data) {
                return (data === ele.VESSEL_NAME_ID) ? true : false;
              });
            }
            if (!found || found.length <= 0) {
              this.vessel_office_id.push(ele.VESSEL_NAME_ID)
              this.vessel_office_value.push(ele.VESSEL_NAME)
            }
          }
          // this.vessel_office_id.forEach( ( x ,i) =>  {
          //   if( typeof x == 'object') {
          //     this.vessel_office_id[i] = 'office'
          //   }
          // });

          console.log(this.vesselOwner_data);

        } else {
          this.vesselOwner_data = [];
        }
      }
      else {
        this.vesselOwner_data = [];
        alert(result.message);
      }
    });
  }

  delete(id) {
    console.log(id);
    if (id) {

      swal({
        title: 'Are you sure?',
        text: "You won't be able to revert this!",
        type: 'warning',
        showCancelButton: true,
        confirmButtonClass: 'btn btn-success',
        cancelButtonClass: 'btn btn-danger',
        confirmButtonText: 'Yes, delete it!',
        buttonsStyling: false

      }).then((result) => {
        if (result.value) {
          this.commonService.sendRequestToNode({ method: 'delete', path: 'vessal-pc-software-report/delete/' + id }).subscribe(result => {
            if (result.status) {
              var dialogueTitle = "Deleted!"
              if (this.vesselOwner_data.length == 1 && Math.ceil(this.totalItems / this.itemsPerPage) == this.currentPage) {
                if (this.currentPage > 1) {
                  this.currentPage--;
                }
              }
              this.getData();
              swal({
                title: dialogueTitle,
                text: result.message,
                type: 'success',
                confirmButtonClass: "btn btn-success",
                buttonsStyling: false
              })
            }
          })
        }
      })
    }
  }

  view(id) {
    this.viewData = true;
    this.openRightSidebar = true;
    this.showSideBarLoader = true;
    this.el.nativeElement.focus();

    this.commonService.sendRequestToNode({ method: 'get', path: 'vessal-pc-software-report/getById/' + id }).subscribe(result => {
      this.showSideBarLoader = false;
      if (result.status) {
        this.vesselOwner_view = result.data;
        console.log(this.vesselOwner_view);
      } else {
        alert(result.message)
      }
    })
  }

  resetForm() {
    this.formSubmittedAttempt = false;
    this.openRightSidebar = false;
    this.edit_id = '';
    this.viewData = false;
    this.SoftwareVersion = '';
    this.selectVessel = false;
    this.selectedLocation = '';
    this.VesselSoftwareReportForm.patchValue({
      VESSEL_FK: null,
      PC_ID: null,
      SOFTWARE_ID: null,
      CURRENT_VESRION: null,
      IS_VESSEL: false,
      VESSEL_LOCATION: null,
      MONTH: null,
      YEAR: null

    })
  }

  // part of grid
  declareGridVariable() {
    this.headerInformation = [
      {
        title: 'Vessel/Office',
        name: 'VESSEL_NAME',
        width: '20%',
        // isSortable : true,
        //highlight:true,
        isFilter: { // filter
          type: 'select',
          placeholder: 'Filter By PC',
          options_display: this.vessel_office_value,
          options_value: this.vessel_office_id
        }

      },
      {
        title: ' PC Name',
        name: 'PC',
        width: '10%',

        isFilter: { // filter
          type: 'select',
          placeholder: 'Filter By PC',
          options_display: this.PC_VALUE_DATA,
          options_value: this.PC_ID_Data
        }
      },
      {
        title: ' PC Location ',
        name: 'SELECTED_LOCATION',
        width: '20%',
        isFilter: { // filter
          type: 'select',
          placeholder: 'Filter By Vessel',
          options_display: this.OFFICE_VALUE_DATA,
          options_value: this.OFFICE_ID_DATA

        }
        // isFilter:{ // filter
        //   type : 'text',
        //   placeholder : 'Filter By PC Location',
        // }
      },
      {
        title: 'Software',
        name: 'SOFTWARE_TITLE',
        width: '15%',

        isFilter: { // filter
          type: 'select',
          placeholder: 'Filter By Software',
          options_display: this.Software_value_data,
          options_value: this.Software_id_data
        }
      },
      {
        title: 'Current Version',
        name: 'SELECTED_CURRENT_VERSION',
        width: '10%',
        isFilter: { // filter
          type: 'select',
          placeholder: 'Filter By Current Version',
          options_display: this.Current_Version_value,
          options_value: this.Current_Version_id

        }
      },
      {
        title: 'Latest Version',
        name: 'LATEST_VERSION',
        width: '10%',
        isFilter: { // filter
          type: 'select',
          placeholder: 'Filter By Latest Version',
          options_display: this.Latest_Version_value,
          options_value: this.Latest_Version_id
        }
      },
      {
        title: 'Report Date',
        name: 'REPORT_DATE',
        width: '10%',
        isDate: 'yes'
        // isFilter: { // filter
        //   type: 'select',
        //   placeholder: 'Filter By Current Version',
        //   options_display: this.Current_Version_value,
        //   options_value: this.Current_Version_id
        // }
      },
      { title: 'Action', name: 'action', width: '15%' }
    ];
    this.actionButtons = [
      // {title:'View',class : "fas fa-eye"},
      { title: 'Edit', class: "far fa-edit" },
      { title: 'Delete', class: "far fa-trash-alt" }
    ]
  }

  //part of grid
  clickOnAction(actionObj) {
    console.log('actionObj'); console.log(actionObj);
    if (actionObj.actionName == 'View') {
      this.view(actionObj.object.ID);
    } else if (actionObj.actionName == 'Edit') {
      this.edit(actionObj.object.ID);
    } else if (actionObj.actionName == 'Delete') {
      this.delete(actionObj.object.ID);
    } else if (actionObj.actionName == 'Status') {
      this.statusChange(actionObj.object.ID, actionObj.object)
    }
  }

  statusChange(id, obj) {
    if (obj.ACTIVE_FLAG == 1) {
      obj.ACTIVE_FLAG = 0;
    } else {
      obj.ACTIVE_FLAG = 1;
    }

    this.commonService.sendRequestToNode({ method: 'put', path: 'vesselowner-isactive/' + id, postData: { ACTIVE_FLAG: obj.ACTIVE_FLAG } }).subscribe(
      data => {
        var dialogueTitle = "Updated!";
        if (data.status) {
          swal({
            title: dialogueTitle,
            text: data.message,
            type: 'success',
            confirmButtonClass: "btn btn-success",
            buttonsStyling: false
          })
          this.getData();
          this.openRightSidebar = false;
          this.resetForm();
        } else {
          alert(data.message);
        }
      })

  }

  //part of grid
  //when change filter ,change page no . etc,
  filter($event) {
    let obj = $event;
    console.log(obj.filter)
    this.currentPage = obj.page;
    this.filterObj = obj.filter;
    this.sortFilter = obj.sort
    this.getData();
  }

  //part of grid
  funOpenRightSidebar() {
    this.openRightSidebar = true;
    this.el.nativeElement.focus();
  }

  getVesselDropdown() {
    this.commonService.sendRequestToNode({ method: 'get', path: 'vessel_master/vessel-dropdown', queryParam: { ACTIVE_FLAG: 1 } }).subscribe(result => {
      if (result.status) {
        this.VesselData = result.data;
        // result.data.forEach((val) => {
        //   this.vessel_dropdown_name[val.ID] = val.VESSEL_NAME;
        // });
      } else {
        this.VesselData = [];
        alert(result.message);
      }
    })
  }

  getPCDropdown(isOffice = false) {
    this.commonService.sendRequestToNode({ method: 'get', path: 'pc-master', queryParam: { IS_OFFICE: isOffice } }).subscribe(result => {
      if (result.status) {
        this.PcDropdown = result.data;
      } else {
        this.PcDropdown = [];
        alert(result.message);
      }
    })
  }

  getSoftwareDropdown() {
    this.commonService.sendRequestToNode({ method: 'get', path: 'softwaredropdown' }).subscribe(result => {
      if (result.status) {
        this.softwareDropdown = result.data;
        console.log(this.softwareDropdown)
        //  this.softwareDropdown.forEach((ele)=>{
        //    this.Software_id_data.push(ele.ID);
        //    this.Software_value_data.push(ele.SOFTWARE_TITLE);
        //  })
      } else {
        this.VesselData = [];
        alert(result.message);
      }
    })
  }

  getPcDetailsById() {
    this.selectedLocation = '';
    if (this.VesselSoftwareReportForm.value.PC_ID && this.VesselSoftwareReportForm.value.IS_VESSEL == 0) {
      let id = this.VesselSoftwareReportForm.value.PC_ID;
      this.commonService.sendRequestToNode({ method: 'get', path: 'pc-master/getById/' + id }).subscribe(
        data => {
          this.selectedLocation = data.data.SELECTED_LOCATION;

        })
    }
  }

  getSoftwareLatestVesrionDetail() {
    this.SoftwareVersion = '';
    if (this.VesselSoftwareReportForm.value.SOFTWARE_ID) {
      let id = this.VesselSoftwareReportForm.value.SOFTWARE_ID;
      this.commonService.sendRequestToNode({ method: 'get', path: 'software/software-version/' + id }).subscribe(result => {
        if (result.status) {
          console.log(result.data)
          if (result.data.length > 0) {
            result.data.forEach((ele) => {
              if (ele.IS_LATEST == 1) {
                this.SoftwareVersion = ele.VERSION;
              }
              //  this.Current_Version_id.push( ele.ID )
              //  this.Current_Version_value.push( ele.VERSION )
            })
            this.softwareVersionDropdown = result.data;
            //  if( this.edit_id ) {
            //     if( this.VesselSoftwareReportForm )
            //       this.VesselSoftwareReportForm.patchValue( {
            //         CURRENT_VESRION : null
            //       })
            //  }

          } else {
            this.SoftwareVersion = '';
            this.softwareVersionDropdown = [];
          }
        }
        else {
          this.SoftwareVersion = '';
          this.softwareVersionDropdown = [];

        }
      })
    }
  }

  // addSoftware( content ){
  //   this.modalRef = this.modalService.open(content,{size: 'sm'});
  // }

  onSubmitSoftware() {
    //console.log(this.edit_id);
    this.softwareFormSubmittedAttempt = true;
    if (this.softwareForm.valid) {
      //console.log(this.Groupinspector.value);
      this.commonService.sendRequestToNode({ method: 'post', path: 'software', postData: this.softwareForm.value }).subscribe(
        data => {
          var dialogueTitle = "Inserted!";
          if (data.status) {
            swal({
              title: dialogueTitle,
              text: data.message,
              type: 'success',
              confirmButtonClass: "btn btn-success",
              buttonsStyling: false
            }).then(() => {
              this.modalRef.close();
              this.getSoftwareDropdown();
              this.resetSoftwareForm();
            })
            // this.modal.close()
          } else {
            alert(data.message);
          }
        })
    }
  }

  resetSoftwareForm() {
    this.softwareFormSubmittedAttempt = false;
    this.softwareForm.patchValue({
      SOFTWARE_TITLE: '',
    })
  }

  change_vessel_type(e, edit_id) {
    this.getPCDropdown(e);

    if (!edit_id) {
      this.SoftwareVersion = '';
      this.selectedLocation = '';
    }

    if (e == true) {
      if (!edit_id) {
        this.vesselTypeAddForm();
      }
      this.selectVessel = true;
    } else {
      if (!edit_id) {
        this.addForm();
      }
      this.selectVessel = false;
    }
  }

  officeDropdown() {
    this.commonService.sendRequestToNode({ method: 'get', path: 'office-location-dropDown', queryParam: { IS_VESSEL: 1 } }).subscribe(result => {
      if (result.status) {
        this.officeLocationData = result.data;
        // result.data.forEach((ele) => {
        //   // if( ele.IS_VESSEL  == 1) {
        //   //   this.officeLocationData.push(ele);

        //   // }
        //    this.OFFICE_ID_DATA.push(ele.ID)
        //    this.OFFICE_VALUE_DATA.push(ele.TITLE)
        // })
      }
      else {
        this.officeLocationData = [];
        alert(result.message);
      }
    })
  }

  getFilterDetails() {
    this.commonService.sendRequestToNode({ method: 'get', path: 'pc-master' }).subscribe(result => {
      if (result.status) {
        if (result.data.length > 0) {
          result.data.forEach((ele) => {
            this.PC_ID_Data.push(ele.ID)
            this.PC_VALUE_DATA.push(ele.NAME)
          })
        }
      } else {
        alert(result.message);
      }
    })

    this.commonService.sendRequestToNode({ method: 'get', path: 'office-location-dropDown' }).subscribe(result => {
      if (result.status) {
        if (result.data.length > 0) {
          result.data.forEach((ele) => {
            this.OFFICE_ID_DATA.push(ele.ID)
            this.OFFICE_VALUE_DATA.push(ele.TITLE)
          })
        }
      }
      else {
        alert(result.message);
      }
    })

    this.commonService.sendRequestToNode({ method: 'get', path: 'softwaredropdown' }).subscribe(result => {
      if (result.status) {
        if (result.data.length > 0) {
          result.data.forEach((ele) => {
            this.Software_id_data.push(ele.ID);
            this.Software_value_data.push(ele.SOFTWARE_TITLE);
          })
        }
      } else {
        alert(result.message);
      }
    })

    this.commonService.sendRequestToNode({ method: 'get', path: 'software-data' }).subscribe(result => {
      if (result.status) {
        if (result.data.length > 0) {
          result.data.forEach((ele) => {
            if (ele.IS_LATEST == 1) {
              this.Latest_Version_id.push(ele.ID);
              this.Latest_Version_value.push(ele.VERSION);
            }
          })
        }
      }
      else {
        alert(result.message);
      }
    })

  }

  exportSelect(content) {
    this.vesselForm.patchValue({
      Vessel_ID: null,
    })
    this.modalRef = this.modalService.open(content, { size: 'sm' });
  }

  vesselDropDown() {
    this.commonService.sendRequestToNode({ method: 'get', path: 'vessel_master/vessel-dropdown', queryParam: { ACTIVE_FLAG: 1, with_non_tanker: true } }).subscribe(result => {
      if (result.status) {
        // this.vessel_dropdown_name[]

        // this.vessel_dropdown = [{VESSEL_NAME : 'All Vessels',ID : 'ALL'},...result.data];
        this.vessel_dropdown_export = result.data;
        this.vessel_dropdown_export.forEach(ele => {
          this.vessel_dropdown_name[ele.ID] = ele.VESSEL_NAME;
        })
      }
      else {
        this.vessel_dropdown_name = [];
        this.vessel_dropdown_export = [];
        alert(result.message);
      }
    })
  }

  exportData() {
    this.formSubmittedAttempt = true;
    if (this.vesselForm.valid) {
      // let Vessel_ID       =  JSON.stringify( this.vesselForm.value.Vessel_ID);
      // let tempVesselName  = JSON.stringify(  this.vessel_dropdown_name );
      //  window.open(this.commonService.getNodeApi()+'/vessal-pc-software-report/exportXls?Vessel_ID=' +  Vessel_ID  + '&VesselName=' + tempVesselName ,'_blank')

      let Vessel_ID = this.vesselForm.value.Vessel_ID;
      Vessel_ID.forEach(element => {
        window.open(this.commonService.getNodeApi() + '/vessal-pc-software-report/exportXls?Vessel_ID=' + element + '&VesselName=' + this.vessel_dropdown_name[element], '_blank')
      })
      this.modalRef.close();
    }

  }

  importOpenModal(content) {
    // this.vesselForm.patchValue({
    //   Vessel_ID: null,
    // });
    // alert('Here');
    // return;
    this.modalRef = this.modalService.open(content, { size: 'sm' });
  }

  // onFileChange(event) {
  //   if(event.target.files.length > 0) {
  //     this.fileObj = event.target.files[0];
  //   }else{
  //     this.fileObj = '';
  //     this.fi ? this.fi.nativeElement.value = "" : '';
  //   }
  // }


  onFileChange(event) {
    this.fileObj = [];
    if (event.target.files.length > 0 && event.target.files.length <= 20) {
      for (var i = 0; i < event.target.files.length; i++) {
        this.fileObj.push(event.target.files[i]);
      }
      // this.groupCdiReportUpload.get('FILE').setValue(fileObj);
    } else {
      alert('You can only upload upto 20 files');
      this.fi ? this.fi.nativeElement.value = "" : '';
    }
  }

  submitImportFile() {
    if (this.fileObj.length > 0) {
      this.mainLoader = true;
      let formData = new FormData();

      console.log(this.fileObj);
      // formData.append('FILE',this.fileObj);
      for (var i = 0; i < this.fileObj.length; i++) {
        formData.append("FILE", this.fileObj[i]);
      }

      this.commonService.sendRequestToNode({ method: 'post', path: 'vessal-pc-software-report-checkimport/checkImportFileOlderOrNot', postData: formData }).subscribe(data => {
        if (data.status) {
          if (data.message == "confirmation_for_import") {
            this.mainLoader = false;
            swal({
              title: 'Are you sure?',
              text: "Last exported file name does not match the  file you are currently trying to import from , do you wish to continue ? . Data might get overwritten if you choose to proceed.",
              type: 'warning',
              showCancelButton: true,
              confirmButtonClass: 'btn btn-success',
              cancelButtonClass: 'btn btn-danger',
              confirmButtonText: 'Yes, Import it!',
              buttonsStyling: false
            }).then((result) => {
              if (result.value) {

                this.importFile();
              }

            })
          }
          else {
            this.importFile();
          }

        }
      })
    }
    else {
      alert('Please Select File');
    }
  }

  importFile() {
    let formData = new FormData();
    // formData.append('FILE',this.fileObj);
    for (var i = 0; i < this.fileObj.length; i++) {
      formData.append("FILE", this.fileObj[i]);
    }
    this.mainLoader = true;
    this.commonService.sendRequestToNode({ method: 'post', path: 'vessal-pc-software-report-importXls/importXls', postData: formData }).subscribe(
      data => {
        this.mainLoader = false;
        var dialogueTitle = "Imported!";
        if (data.status) {
          swal({
            html: 'File Successfully imported',
            title: dialogueTitle,
            type: 'success',
            confirmButtonClass: "btn btn-success",
            buttonsStyling: false
          });
          this.getData();
          this.modalRef.close();
          this.fileObj = ''; // remove data from file Obj
          this.fi ? this.fi.nativeElement.value = "" : ''; // blank input file

        }
        else {
          alert(data.message)
        }
      });
  }

  getDataforcsv() {
    this.commonService.sendRequestToNode({ method: 'post', path: 'vessal-pc-software-report-csv/generateReportCsv', postData: { vesselOwner_data: this.vesselOwner_data } }, { responseType: 'blob' }).subscribe(result => {
      saveAs(result, `SoftwareReport.xlsx`)
    })
  }

  getDataforPdf() {
    this.commonService.sendRequestToNode({ method: 'post', path: 'vessal-pc-software-report-pdf/generateReportPdf', postData: { vesselOwner_data: this.vesselOwner_data } }, { responseType: 'blob' }).subscribe(result => {
      saveAs(result, `SoftwareReport.pdf`)
    })
  }

}
