import { Component, AfterViewInit,OnInit, createPlatformFactory } from '@angular/core';
import { NgbPaginationConfig, NgbModal, NgbModalRef, ModalDismissReasons } from '@ng-bootstrap/ng-bootstrap';
import { CommonService } from '../common-service.service';
import {Router,ActivatedRoute} from "@angular/router";
import {FormGroup,FormBuilder,Validators,FormControl} from '@angular/forms';
import swal from 'sweetalert2';

declare var $: any;
import { PerfectScrollbarConfigInterface } from 'ngx-perfect-scrollbar';

@Component({
  templateUrl: './vessel-flag.component.html',
  styleUrls: ['./vessel-flag.component.scss']
})
export class VesselFlagComponent implements AfterViewInit,OnInit {

  public config: PerfectScrollbarConfigInterface = {};

  options = {
    theme: 'light', // two possible values: light, dark
    dir: 'ltr', // two possible values: ltr, rtl
    layout: 'vertical', // fixed value. shouldn't be changed.
    sidebartype: 'mini-sidebar', // four possible values: full, iconbar, overlay, mini-sidebar 
    sidebarpos: 'fixed', // two possible values: fixed, absolute
    headerpos: 'fixed', // two possible values: fixed, absolute
    boxed: 'full', // two possible values: full, boxed
    navbarbg: 'skin6', // six possible values: skin(1/2/3/4/5/6)
    sidebarbg: 'skin5', // six possible values: skin(1/2/3/4/5/6)
    logobg: 'skin5' // six possible values: skin(1/2/3/4/5/6)
  };
  
  public vesselflagData = [];
  public vesselflagForm:FormGroup;  
  public edit_id;
  public formSubmittedAttempt = false;
  public openRightSidebar = false;
  public showLoader = false;
  public filterObj:any = {};
  public sortFilter:any = {};
  modalReference: NgbModalRef;

  //for grid 
  public headerInformation;
  public actionButtons;

  //for pagination
  itemsPerPage: number = this.commonService.DefaultItemsPerPage;
  totalItems: number;
  currentPage: number = 1;
 
  constructor(private modalService: NgbModal,
    private commonService: CommonService,
    private router: Router,
    private formBuilder: FormBuilder,
    private route: ActivatedRoute){
      this.declareGridVariable()
  }

  // part of grid
  declareGridVariable(){
    this.headerInformation = [
      {
        title : 'Vessel Flag Name',// show title table header
        nameIcon : true,// show icon of First letter
        name:'VESSEL_FLAG_NAME',// name of column in data source
        width : '20%',// width of column in table
        isSortable : true,// sort by column false or true
        isFilter:{ // filter 
          type : 'text',
          placeholder : 'Filter By Vessel Flag'
        }
      },
      {title : '',name:'',width : '70%'},
    ];
   
  }

  ngAfterViewInit(){
   
  }

  ngOnInit(){
    this.getData();
    this.addForm();
  }
  
  getData()
  {
    let filterParams:any = {}
    
    //search filter 
    filterParams = JSON.parse(JSON.stringify(this.filterObj));
    //search filter -end

    // pagination
    filterParams.currentPage = this.currentPage-1;
    filterParams.itemsPerPage = this.itemsPerPage;
    // pagination - end

    //sorting 
    let sortKey = Object.keys(this.sortFilter);
    if(sortKey.length && this.sortFilter[sortKey[0]]){
      filterParams.sortBy = sortKey[0];
      filterParams.sortStatus = this.sortFilter[sortKey[0]];
    }
    //sorting - end

    this.showLoader = true;

    this.commonService.sendRequestToNode({method :'get',path:'vessel-flag',queryParam:filterParams}).subscribe(
      result => {
      this.showLoader = false;  
        if(result.status)
        {
          if(result.data.length > 0){
            this.totalItems = result.data[0].total_records;
            this.vesselflagData = result.data;
          }else{
            this.vesselflagData = [];
          }
        }
        else{
          this.vesselflagData = [];
          alert(result.message);
        }
    })
  }

  addForm(){
    this.vesselflagForm = this.formBuilder.group({
      VESSEL_FLAG_NAME: ['',[Validators.required]],
    });   
  }

  resetForm(){
    this.formSubmittedAttempt = false;
    this.openRightSidebar = false;
    this.edit_id = '';
    this.vesselflagForm.patchValue({
      VESSEL_FLAG_NAME : '',
    })
  }

  edit(id){
    this.openRightSidebar = true;
    this.commonService.sendRequestToNode({method :'get',path:'vessel-flag/'+id}).subscribe(
      data => {         
        this.vesselflagForm.patchValue({
          VESSEL_FLAG_NAME : data.data.VESSEL_FLAG_NAME ,
        })
        this.edit_id = id;
    })
  }

  delete(id){
    if(id){
      swal({
        title: 'Are you sure?',
        text: "You won't be able to revert this!",
        type: 'warning',
        showCancelButton: true,
        confirmButtonClass: 'btn btn-success',
        cancelButtonClass: 'btn btn-danger',
        confirmButtonText: 'Yes, delete it!',
         buttonsStyling: false
      }).then((result) => {
        if (result.value) {
          this.commonService.sendRequestToNode({method :'delete',path:'vessel-flag/'+id}).subscribe(
          data => {
          if(data.status){
            var dialogueTitle = "Deleted!"
            if(this.vesselflagData.length == 1 && Math.ceil(this.totalItems / this.itemsPerPage) == this.currentPage){
              if(this.currentPage>1){
                this.currentPage--;
              }
            }
            this.getData();
            swal({
                title: dialogueTitle,
                text: data.message,
                type: 'success',
                confirmButtonClass: "btn btn-success",
                buttonsStyling: false
              })
          }         
          
      })
         }
      })      
    }
  }

  onSubmit(){ 
    this.formSubmittedAttempt = true;
    if(this.vesselflagForm.valid){
    if(this.edit_id){    
      this.commonService.sendRequestToNode({method :'put',path:'vessel-flag/'+this.edit_id,postData:this.vesselflagForm.value}).subscribe(
        data =>{
          var dialogueTitle = "Updated!"
          if(data.status){
            swal({
                title: dialogueTitle,
                text: data.message,
                type: 'success',
                confirmButtonClass: "btn btn-success",
                buttonsStyling: false
              })
            this.getData();
            this.resetForm(); //after edit form is reset
          }
          else{
            alert(data.message);
          }
      })
    }else{
      this.commonService.sendRequestToNode({method :'post',path:'vessel-flag',postData:this.vesselflagForm.value}).subscribe(
        data =>{
          var dialogueTitle = "Inserted!"
          if(data.status){
            swal({
                title: dialogueTitle,
                text: data.message,
                type: 'success',
                confirmButtonClass: "btn btn-success",
                buttonsStyling: false
              })
            this.getData();
            this.resetForm(); //after edit form is reset

          }
          else{
            alert(data.message);
          }
      })
    }
    }
      
  } 

    //part of grid
    clickOnAction(actionObj){
      if(actionObj.actionName == 'Edit'){
        this.edit(actionObj.object.ID)
      }else if(actionObj.actionName == 'Delete'){
        this.delete(actionObj.object.ID)
      }
    }
  
    //part of grid
    //when change filter ,change page no . etc, 
    filter($event){
      let obj = $event;
      this.currentPage = obj.page;
      this.filterObj = obj.filter;
      this.sortFilter = obj.sort
      this.getData();
    }
  
    //part of grid
    funOpenRightSidebar(){
      this.openRightSidebar = true; 
    }
  

}

