import { Component, AfterViewInit, OnInit, createPlatformFactory, ElementRef, ViewChild } from '@angular/core';
import { NgbModal} from '@ng-bootstrap/ng-bootstrap';
import { CommonService } from '../common-service.service';
import { ActivatedRoute } from "@angular/router";
import swal from 'sweetalert2';


@Component({
  selector: 'vesselReport',
  templateUrl: './vesselReport.component.html',
  styleUrls: ['./vesselReport.component.scss']
})
export class VesselReportComponent implements AfterViewInit, OnInit {

  //for pagination
  itemsPerPage: number = this.commonService.DefaultItemsPerPage;
  totalItems: number;
  currentPage: number = 1;
  isDisabled = true;
  vessel_id = 0;
  public expanded = [];
  public filterObj = {};
  public formData = {};
  public formDataOperatorDate = {};
  public vesselGroup_dropdown = [];
  public vesselFleet_dropdown = [];
  public vesselOwner_dropdown = [];
  public port_dropdown = [];
  public perCompanyObservation;
  public perCompanyRisk;
  public oilMajor_dropdown = [];
  public inspector_dropdown = [];
  public sireReportData = [];
  public withoutPaginationData = [];
  public sireReportDatacsv = [];
  public configData = [];
  public sortFilter: any = {};
  public current_template;
  public link_template;
  public risk_params;

  public pdfLogo;
  

  //for grid 
  public headerInformation;
  public actionButtons;
  public title;

  // public VesselMasterForm:FormGroup;
  // public groupSireReportUpload:FormGroup;

  constructor(
    private commonService: CommonService, private route: ActivatedRoute) {
    this.declareGridVariable();
    this.title = 'Vessel Report';
  }

  ngOnInit() {
    //console.log(location);
    this.pdfLogo = location.origin+location.pathname+'assets/images';
    this.route.params.subscribe(params => {
      this.vessel_id = params['id'];
      
    });
    this.route.queryParams.subscribe(params => {
      this.risk_params = params.type ? params.type : 'glob';
      this.getData();
      this.getDataWithoutPagination();
    });
    
    
  }

  ngAfterViewInit() {
  }

  changePage(page) {
    this.currentPage = page;
    this.sendFilterObjectForUpdateData();
    window.scroll(0, 0);
  }

  sendFilterObjectForUpdateData() {
    let makeFilterObj = {}
    Object.keys(this.filterObj).forEach((key) => {
      makeFilterObj[key] = this.filterObj[key].replace(/'/g, "\\\'").replace(/"/g, '\\\"')
    });
    let filter = {
      filter: makeFilterObj,
      page: this.currentPage,
      sort: this.sortFilter
    }
    this.getData();
  }



  getData() {
    let filterParams: any = {}
    //search filter 
    filterParams = JSON.parse(JSON.stringify(this.filterObj));
    //search filter -end
    // pagination
    filterParams.currentPage = this.currentPage - 1;
    filterParams.itemsPerPage = this.itemsPerPage;
    filterParams.riskFor = this.risk_params;
    if (Object.keys(this.sortFilter).length > 0) {
      filterParams.sortBy = Object.keys(this.sortFilter)[0];
      filterParams.sortStatus = this.sortFilter[Object.keys(this.sortFilter)[0]]
    }

    this.commonService.sendRequestToNode({ method: 'get', path: 'vessel-report/'+this.vessel_id, queryParam: filterParams }).subscribe(result => {
      if (result.status) {
        if(result.data.length >0){
          this.title = result.data[0].VESSEL_NAME;
          this.totalItems = result.data[0].total_records
          this.sireReportData = result.data;
        }
        else{
          this.totalItems = 0;
          this.sireReportData = []
        }
      }
      else {
        this.totalItems = 0;
        this.sireReportData = []
        alert(result.message);
      }
    })
  }

  getDataWithoutPagination(){
    let filterParams: any = {}
    //search filter 
    filterParams = JSON.parse(JSON.stringify(this.filterObj));
    //search filter -end
    // pagination
    filterParams.currentPage = this.currentPage - 1;
    filterParams.itemsPerPage = this.itemsPerPage;
    filterParams.riskFor = this.risk_params;
    if (Object.keys(this.sortFilter).length > 0) {
      filterParams.sortBy = Object.keys(this.sortFilter)[0];
      filterParams.sortStatus = this.sortFilter[Object.keys(this.sortFilter)[0]]
    }

    this.commonService.sendRequestToNode({ method: 'get', path: 'vessel-report/'+this.vessel_id, queryParam: filterParams }).subscribe(result => {
      if (result.status) {
        if(result.data.length >0){
          this.title = result.data[0].VESSEL_NAME;
          this.totalItems = result.data[0].total_records;
          this.withoutPaginationData = result.data;
        }
        else{
          this.totalItems = 0;
          this.withoutPaginationData = []
        }
      }
      else {
        this.totalItems = 0;
        this.withoutPaginationData = []
        alert(result.message);
      }
    })
  }
  
  filter($event) {
    let obj = $event;
    this.currentPage = obj.page;
    this.filterObj = obj.filter;
    this.sortFilter = obj.sort
    this.getData();
  } 

  declareGridVariable() {
    this.headerInformation = [
      {
        title: 'Date',// show title table header
        isDate: 'yes',
        name: 'DATE_OF_INSPECTION',// name of column in data source
        width: '12%',// width of column in table
        isSortable: true,// sort by column false or true
        // isFilter:{ // filter 
        //   type : 'text',
        //   placeholder : 'Filter By Date'
        // }
      },
      {
        title: 'Risk',// show title table header
        name: 'RISK_PROFILE',// name of column in data source
        width: '12%',// width of column in table
        display_value: { '1': 'Low Risk', '2': 'Medium Risk', '3': 'High Risk', '4': 'Very High Risk' } ,
        isFilter: { // filter 
          type: 'select',
          placeholder: 'Filter By Risk',
          options_value: [1,2,3,4],
          options_display: ['Low Risk','Medium Risk','High Risk', 'Very High Risk']
        }
      },

      {
        title: 'VIQ Ref No.',// show title table header
        //nameIcon : true,// show icon of First letter
        name: 'QUESTION_NUMBER',// name of column in data source
        width: '20%',// width of column in table
        isSortable: true,// sort by column false or true
        isFilter: { // filter 
          type: 'text',
          placeholder: 'Filter By VIQ Ref No'
        }
      },
      {
        title: 'VIQ Questions',// show title table header
        //nameIcon : true,// show icon of First letter
        name: 'QUESTION_DESCRIPTION',// name of column in data source
        width: '30%',// width of column in table
        isSortable: true,// sort by column false or true
        isFilter: { // filter 
          type: 'text',
          placeholder: 'Filter By VIQ Questions'
        }
      },
      { title: 'Inspector Observation', name: 'INSPECTION_OBSERVATION', width: '5%', },
      {
        title: 'Port Of Inspection', name: 'PORT_OF_INSPECTION', width: '5%',
        isFilter: { // filter 
          type: 'text',
          placeholder: 'Filter By Port Of Inspection'
        }
      },
      {
        title: 'Oil Major', name: 'INSPECTING_COMPANY', width: '15%', isFilter: { // filter 
          type: 'text',
          placeholder: 'Filter By Oil Major'
        }
      }
    ];

  }

  getDataforcsv() {
    this.generatcsv();
  }

  generatcsv(){
    let postObj = {
      data : this.withoutPaginationData
    }
    this.commonService.sendRequestToNode({method :'post',path:'vesselReport/generateCSVData',postData:postObj}).subscribe(result => {
      if(result.status){
        window.open(this.commonService.getNodeApi()+'/vesselReport/exportCSV', '_blank' );
      }
    })
  }

  generatePdf(){
    var data = document.getElementById('htmlToString').innerHTML;
    // console.log(JSON.stringify(data));
    // console.log(data);
    var htmlData = {'data':data};
    this.commonService.sendRequestToNode({ method: 'post', path: 'vesselReport/generatePDFData',postData:htmlData }).subscribe(result => {
      if(result.status){
        window.location.href = this.commonService.getNodeApi()+'/vesselReport/exportPDF';
      }
    })
  }

  // getkey(obj){
  //   if(obj.RISK_PROFILE == 3){
  //     obj.RISK_PROFILE = 'High Risk';
  //   }else if(obj.RISK_PROFILE == 4){
  //     obj.RISK_PROFILE = 'Very High Risk';
  //   }
  //   return Object.keys(obj);
  // }

}
