import { Component, AfterViewInit,OnInit } from '@angular/core';
import { NgbModal, NgbModalRef } from '@ng-bootstrap/ng-bootstrap';
import { CommonService } from '../common-service.service';
import {Router} from "@angular/router";
import {FormGroup,FormBuilder, Validators} from '@angular/forms';
import swal from 'sweetalert2';
// import { NgbTabset, NgbModal, NgbModalRef, ModalDismissReasons, NgbActiveModal } from '@ng-bootstrap/ng-bootstrap';

declare var require: any;

@Component({
  selector: 'VettingComponent',
  templateUrl: './vettingApproval.component.html',
  styleUrls: ['./vettingApproval.component.scss']
})
export class VettingComponent implements AfterViewInit,OnInit {
  
  public modalRef:NgbModalRef;
  public showLoader = false;
  public showMainLoader = false;
  public showModalLoader = false;
  public type = '';
  public planningIndex = 0; // for port 
  public country_dropdown = [];// user in add port
  public currentVesselInfo = {};
  public filterObj:any = {};
  public sortFilter:any = {};
  public oliMajor_dropdown = [];
  public port_dropdown = [];
  public vesselOwner_dropdown = [];
  public vessel_arr = []; //  this is vessele arr for Export
  public objForExport = {
    vessel_arr : [],
    Owner_Fk : null,
    Owner_Name : '',
    comment : '',
    is_check_all : true
  }
  public validityArr = [
    { label : "3 months",value : 3},
    { label : "6 months",value : 6},
    { label : "12 months",value : 12},
    { label : "18 months",value : 18},
    { label : "24 months",value : 24}
  ] 
  public oil_major_arr = [{ 
    OIL_MAJOR_FK : null,
    VALIDITY : null,
    OIL_MAJOR_FK_Err : null,
    VALIDITY_Err : null,
    COMMENT : ''   
  }];

  public portForm :FormGroup;
  public portFormSubmittedAttempt = false;


  //for grid 
  public headerInformation;
  public actionButtons;

  //for pagination
  itemsPerPage: number = this.commonService.DefaultItemsPerPage;
  totalItems: number;
  currentPage: number = 1;

  public vesselMaster_data = [];
  public openRightSidebar = false;
  public TemplateForm:FormGroup;
  constructor(private modalService: NgbModal,
    private formBuilder: FormBuilder,
    private router: Router,
    private commonService: CommonService){
     
        
  }

  ngOnInit(){
    this.declareGridVariable();
    this.getData();
    this.buildForm();
    this.oilMajor();
    this.portDropdown();
    this.countryDropDown();
    this.vesselOwner();
  }
  open2(content,type = "pdf") {
    this.type = type;
    this.modalRef = this.modalService.open(content,{size: 'lg'});
    this.modalRef.result.then((data) => {
      // on close
      this.objForExport = {
        vessel_arr : [],
        Owner_Fk : null,
        Owner_Name : '',
        comment : '',
        is_check_all : true
        } 
    },reason =>{
      this.objForExport = {
        vessel_arr : [],
        Owner_Fk : null,
        Owner_Name : 'null',
        comment : '',
        is_check_all : true
        }
    });
  }

  vesselOwner(){
    this.commonService.sendRequestToNode({method :'get',path:'vessel_master/vesselOwner'}).subscribe(result => {
      if(result.status){
        this.vesselOwner_dropdown = result.data;
        //console.log(this.vesselOwner_dropdown);
      }
      else{
        this.vesselOwner_dropdown = [];
        alert(result.message);
      }
    })
  }

  buildForm(){
    this.TemplateForm = this.formBuilder.group({
      VESSEL_ID : [null,Validators.required],
      OIL_MAJOR_ARR : ['',Validators.required],
      COMMENT : [''],
      PSC_INSPECTION_DATE : [null],
      PSC_INSPECTION_PORT : [null],
      COG_INSPECTION_DATE : [null],
      COG_INSPECTION_PORT : [null]
    }); 
    this.portForm = this.formBuilder.group({
      PORT_NAME: [null,],
      PORT_CODE: [null,],
      COUNTRY_MST_FK: [null,],
      LATITUDE : [null,],
      LONGITUDE : [null,]
    });
  }

 
  getData()
  {
    let filterParams:any = {}
    
    //search filter 
    filterParams = JSON.parse(JSON.stringify(this.filterObj));
    //search filter -end

    // pagination
    filterParams.currentPage = this.currentPage-1;
    filterParams.itemsPerPage = this.itemsPerPage;
    // pagination - end
    

    //sorting 
    let sortKey = Object.keys(this.sortFilter);
    if(sortKey.length && this.sortFilter[sortKey[0]]){
      filterParams.sortBy = sortKey[0];
      filterParams.sortStatus = this.sortFilter[sortKey[0]];
    }
    //sorting - end

    this.showLoader = true;

    this.commonService.sendRequestToNode({method :'get',path:'vetting-template/getVesselList',queryParam:filterParams}).subscribe(result => {
      this.showLoader = false;    
      if(result.status)
      {
        if(result.data.length > 0){
          this.totalItems = result.data[0].total_records;
          this.vesselMaster_data = result.data;
        }else{
          this.vesselMaster_data = [];
        }
      }
      else{
        this.vesselMaster_data = [];
        alert(result.message);
      }
    })
  }

  portDropdown(portId = 0,planningIndex = 0){
    this.commonService.sendRequestToNode({method :'get',path:'port-dropdown'}).subscribe(result => {
      if(result.status){
        this.port_dropdown = result.data;
        if(portId){
          if(planningIndex == 1){
            this.TemplateForm.patchValue({PSC_INSPECTION_PORT : portId});
          }
          else{
            this.TemplateForm.patchValue({COG_INSPECTION_PORT : portId});
          }
            
        }
      }
      else{
        this.port_dropdown = [];
        alert(result.message);
      }
    })
  }
  oilMajor(){
    this.commonService.sendRequestToNode({method :'get',path:'inspectors/oliMajor-dropdown'}).subscribe(result => {
      if(result.status){
        this.oliMajor_dropdown = result.data;
        
        // this.loader.oilMajor = true;
      }
      else{
        this.oliMajor_dropdown = [];
        alert(result.message);
      }
    })
  }
  

  ngAfterViewInit(){	
  }

  // part of grid
  declareGridVariable(){
    this.headerInformation = [
    {
      title : 'Vessel Name',// show title table header
      name:'VESSEL_NAME',// name of column in data source
      width : '25%',// width of column in table
      isSortable : true,// sort by column false or true
      highlight:true, // name highlight
      isFilter:{ // filter 
        type : 'text',
        placeholder : 'Filter By Vessel Name'
      }
    },
    {
      title : 'IMO No.',// show title table header
      name:'IMO_NO',// name of column in data source
      width : '15%',// width of column in table
      isSortable : true,// sort by column false or true
      isFilter:{ // filter 
        type : 'text',
        placeholder : 'Filter By IMO No.'
      }
    },
    {
      title : 'OCIMF ID',// show title table header
      name:'OCIMF_ID',// name of column in data source
      width : '20%',// width of column in table
      isSortable : true,// sort by column false or true
      isFilter:{ // filter 
        type : 'text',
        placeholder : 'Filter By OCIMF ID'
      }
    },
    {
      title : 'Last Sire date',
      name:'LAST_INSPECTION_DATE',
      width : '15%',
      isSortable : true,
      isDate : 'yes'
    },
    {
      title : 'Last Oil Major',
      name:'LAST_OIL_MAJOR',
      width : '20%',
      isSortable : true,
      isFilter:{ // filter 
        type : 'text',
        placeholder : 'Filter By Fleet Manager'
      }
    },
    {title : 'Action',name:'action',width : '5%'}
    ];
    this.actionButtons = [
    {title:'Template',class : "far fa-file-alt",'redColor' : 'IS_VETTING_TEMPLATE'},
    ]
  }

  //part of grid
  clickOnAction(actionObj){
    if(actionObj.actionName == 'Template'){
      this.clickTemplateBtn(actionObj.object);
    }
  }

  //part of grid
  //when change filter ,change page no . etc, 
  filter($event){
    let obj = $event;
    this.currentPage = obj.page;
    this.filterObj = obj.filter;
    this.sortFilter = obj.sort
    this.getData();
  }

  clickTemplateBtn(obj){
    this.showMainLoader = true;
    this.currentVesselInfo = obj
    let vesselId = obj.ID;
    this.commonService.sendRequestToNode({ method: 'get', path: `vetting-template/${vesselId}`, postData:  this.TemplateForm.value}).subscribe(result => {
      this.showMainLoader = false;
      if (result.status) {
        this.openRightSidebar = true;
        // this.resetForm();
        if(result.getVesselTemplateData && result.getVesselTemplateData.length){
          this.TemplateForm.patchValue({
            VESSEL_ID : vesselId,
            COMMENT : result.getVesselTemplateData.length ? result.getVesselTemplateData[0].COMMENT : '',
            PSC_INSPECTION_DATE : result.getVesselTemplateData.length ? this.commonService.formatDate(result.getVesselTemplateData[0].PSC_INSPECTION_DATE) : null,
            PSC_INSPECTION_PORT : result.getVesselTemplateData.length ? result.getVesselTemplateData[0].PSC_INSPECTION_PORT : null,
            COG_INSPECTION_DATE : result.getVesselTemplateData.length ? this.commonService.formatDate(result.getVesselTemplateData[0].COG_INSPECTION_DATE) : null,
            COG_INSPECTION_PORT : result.getVesselTemplateData.length ? result.getVesselTemplateData[0].COG_INSPECTION_PORT : null
          });
          if(result.getVesselTemplateDetailsData.length){
            this.oil_major_arr = [];
            result.getVesselTemplateDetailsData.forEach(element => {
              this.oil_major_arr.push({ 
                OIL_MAJOR_FK : element.OIL_MAJOR_FK,
                VALIDITY : parseInt(element.VALIDITY),
                OIL_MAJOR_FK_Err : false,
                VALIDITY_Err : false,
                COMMENT : element.COMMENT   
              });
            });
          }
        }
        else{
          this.TemplateForm.patchValue({
            VESSEL_ID : vesselId
          });
        }
      }
      else {
        alert(result.message);
      }
    })
    
  }


  resetForm(){
    this.openRightSidebar = false;
    this.TemplateForm.patchValue({
      VESSEL_ID : null,
      OIL_MAJOR_ARR :'',
      COMMENT : '',
      PSC_INSPECTION_DATE : null,
      PSC_INSPECTION_PORT : null,
      COG_INSPECTION_DATE : null,
      COG_INSPECTION_PORT : null
    }); 
    this.oil_major_arr = [{ 
      OIL_MAJOR_FK : null,
      VALIDITY : null,
      OIL_MAJOR_FK_Err : false,
      VALIDITY_Err : false,
      COMMENT : ''   
    }];
  }

  saveVettingTemplate(){
   
    let isInvalid = false;
    this.oil_major_arr.forEach(ele=>{
      ele.OIL_MAJOR_FK_Err = false;
      ele.VALIDITY_Err = false;
      if(!ele.OIL_MAJOR_FK){
        isInvalid = true;
        ele.OIL_MAJOR_FK_Err = true;
      }
      if(!ele.VALIDITY){
        isInvalid = true;
        ele.VALIDITY_Err = true;
      }
    })
    if(!isInvalid){
      this.showMainLoader = true;
      this.TemplateForm.patchValue({
        OIL_MAJOR_ARR : JSON.stringify(this.oil_major_arr)
      })
      this.commonService.sendRequestToNode({ method: 'post', path: 'vetting-template', postData:  this.TemplateForm.value}).subscribe(result => {
        this.showMainLoader = false;
        if (result.status) {  
          var dialogueTitle = "Saved!"            
          swal({
            title: dialogueTitle,
            text: result.message,
            type: 'success',
            confirmButtonClass: "btn btn-success",
            buttonsStyling: false
          })
          this.resetForm();
        }
        else {
          alert(result.message);
        }
      })
    }
    else{
      alert('Please Fill Proper Form');
    }
    
  }
  
  addReportFormat(){
    this.oil_major_arr.push({
      OIL_MAJOR_FK : null,
      VALIDITY : null,
      OIL_MAJOR_FK_Err : false,
      VALIDITY_Err : false,
      COMMENT : '' 
    })
  }
  removeReportFormat(i){
    this.oil_major_arr.splice(i,1);
  }

  getVesselTemplateByOwner(item){
    
    if(this.objForExport.Owner_Fk){
      this.objForExport.is_check_all = true;
      this.showModalLoader = true;
      this.objForExport.Owner_Name = item.COMPANY_NAME;
      this.commonService.sendRequestToNode({ method: 'post', path: 'vetting-template/getVesselDataByOwner', postData:  {Owner_Fk : this.objForExport.Owner_Fk}}).subscribe(result => {
        if (result.status) {
          this.showModalLoader = false;
          this.objForExport.vessel_arr = result.data;
        }
        else {
          alert(result.message);
        }
      })
    }
    else{
      // this.objForExport.Owner_Name = null;
      this.objForExport = {
        vessel_arr : [],
        Owner_Fk : null,
        Owner_Name : '',
        comment : '',
        is_check_all : true
      }
    }
    
    
  }
  
  changeCommentValue(item){
    this.objForExport.vessel_arr[item].CommentValueChange = true;
  }

  isCheckBoxChange(){
   let check_all = true;
    this.objForExport.vessel_arr.forEach(ele=>{
      if(!ele.vessel_flag){
        check_all = false
      }
    });
    this.objForExport.is_check_all = check_all;
  }
  isCheckAllChange(){
    this.objForExport.vessel_arr.forEach(ele=>{
      ele.vessel_flag = this.objForExport.is_check_all
    });
  }
  
  export(type){
    this.showMainLoader = true;
    let filterVesselArr = this.objForExport.vessel_arr.filter(item=>{
      return (item.vessel_flag ? true : false);
    });
    let postObj = {
      vessel_arr : filterVesselArr,
      Owner_Fk : this.objForExport.Owner_Fk,
      Owner_Name : this.objForExport.Owner_Name,
      comment : this.objForExport.comment
    }
    this.commonService.sendRequestToNode({ method: 'post', path: 'vetting-template/get-vetting-template-data', postData:  postObj}).subscribe(result => {
      this.showMainLoader = false;
      if (result.status) {
        this.modalRef.close();
       
        let url = this.commonService.getNodeApi() + '/vetting-template/export-xls-vetting-template-data';
        if(type =="pdf"){
          url = this.commonService.getNodeApi() + '/vetting-template/export-vetting-template-data';
        }
          
          var mapForm = document.createElement("form");
          mapForm.target = "_blank";
          mapForm.method = "POST"; // or "post" if appropriate
          mapForm.action = url;
      
          var mapInput = document.createElement("input");
          mapInput.type = "hidden";
          mapInput.name = "data";
          mapInput.value = JSON.stringify(result.data);
          mapForm.appendChild(mapInput);
      
          document.body.appendChild(mapForm);
       
          //  let map = window.open("", "Map", "status=0,title=0,height=600,width=800,scrollbars=1");
       
           if (mapForm) {
               mapForm.submit();
           } else {
               alert('You must allow popups for this map to work.');
           }
      }
      else {
        alert('Something is wrong')
      }
    })
  }

  countryDropDown(){
    this.commonService.sendRequestToNode({method :'get',path:'country/dropdown'}).subscribe(result => {
      if(result.status){
        this.country_dropdown = result.data;           
      }
      else{
        this.country_dropdown = [];
        alert(result.message);
      }
    })
  }

  openModel(content,planningIndex) {
    this.planningIndex = planningIndex;
    this.modalRef = this.modalService.open(content,{size: 'lg'});
  } 

  onSubmitPort(){ 
    this.portFormSubmittedAttempt = true;
    if(this.portForm.valid){
     
        this.commonService.sendRequestToNode({method :'post',path:'port',postData:this.portForm.value}).subscribe(
          data =>{
          var dialogueTitle = "Inserted!";
          if(data.status){
            this.modalRef.close();
            swal({
              title: dialogueTitle,
              text: data.message,
              type: 'success',
              confirmButtonClass: "btn btn-success",
              buttonsStyling: false
            })
            
            this.portDropdown(data.insertId,this.planningIndex);
            this.resetPortForm(); //after edit form is reset
          }else{
            alert(data.message);
          }
        })
      }
     
  }
  resetPortForm(){
    this.portFormSubmittedAttempt = false;
    this.portForm.patchValue({
      PORT_NAME : null,
      PORT_CODE : null,
      COUNTRY_MST_FK :null,
      LATITUDE : null,
      LONGITUDE : null,                     
    })
  } 
}